/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "extra_compile_args": [
            "-O3",
            "-g0"
        ],
        "language": "c",
        "name": "dbus_fast.message_bus",
        "sources": [
            "src/dbus_fast/message_bus.py"
        ]
    },
    "module_name": "dbus_fast.message_bus"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 1
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 1
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PYPY_VERSION_NUM >= 0x07030C00)
  #endif
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC (PYPY_VERSION_NUM >= 0x07031100)
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND (__PYX_LIMITED_VERSION_HEX >= 0x030A0000)
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #ifndef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 1
  #endif
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #ifdef Py_GIL_DISABLED
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 1
  #else
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #endif
  #if PY_VERSION_HEX < 0x030A0000
    #undef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #elif !defined(CYTHON_USE_TYPE_SLOTS)
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLIST_INTERNALS)
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #elif !defined(CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL 0
  #elif !defined(CYTHON_FAST_GIL)
    #define CYTHON_FAST_GIL (PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_SYS_MONITORING
    #define CYTHON_USE_SYS_MONITORING (PY_VERSION_HEX >= 0x030d00B1)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5 && !CYTHON_USE_MODULE_STATE)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS (!CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
  #if defined(CYTHON_IMMORTAL_CONSTANTS) && PY_VERSION_HEX < 0x030C0000
    #undef CYTHON_IMMORTAL_CONSTANTS
    #define CYTHON_IMMORTAL_CONSTANTS 0  // definitely won't work
  #elif !defined(CYTHON_IMMORTAL_CONSTANTS)
    #define CYTHON_IMMORTAL_CONSTANTS (PY_VERSION_HEX >= 0x030C0000 && !CYTHON_USE_MODULE_STATE && CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
#endif
#ifndef CYTHON_COMPRESS_STRINGS
  #define CYTHON_COMPRESS_STRINGS 1
#endif
#ifndef CYTHON_FAST_PYCCALL
#define CYTHON_FAST_PYCCALL  CYTHON_FAST_PYCALL
#endif
#ifndef CYTHON_VECTORCALL
#if CYTHON_COMPILING_IN_LIMITED_API
#define CYTHON_VECTORCALL  (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
#else
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL)
#endif
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#include <stdint.h>
typedef uintptr_t  __pyx_uintptr_t;
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifndef Py_UNREACHABLE
  #define Py_UNREACHABLE()  assert(0); abort()
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#define __Pyx_BUILTIN_MODULE_NAME "builtins"
#define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    #ifndef CO_OPTIMIZED
    static int CO_OPTIMIZED;
    #endif
    #ifndef CO_NEWLOCALS
    static int CO_NEWLOCALS;
    #endif
    #ifndef CO_VARARGS
    static int CO_VARARGS;
    #endif
    #ifndef CO_VARKEYWORDS
    static int CO_VARKEYWORDS;
    #endif
    #ifndef CO_ASYNC_GENERATOR
    static int CO_ASYNC_GENERATOR;
    #endif
    #ifndef CO_GENERATOR
    static int CO_GENERATOR;
    #endif
    #ifndef CO_COROUTINE
    static int CO_COROUTINE;
    #endif
#else
    #ifndef CO_COROUTINE
      #define CO_COROUTINE 0x80
    #endif
    #ifndef CO_ASYNC_GENERATOR
      #define CO_ASYNC_GENERATOR 0x200
    #endif
#endif
static int __Pyx_init_co_variables(void);
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef Py_TPFLAGS_IMMUTABLETYPE
  #define Py_TPFLAGS_IMMUTABLETYPE (1UL << 8)
#endif
#ifndef Py_TPFLAGS_DISALLOW_INSTANTIATION
  #define Py_TPFLAGS_DISALLOW_INSTANTIATION (1UL << 7)
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#ifndef METH_FASTCALL
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_VERSION_HEX >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void (*cfunc)(void)) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if PY_VERSION_HEX < 0x03090000 || (CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000)
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) GraalPyFrame_SetLineNumber((frame), (lineno))
#elif CYTHON_COMPILING_IN_GRAAL
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) _PyFrame_SetLineNumber((frame), (lineno))
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#endif
#if CYTHON_USE_MODULE_STATE
static CYTHON_INLINE void *__Pyx__PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#define __Pyx_PyModule_GetState(o) (__pyx_mstatetype *)__Pyx__PyModule_GetState(o)
#else
#define __Pyx_PyModule_GetState(op) ((void)op,__pyx_mstate_global)
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE((PyObject *) obj), name, func_ctype)
#define __Pyx_PyObject_TryGetSlot(obj, name, func_ctype) __Pyx_PyType_TryGetSlot(Py_TYPE(obj), name, func_ctype)
#define __Pyx_PyObject_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#define __Pyx_PyObject_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype) __Pyx_PyType_GetSlot(type, name, func_ctype)
  #define __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype) (((type)->sub) ? ((type)->sub->name) : NULL)
  #define __Pyx_PyType_TryGetSubSlot(type, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype)
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype)\
    ((__PYX_LIMITED_VERSION_HEX >= 0x030A0000 ||\
     (PyType_GetFlags(type) & Py_TPFLAGS_HEAPTYPE) || __Pyx_get_runtime_version() >= 0x030A0000) ?\
     __Pyx_PyType_GetSlot(type, name, func_ctype) : NULL)
  #define __Pyx_PyType_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSlot(obj, name, func_ctype)
  #define __Pyx_PyType_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSlot(obj, name, func_ctype)
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
#define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
#endif
#define __Pyx_PyObject_GetIterNextFunc(iterator)  __Pyx_PyObject_GetSlot(iterator, tp_iternext, iternextfunc)
#if CYTHON_USE_TYPE_SPECS
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#else
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains)
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && PyUnstable_Object_IsUniquelyReferenced(obj)) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#elif CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
enum __Pyx_ReferenceSharing {
  __Pyx_ReferenceSharing_DefinitelyUnique, // We created it so we know it's unshared - no need to check
  __Pyx_ReferenceSharing_OwnStrongReference,
  __Pyx_ReferenceSharing_FunctionArgument,
  __Pyx_ReferenceSharing_SharedReference, // Never trust it to be unshared because it's a global or similar
};
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && PY_VERSION_HEX >= 0x030E0000
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing)\
    (sharing == __Pyx_ReferenceSharing_DefinitelyUnique ? 1 :\
      (sharing == __Pyx_ReferenceSharing_FunctionArgument ? PyUnstable_Object_IsUniqueReferencedTemporary(o) :\
      (sharing == __Pyx_ReferenceSharing_OwnStrongReference ? PyUnstable_Object_IsUniquelyReferenced(o) : 0)))
#elif (CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING) || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)sharing), Py_REFCNT(o) == 1)
#else
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)o), ((void)sharing), 0)
#endif
#if CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyList_GetItemRef(o, i) (likely((i) >= 0) ? PySequence_GetItem(o, i) : (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
  #else
    #define __Pyx_PyList_GetItemRef(o, i) PySequence_ITEM(o, i)
  #endif
#elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #else
    #define __Pyx_PyList_GetItemRef(o, i) __Pyx_XNewRef(PyList_GetItem(o, i))
  #endif
#else
  #define __Pyx_PyList_GetItemRef(o, i) __Pyx_NewRef(PyList_GET_ITEM(o, i))
#endif
#if CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS && !CYTHON_COMPILING_IN_LIMITED_API && CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) (__Pyx_IS_UNIQUELY_REFERENCED(o, unsafe_shared) ?\
    __Pyx_NewRef(PyList_GET_ITEM(o, i)) : __Pyx_PyList_GetItemRef(o, i))
#else
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) __Pyx_PyList_GetItemRef(o, i)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyDict_GetItemRef(dict, key, result) PyDict_GetItemRef(dict, key, result)
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyObject_GetItem(dict, key);
  if (*result == NULL) {
    if (PyErr_ExceptionMatches(PyExc_KeyError)) {
      PyErr_Clear();
      return 0;
    }
    return -1;
  }
  return 1;
}
#else
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyDict_GetItemWithError(dict, key);
  if (*result == NULL) {
    return PyErr_Occurred() ? -1 : 0;
  }
  Py_INCREF(*result);
  return 1;
}
#endif
#if defined(CYTHON_DEBUG_VISIT_CONST) && CYTHON_DEBUG_VISIT_CONST
  #define __Pyx_VISIT_CONST(obj)  Py_VISIT(obj)
#else
  #define __Pyx_VISIT_CONST(obj)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GET_ITEM(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GET_ITEM(o, i)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GetItem(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GetItem(o, i)
#endif
#if CYTHON_ASSUME_SAFE_SIZE
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GET_LENGTH(o)
#else
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GetLength(o)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_InternFromString)
  #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
#endif
#define __Pyx_PyLong_FromHash_t PyLong_FromSsize_t
#define __Pyx_PyLong_AsHash_t   __Pyx_PyIndex_AsSsize_t
#if __PYX_LIMITED_VERSION_HEX >= 0x030A0000
    #define __Pyx_PySendResult PySendResult
#else
    typedef enum {
        PYGEN_RETURN = 0,
        PYGEN_ERROR = -1,
        PYGEN_NEXT = 1,
    } __Pyx_PySendResult;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX < 0x030A00A3
  typedef __Pyx_PySendResult (*__Pyx_pyiter_sendfunc)(PyObject *iter, PyObject *value, PyObject **result);
#else
  #define __Pyx_pyiter_sendfunc sendfunc
#endif
#if !CYTHON_USE_AM_SEND
#define __PYX_HAS_PY_AM_SEND 0
#elif __PYX_LIMITED_VERSION_HEX >= 0x030A0000
#define __PYX_HAS_PY_AM_SEND 1
#else
#define __PYX_HAS_PY_AM_SEND 2  // our own backported implementation
#endif
#if __PYX_HAS_PY_AM_SEND < 2
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
#else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
        __Pyx_pyiter_sendfunc am_send;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_SlotTpAsAsync(s) ((PyAsyncMethods*)(s))
#endif
#if CYTHON_USE_AM_SEND && PY_VERSION_HEX < 0x030A00F0
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (1UL << 21)
#else
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (0)
#endif
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyInterpreterState_Get() PyInterpreterState_Get()
#else
#define __Pyx_PyInterpreterState_Get() PyThreadState_Get()->interp
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030A0000
#ifdef __cplusplus
extern "C"
#endif
PyAPI_FUNC(void *) PyMem_Calloc(size_t nelem, size_t elsize);
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_init_co_variable(PyObject *inspect, const char* name, int *write_to) {
    int value;
    PyObject *py_value = PyObject_GetAttrString(inspect, name);
    if (!py_value) return 0;
    value = (int) PyLong_AsLong(py_value);
    Py_DECREF(py_value);
    *write_to = value;
    return value != -1 || !PyErr_Occurred();
}
static int __Pyx_init_co_variables(void) {
    PyObject *inspect;
    int result;
    inspect = PyImport_ImportModule("inspect");
    result =
#if !defined(CO_OPTIMIZED)
        __Pyx_init_co_variable(inspect, "CO_OPTIMIZED", &CO_OPTIMIZED) &&
#endif
#if !defined(CO_NEWLOCALS)
        __Pyx_init_co_variable(inspect, "CO_NEWLOCALS", &CO_NEWLOCALS) &&
#endif
#if !defined(CO_VARARGS)
        __Pyx_init_co_variable(inspect, "CO_VARARGS", &CO_VARARGS) &&
#endif
#if !defined(CO_VARKEYWORDS)
        __Pyx_init_co_variable(inspect, "CO_VARKEYWORDS", &CO_VARKEYWORDS) &&
#endif
#if !defined(CO_ASYNC_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_ASYNC_GENERATOR", &CO_ASYNC_GENERATOR) &&
#endif
#if !defined(CO_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_GENERATOR", &CO_GENERATOR) &&
#endif
#if !defined(CO_COROUTINE)
        __Pyx_init_co_variable(inspect, "CO_COROUTINE", &CO_COROUTINE) &&
#endif
        1;
    Py_DECREF(inspect);
    return result ? 0 : -1;
}
#else
static int __Pyx_init_co_variables(void) {
    return 0;  // It's a limited API-only feature
}
#endif

/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__dbus_fast__message_bus
#define __PYX_HAVE_API__dbus_fast__message_bus
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "src/dbus_fast/message_bus.py",
  "src/dbus_fast/message_bus.pxd",
  "(tree fragment)",
  "src/dbus_fast/signature.pxd",
  "src/dbus_fast/_private/marshaller.pxd",
  "src/dbus_fast/message.pxd",
  "src/dbus_fast/service.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __PYX_CYTHON_ATOMICS_ENABLED() CYTHON_ATOMICS
#define __PYX_GET_CYTHON_COMPILING_IN_CPYTHON_FREETHREADING() CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __pyx_atomic_int_type int
#define __pyx_nonatomic_int_type int
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__))
    #include <stdatomic.h>
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)))
    #include <atomic>
#endif
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__) &&\
                       ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type atomic_int
    #define __pyx_atomic_ptr_type atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) atomic_fetch_add_explicit(value, 1, memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) atomic_fetch_add_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) atomic_fetch_sub_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) atomic_load(value)
    #define __pyx_atomic_store(value, new_value) atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) atomic_load_explicit(value, memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) atomic_load_explicit(value, memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C atomics"
    #endif
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)) &&\
                    ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type std::atomic_int
    #define __pyx_atomic_ptr_type std::atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) std::atomic_fetch_sub_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) std::atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) std::atomic_load(value)
    #define __pyx_atomic_store(value, new_value) std::atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) std::atomic_load_explicit(value, std::memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) std::atomic_load_explicit(value, std::memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) std::atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C++ atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C++ atomics"
    #endif
#elif CYTHON_ATOMICS && (__GNUC__ >= 5 || (__GNUC__ == 4 &&\
                    (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL__ >= 2))))
    #define __pyx_atomic_ptr_type void*
    #define __pyx_nonatomic_ptr_type void*
    #define __pyx_atomic_incr_relaxed(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) __sync_fetch_and_sub(value, 1)
    #define __pyx_atomic_sub(value, arg) __sync_fetch_and_sub(value, arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_store(value, new_value) __sync_lock_test_and_set(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_load_acquire(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) __sync_lock_test_and_set(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_nonatomic_ptr_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER)
    #include <intrin.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type long
    #define __pyx_atomic_ptr_type void*
    #undef __pyx_nonatomic_int_type
    #define __pyx_nonatomic_int_type long
    #define __pyx_nonatomic_ptr_type void*
    #pragma intrinsic (_InterlockedExchangeAdd, _InterlockedExchange, _InterlockedCompareExchange, _InterlockedCompareExchangePointer, _InterlockedExchangePointer)
    #define __pyx_atomic_incr_relaxed(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) _InterlockedExchangeAdd(value, -1)
    #define __pyx_atomic_sub(value, arg) _InterlockedExchangeAdd(value, -arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = _InterlockedCompareExchange(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) _InterlockedExchangeAdd(value, 0)
    #define __pyx_atomic_store(value, new_value) _InterlockedExchange(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) *(void * volatile *)value
    #define __pyx_atomic_pointer_load_acquire(value) _InterlockedCompareExchangePointer(value, 0, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) _InterlockedExchangePointer(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_atomic_ptr_type old = _InterlockedCompareExchangePointer(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif

/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_9dbus_fast_9signature_SignatureType;
struct __pyx_obj_9dbus_fast_9signature_SignatureTree;
struct __pyx_obj_9dbus_fast_9signature_Variant;
struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller;
struct __pyx_obj_9dbus_fast_7message_Message;
struct __pyx_obj_9dbus_fast_7service__Method;
struct __pyx_obj_9dbus_fast_7service_ServiceInterface;
struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus;
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect;
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added;
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name;
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name;
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler;
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler;
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler;
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client;
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule;
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule;

/* "signature.pxd":6
 * 
 * 
 * cdef class SignatureType:             # <<<<<<<<<<<<<<
 * 
 *     cdef public str token
*/
struct __pyx_obj_9dbus_fast_9signature_SignatureType {
  PyObject_HEAD
  PyObject *token;
  unsigned int token_as_int;
  PyObject *children;
  PyObject *_signature;
  struct __pyx_obj_9dbus_fast_9signature_SignatureType *_child_0;
  struct __pyx_obj_9dbus_fast_9signature_SignatureType *_child_1;
};


/* "signature.pxd":16
 * 
 * 
 * cdef class SignatureTree:             # <<<<<<<<<<<<<<
 * 
 *     cdef public str signature
*/
struct __pyx_obj_9dbus_fast_9signature_SignatureTree {
  PyObject_HEAD
  PyObject *signature;
  PyObject *types;
  struct __pyx_obj_9dbus_fast_9signature_SignatureType *root_type;
};


/* "signature.pxd":23
 * 
 * 
 * cdef class Variant:             # <<<<<<<<<<<<<<
 * 
 *     cdef public SignatureType type
*/
struct __pyx_obj_9dbus_fast_9signature_Variant {
  PyObject_HEAD
  struct __pyx_vtabstruct_9dbus_fast_9signature_Variant *__pyx_vtab;
  struct __pyx_obj_9dbus_fast_9signature_SignatureType *type;
  PyObject *signature;
  PyObject *value;
};


/* "_private/marshaller.pxd":16
 * cdef get_signature_tree
 * 
 * cdef class Marshaller:             # <<<<<<<<<<<<<<
 * 
 *     cdef SignatureTree signature_tree
*/
struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller {
  PyObject_HEAD
  struct __pyx_vtabstruct_9dbus_fast_8_private_10marshaller_Marshaller *__pyx_vtab;
  struct __pyx_obj_9dbus_fast_9signature_SignatureTree *signature_tree;
  PyObject *_buf;
  PyObject *body;
};


/* "message.pxd":36
 * cdef get_signature_tree
 * 
 * cdef class Message:             # <<<<<<<<<<<<<<
 * 
 *     cdef public object destination
*/
struct __pyx_obj_9dbus_fast_7message_Message {
  PyObject_HEAD
  struct __pyx_vtabstruct_9dbus_fast_7message_Message *__pyx_vtab;
  PyObject *destination;
  PyObject *path;
  PyObject *interface;
  PyObject *member;
  PyObject *message_type;
  PyObject *flags;
  PyObject *error_name;
  unsigned int reply_serial;
  PyObject *sender;
  PyObject *unix_fds;
  PyObject *signature;
  struct __pyx_obj_9dbus_fast_9signature_SignatureTree *signature_tree;
  PyObject *body;
  unsigned int serial;
};


/* "service.pxd":9
 * 
 * 
 * cdef class _Method:             # <<<<<<<<<<<<<<
 * 
 *     cdef public str name
*/
struct __pyx_obj_9dbus_fast_7service__Method {
  PyObject_HEAD
  PyObject *name;
  PyObject *fn;
  int disabled;
  PyObject *introspection;
  PyObject *in_signature;
  PyObject *out_signature;
  struct __pyx_obj_9dbus_fast_9signature_SignatureTree *in_signature_tree;
  struct __pyx_obj_9dbus_fast_9signature_SignatureTree *out_signature_tree;
};


/* "service.pxd":28
 * )
 * 
 * cdef class ServiceInterface:             # <<<<<<<<<<<<<<
 * 
 *     cdef public str name
*/
struct __pyx_obj_9dbus_fast_7service_ServiceInterface {
  PyObject_HEAD
  struct __pyx_vtabstruct_9dbus_fast_7service_ServiceInterface *__pyx_vtab;
  PyObject *name;
  PyObject *_ServiceInterface__methods;
  PyObject *_ServiceInterface__properties;
  PyObject *_ServiceInterface__signals;
  PyObject *_ServiceInterface__buses;
  PyObject *_ServiceInterface__handlers;
  PyObject *_ServiceInterface__handlers_by_name_signature;
};


/* "dbus_fast/message_bus.pxd":27
 * 
 * 
 * cdef class BaseMessageBus:             # <<<<<<<<<<<<<<
 * 
 *     cdef public object unique_name
*/
struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus {
  PyObject_HEAD
  struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *__pyx_vtab;
  PyObject *unique_name;
  int _disconnected;
  PyObject *_user_disconnect;
  PyObject *_method_return_handlers;
  PyObject *_serial;
  PyObject *_path_exports;
  PyObject *_user_message_handlers;
  PyObject *_name_owners;
  PyObject *_bus_address;
  PyObject *_name_owner_match_rule;
  PyObject *_match_rules;
  PyObject *_high_level_client_initialized;
  PyObject *_ProxyObject;
  PyObject *_machine_id;
  int _negotiate_unix_fd;
  PyObject *_sock;
  PyObject *_stream;
  PyObject *_fd;
};


/* "dbus_fast/message_bus.py":261
 *         self._emit_interface_removed(path, removed_interface_names)
 * 
 *     def introspect(             # <<<<<<<<<<<<<<
 *         self,
 *         bus_name: str,
*/
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect {
  PyObject_HEAD
  PyObject *__pyx_v_callback;
  int __pyx_v_validate_property_names;
};


/* "dbus_fast/message_bus.py":317
 *         )
 * 
 *     def _emit_interface_added(self, path: str, interface: ServiceInterface) -> None:             # <<<<<<<<<<<<<<
 *         """Emit the ``org.freedesktop.DBus.ObjectManager.InterfacesAdded`` signal.
 * 
*/
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added {
  PyObject_HEAD
  PyObject *__pyx_v_path;
  struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self;
};


/* "dbus_fast/message_bus.py":387
 *         )
 * 
 *     def request_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name {
  PyObject_HEAD
  PyObject *__pyx_v_callback;
};


/* "dbus_fast/message_bus.py":441
 *         self._call(message, reply_notify)
 * 
 *     def release_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name {
  PyObject_HEAD
  PyObject *__pyx_v_callback;
};


/* "dbus_fast/message_bus.py":997
 *         send_reply(Message.new_method_return(msg, "s", [self._machine_id]))
 * 
 *     def _default_get_machine_id_handler(             # <<<<<<<<<<<<<<
 *         self, msg: Message, send_reply: SendReply
 *     ) -> None:
*/
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler {
  PyObject_HEAD
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg;
  struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self;
  PyObject *__pyx_v_send_reply;
};


/* "dbus_fast/message_bus.py":1031
 *         )
 * 
 *     def _default_get_managed_objects_handler(             # <<<<<<<<<<<<<<
 *         self, msg: Message, send_reply: SendReply
 *     ) -> None:
*/
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler {
  PyObject_HEAD
  int __pyx_v_error_handled;
  PyObject *__pyx_v_is_result_complete;
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg;
  PyObject *__pyx_v_result;
  PyObject *__pyx_v_result_signature;
  PyObject *__pyx_v_send_reply;
};


/* "dbus_fast/message_bus.py":1086
 *                 )
 * 
 *     def _default_properties_handler(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         methods = {"Get": "ss", "Set": "ssv", "GetAll": "s"}
 *         if msg.member not in methods or methods[msg.member] != msg.signature:
*/
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler {
  PyObject_HEAD
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg;
  PyObject *__pyx_v_send_reply;
};


/* "dbus_fast/message_bus.py":1233
 *             assert False
 * 
 *     def _init_high_level_client(self) -> None:             # <<<<<<<<<<<<<<
 *         """The high level client is initialized when the first proxy object is
 *         gotten. Currently just sets up the match rules for the name owner cache
*/
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client {
  PyObject_HEAD
  struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self;
};


/* "dbus_fast/message_bus.py":1263
 *         )
 * 
 *     def _add_match_rule(self, match_rule: str) -> None:             # <<<<<<<<<<<<<<
 *         """Add a match rule. Match rules added by this function are refcounted
 *         and must be removed by _remove_match_rule(). This is for use in the
*/
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule {
  PyObject_HEAD
  PyObject *__pyx_v_match_rule;
};


/* "dbus_fast/message_bus.py":1296
 *         )
 * 
 *     def _remove_match_rule(self, match_rule: str) -> None:             # <<<<<<<<<<<<<<
 *         """Remove a match rule added with _add_match_rule(). This is for use in
 *         the high level client only."""
*/
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule {
  PyObject_HEAD
  PyObject *__pyx_v_match_rule;
  struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self;
};



/* "signature.pxd":23
 * 
 * 
 * cdef class Variant:             # <<<<<<<<<<<<<<
 * 
 *     cdef public SignatureType type
*/

struct __pyx_vtabstruct_9dbus_fast_9signature_Variant {
  struct __pyx_obj_9dbus_fast_9signature_Variant *(*_factory)(struct __pyx_obj_9dbus_fast_9signature_SignatureTree *, PyObject *);
};
static struct __pyx_vtabstruct_9dbus_fast_9signature_Variant *__pyx_vtabptr_9dbus_fast_9signature_Variant;


/* "_private/marshaller.pxd":16
 * cdef get_signature_tree
 * 
 * cdef class Marshaller:             # <<<<<<<<<<<<<<
 * 
 *     cdef SignatureTree signature_tree
*/

struct __pyx_vtabstruct_9dbus_fast_8_private_10marshaller_Marshaller {
  PyObject *(*_buffer)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *);
  PyObject *(*align)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, unsigned int, int __pyx_skip_dispatch);
  unsigned int (*_align)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, unsigned int);
  PyObject *(*write_boolean)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, int, struct __pyx_obj_9dbus_fast_9signature_SignatureType *, int __pyx_skip_dispatch);
  unsigned int (*_write_boolean)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, int);
  PyObject *(*write_string)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, PyObject *, struct __pyx_obj_9dbus_fast_9signature_SignatureType *, int __pyx_skip_dispatch);
  unsigned int (*_write_string)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, PyObject *);
  unsigned int (*_write_signature)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, PyObject *);
  PyObject *(*write_array)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, PyObject *, struct __pyx_obj_9dbus_fast_9signature_SignatureType *, int __pyx_skip_dispatch);
  unsigned int (*_write_array)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, PyObject *, struct __pyx_obj_9dbus_fast_9signature_SignatureType *);
  PyObject *(*write_struct)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, PyObject *, struct __pyx_obj_9dbus_fast_9signature_SignatureType *, int __pyx_skip_dispatch);
  unsigned int (*_write_struct)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, PyObject *, struct __pyx_obj_9dbus_fast_9signature_SignatureType *);
  PyObject *(*write_variant)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, struct __pyx_obj_9dbus_fast_9signature_Variant *, struct __pyx_obj_9dbus_fast_9signature_SignatureType *, int __pyx_skip_dispatch);
  unsigned int (*_write_variant)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, struct __pyx_obj_9dbus_fast_9signature_Variant *, struct __pyx_obj_9dbus_fast_9signature_SignatureType *);
  unsigned int (*_write_single)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, struct __pyx_obj_9dbus_fast_9signature_SignatureType *, PyObject *);
  PyObject *(*write_dict_entry)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, PyObject *, struct __pyx_obj_9dbus_fast_9signature_SignatureType *, int __pyx_skip_dispatch);
  PyObject *(*marshall)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *, int __pyx_skip_dispatch);
  PyObject *(*_marshall)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *);
  PyObject *(*_construct_buffer)(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller *);
};
static struct __pyx_vtabstruct_9dbus_fast_8_private_10marshaller_Marshaller *__pyx_vtabptr_9dbus_fast_8_private_10marshaller_Marshaller;


/* "message.pxd":36
 * cdef get_signature_tree
 * 
 * cdef class Message:             # <<<<<<<<<<<<<<
 * 
 *     cdef public object destination
*/

struct __pyx_vtabstruct_9dbus_fast_7message_Message {
  PyObject *(*_marshall)(struct __pyx_obj_9dbus_fast_7message_Message *, int, int __pyx_skip_dispatch);
  PyObject *(*_fast_init)(struct __pyx_obj_9dbus_fast_7message_Message *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, unsigned int, PyObject *, PyObject *, struct __pyx_obj_9dbus_fast_9signature_SignatureTree *, PyObject *, unsigned int, int);
};
static struct __pyx_vtabstruct_9dbus_fast_7message_Message *__pyx_vtabptr_9dbus_fast_7message_Message;


/* "service.pxd":28
 * )
 * 
 * cdef class ServiceInterface:             # <<<<<<<<<<<<<<
 * 
 *     cdef public str name
*/

struct __pyx_vtabstruct_9dbus_fast_7service_ServiceInterface {
  PyObject *(*_get_enabled_handler_by_name_signature)(struct __pyx_obj_9dbus_fast_7service_ServiceInterface *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_c_msg_body_to_args)(struct __pyx_obj_9dbus_fast_7message_Message *);
  PyObject *(*_c_fn_result_to_body)(PyObject *, struct __pyx_obj_9dbus_fast_9signature_SignatureTree *, int);
};
static struct __pyx_vtabstruct_9dbus_fast_7service_ServiceInterface *__pyx_vtabptr_9dbus_fast_7service_ServiceInterface;


/* "dbus_fast/message_bus.py":76
 * 
 * 
 * class BaseMessageBus:             # <<<<<<<<<<<<<<
 *     """An abstract class to manage a connection to a DBus message bus.
 * 
*/

struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus {
  void (*_process_message)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, struct __pyx_obj_9dbus_fast_7message_Message *, int __pyx_skip_dispatch);
  PyObject *(*__pyx_export)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, PyObject *, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *, int __pyx_skip_dispatch);
  PyObject *(*_find_message_handler)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, struct __pyx_obj_9dbus_fast_7message_Message *);
  PyObject *(*_find_any_message_handler_matching_signature)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, PyObject *, struct __pyx_obj_9dbus_fast_7message_Message *);
  PyObject *(*_setup_socket)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *);
  PyObject *(*_call)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, struct __pyx_obj_9dbus_fast_7message_Message *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*next_serial)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, int __pyx_skip_dispatch);
  void (*_callback_method_handler)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *, struct __pyx_obj_9dbus_fast_7service__Method *, struct __pyx_obj_9dbus_fast_7message_Message *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *__pyx_vtabptr_9dbus_fast_11message_bus_BaseMessageBus;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_PySequence_ITEM(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_NewRef(__Pyx_PyTuple_GET_ITEM(args, i))
#else
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_XNewRef(PyTuple_GetItem(args, i))
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_ArgRef_FASTCALL(args, i) __Pyx_NewRef(args[i])
    #define __Pyx_NumKwargs_FASTCALL(kwds) __Pyx_PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
#else
    #define __Pyx_ArgRef_FASTCALL __Pyx_ArgRef_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
#endif
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#if CYTHON_METH_FASTCALL || (CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(args + start, stop - start)
#else
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallCFunction.proto (used by CallUnboundCMethod0) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto (used by PyObjectCallOneArg) */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod0) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyDictVersioning.proto (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __Pyx_XNewRef(__pyx_dict_cached_value);\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_mstate_global->__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* ArgTypeTestFunc.export */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* PyTypeError_Check.proto */
#define __Pyx_PyExc_TypeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_TypeError)

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* DictGetItem.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyValueError_Check.proto */
#define __Pyx_PyExc_ValueError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_ValueError)

/* PyUnicode_Unicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj);

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* dict_getitem_default.proto */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value);

/* PyObjectCall2Args.proto (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* CallUnboundCMethod1.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* IterFinish.proto (used by dict_iter) */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* PyObjectCallNoArg.proto (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectGetMethod.proto (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod0.proto (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNeedMoreValuesToUnpack.proto (used by UnpackTuple2) */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseTooManyValuesToUnpack.proto (used by UnpackItemEndCheck) */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* UnpackItemEndCheck.proto (used by UnpackTuple2) */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* RaiseNoneIterError.proto (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
    PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple);
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck, unsafe_shared) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck, int unsafe_shared);

/* PyObjectVectorCallKwBuilder.proto (used by PyObjectVectorCallMethodKwBuilder) */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* PyObjectVectorCallMethodKwBuilder.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_VectorcallMethod_CallFromBuilder PyObject_VectorcallMethod
#else
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#endif

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* RaiseClosureNameError.proto */
static void __Pyx_RaiseClosureNameError(const char *varname);

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto (used by FetchCommonType) */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* CallTypeTraverse.proto (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && CYTHON_METH_FASTCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_dict;
#endif
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    PyObject *defaults;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_mstate_global->__pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_mstate_global->__pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void));
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func,
                                                         PyTypeObject *defaults_type);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* RejectKeywords.export */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds);

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* CallableCheck.proto */
#if CYTHON_USE_TYPE_SLOTS && !CYTHON_COMPILING_IN_PYPY
#define __Pyx_PyCallable_Check(obj)   (Py_TYPE(obj)->tp_call != NULL)
#else
#define __Pyx_PyCallable_Check(obj)   PyCallable_Check(obj)
#endif

/* PyNotImplementedError_Check.proto */
#define __Pyx_PyExc_NotImplementedError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_NotImplementedError)

/* py_dict_clear.proto */
#define __Pyx_PyDict_Clear(d) (PyDict_Clear(d), 0)

/* PyObjectCallMethod1.proto (used by append) */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* set_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_set_iterator(PyObject* iterable, int is_set,
                                                  Py_ssize_t* p_orig_length, int* p_source_is_set);
static CYTHON_INLINE int __Pyx_set_iter_next(
        PyObject* iter_obj, Py_ssize_t orig_length,
        Py_ssize_t* ppos, PyObject **value,
        int source_is_set);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* AssertionsEnabled.proto */
#if CYTHON_COMPILING_IN_LIMITED_API  ||  PY_VERSION_HEX >= 0x030C0000
  static int __pyx_assertions_enabled_flag;
  #define __pyx_assertions_enabled() (__pyx_assertions_enabled_flag)
  #if __clang__ || __GNUC__
  __attribute__((no_sanitize("thread")))
  #endif
  static int __Pyx_init_assertions_enabled(void) {
    PyObject *builtins, *debug, *debug_str;
    int flag;
    builtins = PyEval_GetBuiltins();
    if (!builtins) goto bad;
    debug_str = PyUnicode_FromStringAndSize("__debug__", 9);
    if (!debug_str) goto bad;
    debug = PyObject_GetItem(builtins, debug_str);
    Py_DECREF(debug_str);
    if (!debug) goto bad;
    flag = PyObject_IsTrue(debug);
    Py_DECREF(debug);
    if (flag == -1) goto bad;
    __pyx_assertions_enabled_flag = flag;
    return 0;
  bad:
    __pyx_assertions_enabled_flag = 1;
    return -1;
  }
#else
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (!Py_OptimizeFlag)
#endif

/* PyAssertionError_Check.proto */
#define __Pyx_PyExc_AssertionError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AssertionError)

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* RaiseUnboundLocalError.proto */
static void __Pyx_RaiseUnboundLocalError(const char *varname);

/* PyObject_Unicode.proto */
#define __Pyx_PyObject_Unicode(obj)\
    (likely(PyUnicode_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* CheckTypeForFreelists.proto */
#if CYTHON_USE_FREELISTS
#if CYTHON_USE_TYPE_SPECS
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t) == (expected_tp)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  Py_TPFLAGS_IS_ABSTRACT
#else
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t)->tp_basicsize == (expected_size)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)
#endif
#define __PYX_CHECK_TYPE_FOR_FREELISTS(t, expected_tp, expected_size)\
    (__PYX_CHECK_FINAL_TYPE_FOR_FREELISTS((t), (expected_tp), (expected_size)) &\
     (int) (!__Pyx_PyType_HasFeature((t), __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS)))
#endif

/* VoidPtrExport.proto */
static int __Pyx_ExportVoidPtr(PyObject *api_dict, const char *name, void *p, const char *sig);

/* GetApiDict.proto */
static PyObject *__Pyx_ApiExport_GetApiDict(void);

/* FunctionExport.proto */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig);

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
static int __Pyx_MergeVtables(PyTypeObject *type);

/* DelItemOnTypeDict.proto (used by SetupReduce) */
static int __Pyx__DelItemOnTypeDict(PyTypeObject *tp, PyObject *k);
#define __Pyx_DelItemOnTypeDict(tp, k) __Pyx__DelItemOnTypeDict((PyTypeObject*)tp, k)

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_2_4
#define __PYX_HAVE_RT_ImportType_proto_3_2_4
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_2_4 {
   __Pyx_ImportType_CheckSize_Error_3_2_4 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_2_4 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_2_4 = 2
};
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size);
#endif

/* VoidPtrImport.proto */
static int __Pyx_ImportVoidPtr_3_2_4(PyObject *module, const char *name, void **p, const char *sig);

/* FunctionImport.proto */
static int __Pyx_ImportFunction_3_2_4(PyObject *module, const char *funcname, void (**f)(void), const char *sig);

/* HasAttr.proto (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CheckUnpickleChecksum.proto */
static CYTHON_INLINE int __Pyx_CheckUnpickleChecksum(long checksum, long checksum1, long checksum2, long checksum3, const char *members);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE unsigned int __Pyx_PyLong_As_unsigned_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_unsigned_int(unsigned int value);

/* UpdateUnpickledDict.proto */
static int __Pyx_UpdateUnpickledDict(PyObject *obj, PyObject *state, Py_ssize_t index);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2) {
    return PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2);
}
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#ifdef PyExceptionInstance_Check
  #define __Pyx_PyBaseException_Check(obj) PyExceptionInstance_Check(obj)
#else
  #define __Pyx_PyBaseException_Check(obj) __Pyx_TypeCheck(obj, PyExc_BaseException)
#endif

/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
    #if CYTHON_METH_FASTCALL
        #define __PYX_FASTCALL_ABI_SUFFIX  "_fastcall"
    #else
        #define __PYX_FASTCALL_ABI_SUFFIX
    #endif
    #define __PYX_LIMITED_ABI_SUFFIX "limited" __PYX_FASTCALL_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#else
    #define __PYX_LIMITED_ABI_SUFFIX
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    #define __PYX_AM_SEND_ABI_SUFFIX
#elif __PYX_HAS_PY_AM_SEND == 2
    #define __PYX_AM_SEND_ABI_SUFFIX "amsendbackport"
#else
    #define __PYX_AM_SEND_ABI_SUFFIX "noamsend"
#endif
#ifndef __PYX_MONITORING_ABI_SUFFIX
    #define __PYX_MONITORING_ABI_SUFFIX
#endif
#if CYTHON_USE_TP_FINALIZE
    #define __PYX_TP_FINALIZE_ABI_SUFFIX
#else
    #define __PYX_TP_FINALIZE_ABI_SUFFIX "nofinalize"
#endif
#if CYTHON_USE_FREELISTS || !defined(__Pyx_AsyncGen_USED)
    #define __PYX_FREELISTS_ABI_SUFFIX
#else
    #define __PYX_FREELISTS_ABI_SUFFIX "nofreelists"
#endif
#define CYTHON_ABI  __PYX_ABI_VERSION __PYX_LIMITED_ABI_SUFFIX __PYX_MONITORING_ABI_SUFFIX __PYX_TP_FINALIZE_ABI_SUFFIX __PYX_FREELISTS_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."

static PyObject *__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus_export(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_path, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus_next_serial(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__setup_socket(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__call(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_callback, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__process_message(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__callback_method_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, struct __pyx_obj_9dbus_fast_7service__Method *__pyx_v_method, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__find_message_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg); /* proto*/
static PyObject *__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__find_any_message_handler_matching_signature(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_interfaces, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg); /* proto*/

/* Module declarations from "cython" */

/* Module declarations from "dbus_fast._private.address" */
static PyObject **__pyx_vp_9dbus_fast_8_private_7address_unquote = 0;
#define __pyx_v_9dbus_fast_8_private_7address_unquote (*__pyx_vp_9dbus_fast_8_private_7address_unquote)
static PyObject *(*__pyx_f_9dbus_fast_8_private_7address_parse_address)(PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *(*__pyx_f_9dbus_fast_8_private_7address_get_bus_address)(PyObject *, int __pyx_skip_dispatch); /*proto*/

/* Module declarations from "dbus_fast.signature" */

/* Module declarations from "dbus_fast._private.marshaller" */
static PyObject **__pyx_vp_9dbus_fast_8_private_10marshaller_PACK_UINT32 = 0;
#define __pyx_v_9dbus_fast_8_private_10marshaller_PACK_UINT32 (*__pyx_vp_9dbus_fast_8_private_10marshaller_PACK_UINT32)
static PyObject **__pyx_vp_9dbus_fast_8_private_10marshaller_PACKED_UINT32_ZERO = 0;
#define __pyx_v_9dbus_fast_8_private_10marshaller_PACKED_UINT32_ZERO (*__pyx_vp_9dbus_fast_8_private_10marshaller_PACKED_UINT32_ZERO)
static PyObject **__pyx_vp_9dbus_fast_8_private_10marshaller_PACKED_BOOL_TRUE = 0;
#define __pyx_v_9dbus_fast_8_private_10marshaller_PACKED_BOOL_TRUE (*__pyx_vp_9dbus_fast_8_private_10marshaller_PACKED_BOOL_TRUE)
static PyObject **__pyx_vp_9dbus_fast_8_private_10marshaller_PACKED_BOOL_FALSE = 0;
#define __pyx_v_9dbus_fast_8_private_10marshaller_PACKED_BOOL_FALSE (*__pyx_vp_9dbus_fast_8_private_10marshaller_PACKED_BOOL_FALSE)
static PyObject **__pyx_vp_9dbus_fast_8_private_10marshaller_get_signature_tree = 0;
#define __pyx_v_9dbus_fast_8_private_10marshaller_get_signature_tree (*__pyx_vp_9dbus_fast_8_private_10marshaller_get_signature_tree)

/* Module declarations from "dbus_fast.message" */
static PyObject **__pyx_vp_9dbus_fast_7message_ErrorType = 0;
#define __pyx_v_9dbus_fast_7message_ErrorType (*__pyx_vp_9dbus_fast_7message_ErrorType)
static PyObject **__pyx_vp_9dbus_fast_7message_MessageType = 0;
#define __pyx_v_9dbus_fast_7message_MessageType (*__pyx_vp_9dbus_fast_7message_MessageType)
static PyObject **__pyx_vp_9dbus_fast_7message_HEADER_PATH = 0;
#define __pyx_v_9dbus_fast_7message_HEADER_PATH (*__pyx_vp_9dbus_fast_7message_HEADER_PATH)
static PyObject **__pyx_vp_9dbus_fast_7message_HEADER_INTERFACE = 0;
#define __pyx_v_9dbus_fast_7message_HEADER_INTERFACE (*__pyx_vp_9dbus_fast_7message_HEADER_INTERFACE)
static PyObject **__pyx_vp_9dbus_fast_7message_HEADER_MEMBER = 0;
#define __pyx_v_9dbus_fast_7message_HEADER_MEMBER (*__pyx_vp_9dbus_fast_7message_HEADER_MEMBER)
static PyObject **__pyx_vp_9dbus_fast_7message_HEADER_ERROR_NAME = 0;
#define __pyx_v_9dbus_fast_7message_HEADER_ERROR_NAME (*__pyx_vp_9dbus_fast_7message_HEADER_ERROR_NAME)
static PyObject **__pyx_vp_9dbus_fast_7message_HEADER_REPLY_SERIAL = 0;
#define __pyx_v_9dbus_fast_7message_HEADER_REPLY_SERIAL (*__pyx_vp_9dbus_fast_7message_HEADER_REPLY_SERIAL)
static PyObject **__pyx_vp_9dbus_fast_7message_HEADER_DESTINATION = 0;
#define __pyx_v_9dbus_fast_7message_HEADER_DESTINATION (*__pyx_vp_9dbus_fast_7message_HEADER_DESTINATION)
static PyObject **__pyx_vp_9dbus_fast_7message_HEADER_SENDER = 0;
#define __pyx_v_9dbus_fast_7message_HEADER_SENDER (*__pyx_vp_9dbus_fast_7message_HEADER_SENDER)
static PyObject **__pyx_vp_9dbus_fast_7message_HEADER_SIGNATURE = 0;
#define __pyx_v_9dbus_fast_7message_HEADER_SIGNATURE (*__pyx_vp_9dbus_fast_7message_HEADER_SIGNATURE)
static PyObject **__pyx_vp_9dbus_fast_7message_HEADER_UNIX_FDS = 0;
#define __pyx_v_9dbus_fast_7message_HEADER_UNIX_FDS (*__pyx_vp_9dbus_fast_7message_HEADER_UNIX_FDS)
static PyObject **__pyx_vp_9dbus_fast_7message_LITTLE_ENDIAN = 0;
#define __pyx_v_9dbus_fast_7message_LITTLE_ENDIAN (*__pyx_vp_9dbus_fast_7message_LITTLE_ENDIAN)
static PyObject **__pyx_vp_9dbus_fast_7message_PROTOCOL_VERSION = 0;
#define __pyx_v_9dbus_fast_7message_PROTOCOL_VERSION (*__pyx_vp_9dbus_fast_7message_PROTOCOL_VERSION)
static PyObject **__pyx_vp_9dbus_fast_7message_MESSAGE_FLAG = 0;
#define __pyx_v_9dbus_fast_7message_MESSAGE_FLAG (*__pyx_vp_9dbus_fast_7message_MESSAGE_FLAG)
static PyObject **__pyx_vp_9dbus_fast_7message_MESSAGE_FLAG_NONE = 0;
#define __pyx_v_9dbus_fast_7message_MESSAGE_FLAG_NONE (*__pyx_vp_9dbus_fast_7message_MESSAGE_FLAG_NONE)
static PyObject **__pyx_vp_9dbus_fast_7message_MESSAGE_TYPE_METHOD_CALL = 0;
#define __pyx_v_9dbus_fast_7message_MESSAGE_TYPE_METHOD_CALL (*__pyx_vp_9dbus_fast_7message_MESSAGE_TYPE_METHOD_CALL)
static struct __pyx_obj_9dbus_fast_9signature_SignatureTree **__pyx_vp_9dbus_fast_7message_SIGNATURE_TREE_G = 0;
#define __pyx_v_9dbus_fast_7message_SIGNATURE_TREE_G (*__pyx_vp_9dbus_fast_7message_SIGNATURE_TREE_G)
static struct __pyx_obj_9dbus_fast_9signature_SignatureTree **__pyx_vp_9dbus_fast_7message_SIGNATURE_TREE_O = 0;
#define __pyx_v_9dbus_fast_7message_SIGNATURE_TREE_O (*__pyx_vp_9dbus_fast_7message_SIGNATURE_TREE_O)
static struct __pyx_obj_9dbus_fast_9signature_SignatureTree **__pyx_vp_9dbus_fast_7message_SIGNATURE_TREE_S = 0;
#define __pyx_v_9dbus_fast_7message_SIGNATURE_TREE_S (*__pyx_vp_9dbus_fast_7message_SIGNATURE_TREE_S)
static struct __pyx_obj_9dbus_fast_9signature_SignatureTree **__pyx_vp_9dbus_fast_7message_SIGNATURE_TREE_U = 0;
#define __pyx_v_9dbus_fast_7message_SIGNATURE_TREE_U (*__pyx_vp_9dbus_fast_7message_SIGNATURE_TREE_U)
static PyObject **__pyx_vp_9dbus_fast_7message_get_signature_tree = 0;
#define __pyx_v_9dbus_fast_7message_get_signature_tree (*__pyx_vp_9dbus_fast_7message_get_signature_tree)

/* Module declarations from "dbus_fast.service" */

/* Module declarations from "dbus_fast.message_bus" */
static int __pyx_v_9dbus_fast_11message_bus_TYPE_CHECKING;
static PyObject *__pyx_v_9dbus_fast_11message_bus_MessageType = 0;
static PyObject *__pyx_v_9dbus_fast_11message_bus_DBusError = 0;
static PyObject *__pyx_v_9dbus_fast_11message_bus_MessageFlag = 0;
static PyObject *__pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_CALL = 0;
static PyObject *__pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_SIGNAL = 0;
static unsigned int __pyx_v_9dbus_fast_11message_bus_NO_REPLY_EXPECTED_VALUE;
static PyObject *__pyx_v_9dbus_fast_11message_bus_NONE = 0;
static PyObject *__pyx_v_9dbus_fast_11message_bus_NO_REPLY_EXPECTED = 0;
static PyObject *__pyx_v_9dbus_fast_11message_bus_BLOCK_UNEXPECTED_REPLY = 0;
static PyObject *__pyx_v_9dbus_fast_11message_bus_assert_object_path_valid = 0;
static PyObject *__pyx_v_9dbus_fast_11message_bus_assert_bus_name_valid = 0;
static int __pyx_f_9dbus_fast_11message_bus__expects_reply(struct __pyx_obj_9dbus_fast_7message_Message *); /*proto*/
static PyObject *__pyx_f_9dbus_fast_11message_bus___pyx_unpickle_BaseMessageBus__set_state(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, PyObject *); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "dbus_fast.message_bus"
extern int __pyx_module_is_main_dbus_fast__message_bus;
int __pyx_module_is_main_dbus_fast__message_bus = 0;

/* Implementation of "dbus_fast.message_bus" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_staticmethod;
static PyObject *__pyx_builtin_enumerate;
/* #### Code section: string_decls ### */
static const char __pyx_k_ProxyObject__bus_address__disco[] = "_ProxyObject, _bus_address, _disconnected, _fd, _high_level_client_initialized, _machine_id, _match_rules, _method_return_handlers, _name_owner_match_rule, _name_owners, _negotiate_unix_fd, _path_exports, _serial, _sock, _stream, _user_disconnect, _user_message_handlers, unique_name";
/* #### Code section: decls ### */
static PyObject *__pyx_pf_9dbus_fast_11message_bus__block_unexpected_reply(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_reply); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus___init__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_bus_address, PyObject *__pyx_v_bus_type, PyObject *__pyx_v_ProxyObject, int __pyx_v_negotiate_unix_fd); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_9connected___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_2export(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_path, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_4unexport(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_interface); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_10introspect_reply_notify(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply, PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_6introspect(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_bus_name, PyObject *__pyx_v_path, PyObject *__pyx_v_callback, int __pyx_v_check_callback_type, int __pyx_v_validate_property_names); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_21_emit_interface_added_get_properties_callback(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, PyObject *__pyx_v_result, CYTHON_UNUSED PyObject *__pyx_v_user_data, PyObject *__pyx_v_e); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_8_emit_interface_added(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_path, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_10_emit_interface_removed(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_removed_interfaces); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12request_name_reply_notify(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply, PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12request_name(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_flags, PyObject *__pyx_v_callback, int __pyx_v_check_callback_type); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12release_name_reply_notify(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply, PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_14release_name(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_callback, int __pyx_v_check_callback_type); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_16get_proxy_object(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_bus_name, PyObject *__pyx_v_path, PyObject *__pyx_v_introspection); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_18disconnect(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_20next_serial(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22add_message_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_handler); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_24remove_message_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_handler); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_26send(CYTHON_UNUSED struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, CYTHON_UNUSED struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_28_finalize(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_30_interface_signal_notify(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, PyObject *__pyx_v_interface_name, PyObject *__pyx_v_member, PyObject *__pyx_v_signature, PyObject *__pyx_v_body, PyObject *__pyx_v_unix_fds); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_32_introspect_export_path(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_path); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_34_reply_notify(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_callback, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply, PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_36_call(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_callback); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_38_check_callback_type(PyObject *__pyx_v_callback); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_40_check_method_return(struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_err, PyObject *__pyx_v_signature); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_42_process_message(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_44_callback_method_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, struct __pyx_obj_9dbus_fast_7service__Method *__pyx_v_method, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_46_make_method_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, struct __pyx_obj_9dbus_fast_7service__Method *__pyx_v_method); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_48_default_introspect_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_50_default_ping_handler(CYTHON_UNUSED struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_52_send_machine_id_reply(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_31_default_get_machine_id_handler_reply_handler(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply, PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_54_default_get_machine_id_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_is_result_complete(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_2get_all_properties_callback(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, PyObject *__pyx_v_values, PyObject *__pyx_v_node, PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_56_default_get_managed_objects_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_get_property_callback(PyObject *__pyx_self, CYTHON_UNUSED struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, PyObject *__pyx_v_prop, PyObject *__pyx_v_prop_value, PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_2set_property_callback(PyObject *__pyx_self, CYTHON_UNUSED struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, CYTHON_UNUSED PyObject *__pyx_v_prop, PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_4get_all_properties_callback(PyObject *__pyx_self, CYTHON_UNUSED struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, PyObject *__pyx_v_values, CYTHON_UNUSED PyObject *__pyx_v_user_data, PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_58_default_properties_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_23_init_high_level_client_add_match_notify(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_60_init_high_level_client(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_15_add_match_rule_add_match_notify(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_62_add_match_rule(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_match_rule); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_18_remove_match_rule_remove_match_notify(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_64_remove_match_rule(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_match_rule); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_disconnected___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_disconnected_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_serial___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_18_negotiate_unix_fd___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_18_negotiate_unix_fd_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_5_sock___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_stream___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_3_fd___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_66__reduce_cython__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_68__setstate_cython__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9dbus_fast_11message_bus_2__pyx_unpickle_BaseMessageBus(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_9dbus_fast_11message_bus_BaseMessageBus(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct__introspect(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyTypeObject *__pyx_ptype_9dbus_fast_9signature_SignatureType;
  PyTypeObject *__pyx_ptype_9dbus_fast_9signature_SignatureTree;
  PyTypeObject *__pyx_ptype_9dbus_fast_9signature_Variant;
  PyTypeObject *__pyx_ptype_9dbus_fast_8_private_10marshaller_Marshaller;
  PyTypeObject *__pyx_ptype_9dbus_fast_7message_Message;
  PyTypeObject *__pyx_ptype_9dbus_fast_7service__Method;
  PyTypeObject *__pyx_ptype_9dbus_fast_7service_ServiceInterface;
  PyObject *__pyx_type_9dbus_fast_11message_bus_BaseMessageBus;
  PyObject *__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct__introspect;
  PyObject *__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added;
  PyObject *__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name;
  PyObject *__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name;
  PyObject *__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler;
  PyObject *__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler;
  PyObject *__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler;
  PyObject *__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client;
  PyObject *__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule;
  PyObject *__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule;
  PyTypeObject *__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus;
  PyTypeObject *__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect;
  PyTypeObject *__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added;
  PyTypeObject *__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name;
  PyTypeObject *__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name;
  PyTypeObject *__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler;
  PyTypeObject *__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler;
  PyTypeObject *__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler;
  PyTypeObject *__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client;
  PyTypeObject *__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule;
  PyTypeObject *__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_get;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  PyObject *__pyx_k_;
  PyObject *__pyx_k__4;
  PyObject *__pyx_k__5;
  PyObject *__pyx_tuple[6];
  PyObject *__pyx_codeobj_tab[49];
  PyObject *__pyx_string_tab[501];
  PyObject *__pyx_number_tab[3];
/* #### Code section: module_state_contents ### */
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;


#if CYTHON_USE_FREELISTS
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct__introspect[8];
int __pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct__introspect;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added[8];
int __pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name[8];
int __pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name[8];
int __pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler[8];
int __pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler[8];
int __pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler[8];
int __pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client[8];
int __pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule *__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule[8];
int __pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule[8];
int __pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule;
#endif
/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_A_message_handler_raised_an_exce __pyx_string_tab[0]
#define __pyx_kp_u_An_exception_ocurred_when_emitti __pyx_string_tab[1]
#define __pyx_kp_u_An_interface_with_this_name_is_a __pyx_string_tab[2]
#define __pyx_kp_u_An_internal_error_occurred __pyx_string_tab[3]
#define __pyx_kp_u_Blocked_attempt_to_send_a_reply __pyx_string_tab[4]
#define __pyx_kp_u_Callable_Message_Message_bool_No __pyx_string_tab[5]
#define __pyx_kp_u_Callable_Message_None_Exception __pyx_string_tab[6]
#define __pyx_kp_u_Callable_Message_None_Exception_2 __pyx_string_tab[7]
#define __pyx_kp_u_Callable_intr_Node_None_Exceptio __pyx_string_tab[8]
#define __pyx_kp_u_Could_not_find_interface_on_bus __pyx_string_tab[9]
#define __pyx_kp_u_Exception_None __pyx_string_tab[10]
#define __pyx_kp_u_Message_None __pyx_string_tab[11]
#define __pyx_kp_u_None __pyx_string_tab[12]
#define __pyx_kp_u_None_Callable_ReleaseNameReply_N __pyx_string_tab[13]
#define __pyx_kp_u_None_Callable_RequestNameReply_N __pyx_string_tab[14]
#define __pyx_kp_u_Note_that_Cython_is_deliberately __pyx_string_tab[15]
#define __pyx_kp_u_ServiceInterface_str_None __pyx_string_tab[16]
#define __pyx_kp_u__10 __pyx_string_tab[17]
#define __pyx_kp_u__11 __pyx_string_tab[18]
#define __pyx_kp_u__12 __pyx_string_tab[19]
#define __pyx_kp_u__2 __pyx_string_tab[20]
#define __pyx_kp_u__3 __pyx_string_tab[21]
#define __pyx_kp_u__6 __pyx_string_tab[22]
#define __pyx_kp_u__7 __pyx_string_tab[23]
#define __pyx_kp_u__9 __pyx_string_tab[24]
#define __pyx_kp_u_a_callback_must_be_callable_with __pyx_string_tab[25]
#define __pyx_kp_u_a_message_handler_must_be_callab __pyx_string_tab[26]
#define __pyx_kp_u_a_message_handler_threw_an_excep __pyx_string_tab[27]
#define __pyx_kp_u_a_oa_sa_sv __pyx_string_tab[28]
#define __pyx_kp_u_a_sv __pyx_string_tab[29]
#define __pyx_kp_u_add_match_request_failed_match __pyx_string_tab[30]
#define __pyx_kp_u_add_note __pyx_string_tab[31]
#define __pyx_kp_u_at_path __pyx_string_tab[32]
#define __pyx_kp_u_could_not_be_found __pyx_string_tab[33]
#define __pyx_kp_u_could_not_find_an_interface __pyx_string_tab[34]
#define __pyx_kp_u_could_not_get_machine_id __pyx_string_tab[35]
#define __pyx_kp_u_could_not_shut_down_socket __pyx_string_tab[36]
#define __pyx_kp_u_dbus_fast __pyx_string_tab[37]
#define __pyx_kp_u_dbus_fast__private_address __pyx_string_tab[38]
#define __pyx_kp_u_dbus_fast__private_util __pyx_string_tab[39]
#define __pyx_kp_u_dbus_fast_constants __pyx_string_tab[40]
#define __pyx_kp_u_dbus_fast_errors __pyx_string_tab[41]
#define __pyx_kp_u_dbus_fast_message __pyx_string_tab[42]
#define __pyx_kp_u_dbus_fast_proxy_object __pyx_string_tab[43]
#define __pyx_kp_u_dbus_fast_send_reply __pyx_string_tab[44]
#define __pyx_kp_u_dbus_fast_service __pyx_string_tab[45]
#define __pyx_kp_u_dbus_fast_signature __pyx_string_tab[46]
#define __pyx_kp_u_dbus_fast_validators __pyx_string_tab[47]
#define __pyx_kp_u_disable __pyx_string_tab[48]
#define __pyx_kp_u_does_not_have_property __pyx_string_tab[49]
#define __pyx_kp_u_empty_list_of_bus_addresses_give __pyx_string_tab[50]
#define __pyx_kp_u_enable __pyx_string_tab[51]
#define __pyx_kp_u_gc __pyx_string_tab[52]
#define __pyx_kp_u_getting_and_setting_properties_w __pyx_string_tab[53]
#define __pyx_kp_u_got_unix_transport_with_unknown __pyx_string_tab[54]
#define __pyx_kp_u_got_unknown_address_transport __pyx_string_tab[55]
#define __pyx_kp_u_interface_2 __pyx_string_tab[56]
#define __pyx_kp_u_interface_must_be_a_ServiceInter __pyx_string_tab[57]
#define __pyx_kp_u_interface_must_be_a_ServiceInter_2 __pyx_string_tab[58]
#define __pyx_kp_u_intr_Node __pyx_string_tab[59]
#define __pyx_kp_u_intr_Node_str_ET_Element __pyx_string_tab[60]
#define __pyx_kp_u_invalid_message_type_for_method __pyx_string_tab[61]
#define __pyx_kp_u_isenabled __pyx_string_tab[62]
#define __pyx_kp_u_list_Any __pyx_string_tab[63]
#define __pyx_kp_u_list_int __pyx_string_tab[64]
#define __pyx_kp_u_list_str __pyx_string_tab[65]
#define __pyx_kp_u_no_interfaces_at_path __pyx_string_tab[66]
#define __pyx_kp_u_oa_sa_sv __pyx_string_tab[67]
#define __pyx_kp_u_org_freedesktop_DBus __pyx_string_tab[68]
#define __pyx_kp_u_org_freedesktop_DBus_2 __pyx_string_tab[69]
#define __pyx_kp_u_org_freedesktop_DBus_3 __pyx_string_tab[70]
#define __pyx_kp_u_org_freedesktop_DBus_Introspecta __pyx_string_tab[71]
#define __pyx_kp_u_org_freedesktop_DBus_ObjectManag __pyx_string_tab[72]
#define __pyx_kp_u_org_freedesktop_DBus_Peer __pyx_string_tab[73]
#define __pyx_kp_u_org_freedesktop_DBus_Properties __pyx_string_tab[74]
#define __pyx_kp_u_properties_interface_doesn_t_hav __pyx_string_tab[75]
#define __pyx_kp_u_remove_match_request_failed_matc __pyx_string_tab[76]
#define __pyx_kp_u_s_s_with_signature_s_could_not __pyx_string_tab[77]
#define __pyx_kp_u_sender_org_freedesktop_DBus_inte __pyx_string_tab[78]
#define __pyx_kp_u_src_dbus_fast_message_bus_py __pyx_string_tab[79]
#define __pyx_kp_u_the_message_bus_implementation_d __pyx_string_tab[80]
#define __pyx_kp_u_the_property_does_not_have_read __pyx_string_tab[81]
#define __pyx_kp_u_the_property_is_readonly __pyx_string_tab[82]
#define __pyx_kp_u_the_send_method_must_be_implemen __pyx_string_tab[83]
#define __pyx_kp_u_tree_fragment __pyx_string_tab[84]
#define __pyx_kp_u_with_signature __pyx_string_tab[85]
#define __pyx_kp_u_with_signature_2 __pyx_string_tab[86]
#define __pyx_kp_u_wrong_signature_for_property_exp __pyx_string_tab[87]
#define __pyx_n_u_AF_INET __pyx_string_tab[88]
#define __pyx_n_u_AF_UNIX __pyx_string_tab[89]
#define __pyx_n_u_AddMatch __pyx_string_tab[90]
#define __pyx_n_u_Any __pyx_string_tab[91]
#define __pyx_n_u_BaseMessageBus __pyx_string_tab[92]
#define __pyx_n_u_BaseMessageBus___reduce_cython __pyx_string_tab[93]
#define __pyx_n_u_BaseMessageBus___setstate_cython __pyx_string_tab[94]
#define __pyx_n_u_BaseMessageBus__add_match_rule __pyx_string_tab[95]
#define __pyx_n_u_BaseMessageBus__call __pyx_string_tab[96]
#define __pyx_n_u_BaseMessageBus__callback_method __pyx_string_tab[97]
#define __pyx_n_u_BaseMessageBus__check_callback_t __pyx_string_tab[98]
#define __pyx_n_u_BaseMessageBus__check_method_ret __pyx_string_tab[99]
#define __pyx_n_u_BaseMessageBus__default_get_mach __pyx_string_tab[100]
#define __pyx_n_u_BaseMessageBus__default_get_mana __pyx_string_tab[101]
#define __pyx_n_u_BaseMessageBus__default_introspe __pyx_string_tab[102]
#define __pyx_n_u_BaseMessageBus__default_ping_han __pyx_string_tab[103]
#define __pyx_n_u_BaseMessageBus__default_properti __pyx_string_tab[104]
#define __pyx_n_u_BaseMessageBus__emit_interface_a __pyx_string_tab[105]
#define __pyx_n_u_BaseMessageBus__emit_interface_r __pyx_string_tab[106]
#define __pyx_n_u_BaseMessageBus__finalize __pyx_string_tab[107]
#define __pyx_n_u_BaseMessageBus__init_high_level __pyx_string_tab[108]
#define __pyx_n_u_BaseMessageBus__interface_signal __pyx_string_tab[109]
#define __pyx_n_u_BaseMessageBus__introspect_expor __pyx_string_tab[110]
#define __pyx_n_u_BaseMessageBus__make_method_hand __pyx_string_tab[111]
#define __pyx_n_u_BaseMessageBus__process_message __pyx_string_tab[112]
#define __pyx_n_u_BaseMessageBus__remove_match_rul __pyx_string_tab[113]
#define __pyx_n_u_BaseMessageBus__reply_notify __pyx_string_tab[114]
#define __pyx_n_u_BaseMessageBus__send_machine_id __pyx_string_tab[115]
#define __pyx_n_u_BaseMessageBus_add_message_handl __pyx_string_tab[116]
#define __pyx_n_u_BaseMessageBus_disconnect __pyx_string_tab[117]
#define __pyx_n_u_BaseMessageBus_export __pyx_string_tab[118]
#define __pyx_n_u_BaseMessageBus_get_proxy_object __pyx_string_tab[119]
#define __pyx_n_u_BaseMessageBus_introspect __pyx_string_tab[120]
#define __pyx_n_u_BaseMessageBus_next_serial __pyx_string_tab[121]
#define __pyx_n_u_BaseMessageBus_release_name __pyx_string_tab[122]
#define __pyx_n_u_BaseMessageBus_remove_message_ha __pyx_string_tab[123]
#define __pyx_n_u_BaseMessageBus_request_name __pyx_string_tab[124]
#define __pyx_n_u_BaseMessageBus_send __pyx_string_tab[125]
#define __pyx_n_u_BaseMessageBus_unexport __pyx_string_tab[126]
#define __pyx_n_u_BaseProxyObject __pyx_string_tab[127]
#define __pyx_n_u_BusType __pyx_string_tab[128]
#define __pyx_n_u_Callable __pyx_string_tab[129]
#define __pyx_n_u_DBusError __pyx_string_tab[130]
#define __pyx_n_u_ERROR __pyx_string_tab[131]
#define __pyx_n_u_ET __pyx_string_tab[132]
#define __pyx_n_u_ElementTree __pyx_string_tab[133]
#define __pyx_n_u_ErrorType __pyx_string_tab[134]
#define __pyx_n_u_ExitStack __pyx_string_tab[135]
#define __pyx_n_u_FAILED __pyx_string_tab[136]
#define __pyx_n_u_Get __pyx_string_tab[137]
#define __pyx_n_u_GetAll __pyx_string_tab[138]
#define __pyx_n_u_GetMachineId __pyx_string_tab[139]
#define __pyx_n_u_GetManagedObjects __pyx_string_tab[140]
#define __pyx_n_u_HandlerType __pyx_string_tab[141]
#define __pyx_n_u_INTERNAL_ERROR __pyx_string_tab[142]
#define __pyx_n_u_INVALID_SIGNATURE __pyx_string_tab[143]
#define __pyx_n_u_InterfacesAdded __pyx_string_tab[144]
#define __pyx_n_u_InterfacesRemoved __pyx_string_tab[145]
#define __pyx_n_u_Introspect __pyx_string_tab[146]
#define __pyx_n_u_InvalidAddressError __pyx_string_tab[147]
#define __pyx_n_u_LOGGER __pyx_string_tab[148]
#define __pyx_n_u_METHOD_CALL __pyx_string_tab[149]
#define __pyx_n_u_METHOD_RETURN __pyx_string_tab[150]
#define __pyx_n_u_Message __pyx_string_tab[151]
#define __pyx_n_u_MessageFlag __pyx_string_tab[152]
#define __pyx_n_u_MessageType __pyx_string_tab[153]
#define __pyx_n_u_Message_2 __pyx_string_tab[154]
#define __pyx_n_u_Method __pyx_string_tab[155]
#define __pyx_n_u_NONE __pyx_string_tab[156]
#define __pyx_n_u_NOT_SUPPORTED __pyx_string_tab[157]
#define __pyx_n_u_NO_REPLY_EXPECTED __pyx_string_tab[158]
#define __pyx_n_u_NameFlag __pyx_string_tab[159]
#define __pyx_n_u_NameOwnerChanged __pyx_string_tab[160]
#define __pyx_n_u_Node __pyx_string_tab[161]
#define __pyx_n_u_None __pyx_string_tab[162]
#define __pyx_n_u_PROPERTY_READ_ONLY __pyx_string_tab[163]
#define __pyx_n_u_Ping __pyx_string_tab[164]
#define __pyx_n_u_Property __pyx_string_tab[165]
#define __pyx_n_u_ProxyObject __pyx_string_tab[166]
#define __pyx_n_u_ProxyObject_2 __pyx_string_tab[167]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[168]
#define __pyx_n_u_ReleaseName __pyx_string_tab[169]
#define __pyx_n_u_ReleaseNameReply __pyx_string_tab[170]
#define __pyx_n_u_RemoveMatch __pyx_string_tab[171]
#define __pyx_n_u_RequestName __pyx_string_tab[172]
#define __pyx_n_u_RequestNameReply __pyx_string_tab[173]
#define __pyx_n_u_SESSION __pyx_string_tab[174]
#define __pyx_n_u_SHUT_RDWR __pyx_string_tab[175]
#define __pyx_n_u_SIGNAL __pyx_string_tab[176]
#define __pyx_n_u_SOCK_STREAM __pyx_string_tab[177]
#define __pyx_n_u_SendReply __pyx_string_tab[178]
#define __pyx_n_u_ServiceInterface __pyx_string_tab[179]
#define __pyx_n_u_Set __pyx_string_tab[180]
#define __pyx_n_u_TYPE_CHECKING __pyx_string_tab[181]
#define __pyx_n_u_UNKNOWN_INTERFACE __pyx_string_tab[182]
#define __pyx_n_u_UNKNOWN_METHOD __pyx_string_tab[183]
#define __pyx_n_u_UNKNOWN_OBJECT __pyx_string_tab[184]
#define __pyx_n_u_UNKNOWN_PROPERTY __pyx_string_tab[185]
#define __pyx_n_u_Variant __pyx_string_tab[186]
#define __pyx_n_u__7 __pyx_string_tab[187]
#define __pyx_n_u_abstract __pyx_string_tab[188]
#define __pyx_n_u_access __pyx_string_tab[189]
#define __pyx_n_u_add_bus __pyx_string_tab[190]
#define __pyx_n_u_add_match_notify __pyx_string_tab[191]
#define __pyx_n_u_add_match_rule __pyx_string_tab[192]
#define __pyx_n_u_add_match_rule_locals_add_match __pyx_string_tab[193]
#define __pyx_n_u_add_message_handler __pyx_string_tab[194]
#define __pyx_n_u_append __pyx_string_tab[195]
#define __pyx_n_u_as_message __pyx_string_tab[196]
#define __pyx_n_u_assert_bus_name_valid __pyx_string_tab[197]
#define __pyx_n_u_assert_object_path_valid __pyx_string_tab[198]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[199]
#define __pyx_n_u_block_unexpected_reply __pyx_string_tab[200]
#define __pyx_n_u_body __pyx_string_tab[201]
#define __pyx_n_u_bool __pyx_string_tab[202]
#define __pyx_n_u_bus_address __pyx_string_tab[203]
#define __pyx_n_u_bus_address_2 __pyx_string_tab[204]
#define __pyx_n_u_bus_name __pyx_string_tab[205]
#define __pyx_n_u_bus_type __pyx_string_tab[206]
#define __pyx_n_u_call __pyx_string_tab[207]
#define __pyx_n_u_callback __pyx_string_tab[208]
#define __pyx_n_u_callback_method_handler __pyx_string_tab[209]
#define __pyx_n_u_check_callback_type __pyx_string_tab[210]
#define __pyx_n_u_check_callback_type_2 __pyx_string_tab[211]
#define __pyx_n_u_check_method_return __pyx_string_tab[212]
#define __pyx_n_u_child_name __pyx_string_tab[213]
#define __pyx_n_u_child_path __pyx_string_tab[214]
#define __pyx_n_u_children __pyx_string_tab[215]
#define __pyx_n_u_clear __pyx_string_tab[216]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[217]
#define __pyx_n_u_close __pyx_string_tab[218]
#define __pyx_n_u_collections_abc __pyx_string_tab[219]
#define __pyx_n_u_connect __pyx_string_tab[220]
#define __pyx_n_u_constants __pyx_string_tab[221]
#define __pyx_n_u_contextlib __pyx_string_tab[222]
#define __pyx_n_u_dbus_fast_message_bus __pyx_string_tab[223]
#define __pyx_n_u_debug __pyx_string_tab[224]
#define __pyx_n_u_default __pyx_string_tab[225]
#define __pyx_n_u_default_get_machine_id_handler __pyx_string_tab[226]
#define __pyx_n_u_default_get_machine_id_handler_2 __pyx_string_tab[227]
#define __pyx_n_u_default_get_managed_objects_han __pyx_string_tab[228]
#define __pyx_n_u_default_get_managed_objects_han_2 __pyx_string_tab[229]
#define __pyx_n_u_default_get_managed_objects_han_3 __pyx_string_tab[230]
#define __pyx_n_u_default_introspect_handler __pyx_string_tab[231]
#define __pyx_n_u_default_ping_handler __pyx_string_tab[232]
#define __pyx_n_u_default_properties_handler __pyx_string_tab[233]
#define __pyx_n_u_default_properties_handler_loca __pyx_string_tab[234]
#define __pyx_n_u_default_properties_handler_loca_2 __pyx_string_tab[235]
#define __pyx_n_u_default_properties_handler_loca_3 __pyx_string_tab[236]
#define __pyx_n_u_destination __pyx_string_tab[237]
#define __pyx_n_u_dict __pyx_string_tab[238]
#define __pyx_n_u_dict_2 __pyx_string_tab[239]
#define __pyx_n_u_disabled __pyx_string_tab[240]
#define __pyx_n_u_disconnect __pyx_string_tab[241]
#define __pyx_n_u_disconnected __pyx_string_tab[242]
#define __pyx_n_u_e __pyx_string_tab[243]
#define __pyx_n_u_emit_interface_added __pyx_string_tab[244]
#define __pyx_n_u_emit_interface_added_locals_get __pyx_string_tab[245]
#define __pyx_n_u_emit_interface_removed __pyx_string_tab[246]
#define __pyx_n_u_encode __pyx_string_tab[247]
#define __pyx_n_u_enter __pyx_string_tab[248]
#define __pyx_n_u_enter_context __pyx_string_tab[249]
#define __pyx_n_u_enumerate __pyx_string_tab[250]
#define __pyx_n_u_err __pyx_string_tab[251]
#define __pyx_n_u_error __pyx_string_tab[252]
#define __pyx_n_u_error_handled __pyx_string_tab[253]
#define __pyx_n_u_error_text __pyx_string_tab[254]
#define __pyx_n_u_errors __pyx_string_tab[255]
#define __pyx_n_u_etree __pyx_string_tab[256]
#define __pyx_n_u_exc_info __pyx_string_tab[257]
#define __pyx_n_u_exception __pyx_string_tab[258]
#define __pyx_n_u_exit __pyx_string_tab[259]
#define __pyx_n_u_export __pyx_string_tab[260]
#define __pyx_n_u_export_path __pyx_string_tab[261]
#define __pyx_n_u_fd __pyx_string_tab[262]
#define __pyx_n_u_fileno __pyx_string_tab[263]
#define __pyx_n_u_finalize __pyx_string_tab[264]
#define __pyx_n_u_flags __pyx_string_tab[265]
#define __pyx_n_u_fn_signature __pyx_string_tab[266]
#define __pyx_n_u_format_exc __pyx_string_tab[267]
#define __pyx_n_u_from_message __pyx_string_tab[268]
#define __pyx_n_u_fromkeys __pyx_string_tab[269]
#define __pyx_n_u_func __pyx_string_tab[270]
#define __pyx_n_u_functools __pyx_string_tab[271]
#define __pyx_n_u_get __pyx_string_tab[272]
#define __pyx_n_u_getLogger __pyx_string_tab[273]
#define __pyx_n_u_get_all_properties_callback __pyx_string_tab[274]
#define __pyx_n_u_get_all_property_values __pyx_string_tab[275]
#define __pyx_n_u_get_bus_address __pyx_string_tab[276]
#define __pyx_n_u_get_properties __pyx_string_tab[277]
#define __pyx_n_u_get_properties_callback __pyx_string_tab[278]
#define __pyx_n_u_get_property_callback __pyx_string_tab[279]
#define __pyx_n_u_get_property_value __pyx_string_tab[280]
#define __pyx_n_u_get_proxy_object __pyx_string_tab[281]
#define __pyx_n_u_getstate __pyx_string_tab[282]
#define __pyx_n_u_h __pyx_string_tab[283]
#define __pyx_n_u_handler __pyx_string_tab[284]
#define __pyx_n_u_handler_signature __pyx_string_tab[285]
#define __pyx_n_u_high_level_client_initialized __pyx_string_tab[286]
#define __pyx_n_u_host __pyx_string_tab[287]
#define __pyx_n_u_i __pyx_string_tab[288]
#define __pyx_n_u_ifaces __pyx_string_tab[289]
#define __pyx_n_u_init_high_level_client __pyx_string_tab[290]
#define __pyx_n_u_init_high_level_client_locals_a __pyx_string_tab[291]
#define __pyx_n_u_inspect __pyx_string_tab[292]
#define __pyx_n_u_interface __pyx_string_tab[293]
#define __pyx_n_u_interface_name __pyx_string_tab[294]
#define __pyx_n_u_interface_signal_notify __pyx_string_tab[295]
#define __pyx_n_u_interfaces __pyx_string_tab[296]
#define __pyx_n_u_intr __pyx_string_tab[297]
#define __pyx_n_u_introspect __pyx_string_tab[298]
#define __pyx_n_u_introspect_export_path __pyx_string_tab[299]
#define __pyx_n_u_introspect_locals_reply_notify __pyx_string_tab[300]
#define __pyx_n_u_introspection __pyx_string_tab[301]
#define __pyx_n_u_io __pyx_string_tab[302]
#define __pyx_n_u_is_coroutine __pyx_string_tab[303]
#define __pyx_n_u_is_result_complete __pyx_string_tab[304]
#define __pyx_n_u_items __pyx_string_tab[305]
#define __pyx_n_u_logging __pyx_string_tab[306]
#define __pyx_n_u_lstrip __pyx_string_tab[307]
#define __pyx_n_u_machine_id __pyx_string_tab[308]
#define __pyx_n_u_main __pyx_string_tab[309]
#define __pyx_n_u_make_method_handler __pyx_string_tab[310]
#define __pyx_n_u_makefile __pyx_string_tab[311]
#define __pyx_n_u_match __pyx_string_tab[312]
#define __pyx_n_u_match_rule __pyx_string_tab[313]
#define __pyx_n_u_match_rules __pyx_string_tab[314]
#define __pyx_n_u_maxsplit __pyx_string_tab[315]
#define __pyx_n_u_member __pyx_string_tab[316]
#define __pyx_n_u_message __pyx_string_tab[317]
#define __pyx_n_u_message_type __pyx_string_tab[318]
#define __pyx_n_u_method __pyx_string_tab[319]
#define __pyx_n_u_method_return_handlers __pyx_string_tab[320]
#define __pyx_n_u_methods __pyx_string_tab[321]
#define __pyx_n_u_module __pyx_string_tab[322]
#define __pyx_n_u_msg __pyx_string_tab[323]
#define __pyx_n_u_n __pyx_string_tab[324]
#define __pyx_n_u_name __pyx_string_tab[325]
#define __pyx_n_u_name_2 __pyx_string_tab[326]
#define __pyx_n_u_name_owner_match_rule __pyx_string_tab[327]
#define __pyx_n_u_name_owners __pyx_string_tab[328]
#define __pyx_n_u_negotiate_unix_fd __pyx_string_tab[329]
#define __pyx_n_u_negotiate_unix_fd_2 __pyx_string_tab[330]
#define __pyx_n_u_new __pyx_string_tab[331]
#define __pyx_n_u_new_error __pyx_string_tab[332]
#define __pyx_n_u_new_method_return __pyx_string_tab[333]
#define __pyx_n_u_new_signal __pyx_string_tab[334]
#define __pyx_n_u_next_serial __pyx_string_tab[335]
#define __pyx_n_u_node __pyx_string_tab[336]
#define __pyx_n_u_nodes __pyx_string_tab[337]
#define __pyx_n_u_oas __pyx_string_tab[338]
#define __pyx_n_u_p __pyx_string_tab[339]
#define __pyx_n_u_parameters __pyx_string_tab[340]
#define __pyx_n_u_parse __pyx_string_tab[341]
#define __pyx_n_u_parse_address __pyx_string_tab[342]
#define __pyx_n_u_partial __pyx_string_tab[343]
#define __pyx_n_u_path __pyx_string_tab[344]
#define __pyx_n_u_path_exports __pyx_string_tab[345]
#define __pyx_n_u_pop __pyx_string_tab[346]
#define __pyx_n_u_pop_all __pyx_string_tab[347]
#define __pyx_n_u_port __pyx_string_tab[348]
#define __pyx_n_u_private_address __pyx_string_tab[349]
#define __pyx_n_u_private_util __pyx_string_tab[350]
#define __pyx_n_u_process_message __pyx_string_tab[351]
#define __pyx_n_u_prop __pyx_string_tab[352]
#define __pyx_n_u_prop_name __pyx_string_tab[353]
#define __pyx_n_u_prop_setter __pyx_string_tab[354]
#define __pyx_n_u_prop_value __pyx_string_tab[355]
#define __pyx_n_u_properties __pyx_string_tab[356]
#define __pyx_n_u_proxy_object __pyx_string_tab[357]
#define __pyx_n_u_pyx_capi __pyx_string_tab[358]
#define __pyx_n_u_pyx_checksum __pyx_string_tab[359]
#define __pyx_n_u_pyx_result __pyx_string_tab[360]
#define __pyx_n_u_pyx_state __pyx_string_tab[361]
#define __pyx_n_u_pyx_type __pyx_string_tab[362]
#define __pyx_n_u_pyx_unpickle_BaseMessageBus __pyx_string_tab[363]
#define __pyx_n_u_pyx_vtable __pyx_string_tab[364]
#define __pyx_n_u_qualname __pyx_string_tab[365]
#define __pyx_n_u_readable __pyx_string_tab[366]
#define __pyx_n_u_reduce __pyx_string_tab[367]
#define __pyx_n_u_reduce_cython __pyx_string_tab[368]
#define __pyx_n_u_reduce_ex __pyx_string_tab[369]
#define __pyx_n_u_release_name __pyx_string_tab[370]
#define __pyx_n_u_release_name_locals_reply_notify __pyx_string_tab[371]
#define __pyx_n_u_remove_bus __pyx_string_tab[372]
#define __pyx_n_u_remove_match_notify __pyx_string_tab[373]
#define __pyx_n_u_remove_match_rule __pyx_string_tab[374]
#define __pyx_n_u_remove_match_rule_locals_remove __pyx_string_tab[375]
#define __pyx_n_u_remove_message_handler __pyx_string_tab[376]
#define __pyx_n_u_removed_interface __pyx_string_tab[377]
#define __pyx_n_u_removed_interface_names __pyx_string_tab[378]
#define __pyx_n_u_removed_interfaces __pyx_string_tab[379]
#define __pyx_n_u_replace_fds_with_idx __pyx_string_tab[380]
#define __pyx_n_u_replace_idx_with_fds __pyx_string_tab[381]
#define __pyx_n_u_reply __pyx_string_tab[382]
#define __pyx_n_u_reply_handler __pyx_string_tab[383]
#define __pyx_n_u_reply_notify __pyx_string_tab[384]
#define __pyx_n_u_reply_notify_2 __pyx_string_tab[385]
#define __pyx_n_u_reply_serial __pyx_string_tab[386]
#define __pyx_n_u_request_name __pyx_string_tab[387]
#define __pyx_n_u_request_name_locals_reply_notify __pyx_string_tab[388]
#define __pyx_n_u_result __pyx_string_tab[389]
#define __pyx_n_u_result_signature __pyx_string_tab[390]
#define __pyx_n_u_return __pyx_string_tab[391]
#define __pyx_n_u_rwb __pyx_string_tab[392]
#define __pyx_n_u_s __pyx_string_tab[393]
#define __pyx_n_u_self __pyx_string_tab[394]
#define __pyx_n_u_send __pyx_string_tab[395]
#define __pyx_n_u_send_error __pyx_string_tab[396]
#define __pyx_n_u_send_machine_id_reply __pyx_string_tab[397]
#define __pyx_n_u_send_reply __pyx_string_tab[398]
#define __pyx_n_u_serial __pyx_string_tab[399]
#define __pyx_n_u_service __pyx_string_tab[400]
#define __pyx_n_u_set_name __pyx_string_tab[401]
#define __pyx_n_u_set_property_callback __pyx_string_tab[402]
#define __pyx_n_u_set_property_value __pyx_string_tab[403]
#define __pyx_n_u_setblocking __pyx_string_tab[404]
#define __pyx_n_u_setdefault __pyx_string_tab[405]
#define __pyx_n_u_setstate __pyx_string_tab[406]
#define __pyx_n_u_setstate_cython __pyx_string_tab[407]
#define __pyx_n_u_shutdown __pyx_string_tab[408]
#define __pyx_n_u_signature __pyx_string_tab[409]
#define __pyx_n_u_slots __pyx_string_tab[410]
#define __pyx_n_u_sock __pyx_string_tab[411]
#define __pyx_n_u_socket __pyx_string_tab[412]
#define __pyx_n_u_split __pyx_string_tab[413]
#define __pyx_n_u_ss __pyx_string_tab[414]
#define __pyx_n_u_ssv __pyx_string_tab[415]
#define __pyx_n_u_startswith __pyx_string_tab[416]
#define __pyx_n_u_state __pyx_string_tab[417]
#define __pyx_n_u_staticmethod __pyx_string_tab[418]
#define __pyx_n_u_str __pyx_string_tab[419]
#define __pyx_n_u_stream __pyx_string_tab[420]
#define __pyx_n_u_su __pyx_string_tab[421]
#define __pyx_n_u_tcp __pyx_string_tab[422]
#define __pyx_n_u_test __pyx_string_tab[423]
#define __pyx_n_u_text __pyx_string_tab[424]
#define __pyx_n_u_tostring __pyx_string_tab[425]
#define __pyx_n_u_traceback __pyx_string_tab[426]
#define __pyx_n_u_typing __pyx_string_tab[427]
#define __pyx_n_u_u __pyx_string_tab[428]
#define __pyx_n_u_unexport __pyx_string_tab[429]
#define __pyx_n_u_unique_name __pyx_string_tab[430]
#define __pyx_n_u_unix __pyx_string_tab[431]
#define __pyx_n_u_unix_fds __pyx_string_tab[432]
#define __pyx_n_u_update __pyx_string_tab[433]
#define __pyx_n_u_use_setstate __pyx_string_tab[434]
#define __pyx_n_u_user_data __pyx_string_tab[435]
#define __pyx_n_u_user_disconnect __pyx_string_tab[436]
#define __pyx_n_u_user_message_handlers __pyx_string_tab[437]
#define __pyx_n_u_v __pyx_string_tab[438]
#define __pyx_n_u_validate_property_names __pyx_string_tab[439]
#define __pyx_n_u_validators __pyx_string_tab[440]
#define __pyx_n_u_value __pyx_string_tab[441]
#define __pyx_n_u_values __pyx_string_tab[442]
#define __pyx_n_u_warning __pyx_string_tab[443]
#define __pyx_n_u_writable __pyx_string_tab[444]
#define __pyx_n_u_xml_etree_ElementTree __pyx_string_tab[445]
#define __pyx_kp_b_PyObject_PACKED_BOOL_FALSE_PACKE __pyx_string_tab[446]
#define __pyx_kp_b_PyObject_PyObject_int___pyx_skip __pyx_string_tab[447]
#define __pyx_kp_b_PyObject_int_unsigned_int_BLOCK __pyx_string_tab[448]
#define __pyx_kp_b_PyObject_struct___pyx_obj_9dbus __pyx_string_tab[449]
#define __pyx_kp_b_PyObject_unquote __pyx_string_tab[450]
#define __pyx_kp_b__8 __pyx_string_tab[451]
#define __pyx_kp_b_int_struct___pyx_obj_9dbus_fast __pyx_string_tab[452]
#define __pyx_kp_b_iso88591_1_4z_Q_1A_5_t1_axq_fCt_A_XXaabb __pyx_string_tab[453]
#define __pyx_kp_b_iso88591_1_Ja_t7_4q_A_k_5_1_7_4AU_LAQ __pyx_string_tab[454]
#define __pyx_kp_b_iso88591_2_4q_Q_HF_F_Kt_37_q_a_xq_H_QR_F __pyx_string_tab[455]
#define __pyx_kp_b_iso88591_4q_a_U_2_7LA_F_1_A_Q_q_Qd __pyx_string_tab[456]
#define __pyx_kp_b_iso88591_4wa_k_k_Q_AQ_5Q_Qa_Qa __pyx_string_tab[457]
#define __pyx_kp_b_iso88591_55J_31G5_U_aq_A_q_AXQ __pyx_string_tab[458]
#define __pyx_kp_b_iso88591_55J_31G5_uAQ_q_AXQ __pyx_string_tab[459]
#define __pyx_kp_b_iso88591_6 __pyx_string_tab[460]
#define __pyx_kp_b_iso88591_66K1_t3fCq_uN_O5_Qa_1E_3k_E_WTU __pyx_string_tab[461]
#define __pyx_kp_b_iso88591_77Gq_t7_Qa_aw_8 __pyx_string_tab[462]
#define __pyx_kp_b_iso88591_77LA_q_vQ_7q_WWXXY_WE_S_c_A_vQ __pyx_string_tab[463]
#define __pyx_kp_b_iso88591_77LA_q_vQ_A_PQQR_WE_S_c_A_vQ_7q __pyx_string_tab[464]
#define __pyx_kp_b_iso88591_A __pyx_string_tab[465]
#define __pyx_kp_b_iso88591_AV1 __pyx_string_tab[466]
#define __pyx_kp_b_iso88591_A_1_A_1_3fG1_A_s_4s_k_V2Q_A_iq_N __pyx_string_tab[467]
#define __pyx_kp_b_iso88591_A_31HC_cQR_s_q_c_0_s_8_1_S_Cq_XQ __pyx_string_tab[468]
#define __pyx_kp_b_iso88591_A_31_wat_6k __pyx_string_tab[469]
#define __pyx_kp_b_iso88591_A_4A_q_4xq_1A_wj_3a_1_1A __pyx_string_tab[470]
#define __pyx_kp_b_iso88591_A_4q_F_1F_xq_iq __pyx_string_tab[471]
#define __pyx_kp_b_iso88591_A_4q_q_Q_1_6K1_F_1_A_Q_q __pyx_string_tab[472]
#define __pyx_kp_b_iso88591_A_4s_z_O3nAV4y_q_Kwa_E_E_4_d_7_A __pyx_string_tab[473]
#define __pyx_kp_b_iso88591_A_4wa_k_k_5Qiq_Qe9F_1 __pyx_string_tab[474]
#define __pyx_kp_b_iso88591_A_6_S_T_a_Qc_1_a __pyx_string_tab[475]
#define __pyx_kp_b_iso88591_A_7q_4_S_1_A_t_6 __pyx_string_tab[476]
#define __pyx_kp_b_iso88591_A_A_1_q_0_5J_F_1_A_Q_q __pyx_string_tab[477]
#define __pyx_kp_b_iso88591_A_CuIQd_r_A_D_q __pyx_string_tab[478]
#define __pyx_kp_b_iso88591_A_DA_S_Q_S_Q_q_1_Ya_1_MQdRSST_Ks __pyx_string_tab[479]
#define __pyx_kp_b_iso88591_A_D_7_t1HCq_E_a_3nCq_Qa_1A_a_z __pyx_string_tab[480]
#define __pyx_kp_b_iso88591_A_JK_A_Qa_9G5_A_q_4q_wa_HAQ_a_1 __pyx_string_tab[481]
#define __pyx_kp_b_iso88591_A_JK_A_Qa_9G5_A_q_a_1_a_9Cq_ay_0 __pyx_string_tab[482]
#define __pyx_kp_b_iso88591_A_L_t1 __pyx_string_tab[483]
#define __pyx_kp_b_iso88591_A_Q_4xq_1A_G_Qa_3a_S_1A_7_1 __pyx_string_tab[484]
#define __pyx_kp_b_iso88591_A_a_1_Cz_6_V7_2S_1_5_1_1_E_a_Q_q __pyx_string_tab[485]
#define __pyx_kp_b_iso88591_A_q_1_4s_1_RRS_3nC_S_3a_3nC_iq_N __pyx_string_tab[486]
#define __pyx_kp_b_iso88591_A_t1_q_vQ_IZwa_vS_q_1 __pyx_string_tab[487]
#define __pyx_kp_b_iso88591_DNRS_1_3fG1_4AS_iq_7_AU_q __pyx_string_tab[488]
#define __pyx_kp_b_iso88591_DNRS_7_wj_3hgXS_q_9Cs_1_QcA __pyx_string_tab[489]
#define __pyx_kp_b_iso88591_E_ST_4q_E_a_Q_q_QfA __pyx_string_tab[490]
#define __pyx_kp_b_iso88591_HA_Ks_nD_q_4uHAQ_Zwa_Kway_1_4uA __pyx_string_tab[491]
#define __pyx_kp_b_iso88591_Oq_4q_q_A_q_q_0_1_Q __pyx_string_tab[492]
#define __pyx_kp_b_iso88591_Oq_t1_q_vQ_WE_S_c_A_vQ_URSST __pyx_string_tab[493]
#define __pyx_kp_b_iso88591_Q_7_AU_q_A __pyx_string_tab[494]
#define __pyx_kp_b_iso88591_T_O47Gt6QUUvvz_I_I_M_M_z_z_W_W __pyx_string_tab[495]
#define __pyx_kp_b_iso88591_XQ_c_Q_c_Q_QoQ_t_Rq_D_Qa_5U_Oq __pyx_string_tab[496]
#define __pyx_kp_b_iso88591_c_Q_c_Q_QoQ_M_U_2_7LA_F_1_A_Q_q __pyx_string_tab[497]
#define __pyx_kp_b_iso88591_nA_7_AQ __pyx_string_tab[498]
#define __pyx_kp_b_iso88591_q_0_kQR_7_0_1B_PQ_1 __pyx_string_tab[499]
#define __pyx_kp_b_iso88591_r_6_IWA_Q_a_1_a __pyx_string_tab[500]
#define __pyx_int_0 __pyx_number_tab[0]
#define __pyx_int_1 __pyx_number_tab[1]
#define __pyx_int_164667464 __pyx_number_tab[2]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_9signature_SignatureType);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_9signature_SignatureTree);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_9signature_Variant);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_8_private_10marshaller_Marshaller);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_7message_Message);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_7service__Method);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_7service_ServiceInterface);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus);
  Py_CLEAR(clear_module_state->__pyx_type_9dbus_fast_11message_bus_BaseMessageBus);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect);
  Py_CLEAR(clear_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct__introspect);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added);
  Py_CLEAR(clear_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name);
  Py_CLEAR(clear_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name);
  Py_CLEAR(clear_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler);
  Py_CLEAR(clear_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler);
  Py_CLEAR(clear_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler);
  Py_CLEAR(clear_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client);
  Py_CLEAR(clear_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule);
  Py_CLEAR(clear_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule);
  Py_CLEAR(clear_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule);
  Py_CLEAR(clear_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule);
  Py_CLEAR(clear_module_state->__pyx_k_);
  Py_CLEAR(clear_module_state->__pyx_k__4);
  Py_CLEAR(clear_module_state->__pyx_k__5);
  for (int i=0; i<6; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<49; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<501; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<3; ++i) { Py_CLEAR(clear_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_9signature_SignatureType);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_9signature_SignatureTree);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_9signature_Variant);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_8_private_10marshaller_Marshaller);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_7message_Message);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_7service__Method);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_7service_ServiceInterface);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus);
  Py_VISIT(traverse_module_state->__pyx_type_9dbus_fast_11message_bus_BaseMessageBus);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect);
  Py_VISIT(traverse_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct__introspect);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added);
  Py_VISIT(traverse_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name);
  Py_VISIT(traverse_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name);
  Py_VISIT(traverse_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler);
  Py_VISIT(traverse_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler);
  Py_VISIT(traverse_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler);
  Py_VISIT(traverse_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client);
  Py_VISIT(traverse_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule);
  Py_VISIT(traverse_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule);
  Py_VISIT(traverse_module_state->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule);
  Py_VISIT(traverse_module_state->__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule);
  Py_VISIT(traverse_module_state->__pyx_k_);
  Py_VISIT(traverse_module_state->__pyx_k__4);
  Py_VISIT(traverse_module_state->__pyx_k__5);
  for (int i=0; i<6; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<49; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<501; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<3; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "dbus_fast/message_bus.py":47
 * 
 * 
 * def _expects_reply(msg: _Message) -> bool:             # <<<<<<<<<<<<<<
 *     """Whether a message expects a reply."""
 *     if msg.flags is NO_REPLY_EXPECTED:
*/

static int __pyx_f_9dbus_fast_11message_bus__expects_reply(struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg) {
  unsigned int __pyx_v_flag_value;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  unsigned int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_expects_reply", 0);

  /* "dbus_fast/message_bus.py":49
 * def _expects_reply(msg: _Message) -> bool:
 *     """Whether a message expects a reply."""
 *     if msg.flags is NO_REPLY_EXPECTED:             # <<<<<<<<<<<<<<
 *         return False
 *     if msg.flags is NONE:
*/
  __pyx_t_1 = (__pyx_v_msg->flags == __pyx_v_9dbus_fast_11message_bus_NO_REPLY_EXPECTED);
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":50
 *     """Whether a message expects a reply."""
 *     if msg.flags is NO_REPLY_EXPECTED:
 *         return False             # <<<<<<<<<<<<<<
 *     if msg.flags is NONE:
 *         return True
*/
    __pyx_r = 0;
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":49
 * def _expects_reply(msg: _Message) -> bool:
 *     """Whether a message expects a reply."""
 *     if msg.flags is NO_REPLY_EXPECTED:             # <<<<<<<<<<<<<<
 *         return False
 *     if msg.flags is NONE:
*/
  }

  /* "dbus_fast/message_bus.py":51
 *     if msg.flags is NO_REPLY_EXPECTED:
 *         return False
 *     if msg.flags is NONE:             # <<<<<<<<<<<<<<
 *         return True
 *     # Slow check for NO_REPLY_EXPECTED
*/
  __pyx_t_1 = (__pyx_v_msg->flags == __pyx_v_9dbus_fast_11message_bus_NONE);
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":52
 *         return False
 *     if msg.flags is NONE:
 *         return True             # <<<<<<<<<<<<<<
 *     # Slow check for NO_REPLY_EXPECTED
 *     flag_value = msg.flags.value
*/
    __pyx_r = 1;
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":51
 *     if msg.flags is NO_REPLY_EXPECTED:
 *         return False
 *     if msg.flags is NONE:             # <<<<<<<<<<<<<<
 *         return True
 *     # Slow check for NO_REPLY_EXPECTED
*/
  }

  /* "dbus_fast/message_bus.py":54
 *         return True
 *     # Slow check for NO_REPLY_EXPECTED
 *     flag_value = msg.flags.value             # <<<<<<<<<<<<<<
 *     return not (flag_value & NO_REPLY_EXPECTED_VALUE)
 * 
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_msg->flags, __pyx_mstate_global->__pyx_n_u_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyLong_As_unsigned_int(__pyx_t_2); if (unlikely((__pyx_t_3 == (unsigned int)-1) && PyErr_Occurred())) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_flag_value = __pyx_t_3;

  /* "dbus_fast/message_bus.py":55
 *     # Slow check for NO_REPLY_EXPECTED
 *     flag_value = msg.flags.value
 *     return not (flag_value & NO_REPLY_EXPECTED_VALUE)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_r = (!((__pyx_v_flag_value & __pyx_v_9dbus_fast_11message_bus_NO_REPLY_EXPECTED_VALUE) != 0));
  goto __pyx_L0;

  /* "dbus_fast/message_bus.py":47
 * 
 * 
 * def _expects_reply(msg: _Message) -> bool:             # <<<<<<<<<<<<<<
 *     """Whether a message expects a reply."""
 *     if msg.flags is NO_REPLY_EXPECTED:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("dbus_fast.message_bus._expects_reply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":58
 * 
 * 
 * def _block_unexpected_reply(reply: _Message) -> None:             # <<<<<<<<<<<<<<
 *     """Block a reply if it's not expected.
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_1_block_unexpected_reply(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus__block_unexpected_reply, "Block a reply if it's not expected.\n\n    Previously we silently ignored replies that were not expected, but this\n    lead to implementation errors that were hard to debug. Now we log a\n    debug message instead.\n    ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_1_block_unexpected_reply = {"_block_unexpected_reply", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_1_block_unexpected_reply, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus__block_unexpected_reply};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_1_block_unexpected_reply(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_reply = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_block_unexpected_reply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_reply,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 58, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 58, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_block_unexpected_reply", 0) < (0)) __PYX_ERR(0, 58, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_block_unexpected_reply", 1, 1, 1, i); __PYX_ERR(0, 58, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 58, __pyx_L3_error)
    }
    __pyx_v_reply = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_block_unexpected_reply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 58, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus._block_unexpected_reply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus__block_unexpected_reply(__pyx_self, __pyx_v_reply);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus__block_unexpected_reply(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_reply) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_block_unexpected_reply", 0);

  /* "dbus_fast/message_bus.py":65
 *     debug message instead.
 *     """
 *     _LOGGER.debug(             # <<<<<<<<<<<<<<
 *         "Blocked attempt to send a reply from handler "
 *         "that received a message with flag "
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_LOGGER); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_debug); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "dbus_fast/message_bus.py":69
 *         "that received a message with flag "
 *         "MessageFlag.NO_REPLY_EXPECTED: %s",
 *         reply,             # <<<<<<<<<<<<<<
 *     )
 * 
*/
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Blocked_attempt_to_send_a_reply, __pyx_v_reply};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":58
 * 
 * 
 * def _block_unexpected_reply(reply: _Message) -> None:             # <<<<<<<<<<<<<<
 *     """Block a reply if it's not expected.
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("dbus_fast.message_bus._block_unexpected_reply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":127
 *     )
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         bus_address: str | None = None,
*/

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_bus_address = 0;
  PyObject *__pyx_v_bus_type = 0;
  PyObject *__pyx_v_ProxyObject = 0;
  int __pyx_v_negotiate_unix_fd;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_bus_address,&__pyx_mstate_global->__pyx_n_u_bus_type,&__pyx_mstate_global->__pyx_n_u_ProxyObject,&__pyx_mstate_global->__pyx_n_u_negotiate_unix_fd,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 127, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_VARARGS(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 127, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 127, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 127, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 127, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 127, __pyx_L3_error)

      /* "dbus_fast/message_bus.py":129
 *     def __init__(
 *         self,
 *         bus_address: str | None = None,             # <<<<<<<<<<<<<<
 *         bus_type: BusType = BusType.SESSION,
 *         ProxyObject: type[BaseProxyObject] | None = None,
*/
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject*)Py_None));
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k_);

      /* "dbus_fast/message_bus.py":131
 *         bus_address: str | None = None,
 *         bus_type: BusType = BusType.SESSION,
 *         ProxyObject: type[BaseProxyObject] | None = None,             # <<<<<<<<<<<<<<
 *         negotiate_unix_fd: bool = False,
 *     ) -> None:
*/
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_VARARGS(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 127, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_VARARGS(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 127, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 127, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 127, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }

      /* "dbus_fast/message_bus.py":129
 *     def __init__(
 *         self,
 *         bus_address: str | None = None,             # <<<<<<<<<<<<<<
 *         bus_type: BusType = BusType.SESSION,
 *         ProxyObject: type[BaseProxyObject] | None = None,
*/
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject*)Py_None));
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k_);

      /* "dbus_fast/message_bus.py":131
 *         bus_address: str | None = None,
 *         bus_type: BusType = BusType.SESSION,
 *         ProxyObject: type[BaseProxyObject] | None = None,             # <<<<<<<<<<<<<<
 *         negotiate_unix_fd: bool = False,
 *     ) -> None:
*/
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_bus_address = ((PyObject*)values[0]);
    __pyx_v_bus_type = values[1];
    __pyx_v_ProxyObject = values[2];
    if (values[3]) {
      __pyx_v_negotiate_unix_fd = __Pyx_PyObject_IsTrue(values[3]); if (unlikely((__pyx_v_negotiate_unix_fd == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 132, __pyx_L3_error)
    } else {

      /* "dbus_fast/message_bus.py":132
 *         bus_type: BusType = BusType.SESSION,
 *         ProxyObject: type[BaseProxyObject] | None = None,
 *         negotiate_unix_fd: bool = False,             # <<<<<<<<<<<<<<
 *     ) -> None:
 *         self.unique_name: str | None = None
*/
      __pyx_v_negotiate_unix_fd = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 4, __pyx_nargs); __PYX_ERR(0, 127, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_bus_address), (&PyUnicode_Type), 1, "bus_address", 2))) __PYX_ERR(0, 129, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus___init__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_bus_address, __pyx_v_bus_type, __pyx_v_ProxyObject, __pyx_v_negotiate_unix_fd);

  /* "dbus_fast/message_bus.py":127
 *     )
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         bus_address: str | None = None,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus___init__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_bus_address, PyObject *__pyx_v_bus_type, PyObject *__pyx_v_ProxyObject, int __pyx_v_negotiate_unix_fd) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "dbus_fast/message_bus.py":134
 *         negotiate_unix_fd: bool = False,
 *     ) -> None:
 *         self.unique_name: str | None = None             # <<<<<<<<<<<<<<
 *         self._disconnected = False
 *         self._negotiate_unix_fd = negotiate_unix_fd
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->unique_name);
  __Pyx_DECREF(__pyx_v_self->unique_name);
  __pyx_v_self->unique_name = Py_None;

  /* "dbus_fast/message_bus.py":135
 *     ) -> None:
 *         self.unique_name: str | None = None
 *         self._disconnected = False             # <<<<<<<<<<<<<<
 *         self._negotiate_unix_fd = negotiate_unix_fd
 * 
*/
  __pyx_v_self->_disconnected = 0;

  /* "dbus_fast/message_bus.py":136
 *         self.unique_name: str | None = None
 *         self._disconnected = False
 *         self._negotiate_unix_fd = negotiate_unix_fd             # <<<<<<<<<<<<<<
 * 
 *         # True if the user disconnected himself, so don't throw errors out of
*/
  __pyx_v_self->_negotiate_unix_fd = __pyx_v_negotiate_unix_fd;

  /* "dbus_fast/message_bus.py":140
 *         # True if the user disconnected himself, so don't throw errors out of
 *         # the main loop.
 *         self._user_disconnect = False             # <<<<<<<<<<<<<<
 * 
 *         self._method_return_handlers: dict[
*/
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  __Pyx_GOTREF(__pyx_v_self->_user_disconnect);
  __Pyx_DECREF(__pyx_v_self->_user_disconnect);
  __pyx_v_self->_user_disconnect = Py_False;

  /* "dbus_fast/message_bus.py":144
 *         self._method_return_handlers: dict[
 *             int, Callable[[Message | None, Exception | None], None]
 *         ] = {}             # <<<<<<<<<<<<<<
 *         self._serial = 0
 *         self._user_message_handlers: list[
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "dbus_fast/message_bus.py":142
 *         self._user_disconnect = False
 * 
 *         self._method_return_handlers: dict[             # <<<<<<<<<<<<<<
 *             int, Callable[[Message | None, Exception | None], None]
 *         ] = {}
*/
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_method_return_handlers);
  __Pyx_DECREF(__pyx_v_self->_method_return_handlers);
  __pyx_v_self->_method_return_handlers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":145
 *             int, Callable[[Message | None, Exception | None], None]
 *         ] = {}
 *         self._serial = 0             # <<<<<<<<<<<<<<
 *         self._user_message_handlers: list[
 *             Callable[[Message], Message | bool | None]
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_0);
  __Pyx_GOTREF(__pyx_v_self->_serial);
  __Pyx_DECREF(__pyx_v_self->_serial);
  __pyx_v_self->_serial = __pyx_mstate_global->__pyx_int_0;

  /* "dbus_fast/message_bus.py":148
 *         self._user_message_handlers: list[
 *             Callable[[Message], Message | bool | None]
 *         ] = []             # <<<<<<<<<<<<<<
 *         # the key is the name and the value is the unique name of the owner.
 *         # This cache is kept up to date by the NameOwnerChanged signal and is
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "dbus_fast/message_bus.py":146
 *         ] = {}
 *         self._serial = 0
 *         self._user_message_handlers: list[             # <<<<<<<<<<<<<<
 *             Callable[[Message], Message | bool | None]
 *         ] = []
*/
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_user_message_handlers);
  __Pyx_DECREF(__pyx_v_self->_user_message_handlers);
  __pyx_v_self->_user_message_handlers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":153
 *         # used to route messages to the correct proxy object. (used for the
 *         # high level client only)
 *         self._name_owners: dict[str, str] = {}             # <<<<<<<<<<<<<<
 *         # used for the high level service
 *         self._path_exports: dict[str, dict[str, ServiceInterface]] = {}
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_name_owners);
  __Pyx_DECREF(__pyx_v_self->_name_owners);
  __pyx_v_self->_name_owners = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":155
 *         self._name_owners: dict[str, str] = {}
 *         # used for the high level service
 *         self._path_exports: dict[str, dict[str, ServiceInterface]] = {}             # <<<<<<<<<<<<<<
 *         self._bus_address = (
 *             parse_address(bus_address)
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_path_exports);
  __Pyx_DECREF(__pyx_v_self->_path_exports);
  __pyx_v_self->_path_exports = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":158
 *         self._bus_address = (
 *             parse_address(bus_address)
 *             if bus_address             # <<<<<<<<<<<<<<
 *             else parse_address(get_bus_address(bus_type))
 *         )
*/
  if (__pyx_v_bus_address == Py_None) __pyx_t_2 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyUnicode_IS_TRUE(__pyx_v_bus_address);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 158, __pyx_L1_error)
    __pyx_t_2 = (__pyx_temp != 0);
  }

  if (__pyx_t_2) {

    /* "dbus_fast/message_bus.py":157
 *         self._path_exports: dict[str, dict[str, ServiceInterface]] = {}
 *         self._bus_address = (
 *             parse_address(bus_address)             # <<<<<<<<<<<<<<
 *             if bus_address
 *             else parse_address(get_bus_address(bus_type))
*/
    __pyx_t_3 = __pyx_f_9dbus_fast_8_private_7address_parse_address(__pyx_v_bus_address, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 157, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {

    /* "dbus_fast/message_bus.py":159
 *             parse_address(bus_address)
 *             if bus_address
 *             else parse_address(get_bus_address(bus_type))             # <<<<<<<<<<<<<<
 *         )
 *         # the bus implementations need this rule for the high level client to
*/
    __pyx_t_3 = __pyx_f_9dbus_fast_8_private_7address_get_bus_address(__pyx_v_bus_type, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_3))) __PYX_ERR(0, 159, __pyx_L1_error)
    __pyx_t_4 = __pyx_f_9dbus_fast_8_private_7address_parse_address(((PyObject*)__pyx_t_3), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __pyx_t_4;
    __pyx_t_4 = 0;
  }

  /* "dbus_fast/message_bus.py":156
 *         # used for the high level service
 *         self._path_exports: dict[str, dict[str, ServiceInterface]] = {}
 *         self._bus_address = (             # <<<<<<<<<<<<<<
 *             parse_address(bus_address)
 *             if bus_address
*/
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_bus_address);
  __Pyx_DECREF(__pyx_v_self->_bus_address);
  __pyx_v_self->_bus_address = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":163
 *         # the bus implementations need this rule for the high level client to
 *         # work correctly.
 *         self._name_owner_match_rule = "sender='org.freedesktop.DBus',interface='org.freedesktop.DBus',path='/org/freedesktop/DBus',member='NameOwnerChanged'"             # <<<<<<<<<<<<<<
 *         # _match_rules: the keys are match rules and the values are ref counts
 *         # (used for the high level client only)
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u_sender_org_freedesktop_DBus_inte);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_kp_u_sender_org_freedesktop_DBus_inte);
  __Pyx_GOTREF(__pyx_v_self->_name_owner_match_rule);
  __Pyx_DECREF(__pyx_v_self->_name_owner_match_rule);
  __pyx_v_self->_name_owner_match_rule = __pyx_mstate_global->__pyx_kp_u_sender_org_freedesktop_DBus_inte;

  /* "dbus_fast/message_bus.py":166
 *         # _match_rules: the keys are match rules and the values are ref counts
 *         # (used for the high level client only)
 *         self._match_rules: dict[str, int] = {}             # <<<<<<<<<<<<<<
 *         self._high_level_client_initialized = False
 *         self._ProxyObject = ProxyObject
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_match_rules);
  __Pyx_DECREF(__pyx_v_self->_match_rules);
  __pyx_v_self->_match_rules = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":167
 *         # (used for the high level client only)
 *         self._match_rules: dict[str, int] = {}
 *         self._high_level_client_initialized = False             # <<<<<<<<<<<<<<
 *         self._ProxyObject = ProxyObject
 * 
*/
  __Pyx_INCREF(Py_False);
  __Pyx_GIVEREF(Py_False);
  __Pyx_GOTREF(__pyx_v_self->_high_level_client_initialized);
  __Pyx_DECREF(__pyx_v_self->_high_level_client_initialized);
  __pyx_v_self->_high_level_client_initialized = Py_False;

  /* "dbus_fast/message_bus.py":168
 *         self._match_rules: dict[str, int] = {}
 *         self._high_level_client_initialized = False
 *         self._ProxyObject = ProxyObject             # <<<<<<<<<<<<<<
 * 
 *         # machine id is lazy loaded
*/
  __Pyx_INCREF(__pyx_v_ProxyObject);
  __Pyx_GIVEREF(__pyx_v_ProxyObject);
  __Pyx_GOTREF(__pyx_v_self->_ProxyObject);
  __Pyx_DECREF(__pyx_v_self->_ProxyObject);
  __pyx_v_self->_ProxyObject = __pyx_v_ProxyObject;

  /* "dbus_fast/message_bus.py":171
 * 
 *         # machine id is lazy loaded
 *         self._machine_id: int | None = None             # <<<<<<<<<<<<<<
 *         self._sock: socket.socket | None = None
 *         self._fd: int | None = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_machine_id);
  __Pyx_DECREF(__pyx_v_self->_machine_id);
  __pyx_v_self->_machine_id = Py_None;

  /* "dbus_fast/message_bus.py":172
 *         # machine id is lazy loaded
 *         self._machine_id: int | None = None
 *         self._sock: socket.socket | None = None             # <<<<<<<<<<<<<<
 *         self._fd: int | None = None
 *         self._stream: io.BufferedRWPair | None = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_sock);
  __Pyx_DECREF(__pyx_v_self->_sock);
  __pyx_v_self->_sock = Py_None;

  /* "dbus_fast/message_bus.py":173
 *         self._machine_id: int | None = None
 *         self._sock: socket.socket | None = None
 *         self._fd: int | None = None             # <<<<<<<<<<<<<<
 *         self._stream: io.BufferedRWPair | None = None
 * 
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_fd);
  __Pyx_DECREF(__pyx_v_self->_fd);
  __pyx_v_self->_fd = Py_None;

  /* "dbus_fast/message_bus.py":174
 *         self._sock: socket.socket | None = None
 *         self._fd: int | None = None
 *         self._stream: io.BufferedRWPair | None = None             # <<<<<<<<<<<<<<
 * 
 *         self._setup_socket()
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_stream);
  __Pyx_DECREF(__pyx_v_self->_stream);
  __pyx_v_self->_stream = Py_None;

  /* "dbus_fast/message_bus.py":176
 *         self._stream: io.BufferedRWPair | None = None
 * 
 *         self._setup_socket()             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self->__pyx_vtab)->_setup_socket(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":127
 *     )
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         bus_address: str | None = None,
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":178
 *         self._setup_socket()
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def connected(self) -> bool:
 *         if self.unique_name is None or self._disconnected or self._user_disconnect:
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_9connected_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_9connected_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_9connected___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_9connected___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "dbus_fast/message_bus.py":180
 *     @property
 *     def connected(self) -> bool:
 *         if self.unique_name is None or self._disconnected or self._user_disconnect:             # <<<<<<<<<<<<<<
 *             return False
 *         return True
*/
  __pyx_t_2 = (__pyx_v_self->unique_name == Py_None);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  if (!__pyx_v_self->_disconnected) {
  } else {
    __pyx_t_1 = __pyx_v_self->_disconnected;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->_user_disconnect); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 180, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":181
 *     def connected(self) -> bool:
 *         if self.unique_name is None or self._disconnected or self._user_disconnect:
 *             return False             # <<<<<<<<<<<<<<
 *         return True
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":180
 *     @property
 *     def connected(self) -> bool:
 *         if self.unique_name is None or self._disconnected or self._user_disconnect:             # <<<<<<<<<<<<<<
 *             return False
 *         return True
*/
  }

  /* "dbus_fast/message_bus.py":182
 *         if self.unique_name is None or self._disconnected or self._user_disconnect:
 *             return False
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     def export(self, path: str, interface: ServiceInterface) -> None:
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "dbus_fast/message_bus.py":178
 *         self._setup_socket()
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def connected(self) -> bool:
 *         if self.unique_name is None or self._disconnected or self._user_disconnect:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.connected.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":184
 *         return True
 * 
 *     def export(self, path: str, interface: ServiceInterface) -> None:             # <<<<<<<<<<<<<<
 *         """Export the service interface on this message bus to make it available
 *         to other clients.
*/

static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3export(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus_export(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_path, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8[5];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("export", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_export); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3export)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_path, ((PyObject *)__pyx_v_interface)};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 184, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "dbus_fast/message_bus.py":198
 *             - :class:`ValueError` - If an interface with this name is already exported on the message bus at this path
 *         """
 *         assert_object_path_valid(path)             # <<<<<<<<<<<<<<
 *         if not isinstance(interface, ServiceInterface):
 *             raise TypeError("interface must be a ServiceInterface")
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_assert_object_path_valid);
  __pyx_t_4 = __pyx_v_9dbus_fast_11message_bus_assert_object_path_valid; 
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_path};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":199
 *         """
 *         assert_object_path_valid(path)
 *         if not isinstance(interface, ServiceInterface):             # <<<<<<<<<<<<<<
 *             raise TypeError("interface must be a ServiceInterface")
 * 
*/
  __pyx_t_6 = __Pyx_TypeCheck(((PyObject *)__pyx_v_interface), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface); 
  __pyx_t_7 = (!__pyx_t_6);
  if (unlikely(__pyx_t_7)) {

    /* "dbus_fast/message_bus.py":200
 *         assert_object_path_valid(path)
 *         if not isinstance(interface, ServiceInterface):
 *             raise TypeError("interface must be a ServiceInterface")             # <<<<<<<<<<<<<<
 * 
 *         if path not in self._path_exports:
*/
    __pyx_t_4 = NULL;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_interface_must_be_a_ServiceInter};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 200, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 200, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":199
 *         """
 *         assert_object_path_valid(path)
 *         if not isinstance(interface, ServiceInterface):             # <<<<<<<<<<<<<<
 *             raise TypeError("interface must be a ServiceInterface")
 * 
*/
  }

  /* "dbus_fast/message_bus.py":202
 *             raise TypeError("interface must be a ServiceInterface")
 * 
 *         if path not in self._path_exports:             # <<<<<<<<<<<<<<
 *             self._path_exports[path] = {}
 *         elif interface.name in self._path_exports[path]:
*/
  if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 202, __pyx_L1_error)
  }
  __pyx_t_7 = (__Pyx_PyDict_ContainsTF(__pyx_v_path, __pyx_v_self->_path_exports, Py_NE)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 202, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "dbus_fast/message_bus.py":203
 * 
 *         if path not in self._path_exports:
 *             self._path_exports[path] = {}             # <<<<<<<<<<<<<<
 *         elif interface.name in self._path_exports[path]:
 *             raise ValueError(
*/
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 203, __pyx_L1_error)
    }
    if (unlikely((PyDict_SetItem(__pyx_v_self->_path_exports, __pyx_v_path, __pyx_t_1) < 0))) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":202
 *             raise TypeError("interface must be a ServiceInterface")
 * 
 *         if path not in self._path_exports:             # <<<<<<<<<<<<<<
 *             self._path_exports[path] = {}
 *         elif interface.name in self._path_exports[path]:
*/
    goto __pyx_L4;
  }

  /* "dbus_fast/message_bus.py":204
 *         if path not in self._path_exports:
 *             self._path_exports[path] = {}
 *         elif interface.name in self._path_exports[path]:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 f'An interface with this name is already exported on this bus at path "{path}": "{interface.name}"'
*/
  if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 204, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->_path_exports, __pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_v_interface->name, __pyx_t_1, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(__pyx_t_7)) {

    /* "dbus_fast/message_bus.py":205
 *             self._path_exports[path] = {}
 *         elif interface.name in self._path_exports[path]:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 f'An interface with this name is already exported on this bus at path "{path}": "{interface.name}"'
 *             )
*/
    __pyx_t_4 = NULL;

    /* "dbus_fast/message_bus.py":206
 *         elif interface.name in self._path_exports[path]:
 *             raise ValueError(
 *                 f'An interface with this name is already exported on this bus at path "{path}": "{interface.name}"'             # <<<<<<<<<<<<<<
 *             )
 * 
*/
    __pyx_t_2 = __Pyx_PyUnicode_Unicode(__pyx_v_interface->name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8[0] = __pyx_mstate_global->__pyx_kp_u_An_interface_with_this_name_is_a;
    __pyx_t_8[1] = __pyx_v_path;
    __pyx_t_8[2] = __pyx_mstate_global->__pyx_kp_u__2;
    __pyx_t_8[3] = __pyx_t_2;
    __pyx_t_8[4] = __pyx_mstate_global->__pyx_kp_u__3;
    __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_8, 5, 69 + __Pyx_PyUnicode_GET_LENGTH(__pyx_v_path) + 4 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_v_path) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2));
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 205, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 205, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":204
 *         if path not in self._path_exports:
 *             self._path_exports[path] = {}
 *         elif interface.name in self._path_exports[path]:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 f'An interface with this name is already exported on this bus at path "{path}": "{interface.name}"'
*/
  }
  __pyx_L4:;

  /* "dbus_fast/message_bus.py":209
 *             )
 * 
 *         ServiceInterface._add_bus(interface, self, self._make_method_handler)             # <<<<<<<<<<<<<<
 *         self._path_exports[path][interface.name] = interface
 *         self._emit_interface_added(path, interface)
*/
  __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_make_method_handler); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, ((PyObject *)__pyx_v_interface), ((PyObject *)__pyx_v_self), __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_add_bus, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":210
 * 
 *         ServiceInterface._add_bus(interface, self, self._make_method_handler)
 *         self._path_exports[path][interface.name] = interface             # <<<<<<<<<<<<<<
 *         self._emit_interface_added(path, interface)
 * 
*/
  if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 210, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->_path_exports, __pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_interface->name, ((PyObject *)__pyx_v_interface)) < 0))) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":211
 *         ServiceInterface._add_bus(interface, self, self._make_method_handler)
 *         self._path_exports[path][interface.name] = interface
 *         self._emit_interface_added(path, interface)             # <<<<<<<<<<<<<<
 * 
 *     def unexport(
*/
  __pyx_t_4 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_path, ((PyObject *)__pyx_v_interface)};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_emit_interface_added, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":184
 *         return True
 * 
 *     def export(self, path: str, interface: ServiceInterface) -> None:             # <<<<<<<<<<<<<<
 *         """Export the service interface on this message bus to make it available
 *         to other clients.
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.export", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3export(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_2export, "Export the service interface on this message bus to make it available\n        to other clients.\n\n        :param path: The object path to export this interface on.\n        :type path: str\n        :param interface: The service interface to export.\n        :type interface: :class:`ServiceInterface\n            <dbus_fast.service.ServiceInterface>`\n\n        :raises:\n            - :class:`InvalidObjectPathError <dbus_fast.InvalidObjectPathError>` - If the given object path is not valid.\n            - :class:`ValueError` - If an interface with this name is already exported on the message bus at this path\n        ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_3export = {"export", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3export, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_2export};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3export(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_path = 0;
  struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("export (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_path,&__pyx_mstate_global->__pyx_n_u_interface,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 184, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 184, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 184, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "export", 0) < (0)) __PYX_ERR(0, 184, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("export", 1, 2, 2, i); __PYX_ERR(0, 184, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 184, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 184, __pyx_L3_error)
    }
    __pyx_v_path = ((PyObject*)values[0]);
    __pyx_v_interface = ((struct __pyx_obj_9dbus_fast_7service_ServiceInterface *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("export", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 184, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.export", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_path), (&PyUnicode_Type), 0, "path", 2))) __PYX_ERR(0, 184, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_interface), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface, 0, "interface", 0))) __PYX_ERR(0, 184, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_2export(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_path, __pyx_v_interface);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_2export(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_path, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("export", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9dbus_fast_11message_bus_14BaseMessageBus_export(__pyx_v_self, __pyx_v_path, __pyx_v_interface, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.export", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":213
 *         self._emit_interface_added(path, interface)
 * 
 *     def unexport(             # <<<<<<<<<<<<<<
 *         self, path: str, interface: ServiceInterface | str | None = None
 *     ) -> None:
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_5unexport(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_4unexport, "Unexport the path or service interface to make it no longer\n        available to clients.\n\n        :param path: The object path to unexport.\n        :type path: str\n        :param interface: The interface instance or the name of the interface\n            to unexport. If ``None``, unexport every interface on the path.\n        :type interface: :class:`ServiceInterface\n            <dbus_fast.service.ServiceInterface>` or str or None\n\n        :raises:\n            - :class:`InvalidObjectPathError <dbus_fast.InvalidObjectPathError>` - If the given object path is not valid.\n        ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_5unexport = {"unexport", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_5unexport, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_4unexport};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_5unexport(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_interface = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unexport (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_path,&__pyx_mstate_global->__pyx_n_u_interface,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 213, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 213, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 213, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "unexport", 0) < (0)) __PYX_ERR(0, 213, __pyx_L3_error)

      /* "dbus_fast/message_bus.py":214
 * 
 *     def unexport(
 *         self, path: str, interface: ServiceInterface | str | None = None             # <<<<<<<<<<<<<<
 *     ) -> None:
 *         """Unexport the path or service interface to make it no longer
*/
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("unexport", 0, 1, 2, i); __PYX_ERR(0, 213, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 213, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 213, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_path = ((PyObject*)values[0]);
    __pyx_v_interface = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unexport", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 213, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.unexport", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_path), (&PyUnicode_Type), 0, "path", 2))) __PYX_ERR(0, 214, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_4unexport(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_path, __pyx_v_interface);

  /* "dbus_fast/message_bus.py":213
 *         self._emit_interface_added(path, interface)
 * 
 *     def unexport(             # <<<<<<<<<<<<<<
 *         self, path: str, interface: ServiceInterface | str | None = None
 *     ) -> None:
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_4unexport(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_interface) {
  PyObject *__pyx_v_interface_name = 0;
  PyObject *__pyx_v_removed_interface_names = 0;
  PyObject *__pyx_v_removed_interface = NULL;
  PyObject *__pyx_v_interfaces = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unexport", 0);

  /* "dbus_fast/message_bus.py":229
 *             - :class:`InvalidObjectPathError <dbus_fast.InvalidObjectPathError>` - If the given object path is not valid.
 *         """
 *         assert_object_path_valid(path)             # <<<<<<<<<<<<<<
 *         interface_name: str | None
 *         if interface is None:
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_assert_object_path_valid);
  __pyx_t_3 = __pyx_v_9dbus_fast_11message_bus_assert_object_path_valid; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_path};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":231
 *         assert_object_path_valid(path)
 *         interface_name: str | None
 *         if interface is None:             # <<<<<<<<<<<<<<
 *             interface_name = None
 *         elif type(interface) is str:
*/
  __pyx_t_5 = (__pyx_v_interface == Py_None);
  if (__pyx_t_5) {

    /* "dbus_fast/message_bus.py":232
 *         interface_name: str | None
 *         if interface is None:
 *             interface_name = None             # <<<<<<<<<<<<<<
 *         elif type(interface) is str:
 *             interface_name = interface
*/
    __Pyx_INCREF(Py_None);
    __pyx_v_interface_name = ((PyObject*)Py_None);

    /* "dbus_fast/message_bus.py":231
 *         assert_object_path_valid(path)
 *         interface_name: str | None
 *         if interface is None:             # <<<<<<<<<<<<<<
 *             interface_name = None
 *         elif type(interface) is str:
*/
    goto __pyx_L3;
  }

  /* "dbus_fast/message_bus.py":233
 *         if interface is None:
 *             interface_name = None
 *         elif type(interface) is str:             # <<<<<<<<<<<<<<
 *             interface_name = interface
 *         elif isinstance(interface, ServiceInterface):
*/
  __pyx_t_5 = (((PyObject *)Py_TYPE(__pyx_v_interface)) == ((PyObject *)(&PyUnicode_Type)));
  if (__pyx_t_5) {

    /* "dbus_fast/message_bus.py":234
 *             interface_name = None
 *         elif type(interface) is str:
 *             interface_name = interface             # <<<<<<<<<<<<<<
 *         elif isinstance(interface, ServiceInterface):
 *             interface_name = interface.name
*/
    __pyx_t_1 = __pyx_v_interface;
    __Pyx_INCREF(__pyx_t_1);
    if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_1))) __PYX_ERR(0, 234, __pyx_L1_error)
    __pyx_v_interface_name = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":233
 *         if interface is None:
 *             interface_name = None
 *         elif type(interface) is str:             # <<<<<<<<<<<<<<
 *             interface_name = interface
 *         elif isinstance(interface, ServiceInterface):
*/
    goto __pyx_L3;
  }

  /* "dbus_fast/message_bus.py":235
 *         elif type(interface) is str:
 *             interface_name = interface
 *         elif isinstance(interface, ServiceInterface):             # <<<<<<<<<<<<<<
 *             interface_name = interface.name
 *         else:
*/
  __pyx_t_5 = __Pyx_TypeCheck(__pyx_v_interface, __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface); 
  if (likely(__pyx_t_5)) {

    /* "dbus_fast/message_bus.py":236
 *             interface_name = interface
 *         elif isinstance(interface, ServiceInterface):
 *             interface_name = interface.name             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError(
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_interface, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_1))) __PYX_ERR(0, 236, __pyx_L1_error)
    __pyx_v_interface_name = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":235
 *         elif type(interface) is str:
 *             interface_name = interface
 *         elif isinstance(interface, ServiceInterface):             # <<<<<<<<<<<<<<
 *             interface_name = interface.name
 *         else:
*/
    goto __pyx_L3;
  }

  /* "dbus_fast/message_bus.py":238
 *             interface_name = interface.name
 *         else:
 *             raise TypeError(             # <<<<<<<<<<<<<<
 *                 f"interface must be a ServiceInterface or interface name not {type(interface)}"
 *             )
*/
  /*else*/ {
    __pyx_t_3 = NULL;

    /* "dbus_fast/message_bus.py":239
 *         else:
 *             raise TypeError(
 *                 f"interface must be a ServiceInterface or interface name not {type(interface)}"             # <<<<<<<<<<<<<<
 *             )
 * 
*/
    __pyx_t_2 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_interface)), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_interface_must_be_a_ServiceInter_2, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_6};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 238, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 238, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "dbus_fast/message_bus.py":242
 *             )
 * 
 *         if (interfaces := self._path_exports.get(path)) is None:             # <<<<<<<<<<<<<<
 *             return
 *         removed_interface_names: list[str] = []
*/
  if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
    __PYX_ERR(0, 242, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_self->_path_exports, __pyx_v_path, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_interfaces = __pyx_t_1;
  __pyx_t_5 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "dbus_fast/message_bus.py":243
 * 
 *         if (interfaces := self._path_exports.get(path)) is None:
 *             return             # <<<<<<<<<<<<<<
 *         removed_interface_names: list[str] = []
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":242
 *             )
 * 
 *         if (interfaces := self._path_exports.get(path)) is None:             # <<<<<<<<<<<<<<
 *             return
 *         removed_interface_names: list[str] = []
*/
  }

  /* "dbus_fast/message_bus.py":244
 *         if (interfaces := self._path_exports.get(path)) is None:
 *             return
 *         removed_interface_names: list[str] = []             # <<<<<<<<<<<<<<
 * 
 *         if interface_name is not None:
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_removed_interface_names = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":246
 *         removed_interface_names: list[str] = []
 * 
 *         if interface_name is not None:             # <<<<<<<<<<<<<<
 *             if (removed_interface := interfaces.pop(interface_name, None)) is None:
 *                 return
*/
  __pyx_t_5 = (__pyx_v_interface_name != ((PyObject*)Py_None));
  if (__pyx_t_5) {

    /* "dbus_fast/message_bus.py":247
 * 
 *         if interface_name is not None:
 *             if (removed_interface := interfaces.pop(interface_name, None)) is None:             # <<<<<<<<<<<<<<
 *                 return
 *             removed_interface_names.append(interface_name)
*/
    __pyx_t_6 = __pyx_v_interfaces;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_interface_name, Py_None};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_pop, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_removed_interface = __pyx_t_1;
    __pyx_t_5 = (__pyx_t_1 == Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_5) {

      /* "dbus_fast/message_bus.py":248
 *         if interface_name is not None:
 *             if (removed_interface := interfaces.pop(interface_name, None)) is None:
 *                 return             # <<<<<<<<<<<<<<
 *             removed_interface_names.append(interface_name)
 *             if not interfaces:
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "dbus_fast/message_bus.py":247
 * 
 *         if interface_name is not None:
 *             if (removed_interface := interfaces.pop(interface_name, None)) is None:             # <<<<<<<<<<<<<<
 *                 return
 *             removed_interface_names.append(interface_name)
*/
    }

    /* "dbus_fast/message_bus.py":249
 *             if (removed_interface := interfaces.pop(interface_name, None)) is None:
 *                 return
 *             removed_interface_names.append(interface_name)             # <<<<<<<<<<<<<<
 *             if not interfaces:
 *                 del self._path_exports[path]
*/
    __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_removed_interface_names, __pyx_v_interface_name); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 249, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":250
 *                 return
 *             removed_interface_names.append(interface_name)
 *             if not interfaces:             # <<<<<<<<<<<<<<
 *                 del self._path_exports[path]
 *             ServiceInterface._remove_bus(removed_interface, self)
*/
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_interfaces); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 250, __pyx_L1_error)
    __pyx_t_8 = (!__pyx_t_5);
    if (__pyx_t_8) {

      /* "dbus_fast/message_bus.py":251
 *             removed_interface_names.append(interface_name)
 *             if not interfaces:
 *                 del self._path_exports[path]             # <<<<<<<<<<<<<<
 *             ServiceInterface._remove_bus(removed_interface, self)
 *         else:
*/
      if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 251, __pyx_L1_error)
      }
      if (unlikely((PyDict_DelItem(__pyx_v_self->_path_exports, __pyx_v_path) < 0))) __PYX_ERR(0, 251, __pyx_L1_error)

      /* "dbus_fast/message_bus.py":250
 *                 return
 *             removed_interface_names.append(interface_name)
 *             if not interfaces:             # <<<<<<<<<<<<<<
 *                 del self._path_exports[path]
 *             ServiceInterface._remove_bus(removed_interface, self)
*/
    }

    /* "dbus_fast/message_bus.py":252
 *             if not interfaces:
 *                 del self._path_exports[path]
 *             ServiceInterface._remove_bus(removed_interface, self)             # <<<<<<<<<<<<<<
 *         else:
 *             del self._path_exports[path]
*/
    __pyx_t_6 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_removed_interface, ((PyObject *)__pyx_v_self)};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_remove_bus, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 252, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":246
 *         removed_interface_names: list[str] = []
 * 
 *         if interface_name is not None:             # <<<<<<<<<<<<<<
 *             if (removed_interface := interfaces.pop(interface_name, None)) is None:
 *                 return
*/
    goto __pyx_L5;
  }

  /* "dbus_fast/message_bus.py":254
 *             ServiceInterface._remove_bus(removed_interface, self)
 *         else:
 *             del self._path_exports[path]             # <<<<<<<<<<<<<<
 *             for removed_interface in interfaces.values():
 *                 removed_interface_names.append(removed_interface.name)
*/
  /*else*/ {
    if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 254, __pyx_L1_error)
    }
    if (unlikely((PyDict_DelItem(__pyx_v_self->_path_exports, __pyx_v_path) < 0))) __PYX_ERR(0, 254, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":255
 *         else:
 *             del self._path_exports[path]
 *             for removed_interface in interfaces.values():             # <<<<<<<<<<<<<<
 *                 removed_interface_names.append(removed_interface.name)
 *                 ServiceInterface._remove_bus(removed_interface, self)
*/
    __pyx_t_9 = 0;
    if (unlikely(__pyx_v_interfaces == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
      __PYX_ERR(0, 255, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_dict_iterator(__pyx_v_interfaces, 0, __pyx_mstate_global->__pyx_n_u_values, (&__pyx_t_10), (&__pyx_t_11)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1);
    __pyx_t_1 = __pyx_t_6;
    __pyx_t_6 = 0;
    while (1) {
      __pyx_t_12 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_10, &__pyx_t_9, NULL, &__pyx_t_6, NULL, __pyx_t_11);
      if (unlikely(__pyx_t_12 == 0)) break;
      if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 255, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_XDECREF_SET(__pyx_v_removed_interface, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "dbus_fast/message_bus.py":256
 *             del self._path_exports[path]
 *             for removed_interface in interfaces.values():
 *                 removed_interface_names.append(removed_interface.name)             # <<<<<<<<<<<<<<
 *                 ServiceInterface._remove_bus(removed_interface, self)
 * 
*/
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_removed_interface, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 256, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_removed_interface_names, __pyx_t_6); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 256, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "dbus_fast/message_bus.py":257
 *             for removed_interface in interfaces.values():
 *                 removed_interface_names.append(removed_interface.name)
 *                 ServiceInterface._remove_bus(removed_interface, self)             # <<<<<<<<<<<<<<
 * 
 *         self._emit_interface_removed(path, removed_interface_names)
*/
      __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_removed_interface, ((PyObject *)__pyx_v_self)};
        __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_remove_bus, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 257, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L5:;

  /* "dbus_fast/message_bus.py":259
 *                 ServiceInterface._remove_bus(removed_interface, self)
 * 
 *         self._emit_interface_removed(path, removed_interface_names)             # <<<<<<<<<<<<<<
 * 
 *     def introspect(
*/
  __pyx_t_6 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_path, __pyx_v_removed_interface_names};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_emit_interface_removed, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":213
 *         self._emit_interface_added(path, interface)
 * 
 *     def unexport(             # <<<<<<<<<<<<<<
 *         self, path: str, interface: ServiceInterface | str | None = None
 *     ) -> None:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.unexport", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_interface_name);
  __Pyx_XDECREF(__pyx_v_removed_interface_names);
  __Pyx_XDECREF(__pyx_v_removed_interface);
  __Pyx_XDECREF(__pyx_v_interfaces);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":261
 *         self._emit_interface_removed(path, removed_interface_names)
 * 
 *     def introspect(             # <<<<<<<<<<<<<<
 *         self,
 *         bus_name: str,
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7introspect(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_6introspect, "Get introspection data for the node at the given path from the given\n        bus name.\n\n        Calls the standard ``org.freedesktop.DBus.Introspectable.Introspect``\n        on the bus for the path.\n\n        :param bus_name: The name to introspect.\n        :type bus_name: str\n        :param path: The path to introspect.\n        :type path: str\n        :param callback: A callback that will be called with the introspection\n            data as a :class:`Node <dbus_fast.introspection.Node>`.\n        :type callback: :class:`Callable`\n        :param check_callback_type: Whether to check callback type or not.\n        :type check_callback_type: bool\n        :param validate_property_names: Whether to validate property names or not.\n        :type validate_property_names: bool\n\n        :raises:\n            - :class:`InvalidObjectPathError <dbus_fast.InvalidObjectPathError>` - If the given object path is not valid.\n            - :class:`InvalidBusNameError <dbus_fast.InvalidBusNameError>` - If the given bus name is not valid.\n        ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_7introspect = {"introspect", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7introspect, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_6introspect};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7introspect(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_bus_name = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_callback = 0;
  int __pyx_v_check_callback_type;
  int __pyx_v_validate_property_names;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("introspect (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_bus_name,&__pyx_mstate_global->__pyx_n_u_path,&__pyx_mstate_global->__pyx_n_u_callback,&__pyx_mstate_global->__pyx_n_u_check_callback_type,&__pyx_mstate_global->__pyx_n_u_validate_property_names,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 261, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 261, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 261, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 261, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 261, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 261, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "introspect", 0) < (0)) __PYX_ERR(0, 261, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("introspect", 0, 3, 5, i); __PYX_ERR(0, 261, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 261, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 261, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 261, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 261, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 261, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_bus_name = ((PyObject*)values[0]);
    __pyx_v_path = ((PyObject*)values[1]);
    __pyx_v_callback = values[2];
    if (values[3]) {
      __pyx_v_check_callback_type = __Pyx_PyObject_IsTrue(values[3]); if (unlikely((__pyx_v_check_callback_type == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 266, __pyx_L3_error)
    } else {

      /* "dbus_fast/message_bus.py":266
 *         path: str,
 *         callback: Callable[[intr.Node | None, Exception | None], None],
 *         check_callback_type: bool = True,             # <<<<<<<<<<<<<<
 *         validate_property_names: bool = True,
 *     ) -> None:
*/
      __pyx_v_check_callback_type = ((int)1);
    }
    if (values[4]) {
      __pyx_v_validate_property_names = __Pyx_PyObject_IsTrue(values[4]); if (unlikely((__pyx_v_validate_property_names == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 267, __pyx_L3_error)
    } else {

      /* "dbus_fast/message_bus.py":267
 *         callback: Callable[[intr.Node | None, Exception | None], None],
 *         check_callback_type: bool = True,
 *         validate_property_names: bool = True,             # <<<<<<<<<<<<<<
 *     ) -> None:
 *         """Get introspection data for the node at the given path from the given
*/
      __pyx_v_validate_property_names = ((int)1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("introspect", 0, 3, 5, __pyx_nargs); __PYX_ERR(0, 261, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.introspect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_bus_name), (&PyUnicode_Type), 0, "bus_name", 2))) __PYX_ERR(0, 263, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_path), (&PyUnicode_Type), 0, "path", 2))) __PYX_ERR(0, 264, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_6introspect(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_bus_name, __pyx_v_path, __pyx_v_callback, __pyx_v_check_callback_type, __pyx_v_validate_property_names);

  /* "dbus_fast/message_bus.py":261
 *         self._emit_interface_removed(path, removed_interface_names)
 * 
 *     def introspect(             # <<<<<<<<<<<<<<
 *         self,
 *         bus_name: str,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":294
 *             BaseMessageBus._check_callback_type(callback)
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "s")
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_10introspect_1reply_notify(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_10introspect_1reply_notify = {"reply_notify", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_10introspect_1reply_notify, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_10introspect_1reply_notify(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply = 0;
  PyObject *__pyx_v_err = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reply_notify (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_reply,&__pyx_mstate_global->__pyx_n_u_err,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 294, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 294, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 294, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "reply_notify", 0) < (0)) __PYX_ERR(0, 294, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("reply_notify", 1, 2, 2, i); __PYX_ERR(0, 294, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 294, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 294, __pyx_L3_error)
    }
    __pyx_v_reply = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_err = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("reply_notify", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 294, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.introspect.reply_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_reply), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 1, "reply", 0))) __PYX_ERR(0, 294, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 294, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_10introspect_reply_notify(__pyx_self, __pyx_v_reply, __pyx_v_err);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_10introspect_reply_notify(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply, PyObject *__pyx_v_err) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *__pyx_outer_scope;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  char const *__pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reply_notify", 0);
  __pyx_outer_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "dbus_fast/message_bus.py":295
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
 *             try:             # <<<<<<<<<<<<<<
 *                 BaseMessageBus._check_method_return(reply, err, "s")
 *                 result = intr.Node.parse(
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "dbus_fast/message_bus.py":296
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "s")             # <<<<<<<<<<<<<<
 *                 result = intr.Node.parse(
 *                     reply.body[0],  # type: ignore[union-attr]
*/
      __pyx_t_5 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_5, ((PyObject *)__pyx_v_reply), __pyx_v_err, __pyx_mstate_global->__pyx_n_u_s};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_check_method_return, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 296, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "dbus_fast/message_bus.py":297
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "s")
 *                 result = intr.Node.parse(             # <<<<<<<<<<<<<<
 *                     reply.body[0],  # type: ignore[union-attr]
 *                     validate_property_names=validate_property_names,
*/
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_intr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 297, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_Node); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 297, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_5 = __pyx_t_8;
      __Pyx_INCREF(__pyx_t_5);

      /* "dbus_fast/message_bus.py":298
 *                 BaseMessageBus._check_method_return(reply, err, "s")
 *                 result = intr.Node.parse(
 *                     reply.body[0],  # type: ignore[union-attr]             # <<<<<<<<<<<<<<
 *                     validate_property_names=validate_property_names,
 *                 )
*/
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_reply->body, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 298, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);

      /* "dbus_fast/message_bus.py":299
 *                 result = intr.Node.parse(
 *                     reply.body[0],  # type: ignore[union-attr]
 *                     validate_property_names=validate_property_names,             # <<<<<<<<<<<<<<
 *                 )
 *             except Exception as e:
*/
      __pyx_t_9 = __Pyx_PyBool_FromLong(__pyx_cur_scope->__pyx_v_validate_property_names); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 299, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_5, __pyx_t_7};
        __pyx_t_10 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 297, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_validate_property_names, __pyx_t_9, __pyx_t_10, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 297, __pyx_L3_error)
        __pyx_t_4 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_parse, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 297, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_v_result = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "dbus_fast/message_bus.py":295
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
 *             try:             # <<<<<<<<<<<<<<
 *                 BaseMessageBus._check_method_return(reply, err, "s")
 *                 result = intr.Node.parse(
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "dbus_fast/message_bus.py":301
 *                     validate_property_names=validate_property_names,
 *                 )
 *             except Exception as e:             # <<<<<<<<<<<<<<
 *                 callback(None, e)
 *                 return
*/
    __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
    if (__pyx_t_11) {
      __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.introspect.reply_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_10) < 0) __PYX_ERR(0, 301, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_8);
      __pyx_v_e = __pyx_t_8;
      /*try:*/ {

        /* "dbus_fast/message_bus.py":302
 *                 )
 *             except Exception as e:
 *                 callback(None, e)             # <<<<<<<<<<<<<<
 *                 return
 * 
*/
        __pyx_t_7 = NULL;
        if (unlikely(!__pyx_cur_scope->__pyx_v_callback)) { __Pyx_RaiseClosureNameError("callback"); __PYX_ERR(0, 302, __pyx_L14_error) }
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_callback);
        __pyx_t_5 = __pyx_cur_scope->__pyx_v_callback; 
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
          assert(__pyx_t_7);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_7, Py_None, __pyx_v_e};
          __pyx_t_9 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 302, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_9);
        }
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "dbus_fast/message_bus.py":303
 *             except Exception as e:
 *                 callback(None, e)
 *                 return             # <<<<<<<<<<<<<<
 * 
 *             callback(result, None)
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L13_return;
      }

      /* "dbus_fast/message_bus.py":301
 *                     validate_property_names=validate_property_names,
 *                 )
 *             except Exception as e:             # <<<<<<<<<<<<<<
 *                 callback(None, e)
 *                 return
*/
      /*finally:*/ {
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
          if ( unlikely(__Pyx_GetException(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __pyx_t_11 = __pyx_lineno; __pyx_t_12 = __pyx_clineno; __pyx_t_13 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_ErrRestore(__pyx_t_14, __pyx_t_15, __pyx_t_16);
          __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_12; __pyx_filename = __pyx_t_13;
          goto __pyx_L5_except_error;
        }
        __pyx_L13_return: {
          __pyx_t_19 = __pyx_r;
          __pyx_r = 0;
          __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          __pyx_r = __pyx_t_19;
          __pyx_t_19 = 0;
          goto __pyx_L6_except_return;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "dbus_fast/message_bus.py":295
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
 *             try:             # <<<<<<<<<<<<<<
 *                 BaseMessageBus._check_method_return(reply, err, "s")
 *                 result = intr.Node.parse(
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "dbus_fast/message_bus.py":305
 *                 return
 * 
 *             callback(result, None)             # <<<<<<<<<<<<<<
 * 
 *         self._call(
*/
  __pyx_t_8 = NULL;
  if (unlikely(!__pyx_cur_scope->__pyx_v_callback)) { __Pyx_RaiseClosureNameError("callback"); __PYX_ERR(0, 305, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_callback);
  __pyx_t_4 = __pyx_cur_scope->__pyx_v_callback; 
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_8);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_8);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_result, Py_None};
    __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
  }
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "dbus_fast/message_bus.py":294
 *             BaseMessageBus._check_callback_type(callback)
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "s")
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.introspect.reply_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":261
 *         self._emit_interface_removed(path, removed_interface_names)
 * 
 *     def introspect(             # <<<<<<<<<<<<<<
 *         self,
 *         bus_name: str,
*/

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_6introspect(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_bus_name, PyObject *__pyx_v_path, PyObject *__pyx_v_callback, int __pyx_v_check_callback_type, int __pyx_v_validate_property_names) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *__pyx_cur_scope;
  PyObject *__pyx_v_reply_notify = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("introspect", 0);
  __pyx_cur_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct__introspect(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 261, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_callback = __pyx_v_callback;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_callback);
  __pyx_cur_scope->__pyx_v_validate_property_names = __pyx_v_validate_property_names;

  /* "dbus_fast/message_bus.py":291
 *             - :class:`InvalidBusNameError <dbus_fast.InvalidBusNameError>` - If the given bus name is not valid.
 *         """
 *         if check_callback_type:             # <<<<<<<<<<<<<<
 *             BaseMessageBus._check_callback_type(callback)
 * 
*/
  if (__pyx_v_check_callback_type) {

    /* "dbus_fast/message_bus.py":292
 *         """
 *         if check_callback_type:
 *             BaseMessageBus._check_callback_type(callback)             # <<<<<<<<<<<<<<
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
*/
    __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_cur_scope->__pyx_v_callback};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_check_callback_type_2, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":291
 *             - :class:`InvalidBusNameError <dbus_fast.InvalidBusNameError>` - If the given bus name is not valid.
 *         """
 *         if check_callback_type:             # <<<<<<<<<<<<<<
 *             BaseMessageBus._check_callback_type(callback)
 * 
*/
  }

  /* "dbus_fast/message_bus.py":294
 *             BaseMessageBus._check_callback_type(callback)
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "s")
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_reply, __pyx_mstate_global->__pyx_kp_u_Message_None) < (0)) __PYX_ERR(0, 294, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 294, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 294, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_10introspect_1reply_notify, 0, __pyx_mstate_global->__pyx_n_u_introspect_locals_reply_notify, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_reply_notify = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":308
 * 
 *         self._call(
 *             Message(             # <<<<<<<<<<<<<<
 *                 destination=bus_name,
 *                 path=path,
*/
  __pyx_t_1 = NULL;

  /* "dbus_fast/message_bus.py":310
 *             Message(
 *                 destination=bus_name,
 *                 path=path,             # <<<<<<<<<<<<<<
 *                 interface="org.freedesktop.DBus.Introspectable",
 *                 member="Introspect",
*/
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_1, NULL};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_destination, __pyx_v_bus_name, __pyx_t_4, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 308, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_path, __pyx_v_path, __pyx_t_4, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 308, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_Introspecta, __pyx_t_4, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 308, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_member, __pyx_mstate_global->__pyx_n_u_Introspect, __pyx_t_4, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 308, __pyx_L1_error)
    __pyx_t_2 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 308, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_2);
  }

  /* "dbus_fast/message_bus.py":307
 *             callback(result, None)
 * 
 *         self._call(             # <<<<<<<<<<<<<<
 *             Message(
 *                 destination=bus_name,
*/
  __pyx_t_4 = ((struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self->__pyx_vtab)->_call(__pyx_v_self, ((struct __pyx_obj_9dbus_fast_7message_Message *)__pyx_t_2), __pyx_v_reply_notify, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF((PyObject *)__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "dbus_fast/message_bus.py":261
 *         self._emit_interface_removed(path, removed_interface_names)
 * 
 *     def introspect(             # <<<<<<<<<<<<<<
 *         self,
 *         bus_name: str,
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.introspect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_reply_notify);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":317
 *         )
 * 
 *     def _emit_interface_added(self, path: str, interface: ServiceInterface) -> None:             # <<<<<<<<<<<<<<
 *         """Emit the ``org.freedesktop.DBus.ObjectManager.InterfacesAdded`` signal.
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_9_emit_interface_added(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_8_emit_interface_added, "Emit the ``org.freedesktop.DBus.ObjectManager.InterfacesAdded`` signal.\n\n        This signal is intended to be used to alert clients when\n        a new interface has been added.\n\n        :param path: Path of exported object.\n        :type path: str\n        :param interface: Exported service interface.\n        :type interface: :class:`ServiceInterface\n            <dbus_fast.service.ServiceInterface>`\n        ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_9_emit_interface_added = {"_emit_interface_added", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_9_emit_interface_added, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_8_emit_interface_added};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_9_emit_interface_added(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_path = 0;
  struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_emit_interface_added (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_path,&__pyx_mstate_global->__pyx_n_u_interface,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 317, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 317, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 317, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_emit_interface_added", 0) < (0)) __PYX_ERR(0, 317, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_emit_interface_added", 1, 2, 2, i); __PYX_ERR(0, 317, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 317, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 317, __pyx_L3_error)
    }
    __pyx_v_path = ((PyObject*)values[0]);
    __pyx_v_interface = ((struct __pyx_obj_9dbus_fast_7service_ServiceInterface *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_emit_interface_added", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 317, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._emit_interface_added", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_path), (&PyUnicode_Type), 0, "path", 2))) __PYX_ERR(0, 317, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_interface), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface, 0, "interface", 0))) __PYX_ERR(0, 317, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_8_emit_interface_added(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_path, __pyx_v_interface);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":332
 *             return
 * 
 *         def get_properties_callback(             # <<<<<<<<<<<<<<
 *             interface: ServiceInterface,
 *             result: Any,
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_21_emit_interface_added_1get_properties_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_21_emit_interface_added_1get_properties_callback = {"get_properties_callback", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_21_emit_interface_added_1get_properties_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_21_emit_interface_added_1get_properties_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface = 0;
  PyObject *__pyx_v_result = 0;
  CYTHON_UNUSED PyObject *__pyx_v_user_data = 0;
  PyObject *__pyx_v_e = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_properties_callback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_interface,&__pyx_mstate_global->__pyx_n_u_result,&__pyx_mstate_global->__pyx_n_u_user_data,&__pyx_mstate_global->__pyx_n_u_e,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 332, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 332, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 332, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 332, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 332, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_properties_callback", 0) < (0)) __PYX_ERR(0, 332, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 4; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_properties_callback", 1, 4, 4, i); __PYX_ERR(0, 332, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 332, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 332, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 332, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 332, __pyx_L3_error)
    }
    __pyx_v_interface = ((struct __pyx_obj_9dbus_fast_7service_ServiceInterface *)values[0]);
    __pyx_v_result = values[1];
    __pyx_v_user_data = values[2];
    __pyx_v_e = ((PyObject*)values[3]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_properties_callback", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 332, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._emit_interface_added.get_properties_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_interface), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface, 0, "interface", 0))) __PYX_ERR(0, 333, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_e), (((PyTypeObject*)PyExc_Exception)), 1, "e", 0))) __PYX_ERR(0, 336, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_21_emit_interface_added_get_properties_callback(__pyx_self, __pyx_v_interface, __pyx_v_result, __pyx_v_user_data, __pyx_v_e);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_21_emit_interface_added_get_properties_callback(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, PyObject *__pyx_v_result, CYTHON_UNUSED PyObject *__pyx_v_user_data, PyObject *__pyx_v_e) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *__pyx_outer_scope;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  size_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_properties_callback", 0);
  __pyx_outer_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "dbus_fast/message_bus.py":338
 *             e: Exception | None,
 *         ) -> None:
 *             if e is not None:             # <<<<<<<<<<<<<<
 *                 try:
 *                     raise e
*/
  __pyx_t_1 = (__pyx_v_e != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":339
 *         ) -> None:
 *             if e is not None:
 *                 try:             # <<<<<<<<<<<<<<
 *                     raise e
 *                 except Exception:
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      /*try:*/ {

        /* "dbus_fast/message_bus.py":340
 *             if e is not None:
 *                 try:
 *                     raise e             # <<<<<<<<<<<<<<
 *                 except Exception:
 *                     _LOGGER.error(
*/
        __Pyx_Raise(__pyx_v_e, 0, 0, 0);
        __PYX_ERR(0, 340, __pyx_L4_error)

        /* "dbus_fast/message_bus.py":339
 *         ) -> None:
 *             if e is not None:
 *                 try:             # <<<<<<<<<<<<<<
 *                     raise e
 *                 except Exception:
*/
      }
      __pyx_L4_error:;

      /* "dbus_fast/message_bus.py":341
 *                 try:
 *                     raise e
 *                 except Exception:             # <<<<<<<<<<<<<<
 *                     _LOGGER.error(
 *                         "An exception ocurred when emitting ObjectManager.InterfacesAdded for %s. "
*/
      __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
      if (__pyx_t_5) {
        __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._emit_interface_added.get_properties_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(0, 341, __pyx_L6_except_error)
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);

        /* "dbus_fast/message_bus.py":342
 *                     raise e
 *                 except Exception:
 *                     _LOGGER.error(             # <<<<<<<<<<<<<<
 *                         "An exception ocurred when emitting ObjectManager.InterfacesAdded for %s. "
 *                         "Some properties will not be included in the signal.",
*/
        __pyx_t_10 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_LOGGER); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 342, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_error); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 342, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "dbus_fast/message_bus.py":346
 *                         "Some properties will not be included in the signal.",
 *                         interface.name,
 *                         exc_info=True,             # <<<<<<<<<<<<<<
 *                     )
 * 
*/
        __pyx_t_13 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_12))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_12);
          assert(__pyx_t_10);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_12, __pyx__function);
          __pyx_t_13 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_10, __pyx_mstate_global->__pyx_kp_u_An_exception_ocurred_when_emitti, __pyx_v_interface->name};
          __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 342, __pyx_L6_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_exc_info, Py_True, __pyx_t_11, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 342, __pyx_L6_except_error)
          __pyx_t_9 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_12, __pyx_callargs+__pyx_t_13, (3-__pyx_t_13) | (__pyx_t_13*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 342, __pyx_L6_except_error)
          __Pyx_GOTREF(__pyx_t_9);
        }
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L5_exception_handled;
      }
      goto __pyx_L6_except_error;

      /* "dbus_fast/message_bus.py":339
 *         ) -> None:
 *             if e is not None:
 *                 try:             # <<<<<<<<<<<<<<
 *                     raise e
 *                 except Exception:
*/
      __pyx_L6_except_error:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L1_error;
      __pyx_L5_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    }

    /* "dbus_fast/message_bus.py":338
 *             e: Exception | None,
 *         ) -> None:
 *             if e is not None:             # <<<<<<<<<<<<<<
 *                 try:
 *                     raise e
*/
  }

  /* "dbus_fast/message_bus.py":349
 *                     )
 * 
 *             body = {interface.name: result}             # <<<<<<<<<<<<<<
 * 
 *             self.send(
*/
  __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_v_interface->name, __pyx_v_result) < (0)) __PYX_ERR(0, 349, __pyx_L1_error)
  __pyx_v_body = ((PyObject*)__pyx_t_8);
  __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":351
 *             body = {interface.name: result}
 * 
 *             self.send(             # <<<<<<<<<<<<<<
 *                 Message.new_signal(
 *                     path=path,
*/
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 351, __pyx_L1_error) }
  __pyx_t_7 = ((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF(__pyx_t_7);

  /* "dbus_fast/message_bus.py":352
 * 
 *             self.send(
 *                 Message.new_signal(             # <<<<<<<<<<<<<<
 *                     path=path,
 *                     interface="org.freedesktop.DBus.ObjectManager",
*/
  __pyx_t_9 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
  __Pyx_INCREF(__pyx_t_9);

  /* "dbus_fast/message_bus.py":353
 *             self.send(
 *                 Message.new_signal(
 *                     path=path,             # <<<<<<<<<<<<<<
 *                     interface="org.freedesktop.DBus.ObjectManager",
 *                     member="InterfacesAdded",
*/
  if (unlikely(!__pyx_cur_scope->__pyx_v_path)) { __Pyx_RaiseClosureNameError("path"); __PYX_ERR(0, 353, __pyx_L1_error) }

  /* "dbus_fast/message_bus.py":357
 *                     member="InterfacesAdded",
 *                     signature="oa{sa{sv}}",
 *                     body=[path, body],             # <<<<<<<<<<<<<<
 *                 )
 *             )
*/
  if (unlikely(!__pyx_cur_scope->__pyx_v_path)) { __Pyx_RaiseClosureNameError("path"); __PYX_ERR(0, 357, __pyx_L1_error) }
  __pyx_t_12 = PyList_New(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_path);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_path);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_12, 0, __pyx_cur_scope->__pyx_v_path) != (0)) __PYX_ERR(0, 357, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_body);
  __Pyx_GIVEREF(__pyx_v_body);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_12, 1, __pyx_v_body) != (0)) __PYX_ERR(0, 357, __pyx_L1_error);
  __pyx_t_13 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 5 : 0)] = {__pyx_t_9, NULL};
    __pyx_t_11 = __Pyx_MakeVectorcallBuilderKwds(5); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 352, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_path, __pyx_cur_scope->__pyx_v_path, __pyx_t_11, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_ObjectManag, __pyx_t_11, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_member, __pyx_mstate_global->__pyx_n_u_InterfacesAdded, __pyx_t_11, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_signature, __pyx_mstate_global->__pyx_kp_u_oa_sa_sv, __pyx_t_11, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_t_12, __pyx_t_11, __pyx_callargs+1, 4) < (0)) __PYX_ERR(0, 352, __pyx_L1_error)
    __pyx_t_6 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_new_signal, __pyx_callargs+__pyx_t_13, (1-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_11);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 352, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  }
  __pyx_t_13 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send, __pyx_callargs+__pyx_t_13, (2-__pyx_t_13) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 351, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":332
 *             return
 * 
 *         def get_properties_callback(             # <<<<<<<<<<<<<<
 *             interface: ServiceInterface,
 *             result: Any,
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._emit_interface_added.get_properties_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":317
 *         )
 * 
 *     def _emit_interface_added(self, path: str, interface: ServiceInterface) -> None:             # <<<<<<<<<<<<<<
 *         """Emit the ``org.freedesktop.DBus.ObjectManager.InterfacesAdded`` signal.
 * 
*/

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_8_emit_interface_added(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_path, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *__pyx_cur_scope;
  PyObject *__pyx_v_get_properties_callback = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_emit_interface_added", 0);
  __pyx_cur_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 317, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_path = __pyx_v_path;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_path);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_path);

  /* "dbus_fast/message_bus.py":329
 *             <dbus_fast.service.ServiceInterface>`
 *         """
 *         if self._disconnected:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  if (__pyx_cur_scope->__pyx_v_self->_disconnected) {

    /* "dbus_fast/message_bus.py":330
 *         """
 *         if self._disconnected:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         def get_properties_callback(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":329
 *             <dbus_fast.service.ServiceInterface>`
 *         """
 *         if self._disconnected:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  }

  /* "dbus_fast/message_bus.py":332
 *             return
 * 
 *         def get_properties_callback(             # <<<<<<<<<<<<<<
 *             interface: ServiceInterface,
 *             result: Any,
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_n_u_ServiceInterface) < (0)) __PYX_ERR(0, 332, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_result, __pyx_mstate_global->__pyx_n_u_Any) < (0)) __PYX_ERR(0, 332, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_user_data, __pyx_mstate_global->__pyx_n_u_Any) < (0)) __PYX_ERR(0, 332, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_e, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 332, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 332, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_21_emit_interface_added_1get_properties_callback, 0, __pyx_mstate_global->__pyx_n_u_emit_interface_added_locals_get, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_get_properties_callback = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":361
 *             )
 * 
 *         ServiceInterface._get_all_property_values(interface, get_properties_callback)             # <<<<<<<<<<<<<<
 * 
 *     def _emit_interface_removed(self, path: str, removed_interfaces: list[str]) -> None:
*/
  __pyx_t_1 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_1, ((PyObject *)__pyx_v_interface), __pyx_v_get_properties_callback};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_all_property_values, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 361, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":317
 *         )
 * 
 *     def _emit_interface_added(self, path: str, interface: ServiceInterface) -> None:             # <<<<<<<<<<<<<<
 *         """Emit the ``org.freedesktop.DBus.ObjectManager.InterfacesAdded`` signal.
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._emit_interface_added", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_get_properties_callback);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":363
 *         ServiceInterface._get_all_property_values(interface, get_properties_callback)
 * 
 *     def _emit_interface_removed(self, path: str, removed_interfaces: list[str]) -> None:             # <<<<<<<<<<<<<<
 *         """Emit the ``org.freedesktop.DBus.ObjectManager.InterfacesRemoved` signal.
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11_emit_interface_removed(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_10_emit_interface_removed, "Emit the ``org.freedesktop.DBus.ObjectManager.InterfacesRemoved` signal.\n\n        This signal is intended to be used to alert clients when\n        a interface has been removed.\n\n        :param path: Path of removed (unexported) object.\n        :type path: str\n        :param removed_interfaces: List of unexported service interfaces.\n        :type removed_interfaces: list[str]\n        ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_11_emit_interface_removed = {"_emit_interface_removed", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11_emit_interface_removed, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_10_emit_interface_removed};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11_emit_interface_removed(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_removed_interfaces = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_emit_interface_removed (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_path,&__pyx_mstate_global->__pyx_n_u_removed_interfaces,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 363, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 363, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 363, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_emit_interface_removed", 0) < (0)) __PYX_ERR(0, 363, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_emit_interface_removed", 1, 2, 2, i); __PYX_ERR(0, 363, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 363, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 363, __pyx_L3_error)
    }
    __pyx_v_path = ((PyObject*)values[0]);
    __pyx_v_removed_interfaces = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_emit_interface_removed", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 363, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._emit_interface_removed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_path), (&PyUnicode_Type), 0, "path", 2))) __PYX_ERR(0, 363, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_removed_interfaces), (&PyList_Type), 0, "removed_interfaces", 2))) __PYX_ERR(0, 363, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_10_emit_interface_removed(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_path, __pyx_v_removed_interfaces);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_10_emit_interface_removed(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_path, PyObject *__pyx_v_removed_interfaces) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_emit_interface_removed", 0);

  /* "dbus_fast/message_bus.py":374
 *         :type removed_interfaces: list[str]
 *         """
 *         if self._disconnected:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  if (__pyx_v_self->_disconnected) {

    /* "dbus_fast/message_bus.py":375
 *         """
 *         if self._disconnected:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self.send(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":374
 *         :type removed_interfaces: list[str]
 *         """
 *         if self._disconnected:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  }

  /* "dbus_fast/message_bus.py":377
 *             return
 * 
 *         self.send(             # <<<<<<<<<<<<<<
 *             Message.new_signal(
 *                 path=path,
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);

  /* "dbus_fast/message_bus.py":378
 * 
 *         self.send(
 *             Message.new_signal(             # <<<<<<<<<<<<<<
 *                 path=path,
 *                 interface="org.freedesktop.DBus.ObjectManager",
*/
  __pyx_t_4 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
  __Pyx_INCREF(__pyx_t_4);

  /* "dbus_fast/message_bus.py":383
 *                 member="InterfacesRemoved",
 *                 signature="oas",
 *                 body=[path, removed_interfaces],             # <<<<<<<<<<<<<<
 *             )
 *         )
*/
  __pyx_t_5 = PyList_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_path);
  __Pyx_GIVEREF(__pyx_v_path);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_path) != (0)) __PYX_ERR(0, 383, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_removed_interfaces);
  __Pyx_GIVEREF(__pyx_v_removed_interfaces);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 1, __pyx_v_removed_interfaces) != (0)) __PYX_ERR(0, 383, __pyx_L1_error);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 5 : 0)] = {__pyx_t_4, NULL};
    __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 378, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_path, __pyx_v_path, __pyx_t_7, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 378, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_ObjectManag, __pyx_t_7, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 378, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_member, __pyx_mstate_global->__pyx_n_u_InterfacesRemoved, __pyx_t_7, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 378, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_signature, __pyx_mstate_global->__pyx_n_u_oas, __pyx_t_7, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 378, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_t_5, __pyx_t_7, __pyx_callargs+1, 4) < (0)) __PYX_ERR(0, 378, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_new_signal, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 378, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":363
 *         ServiceInterface._get_all_property_values(interface, get_properties_callback)
 * 
 *     def _emit_interface_removed(self, path: str, removed_interfaces: list[str]) -> None:             # <<<<<<<<<<<<<<
 *         """Emit the ``org.freedesktop.DBus.ObjectManager.InterfacesRemoved` signal.
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._emit_interface_removed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":387
 *         )
 * 
 *     def request_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13request_name(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_12request_name, "Request that this message bus owns the given name.\n\n        :param name: The name to request.\n        :type name: str\n        :param flags: Name flags that affect the behavior of the name request.\n        :type flags: :class:`NameFlag <dbus_fast.NameFlag>`\n        :param callback: A callback that will be called with the reply of the\n            request as a :class:`RequestNameReply <dbus_fast.RequestNameReply>`.\n        :type callback: :class:`Callable`\n\n        :raises:\n            - :class:`InvalidBusNameError <dbus_fast.InvalidBusNameError>` - If the given bus name is not valid.\n        ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_13request_name = {"request_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13request_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_12request_name};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13request_name(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_flags = 0;
  PyObject *__pyx_v_callback = 0;
  int __pyx_v_check_callback_type;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("request_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_flags,&__pyx_mstate_global->__pyx_n_u_callback,&__pyx_mstate_global->__pyx_n_u_check_callback_type,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 387, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 387, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 387, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 387, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 387, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "request_name", 0) < (0)) __PYX_ERR(0, 387, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__4);

      /* "dbus_fast/message_bus.py":392
 *         flags: NameFlag = NameFlag.NONE,
 *         callback: None
 *         | (Callable[[RequestNameReply | None, Exception | None], None]) = None,             # <<<<<<<<<<<<<<
 *         check_callback_type: bool = True,
 *     ) -> None:
*/
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("request_name", 0, 1, 4, i); __PYX_ERR(0, 387, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 387, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 387, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 387, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 387, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__4);
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_name = ((PyObject*)values[0]);
    __pyx_v_flags = values[1];
    __pyx_v_callback = values[2];
    if (values[3]) {
      __pyx_v_check_callback_type = __Pyx_PyObject_IsTrue(values[3]); if (unlikely((__pyx_v_check_callback_type == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 393, __pyx_L3_error)
    } else {

      /* "dbus_fast/message_bus.py":393
 *         callback: None
 *         | (Callable[[RequestNameReply | None, Exception | None], None]) = None,
 *         check_callback_type: bool = True,             # <<<<<<<<<<<<<<
 *     ) -> None:
 *         """Request that this message bus owns the given name.
*/
      __pyx_v_check_callback_type = ((int)1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("request_name", 0, 1, 4, __pyx_nargs); __PYX_ERR(0, 387, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.request_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_name), (&PyUnicode_Type), 0, "name", 2))) __PYX_ERR(0, 389, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12request_name(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_name, __pyx_v_flags, __pyx_v_callback, __pyx_v_check_callback_type);

  /* "dbus_fast/message_bus.py":387
 *         )
 * 
 *     def request_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":429
 *             return
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "u")
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12request_name_1reply_notify(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_12request_name_1reply_notify = {"reply_notify", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12request_name_1reply_notify, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12request_name_1reply_notify(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply = 0;
  PyObject *__pyx_v_err = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reply_notify (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_reply,&__pyx_mstate_global->__pyx_n_u_err,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 429, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 429, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 429, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "reply_notify", 0) < (0)) __PYX_ERR(0, 429, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("reply_notify", 1, 2, 2, i); __PYX_ERR(0, 429, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 429, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 429, __pyx_L3_error)
    }
    __pyx_v_reply = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_err = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("reply_notify", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 429, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.request_name.reply_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_reply), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 1, "reply", 0))) __PYX_ERR(0, 429, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 429, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12request_name_reply_notify(__pyx_self, __pyx_v_reply, __pyx_v_err);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12request_name_reply_notify(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply, PyObject *__pyx_v_err) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *__pyx_outer_scope;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  char const *__pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reply_notify", 0);
  __pyx_outer_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "dbus_fast/message_bus.py":430
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
 *             try:             # <<<<<<<<<<<<<<
 *                 BaseMessageBus._check_method_return(reply, err, "u")
 *                 result = RequestNameReply(reply.body[0])  # type: ignore[union-attr]
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "dbus_fast/message_bus.py":431
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "u")             # <<<<<<<<<<<<<<
 *                 result = RequestNameReply(reply.body[0])  # type: ignore[union-attr]
 *             except Exception as e:
*/
      __pyx_t_5 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_5, ((PyObject *)__pyx_v_reply), __pyx_v_err, __pyx_mstate_global->__pyx_n_u_u};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_check_method_return, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 431, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "dbus_fast/message_bus.py":432
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "u")
 *                 result = RequestNameReply(reply.body[0])  # type: ignore[union-attr]             # <<<<<<<<<<<<<<
 *             except Exception as e:
 *                 callback(None, e)
*/
      __pyx_t_5 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_RequestNameReply); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 432, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_reply->body, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 432, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_8};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 432, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_v_result = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "dbus_fast/message_bus.py":430
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
 *             try:             # <<<<<<<<<<<<<<
 *                 BaseMessageBus._check_method_return(reply, err, "u")
 *                 result = RequestNameReply(reply.body[0])  # type: ignore[union-attr]
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "dbus_fast/message_bus.py":433
 *                 BaseMessageBus._check_method_return(reply, err, "u")
 *                 result = RequestNameReply(reply.body[0])  # type: ignore[union-attr]
 *             except Exception as e:             # <<<<<<<<<<<<<<
 *                 callback(None, e)
 *                 return
*/
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
    if (__pyx_t_9) {
      __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.request_name.reply_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(0, 433, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_e = __pyx_t_7;
      /*try:*/ {

        /* "dbus_fast/message_bus.py":434
 *                 result = RequestNameReply(reply.body[0])  # type: ignore[union-attr]
 *             except Exception as e:
 *                 callback(None, e)             # <<<<<<<<<<<<<<
 *                 return
 * 
*/
        __pyx_t_10 = NULL;
        if (unlikely(!__pyx_cur_scope->__pyx_v_callback)) { __Pyx_RaiseClosureNameError("callback"); __PYX_ERR(0, 434, __pyx_L14_error) }
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_callback);
        __pyx_t_11 = __pyx_cur_scope->__pyx_v_callback; 
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_11);
          assert(__pyx_t_10);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_10, Py_None, __pyx_v_e};
          __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 434, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "dbus_fast/message_bus.py":435
 *             except Exception as e:
 *                 callback(None, e)
 *                 return             # <<<<<<<<<<<<<<
 * 
 *             callback(result, None)
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L13_return;
      }

      /* "dbus_fast/message_bus.py":433
 *                 BaseMessageBus._check_method_return(reply, err, "u")
 *                 result = RequestNameReply(reply.body[0])  # type: ignore[union-attr]
 *             except Exception as e:             # <<<<<<<<<<<<<<
 *                 callback(None, e)
 *                 return
*/
      /*finally:*/ {
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
          if ( unlikely(__Pyx_GetException(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __pyx_t_9 = __pyx_lineno; __pyx_t_12 = __pyx_clineno; __pyx_t_13 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_ErrRestore(__pyx_t_14, __pyx_t_15, __pyx_t_16);
          __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_12; __pyx_filename = __pyx_t_13;
          goto __pyx_L5_except_error;
        }
        __pyx_L13_return: {
          __pyx_t_19 = __pyx_r;
          __pyx_r = 0;
          __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          __pyx_r = __pyx_t_19;
          __pyx_t_19 = 0;
          goto __pyx_L6_except_return;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "dbus_fast/message_bus.py":430
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
 *             try:             # <<<<<<<<<<<<<<
 *                 BaseMessageBus._check_method_return(reply, err, "u")
 *                 result = RequestNameReply(reply.body[0])  # type: ignore[union-attr]
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "dbus_fast/message_bus.py":437
 *                 return
 * 
 *             callback(result, None)             # <<<<<<<<<<<<<<
 * 
 *         self._call(message, reply_notify)
*/
  __pyx_t_7 = NULL;
  if (unlikely(!__pyx_cur_scope->__pyx_v_callback)) { __Pyx_RaiseClosureNameError("callback"); __PYX_ERR(0, 437, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_callback);
  __pyx_t_4 = __pyx_cur_scope->__pyx_v_callback; 
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_7);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_7);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_result, Py_None};
    __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":429
 *             return
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "u")
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.request_name.reply_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":387
 *         )
 * 
 *     def request_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12request_name(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_flags, PyObject *__pyx_v_callback, int __pyx_v_check_callback_type) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_message = NULL;
  PyObject *__pyx_v_reply_notify = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("request_name", 0);
  __pyx_cur_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 387, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_callback = __pyx_v_callback;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_callback);
  __Pyx_INCREF(__pyx_v_flags);

  /* "dbus_fast/message_bus.py":408
 *             - :class:`InvalidBusNameError <dbus_fast.InvalidBusNameError>` - If the given bus name is not valid.
 *         """
 *         assert_bus_name_valid(name)             # <<<<<<<<<<<<<<
 * 
 *         if callback is not None and check_callback_type:
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_assert_bus_name_valid);
  __pyx_t_3 = __pyx_v_9dbus_fast_11message_bus_assert_bus_name_valid; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_name};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":410
 *         assert_bus_name_valid(name)
 * 
 *         if callback is not None and check_callback_type:             # <<<<<<<<<<<<<<
 *             BaseMessageBus._check_callback_type(callback)
 * 
*/
  __pyx_t_6 = (__pyx_cur_scope->__pyx_v_callback != Py_None);
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __pyx_v_check_callback_type;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "dbus_fast/message_bus.py":411
 * 
 *         if callback is not None and check_callback_type:
 *             BaseMessageBus._check_callback_type(callback)             # <<<<<<<<<<<<<<
 * 
 *         if type(flags) is not NameFlag:
*/
    __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_callback};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_check_callback_type_2, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 411, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":410
 *         assert_bus_name_valid(name)
 * 
 *         if callback is not None and check_callback_type:             # <<<<<<<<<<<<<<
 *             BaseMessageBus._check_callback_type(callback)
 * 
*/
  }

  /* "dbus_fast/message_bus.py":413
 *             BaseMessageBus._check_callback_type(callback)
 * 
 *         if type(flags) is not NameFlag:             # <<<<<<<<<<<<<<
 *             flags = NameFlag(flags)
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_NameFlag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (((PyObject *)Py_TYPE(__pyx_v_flags)) != __pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "dbus_fast/message_bus.py":414
 * 
 *         if type(flags) is not NameFlag:
 *             flags = NameFlag(flags)             # <<<<<<<<<<<<<<
 * 
 *         message = Message(
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_NameFlag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_flags};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 414, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_flags, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":413
 *             BaseMessageBus._check_callback_type(callback)
 * 
 *         if type(flags) is not NameFlag:             # <<<<<<<<<<<<<<
 *             flags = NameFlag(flags)
 * 
*/
  }

  /* "dbus_fast/message_bus.py":416
 *             flags = NameFlag(flags)
 * 
 *         message = Message(             # <<<<<<<<<<<<<<
 *             destination="org.freedesktop.DBus",
 *             path="/org/freedesktop/DBus",
*/
  __pyx_t_2 = NULL;

  /* "dbus_fast/message_bus.py":422
 *             member="RequestName",
 *             signature="su",
 *             body=[name, flags],             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_3 = PyList_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_name) != (0)) __PYX_ERR(0, 422, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_flags);
  __Pyx_GIVEREF(__pyx_v_flags);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_v_flags) != (0)) __PYX_ERR(0, 422, __pyx_L1_error);
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 6 : 0)] = {__pyx_t_2, NULL};
    __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_destination, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus, __pyx_t_7, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 416, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_path, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_2, __pyx_t_7, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 416, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus, __pyx_t_7, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 416, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_member, __pyx_mstate_global->__pyx_n_u_RequestName, __pyx_t_7, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 416, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_signature, __pyx_mstate_global->__pyx_n_u_su, __pyx_t_7, __pyx_callargs+1, 4) < (0)) __PYX_ERR(0, 416, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_t_3, __pyx_t_7, __pyx_callargs+1, 5) < (0)) __PYX_ERR(0, 416, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 416, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_message = ((struct __pyx_obj_9dbus_fast_7message_Message *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":425
 *         )
 * 
 *         if callback is None:             # <<<<<<<<<<<<<<
 *             self._call(message, None)
 *             return
*/
  __pyx_t_5 = (__pyx_cur_scope->__pyx_v_callback == Py_None);
  if (__pyx_t_5) {

    /* "dbus_fast/message_bus.py":426
 * 
 *         if callback is None:
 *             self._call(message, None)             # <<<<<<<<<<<<<<
 *             return
 * 
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self->__pyx_vtab)->_call(__pyx_v_self, __pyx_v_message, Py_None, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 426, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":427
 *         if callback is None:
 *             self._call(message, None)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":425
 *         )
 * 
 *         if callback is None:             # <<<<<<<<<<<<<<
 *             self._call(message, None)
 *             return
*/
  }

  /* "dbus_fast/message_bus.py":429
 *             return
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "u")
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_reply, __pyx_mstate_global->__pyx_kp_u_Message_None) < (0)) __PYX_ERR(0, 429, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 429, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 429, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_12request_name_1reply_notify, 0, __pyx_mstate_global->__pyx_n_u_request_name_locals_reply_notify, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_reply_notify = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "dbus_fast/message_bus.py":439
 *             callback(result, None)
 * 
 *         self._call(message, reply_notify)             # <<<<<<<<<<<<<<
 * 
 *     def release_name(
*/
  __pyx_t_7 = ((struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self->__pyx_vtab)->_call(__pyx_v_self, __pyx_v_message, __pyx_v_reply_notify, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "dbus_fast/message_bus.py":387
 *         )
 * 
 *     def request_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.request_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_message);
  __Pyx_XDECREF(__pyx_v_reply_notify);
  __Pyx_XDECREF(__pyx_v_flags);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":441
 *         self._call(message, reply_notify)
 * 
 *     def release_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_15release_name(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_14release_name, "Request that this message bus release the given name.\n\n        :param name: The name to release.\n        :type name: str\n        :param callback: A callback that will be called with the reply of the\n            release request as a :class:`ReleaseNameReply\n            <dbus_fast.ReleaseNameReply>`.\n        :type callback: :class:`Callable`\n\n        :raises:\n            - :class:`InvalidBusNameError <dbus_fast.InvalidBusNameError>` - If the given bus name is not valid.\n        ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_15release_name = {"release_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_15release_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_14release_name};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_15release_name(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_callback = 0;
  int __pyx_v_check_callback_type;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("release_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_name,&__pyx_mstate_global->__pyx_n_u_callback,&__pyx_mstate_global->__pyx_n_u_check_callback_type,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 441, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 441, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 441, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 441, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "release_name", 0) < (0)) __PYX_ERR(0, 441, __pyx_L3_error)

      /* "dbus_fast/message_bus.py":445
 *         name: str,
 *         callback: None
 *         | (Callable[[ReleaseNameReply | None, Exception | None], None]) = None,             # <<<<<<<<<<<<<<
 *         check_callback_type: bool = True,
 *     ) -> None:
*/
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("release_name", 0, 1, 3, i); __PYX_ERR(0, 441, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 441, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 441, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 441, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_name = ((PyObject*)values[0]);
    __pyx_v_callback = values[1];
    if (values[2]) {
      __pyx_v_check_callback_type = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_check_callback_type == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 446, __pyx_L3_error)
    } else {

      /* "dbus_fast/message_bus.py":446
 *         callback: None
 *         | (Callable[[ReleaseNameReply | None, Exception | None], None]) = None,
 *         check_callback_type: bool = True,             # <<<<<<<<<<<<<<
 *     ) -> None:
 *         """Request that this message bus release the given name.
*/
      __pyx_v_check_callback_type = ((int)1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("release_name", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 441, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.release_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_name), (&PyUnicode_Type), 0, "name", 2))) __PYX_ERR(0, 443, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_14release_name(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_name, __pyx_v_callback, __pyx_v_check_callback_type);

  /* "dbus_fast/message_bus.py":441
 *         self._call(message, reply_notify)
 * 
 *     def release_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":478
 *             return
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "u")
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12release_name_1reply_notify(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_12release_name_1reply_notify = {"reply_notify", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12release_name_1reply_notify, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12release_name_1reply_notify(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply = 0;
  PyObject *__pyx_v_err = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reply_notify (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_reply,&__pyx_mstate_global->__pyx_n_u_err,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 478, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 478, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 478, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "reply_notify", 0) < (0)) __PYX_ERR(0, 478, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("reply_notify", 1, 2, 2, i); __PYX_ERR(0, 478, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 478, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 478, __pyx_L3_error)
    }
    __pyx_v_reply = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_err = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("reply_notify", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 478, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.release_name.reply_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_reply), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 1, "reply", 0))) __PYX_ERR(0, 478, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 478, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12release_name_reply_notify(__pyx_self, __pyx_v_reply, __pyx_v_err);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12release_name_reply_notify(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply, PyObject *__pyx_v_err) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *__pyx_outer_scope;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  char const *__pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reply_notify", 0);
  __pyx_outer_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "dbus_fast/message_bus.py":479
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
 *             try:             # <<<<<<<<<<<<<<
 *                 BaseMessageBus._check_method_return(reply, err, "u")
 *                 result = ReleaseNameReply(reply.body[0])  # type: ignore[union-attr]
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "dbus_fast/message_bus.py":480
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "u")             # <<<<<<<<<<<<<<
 *                 result = ReleaseNameReply(reply.body[0])  # type: ignore[union-attr]
 *             except Exception as e:
*/
      __pyx_t_5 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_5, ((PyObject *)__pyx_v_reply), __pyx_v_err, __pyx_mstate_global->__pyx_n_u_u};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_check_method_return, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 480, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "dbus_fast/message_bus.py":481
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "u")
 *                 result = ReleaseNameReply(reply.body[0])  # type: ignore[union-attr]             # <<<<<<<<<<<<<<
 *             except Exception as e:
 *                 callback(None, e)
*/
      __pyx_t_5 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_ReleaseNameReply); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 481, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_reply->body, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 481, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_8};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 481, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_v_result = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "dbus_fast/message_bus.py":479
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
 *             try:             # <<<<<<<<<<<<<<
 *                 BaseMessageBus._check_method_return(reply, err, "u")
 *                 result = ReleaseNameReply(reply.body[0])  # type: ignore[union-attr]
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "dbus_fast/message_bus.py":482
 *                 BaseMessageBus._check_method_return(reply, err, "u")
 *                 result = ReleaseNameReply(reply.body[0])  # type: ignore[union-attr]
 *             except Exception as e:             # <<<<<<<<<<<<<<
 *                 callback(None, e)
 *                 return
*/
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
    if (__pyx_t_9) {
      __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.release_name.reply_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(0, 482, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_e = __pyx_t_7;
      /*try:*/ {

        /* "dbus_fast/message_bus.py":483
 *                 result = ReleaseNameReply(reply.body[0])  # type: ignore[union-attr]
 *             except Exception as e:
 *                 callback(None, e)             # <<<<<<<<<<<<<<
 *                 return
 * 
*/
        __pyx_t_10 = NULL;
        if (unlikely(!__pyx_cur_scope->__pyx_v_callback)) { __Pyx_RaiseClosureNameError("callback"); __PYX_ERR(0, 483, __pyx_L14_error) }
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_callback);
        __pyx_t_11 = __pyx_cur_scope->__pyx_v_callback; 
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_11);
          assert(__pyx_t_10);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_10, Py_None, __pyx_v_e};
          __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 483, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "dbus_fast/message_bus.py":484
 *             except Exception as e:
 *                 callback(None, e)
 *                 return             # <<<<<<<<<<<<<<
 * 
 *             callback(result, None)
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L13_return;
      }

      /* "dbus_fast/message_bus.py":482
 *                 BaseMessageBus._check_method_return(reply, err, "u")
 *                 result = ReleaseNameReply(reply.body[0])  # type: ignore[union-attr]
 *             except Exception as e:             # <<<<<<<<<<<<<<
 *                 callback(None, e)
 *                 return
*/
      /*finally:*/ {
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
          if ( unlikely(__Pyx_GetException(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __pyx_t_9 = __pyx_lineno; __pyx_t_12 = __pyx_clineno; __pyx_t_13 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_ErrRestore(__pyx_t_14, __pyx_t_15, __pyx_t_16);
          __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_12; __pyx_filename = __pyx_t_13;
          goto __pyx_L5_except_error;
        }
        __pyx_L13_return: {
          __pyx_t_19 = __pyx_r;
          __pyx_r = 0;
          __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          __pyx_r = __pyx_t_19;
          __pyx_t_19 = 0;
          goto __pyx_L6_except_return;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "dbus_fast/message_bus.py":479
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
 *             try:             # <<<<<<<<<<<<<<
 *                 BaseMessageBus._check_method_return(reply, err, "u")
 *                 result = ReleaseNameReply(reply.body[0])  # type: ignore[union-attr]
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "dbus_fast/message_bus.py":486
 *                 return
 * 
 *             callback(result, None)             # <<<<<<<<<<<<<<
 * 
 *         self._call(message, reply_notify)
*/
  __pyx_t_7 = NULL;
  if (unlikely(!__pyx_cur_scope->__pyx_v_callback)) { __Pyx_RaiseClosureNameError("callback"); __PYX_ERR(0, 486, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_callback);
  __pyx_t_4 = __pyx_cur_scope->__pyx_v_callback; 
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_7);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_7);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_result, Py_None};
    __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":478
 *             return
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "u")
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.release_name.reply_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":441
 *         self._call(message, reply_notify)
 * 
 *     def release_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_14release_name(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_callback, int __pyx_v_check_callback_type) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_message = NULL;
  PyObject *__pyx_v_reply_notify = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("release_name", 0);
  __pyx_cur_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 441, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_callback = __pyx_v_callback;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_callback);

  /* "dbus_fast/message_bus.py":460
 *             - :class:`InvalidBusNameError <dbus_fast.InvalidBusNameError>` - If the given bus name is not valid.
 *         """
 *         assert_bus_name_valid(name)             # <<<<<<<<<<<<<<
 * 
 *         if callback is not None and check_callback_type:
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_assert_bus_name_valid);
  __pyx_t_3 = __pyx_v_9dbus_fast_11message_bus_assert_bus_name_valid; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_name};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 460, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":462
 *         assert_bus_name_valid(name)
 * 
 *         if callback is not None and check_callback_type:             # <<<<<<<<<<<<<<
 *             BaseMessageBus._check_callback_type(callback)
 * 
*/
  __pyx_t_6 = (__pyx_cur_scope->__pyx_v_callback != Py_None);
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __pyx_v_check_callback_type;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "dbus_fast/message_bus.py":463
 * 
 *         if callback is not None and check_callback_type:
 *             BaseMessageBus._check_callback_type(callback)             # <<<<<<<<<<<<<<
 * 
 *         message = Message(
*/
    __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_callback};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_check_callback_type_2, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 463, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":462
 *         assert_bus_name_valid(name)
 * 
 *         if callback is not None and check_callback_type:             # <<<<<<<<<<<<<<
 *             BaseMessageBus._check_callback_type(callback)
 * 
*/
  }

  /* "dbus_fast/message_bus.py":465
 *             BaseMessageBus._check_callback_type(callback)
 * 
 *         message = Message(             # <<<<<<<<<<<<<<
 *             destination="org.freedesktop.DBus",
 *             path="/org/freedesktop/DBus",
*/
  __pyx_t_3 = NULL;

  /* "dbus_fast/message_bus.py":471
 *             member="ReleaseName",
 *             signature="s",
 *             body=[name],             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_name) != (0)) __PYX_ERR(0, 471, __pyx_L1_error);
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 6 : 0)] = {__pyx_t_3, NULL};
    __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 465, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_destination, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus, __pyx_t_7, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 465, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_path, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_2, __pyx_t_7, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 465, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus, __pyx_t_7, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 465, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_member, __pyx_mstate_global->__pyx_n_u_ReleaseName, __pyx_t_7, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 465, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_signature, __pyx_mstate_global->__pyx_n_u_s, __pyx_t_7, __pyx_callargs+1, 4) < (0)) __PYX_ERR(0, 465, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_t_2, __pyx_t_7, __pyx_callargs+1, 5) < (0)) __PYX_ERR(0, 465, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 465, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_message = ((struct __pyx_obj_9dbus_fast_7message_Message *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":474
 *         )
 * 
 *         if callback is None:             # <<<<<<<<<<<<<<
 *             self._call(message, None)
 *             return
*/
  __pyx_t_5 = (__pyx_cur_scope->__pyx_v_callback == Py_None);
  if (__pyx_t_5) {

    /* "dbus_fast/message_bus.py":475
 * 
 *         if callback is None:
 *             self._call(message, None)             # <<<<<<<<<<<<<<
 *             return
 * 
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self->__pyx_vtab)->_call(__pyx_v_self, __pyx_v_message, Py_None, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":476
 *         if callback is None:
 *             self._call(message, None)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":474
 *         )
 * 
 *         if callback is None:             # <<<<<<<<<<<<<<
 *             self._call(message, None)
 *             return
*/
  }

  /* "dbus_fast/message_bus.py":478
 *             return
 * 
 *         def reply_notify(reply: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             try:
 *                 BaseMessageBus._check_method_return(reply, err, "u")
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_reply, __pyx_mstate_global->__pyx_kp_u_Message_None) < (0)) __PYX_ERR(0, 478, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 478, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 478, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_12release_name_1reply_notify, 0, __pyx_mstate_global->__pyx_n_u_release_name_locals_reply_notify, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_reply_notify = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "dbus_fast/message_bus.py":488
 *             callback(result, None)
 * 
 *         self._call(message, reply_notify)             # <<<<<<<<<<<<<<
 * 
 *     def get_proxy_object(
*/
  __pyx_t_7 = ((struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self->__pyx_vtab)->_call(__pyx_v_self, __pyx_v_message, __pyx_v_reply_notify, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "dbus_fast/message_bus.py":441
 *         self._call(message, reply_notify)
 * 
 *     def release_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.release_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_message);
  __Pyx_XDECREF(__pyx_v_reply_notify);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":490
 *         self._call(message, reply_notify)
 * 
 *     def get_proxy_object(             # <<<<<<<<<<<<<<
 *         self, bus_name: str, path: str, introspection: intr.Node | str | ET.Element
 *     ) -> BaseProxyObject:
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_17get_proxy_object(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_16get_proxy_object, "Get a proxy object for the path exported on the bus that owns the\n        name. The object is expected to export the interfaces and nodes\n        specified in the introspection data.\n\n        This is the entry point into the high-level client.\n\n        :param bus_name: The name on the bus to get the proxy object for.\n        :type bus_name: str\n        :param path: The path on the client for the proxy object.\n        :type path: str\n        :param introspection: XML introspection data used to build the\n            interfaces on the proxy object.\n        :type introspection: :class:`Node <dbus_fast.introspection.Node>` or str or :class:`ElementTree`\n\n        :returns: A proxy object for the given path on the given name.\n        :rtype: :class:`BaseProxyObject <dbus_fast.proxy_object.BaseProxyObject>`\n\n        :raises:\n            - :class:`InvalidBusNameError <dbus_fast.InvalidBusNameError>` - If the given bus name is not valid.\n            - :class:`InvalidObjectPathError <dbus_fast.InvalidObjectPathError>` - If the given object path is not valid.\n            - :class:`InvalidIntrospectionError <dbus_fast.InvalidIntrospectionError>` - If the introspection data for the node is not valid.\n        ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_17get_proxy_object = {"get_proxy_object", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_17get_proxy_object, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_16get_proxy_object};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_17get_proxy_object(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_bus_name = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_introspection = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_proxy_object (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_bus_name,&__pyx_mstate_global->__pyx_n_u_path,&__pyx_mstate_global->__pyx_n_u_introspection,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 490, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 490, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 490, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 490, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_proxy_object", 0) < (0)) __PYX_ERR(0, 490, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_proxy_object", 1, 3, 3, i); __PYX_ERR(0, 490, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 490, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 490, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 490, __pyx_L3_error)
    }
    __pyx_v_bus_name = ((PyObject*)values[0]);
    __pyx_v_path = ((PyObject*)values[1]);
    __pyx_v_introspection = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_proxy_object", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 490, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.get_proxy_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_bus_name), (&PyUnicode_Type), 0, "bus_name", 2))) __PYX_ERR(0, 491, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_path), (&PyUnicode_Type), 0, "path", 2))) __PYX_ERR(0, 491, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_16get_proxy_object(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_bus_name, __pyx_v_path, __pyx_v_introspection);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_16get_proxy_object(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_bus_name, PyObject *__pyx_v_path, PyObject *__pyx_v_introspection) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_proxy_object", 0);

  /* "dbus_fast/message_bus.py":515
 *             - :class:`InvalidIntrospectionError <dbus_fast.InvalidIntrospectionError>` - If the introspection data for the node is not valid.
 *         """
 *         if self._ProxyObject is None:             # <<<<<<<<<<<<<<
 *             raise Exception(
 *                 "the message bus implementation did not provide a proxy object class"
*/
  __pyx_t_1 = (__pyx_v_self->_ProxyObject == Py_None);
  if (unlikely(__pyx_t_1)) {

    /* "dbus_fast/message_bus.py":516
 *         """
 *         if self._ProxyObject is None:
 *             raise Exception(             # <<<<<<<<<<<<<<
 *                 "the message bus implementation did not provide a proxy object class"
 *             )
*/
    __pyx_t_3 = NULL;
    __pyx_t_4 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_the_message_bus_implementation_d};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_Exception)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 516, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 516, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":515
 *             - :class:`InvalidIntrospectionError <dbus_fast.InvalidIntrospectionError>` - If the introspection data for the node is not valid.
 *         """
 *         if self._ProxyObject is None:             # <<<<<<<<<<<<<<
 *             raise Exception(
 *                 "the message bus implementation did not provide a proxy object class"
*/
  }

  /* "dbus_fast/message_bus.py":520
 *             )
 * 
 *         self._init_high_level_client()             # <<<<<<<<<<<<<<
 * 
 *         return self._ProxyObject(bus_name, path, introspection, self)
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_init_high_level_client, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 520, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":522
 *         self._init_high_level_client()
 * 
 *         return self._ProxyObject(bus_name, path, introspection, self)             # <<<<<<<<<<<<<<
 * 
 *     def disconnect(self) -> None:
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = NULL;
  __Pyx_INCREF(__pyx_v_self->_ProxyObject);
  __pyx_t_5 = __pyx_v_self->_ProxyObject; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_3, __pyx_v_bus_name, __pyx_v_path, __pyx_v_introspection, ((PyObject *)__pyx_v_self)};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_4, (5-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "dbus_fast/message_bus.py":490
 *         self._call(message, reply_notify)
 * 
 *     def get_proxy_object(             # <<<<<<<<<<<<<<
 *         self, bus_name: str, path: str, introspection: intr.Node | str | ET.Element
 *     ) -> BaseProxyObject:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.get_proxy_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":524
 *         return self._ProxyObject(bus_name, path, introspection, self)
 * 
 *     def disconnect(self) -> None:             # <<<<<<<<<<<<<<
 *         """Disconnect the message bus by closing the underlying connection asynchronously.
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_19disconnect(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_18disconnect, "Disconnect the message bus by closing the underlying connection asynchronously.\n\n        All pending  and future calls will error with a connection error.\n        ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_19disconnect = {"disconnect", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_19disconnect, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_18disconnect};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_19disconnect(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("disconnect (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("disconnect", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("disconnect", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_18disconnect(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_18disconnect(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("disconnect", 0);

  /* "dbus_fast/message_bus.py":529
 *         All pending  and future calls will error with a connection error.
 *         """
 *         self._user_disconnect = True             # <<<<<<<<<<<<<<
 *         if self._sock:
 *             try:
*/
  __Pyx_INCREF(Py_True);
  __Pyx_GIVEREF(Py_True);
  __Pyx_GOTREF(__pyx_v_self->_user_disconnect);
  __Pyx_DECREF(__pyx_v_self->_user_disconnect);
  __pyx_v_self->_user_disconnect = Py_True;

  /* "dbus_fast/message_bus.py":530
 *         """
 *         self._user_disconnect = True
 *         if self._sock:             # <<<<<<<<<<<<<<
 *             try:
 *                 self._sock.shutdown(socket.SHUT_RDWR)
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->_sock); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 530, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":531
 *         self._user_disconnect = True
 *         if self._sock:
 *             try:             # <<<<<<<<<<<<<<
 *                 self._sock.shutdown(socket.SHUT_RDWR)
 *             except Exception:
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      /*try:*/ {

        /* "dbus_fast/message_bus.py":532
 *         if self._sock:
 *             try:
 *                 self._sock.shutdown(socket.SHUT_RDWR)             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 _LOGGER.warning("could not shut down socket", exc_info=True)
*/
        __pyx_t_6 = __pyx_v_self->_sock;
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 532, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_SHUT_RDWR); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 532, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_9 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_8};
          __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_shutdown, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 532, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "dbus_fast/message_bus.py":531
 *         self._user_disconnect = True
 *         if self._sock:
 *             try:             # <<<<<<<<<<<<<<
 *                 self._sock.shutdown(socket.SHUT_RDWR)
 *             except Exception:
*/
      }
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "dbus_fast/message_bus.py":533
 *             try:
 *                 self._sock.shutdown(socket.SHUT_RDWR)
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 _LOGGER.warning("could not shut down socket", exc_info=True)
 * 
*/
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
      if (__pyx_t_10) {
        __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.disconnect", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_8, &__pyx_t_6) < 0) __PYX_ERR(0, 533, __pyx_L6_except_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);

        /* "dbus_fast/message_bus.py":534
 *                 self._sock.shutdown(socket.SHUT_RDWR)
 *             except Exception:
 *                 _LOGGER.warning("could not shut down socket", exc_info=True)             # <<<<<<<<<<<<<<
 * 
 *     def next_serial(self) -> int:
*/
        __pyx_t_11 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_LOGGER); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 534, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_warning); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 534, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_9 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_13))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_13);
          assert(__pyx_t_11);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
          __pyx_t_9 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_11, __pyx_mstate_global->__pyx_kp_u_could_not_shut_down_socket};
          __pyx_t_12 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 534, __pyx_L6_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_exc_info, Py_True, __pyx_t_12, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 534, __pyx_L6_except_error)
          __pyx_t_7 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_12);
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 534, __pyx_L6_except_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L5_exception_handled;
      }
      goto __pyx_L6_except_error;

      /* "dbus_fast/message_bus.py":531
 *         self._user_disconnect = True
 *         if self._sock:
 *             try:             # <<<<<<<<<<<<<<
 *                 self._sock.shutdown(socket.SHUT_RDWR)
 *             except Exception:
*/
      __pyx_L6_except_error:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L1_error;
      __pyx_L5_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      __pyx_L9_try_end:;
    }

    /* "dbus_fast/message_bus.py":530
 *         """
 *         self._user_disconnect = True
 *         if self._sock:             # <<<<<<<<<<<<<<
 *             try:
 *                 self._sock.shutdown(socket.SHUT_RDWR)
*/
  }

  /* "dbus_fast/message_bus.py":524
 *         return self._ProxyObject(bus_name, path, introspection, self)
 * 
 *     def disconnect(self) -> None:             # <<<<<<<<<<<<<<
 *         """Disconnect the message bus by closing the underlying connection asynchronously.
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.disconnect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":536
 *                 _LOGGER.warning("could not shut down socket", exc_info=True)
 * 
 *     def next_serial(self) -> int:             # <<<<<<<<<<<<<<
 *         """Get the next serial for this bus. This can be used as the ``serial``
 *         attribute of a :class:`Message <dbus_fast.Message>` to manually handle
*/

static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_21next_serial(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus_next_serial(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("next_serial", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_next_serial); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_21next_serial)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 536, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "dbus_fast/message_bus.py":544
 *         :rtype: int
 *         """
 *         self._serial += 1             # <<<<<<<<<<<<<<
 *         return self._serial
 * 
*/
  __pyx_t_1 = __Pyx_PyLong_AddObjC(__pyx_v_self->_serial, __pyx_mstate_global->__pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_serial);
  __Pyx_DECREF(__pyx_v_self->_serial);
  __pyx_v_self->_serial = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":545
 *         """
 *         self._serial += 1
 *         return self._serial             # <<<<<<<<<<<<<<
 * 
 *     def add_message_handler(
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_serial);
  __pyx_r = __pyx_v_self->_serial;
  goto __pyx_L0;

  /* "dbus_fast/message_bus.py":536
 *                 _LOGGER.warning("could not shut down socket", exc_info=True)
 * 
 *     def next_serial(self) -> int:             # <<<<<<<<<<<<<<
 *         """Get the next serial for this bus. This can be used as the ``serial``
 *         attribute of a :class:`Message <dbus_fast.Message>` to manually handle
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.next_serial", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_21next_serial(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_20next_serial, "Get the next serial for this bus. This can be used as the ``serial``\n        attribute of a :class:`Message <dbus_fast.Message>` to manually handle\n        the serial of messages.\n\n        :returns: The next serial for the bus.\n        :rtype: int\n        ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_21next_serial = {"next_serial", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_21next_serial, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_20next_serial};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_21next_serial(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("next_serial (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("next_serial", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("next_serial", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_20next_serial(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_20next_serial(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("next_serial", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9dbus_fast_11message_bus_14BaseMessageBus_next_serial(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.next_serial", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":547
 *         return self._serial
 * 
 *     def add_message_handler(             # <<<<<<<<<<<<<<
 *         self, handler: Callable[[Message], Message | bool | None]
 *     ) -> None:
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23add_message_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_22add_message_handler, "Add a custom message handler for incoming messages.\n\n        The handler should be a callable that takes a :class:`Message\n        <dbus_fast.Message>`. If the message is a method call, you may return\n        another Message as a reply and it will be marked as handled. You may\n        also return ``True`` to mark the message as handled without sending a\n        reply.\n\n        :param handler: A handler that will be run for every message the bus\n            connection received.\n        :type handler: :class:`Callable` or None\n        ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_23add_message_handler = {"add_message_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23add_message_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_22add_message_handler};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23add_message_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_handler = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_message_handler (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_handler,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 547, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 547, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "add_message_handler", 0) < (0)) __PYX_ERR(0, 547, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("add_message_handler", 1, 1, 1, i); __PYX_ERR(0, 547, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 547, __pyx_L3_error)
    }
    __pyx_v_handler = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("add_message_handler", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 547, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.add_message_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22add_message_handler(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_handler);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22add_message_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_handler) {
  PyObject *__pyx_v_error_text = NULL;
  PyObject *__pyx_v_handler_signature = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add_message_handler", 0);

  /* "dbus_fast/message_bus.py":562
 *         :type handler: :class:`Callable` or None
 *         """
 *         error_text = "a message handler must be callable with a single parameter"             # <<<<<<<<<<<<<<
 *         if not callable(handler):
 *             raise TypeError(error_text)
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u_a_message_handler_must_be_callab);
  __pyx_v_error_text = __pyx_mstate_global->__pyx_kp_u_a_message_handler_must_be_callab;

  /* "dbus_fast/message_bus.py":563
 *         """
 *         error_text = "a message handler must be callable with a single parameter"
 *         if not callable(handler):             # <<<<<<<<<<<<<<
 *             raise TypeError(error_text)
 * 
*/
  __pyx_t_1 = __Pyx_PyCallable_Check(__pyx_v_handler); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 563, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (unlikely(__pyx_t_2)) {

    /* "dbus_fast/message_bus.py":564
 *         error_text = "a message handler must be callable with a single parameter"
 *         if not callable(handler):
 *             raise TypeError(error_text)             # <<<<<<<<<<<<<<
 * 
 *         handler_signature = inspect.signature(handler)
*/
    __pyx_t_4 = NULL;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_error_text};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 564, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 564, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":563
 *         """
 *         error_text = "a message handler must be callable with a single parameter"
 *         if not callable(handler):             # <<<<<<<<<<<<<<
 *             raise TypeError(error_text)
 * 
*/
  }

  /* "dbus_fast/message_bus.py":566
 *             raise TypeError(error_text)
 * 
 *         handler_signature = inspect.signature(handler)             # <<<<<<<<<<<<<<
 *         if len(handler_signature.parameters) != 1:
 *             raise TypeError(error_text)
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_inspect); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_signature); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_handler};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_v_handler_signature = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "dbus_fast/message_bus.py":567
 * 
 *         handler_signature = inspect.signature(handler)
 *         if len(handler_signature.parameters) != 1:             # <<<<<<<<<<<<<<
 *             raise TypeError(error_text)
 * 
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_handler_signature, __pyx_mstate_global->__pyx_n_u_parameters); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = (__pyx_t_8 != 1);
  if (unlikely(__pyx_t_2)) {

    /* "dbus_fast/message_bus.py":568
 *         handler_signature = inspect.signature(handler)
 *         if len(handler_signature.parameters) != 1:
 *             raise TypeError(error_text)             # <<<<<<<<<<<<<<
 * 
 *         self._user_message_handlers.append(handler)
*/
    __pyx_t_7 = NULL;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_error_text};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 568, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":567
 * 
 *         handler_signature = inspect.signature(handler)
 *         if len(handler_signature.parameters) != 1:             # <<<<<<<<<<<<<<
 *             raise TypeError(error_text)
 * 
*/
  }

  /* "dbus_fast/message_bus.py":570
 *             raise TypeError(error_text)
 * 
 *         self._user_message_handlers.append(handler)             # <<<<<<<<<<<<<<
 * 
 *     def remove_message_handler(
*/
  if (unlikely(__pyx_v_self->_user_message_handlers == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 570, __pyx_L1_error)
  }
  __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_self->_user_message_handlers, __pyx_v_handler); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 570, __pyx_L1_error)

  /* "dbus_fast/message_bus.py":547
 *         return self._serial
 * 
 *     def add_message_handler(             # <<<<<<<<<<<<<<
 *         self, handler: Callable[[Message], Message | bool | None]
 *     ) -> None:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.add_message_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_error_text);
  __Pyx_XDECREF(__pyx_v_handler_signature);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":572
 *         self._user_message_handlers.append(handler)
 * 
 *     def remove_message_handler(             # <<<<<<<<<<<<<<
 *         self, handler: Callable[[Message], Message | bool | None]
 *     ) -> None:
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_25remove_message_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_24remove_message_handler, "Remove a message handler that was previously added by\n        :func:`add_message_handler()\n        <dbus_fast.message_bus.BaseMessageBus.add_message_handler>`.\n\n        :param handler: A message handler.\n        :type handler: :class:`Callable`\n        ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_25remove_message_handler = {"remove_message_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_25remove_message_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_24remove_message_handler};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_25remove_message_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_handler = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("remove_message_handler (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_handler,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 572, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 572, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "remove_message_handler", 0) < (0)) __PYX_ERR(0, 572, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("remove_message_handler", 1, 1, 1, i); __PYX_ERR(0, 572, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 572, __pyx_L3_error)
    }
    __pyx_v_handler = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("remove_message_handler", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 572, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.remove_message_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_24remove_message_handler(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_handler);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_24remove_message_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_handler) {
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_h = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("remove_message_handler", 0);

  /* "dbus_fast/message_bus.py":582
 *         :type handler: :class:`Callable`
 *         """
 *         for i, h in enumerate(self._user_message_handlers):             # <<<<<<<<<<<<<<
 *             if h == handler:
 *                 del self._user_message_handlers[i]
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
  __pyx_t_1 = __pyx_mstate_global->__pyx_int_0;
  __pyx_t_2 = __pyx_v_self->_user_message_handlers; __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 582, __pyx_L1_error)
      #endif
      if (__pyx_t_3 >= __pyx_temp) break;
    }
    __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_3;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 582, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_h, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_4 = __Pyx_PyLong_AddObjC(__pyx_t_1, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 582, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1);
    __pyx_t_1 = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "dbus_fast/message_bus.py":583
 *         """
 *         for i, h in enumerate(self._user_message_handlers):
 *             if h == handler:             # <<<<<<<<<<<<<<
 *                 del self._user_message_handlers[i]
 *                 return
*/
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_h, __pyx_v_handler, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 583, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 583, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_5) {

      /* "dbus_fast/message_bus.py":584
 *         for i, h in enumerate(self._user_message_handlers):
 *             if h == handler:
 *                 del self._user_message_handlers[i]             # <<<<<<<<<<<<<<
 *                 return
 * 
*/
      if (unlikely(__pyx_v_self->_user_message_handlers == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 584, __pyx_L1_error)
      }
      if (unlikely((PyObject_DelItem(__pyx_v_self->_user_message_handlers, __pyx_v_i) < 0))) __PYX_ERR(0, 584, __pyx_L1_error)

      /* "dbus_fast/message_bus.py":585
 *             if h == handler:
 *                 del self._user_message_handlers[i]
 *                 return             # <<<<<<<<<<<<<<
 * 
 *     def send(self, msg: Message) -> None:
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "dbus_fast/message_bus.py":583
 *         """
 *         for i, h in enumerate(self._user_message_handlers):
 *             if h == handler:             # <<<<<<<<<<<<<<
 *                 del self._user_message_handlers[i]
 *                 return
*/
    }

    /* "dbus_fast/message_bus.py":582
 *         :type handler: :class:`Callable`
 *         """
 *         for i, h in enumerate(self._user_message_handlers):             # <<<<<<<<<<<<<<
 *             if h == handler:
 *                 del self._user_message_handlers[i]
*/
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":572
 *         self._user_message_handlers.append(handler)
 * 
 *     def remove_message_handler(             # <<<<<<<<<<<<<<
 *         self, handler: Callable[[Message], Message | bool | None]
 *     ) -> None:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.remove_message_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_h);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":587
 *                 return
 * 
 *     def send(self, msg: Message) -> None:             # <<<<<<<<<<<<<<
 *         """Asynchronously send a message on the message bus.
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_27send(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_26send, "Asynchronously send a message on the message bus.\n\n        :param msg: The message to send.\n        :type msg: :class:`Message <dbus_fast.Message>`\n        ");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_27send = {"send", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_27send, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_26send};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_27send(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("send (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 587, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 587, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "send", 0) < (0)) __PYX_ERR(0, 587, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("send", 1, 1, 1, i); __PYX_ERR(0, 587, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 587, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("send", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 587, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.send", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 0, "msg", 0))) __PYX_ERR(0, 587, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_26send(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_msg);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_26send(CYTHON_UNUSED struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, CYTHON_UNUSED struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("send", 0);

  /* "dbus_fast/message_bus.py":593
 *         :type msg: :class:`Message <dbus_fast.Message>`
 *         """
 *         raise NotImplementedError(             # <<<<<<<<<<<<<<
 *             'the "send" method must be implemented in the inheriting class'
 *         )
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_the_send_method_must_be_implemen};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_NotImplementedError)), __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 593, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 593, __pyx_L1_error)

  /* "dbus_fast/message_bus.py":587
 *                 return
 * 
 *     def send(self, msg: Message) -> None:             # <<<<<<<<<<<<<<
 *         """Asynchronously send a message on the message bus.
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.send", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":597
 *         )
 * 
 *     def _finalize(self, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *         """should be called after the socket disconnects with the disconnection
 *         error to clean up resources and put the bus in a disconnected state"""
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_29_finalize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_28_finalize, "should be called after the socket disconnects with the disconnection\n        error to clean up resources and put the bus in a disconnected state");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_29_finalize = {"_finalize", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_29_finalize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_28_finalize};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_29_finalize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_err = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_finalize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_err,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 597, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 597, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_finalize", 0) < (0)) __PYX_ERR(0, 597, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_finalize", 1, 1, 1, i); __PYX_ERR(0, 597, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 597, __pyx_L3_error)
    }
    __pyx_v_err = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_finalize", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 597, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._finalize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 597, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_28_finalize(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_err);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_28_finalize(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_err) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_v_path = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_finalize", 0);

  /* "dbus_fast/message_bus.py":600
 *         """should be called after the socket disconnects with the disconnection
 *         error to clean up resources and put the bus in a disconnected state"""
 *         if self._disconnected:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  if (__pyx_v_self->_disconnected) {

    /* "dbus_fast/message_bus.py":601
 *         error to clean up resources and put the bus in a disconnected state"""
 *         if self._disconnected:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._disconnected = True
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":600
 *         """should be called after the socket disconnects with the disconnection
 *         error to clean up resources and put the bus in a disconnected state"""
 *         if self._disconnected:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  }

  /* "dbus_fast/message_bus.py":603
 *             return
 * 
 *         self._disconnected = True             # <<<<<<<<<<<<<<
 * 
 *         self._stream.close()
*/
  __pyx_v_self->_disconnected = 1;

  /* "dbus_fast/message_bus.py":605
 *         self._disconnected = True
 * 
 *         self._stream.close()             # <<<<<<<<<<<<<<
 *         self._sock.close()
 * 
*/
  __pyx_t_2 = __pyx_v_self->_stream;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_close, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":606
 * 
 *         self._stream.close()
 *         self._sock.close()             # <<<<<<<<<<<<<<
 * 
 *         for handler in self._method_return_handlers.values():
*/
  __pyx_t_2 = __pyx_v_self->_sock;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_close, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":608
 *         self._sock.close()
 * 
 *         for handler in self._method_return_handlers.values():             # <<<<<<<<<<<<<<
 *             try:
 *                 handler(None, err)
*/
  __pyx_t_4 = 0;
  if (unlikely(__pyx_v_self->_method_return_handlers == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
    __PYX_ERR(0, 608, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_dict_iterator(__pyx_v_self->_method_return_handlers, 1, __pyx_mstate_global->__pyx_n_u_values, (&__pyx_t_5), (&__pyx_t_6)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_2;
  __pyx_t_2 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_5, &__pyx_t_4, NULL, &__pyx_t_2, NULL, __pyx_t_6);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 608, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_handler, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":609
 * 
 *         for handler in self._method_return_handlers.values():
 *             try:             # <<<<<<<<<<<<<<
 *                 handler(None, err)
 *             except Exception:
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {

        /* "dbus_fast/message_bus.py":610
 *         for handler in self._method_return_handlers.values():
 *             try:
 *                 handler(None, err)             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 _LOGGER.warning(
*/
        __pyx_t_11 = NULL;
        __Pyx_INCREF(__pyx_v_handler);
        __pyx_t_12 = __pyx_v_handler; 
        __pyx_t_3 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_12))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_12);
          assert(__pyx_t_11);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_12, __pyx__function);
          __pyx_t_3 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_11, Py_None, __pyx_v_err};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_12, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 610, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "dbus_fast/message_bus.py":609
 * 
 *         for handler in self._method_return_handlers.values():
 *             try:             # <<<<<<<<<<<<<<
 *                 handler(None, err)
 *             except Exception:
*/
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L13_try_end;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "dbus_fast/message_bus.py":611
 *             try:
 *                 handler(None, err)
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 _LOGGER.warning(
 *                     "a message handler threw an exception on shutdown", exc_info=True
*/
      __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
      if (__pyx_t_7) {
        __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._finalize", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_12, &__pyx_t_11) < 0) __PYX_ERR(0, 611, __pyx_L8_except_error)
        __Pyx_XGOTREF(__pyx_t_2);
        __Pyx_XGOTREF(__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_11);

        /* "dbus_fast/message_bus.py":612
 *                 handler(None, err)
 *             except Exception:
 *                 _LOGGER.warning(             # <<<<<<<<<<<<<<
 *                     "a message handler threw an exception on shutdown", exc_info=True
 *                 )
*/
        __pyx_t_14 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_LOGGER); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 612, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_15);
        __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_warning); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 612, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

        /* "dbus_fast/message_bus.py":613
 *             except Exception:
 *                 _LOGGER.warning(
 *                     "a message handler threw an exception on shutdown", exc_info=True             # <<<<<<<<<<<<<<
 *                 )
 * 
*/
        __pyx_t_3 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_16))) {
          __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_16);
          assert(__pyx_t_14);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_16);
          __Pyx_INCREF(__pyx_t_14);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_16, __pyx__function);
          __pyx_t_3 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_14, __pyx_mstate_global->__pyx_kp_u_a_message_handler_threw_an_excep};
          __pyx_t_15 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 612, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_15);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_exc_info, Py_True, __pyx_t_15, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 612, __pyx_L8_except_error)
          __pyx_t_13 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_16, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_15);
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 612, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_13);
        }
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L7_exception_handled;
      }
      goto __pyx_L8_except_error;

      /* "dbus_fast/message_bus.py":609
 * 
 *         for handler in self._method_return_handlers.values():
 *             try:             # <<<<<<<<<<<<<<
 *                 handler(None, err)
 *             except Exception:
*/
      __pyx_L8_except_error:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L7_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      __pyx_L13_try_end:;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":616
 *                 )
 * 
 *         self._method_return_handlers.clear()             # <<<<<<<<<<<<<<
 * 
 *         for path in list(self._path_exports):
*/
  if (unlikely(__pyx_v_self->_method_return_handlers == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "clear");
    __PYX_ERR(0, 616, __pyx_L1_error)
  }
  __pyx_t_17 = __Pyx_PyDict_Clear(__pyx_v_self->_method_return_handlers); if (unlikely(__pyx_t_17 == ((int)-1))) __PYX_ERR(0, 616, __pyx_L1_error)

  /* "dbus_fast/message_bus.py":618
 *         self._method_return_handlers.clear()
 * 
 *         for path in list(self._path_exports):             # <<<<<<<<<<<<<<
 *             self.unexport(path)
 * 
*/
  __pyx_t_1 = PySequence_List(__pyx_v_self->_path_exports); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_11 = __pyx_t_1; __Pyx_INCREF(__pyx_t_11);
  __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_11);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 618, __pyx_L1_error)
      #endif
      if (__pyx_t_5 >= __pyx_temp) break;
    }
    __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_11, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_5;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_path, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":619
 * 
 *         for path in list(self._path_exports):
 *             self.unexport(path)             # <<<<<<<<<<<<<<
 * 
 *         self._user_message_handlers.clear()
*/
    __pyx_t_12 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_12);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_v_path};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_unexport, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 619, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":618
 *         self._method_return_handlers.clear()
 * 
 *         for path in list(self._path_exports):             # <<<<<<<<<<<<<<
 *             self.unexport(path)
 * 
*/
  }
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "dbus_fast/message_bus.py":621
 *             self.unexport(path)
 * 
 *         self._user_message_handlers.clear()             # <<<<<<<<<<<<<<
 * 
 *     def _interface_signal_notify(
*/
  __pyx_t_1 = __pyx_v_self->_user_message_handlers;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_11 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_clear, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
  }
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "dbus_fast/message_bus.py":597
 *         )
 * 
 *     def _finalize(self, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *         """should be called after the socket disconnects with the disconnection
 *         error to clean up resources and put the bus in a disconnected state"""
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._finalize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XDECREF(__pyx_v_path);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":623
 *         self._user_message_handlers.clear()
 * 
 *     def _interface_signal_notify(             # <<<<<<<<<<<<<<
 *         self,
 *         interface: ServiceInterface,
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_31_interface_signal_notify(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_31_interface_signal_notify = {"_interface_signal_notify", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_31_interface_signal_notify, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_31_interface_signal_notify(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface = 0;
  PyObject *__pyx_v_interface_name = 0;
  PyObject *__pyx_v_member = 0;
  PyObject *__pyx_v_signature = 0;
  PyObject *__pyx_v_body = 0;
  PyObject *__pyx_v_unix_fds = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_interface_signal_notify (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_interface,&__pyx_mstate_global->__pyx_n_u_interface_name,&__pyx_mstate_global->__pyx_n_u_member,&__pyx_mstate_global->__pyx_n_u_signature,&__pyx_mstate_global->__pyx_n_u_body,&__pyx_mstate_global->__pyx_n_u_unix_fds,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 623, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 623, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 623, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 623, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 623, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 623, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 623, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_interface_signal_notify", 0) < (0)) __PYX_ERR(0, 623, __pyx_L3_error)
      if (!values[5]) values[5] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__5);
      for (Py_ssize_t i = __pyx_nargs; i < 5; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_interface_signal_notify", 0, 5, 6, i); __PYX_ERR(0, 623, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 623, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 623, __pyx_L3_error)
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 623, __pyx_L3_error)
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 623, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 623, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 623, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[5]) values[5] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__5);
    }
    __pyx_v_interface = ((struct __pyx_obj_9dbus_fast_7service_ServiceInterface *)values[0]);
    __pyx_v_interface_name = ((PyObject*)values[1]);
    __pyx_v_member = ((PyObject*)values[2]);
    __pyx_v_signature = ((PyObject*)values[3]);
    __pyx_v_body = ((PyObject*)values[4]);
    __pyx_v_unix_fds = ((PyObject*)values[5]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_interface_signal_notify", 0, 5, 6, __pyx_nargs); __PYX_ERR(0, 623, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._interface_signal_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_interface), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface, 0, "interface", 0))) __PYX_ERR(0, 625, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_interface_name), (&PyUnicode_Type), 0, "interface_name", 2))) __PYX_ERR(0, 626, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_member), (&PyUnicode_Type), 0, "member", 2))) __PYX_ERR(0, 627, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_signature), (&PyUnicode_Type), 0, "signature", 2))) __PYX_ERR(0, 628, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_body), (&PyList_Type), 0, "body", 2))) __PYX_ERR(0, 629, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_unix_fds), (&PyList_Type), 0, "unix_fds", 2))) __PYX_ERR(0, 630, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_30_interface_signal_notify(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_interface, __pyx_v_interface_name, __pyx_v_member, __pyx_v_signature, __pyx_v_body, __pyx_v_unix_fds);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_30_interface_signal_notify(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, PyObject *__pyx_v_interface_name, PyObject *__pyx_v_member, PyObject *__pyx_v_signature, PyObject *__pyx_v_body, PyObject *__pyx_v_unix_fds) {
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_p = NULL;
  PyObject *__pyx_v_ifaces = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  size_t __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_interface_signal_notify", 0);

  /* "dbus_fast/message_bus.py":632
 *         unix_fds: list[int] = [],
 *     ) -> None:
 *         path: str | None = None             # <<<<<<<<<<<<<<
 *         for p, ifaces in self._path_exports.items():
 *             for i in ifaces.values():
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_path = ((PyObject*)Py_None);

  /* "dbus_fast/message_bus.py":633
 *     ) -> None:
 *         path: str | None = None
 *         for p, ifaces in self._path_exports.items():             # <<<<<<<<<<<<<<
 *             for i in ifaces.values():
 *                 if i is interface:
*/
  __pyx_t_2 = 0;
  if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 633, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_v_self->_path_exports, 1, __pyx_mstate_global->__pyx_n_u_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, &__pyx_t_6, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_p, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_ifaces, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "dbus_fast/message_bus.py":634
 *         path: str | None = None
 *         for p, ifaces in self._path_exports.items():
 *             for i in ifaces.values():             # <<<<<<<<<<<<<<
 *                 if i is interface:
 *                     path = p
*/
    __pyx_t_8 = 0;
    if (unlikely(__pyx_v_ifaces == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
      __PYX_ERR(0, 634, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_dict_iterator(__pyx_v_ifaces, 0, __pyx_mstate_global->__pyx_n_u_values, (&__pyx_t_9), (&__pyx_t_7)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6);
    __pyx_t_6 = __pyx_t_5;
    __pyx_t_5 = 0;
    while (1) {
      __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_6, __pyx_t_9, &__pyx_t_8, NULL, &__pyx_t_5, NULL, __pyx_t_7);
      if (unlikely(__pyx_t_10 == 0)) break;
      if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 634, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "dbus_fast/message_bus.py":635
 *         for p, ifaces in self._path_exports.items():
 *             for i in ifaces.values():
 *                 if i is interface:             # <<<<<<<<<<<<<<
 *                     path = p
 * 
*/
      __pyx_t_11 = (__pyx_v_i == ((PyObject *)__pyx_v_interface));
      if (__pyx_t_11) {

        /* "dbus_fast/message_bus.py":636
 *             for i in ifaces.values():
 *                 if i is interface:
 *                     path = p             # <<<<<<<<<<<<<<
 * 
 *         if path is None:
*/
        __pyx_t_5 = __pyx_v_p;
        __Pyx_INCREF(__pyx_t_5);
        if (!(likely(PyUnicode_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_5))) __PYX_ERR(0, 636, __pyx_L1_error)
        __Pyx_DECREF_SET(__pyx_v_path, ((PyObject*)__pyx_t_5));
        __pyx_t_5 = 0;

        /* "dbus_fast/message_bus.py":635
 *         for p, ifaces in self._path_exports.items():
 *             for i in ifaces.values():
 *                 if i is interface:             # <<<<<<<<<<<<<<
 *                     path = p
 * 
*/
      }
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":638
 *                     path = p
 * 
 *         if path is None:             # <<<<<<<<<<<<<<
 *             raise Exception(
 *                 "Could not find interface on bus (this is a bug in dbus-fast)"
*/
  __pyx_t_11 = (__pyx_v_path == ((PyObject*)Py_None));
  if (unlikely(__pyx_t_11)) {

    /* "dbus_fast/message_bus.py":639
 * 
 *         if path is None:
 *             raise Exception(             # <<<<<<<<<<<<<<
 *                 "Could not find interface on bus (this is a bug in dbus-fast)"
 *             )
*/
    __pyx_t_6 = NULL;
    __pyx_t_12 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Could_not_find_interface_on_bus};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_Exception)), __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 639, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 639, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":638
 *                     path = p
 * 
 *         if path is None:             # <<<<<<<<<<<<<<
 *             raise Exception(
 *                 "Could not find interface on bus (this is a bug in dbus-fast)"
*/
  }

  /* "dbus_fast/message_bus.py":643
 *             )
 * 
 *         self.send(             # <<<<<<<<<<<<<<
 *             Message.new_signal(
 *                 path=path,
*/
  __pyx_t_6 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_6);

  /* "dbus_fast/message_bus.py":644
 * 
 *         self.send(
 *             Message.new_signal(             # <<<<<<<<<<<<<<
 *                 path=path,
 *                 interface=interface_name,
*/
  __pyx_t_13 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
  __Pyx_INCREF(__pyx_t_13);

  /* "dbus_fast/message_bus.py":650
 *                 signature=signature,
 *                 body=body,
 *                 unix_fds=unix_fds,             # <<<<<<<<<<<<<<
 *             )
 *         )
*/
  __pyx_t_12 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 6 : 0)] = {__pyx_t_13, NULL};
    __pyx_t_14 = __Pyx_MakeVectorcallBuilderKwds(6); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_path, __pyx_v_path, __pyx_t_14, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 644, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_interface, __pyx_v_interface_name, __pyx_t_14, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 644, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_member, __pyx_v_member, __pyx_t_14, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 644, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_signature, __pyx_v_signature, __pyx_t_14, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 644, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_v_body, __pyx_t_14, __pyx_callargs+1, 4) < (0)) __PYX_ERR(0, 644, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_unix_fds, __pyx_v_unix_fds, __pyx_t_14, __pyx_callargs+1, 5) < (0)) __PYX_ERR(0, 644, __pyx_L1_error)
    __pyx_t_5 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_new_signal, __pyx_callargs+__pyx_t_12, (1-__pyx_t_12) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_14);
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __pyx_t_12 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send, __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":623
 *         self._user_message_handlers.clear()
 * 
 *     def _interface_signal_notify(             # <<<<<<<<<<<<<<
 *         self,
 *         interface: ServiceInterface,
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._interface_signal_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_path);
  __Pyx_XDECREF(__pyx_v_p);
  __Pyx_XDECREF(__pyx_v_ifaces);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":654
 *         )
 * 
 *     def _introspect_export_path(self, path: str) -> intr.Node:             # <<<<<<<<<<<<<<
 *         assert_object_path_valid(path)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_33_introspect_export_path(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_33_introspect_export_path = {"_introspect_export_path", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_33_introspect_export_path, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_33_introspect_export_path(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_path = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_introspect_export_path (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_path,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 654, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 654, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_introspect_export_path", 0) < (0)) __PYX_ERR(0, 654, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_introspect_export_path", 1, 1, 1, i); __PYX_ERR(0, 654, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 654, __pyx_L3_error)
    }
    __pyx_v_path = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_introspect_export_path", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 654, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._introspect_export_path", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_path), (&PyUnicode_Type), 0, "path", 2))) __PYX_ERR(0, 654, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_32_introspect_export_path(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_path);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_32_introspect_export_path(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_path) {
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_v_interface = NULL;
  PyObject *__pyx_v_children = NULL;
  PyObject *__pyx_v_export_path = NULL;
  PyObject *__pyx_v_child_path = NULL;
  PyObject *__pyx_v_child_name = NULL;
  PyObject *__pyx_v_interfaces = NULL;
  PyObject *__pyx_7genexpr__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_introspect_export_path", 0);

  /* "dbus_fast/message_bus.py":655
 * 
 *     def _introspect_export_path(self, path: str) -> intr.Node:
 *         assert_object_path_valid(path)             # <<<<<<<<<<<<<<
 * 
 *         if (interfaces := self._path_exports.get(path)) is not None:
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_assert_object_path_valid);
  __pyx_t_3 = __pyx_v_9dbus_fast_11message_bus_assert_object_path_valid; 
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_path};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":657
 *         assert_object_path_valid(path)
 * 
 *         if (interfaces := self._path_exports.get(path)) is not None:             # <<<<<<<<<<<<<<
 *             node = intr.Node.default(path)
 *             for interface in interfaces.values():
*/
  if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
    __PYX_ERR(0, 657, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_self->_path_exports, __pyx_v_path, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_interfaces = __pyx_t_1;
  __pyx_t_5 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "dbus_fast/message_bus.py":658
 * 
 *         if (interfaces := self._path_exports.get(path)) is not None:
 *             node = intr.Node.default(path)             # <<<<<<<<<<<<<<
 *             for interface in interfaces.values():
 *                 node.interfaces.append(interface.introspect())
*/
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_intr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 658, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Node); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 658, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = __pyx_t_6;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_path};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_default, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 658, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_node = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":659
 *         if (interfaces := self._path_exports.get(path)) is not None:
 *             node = intr.Node.default(path)
 *             for interface in interfaces.values():             # <<<<<<<<<<<<<<
 *                 node.interfaces.append(interface.introspect())
 *         else:
*/
    __pyx_t_7 = 0;
    if (unlikely(__pyx_v_interfaces == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
      __PYX_ERR(0, 659, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_dict_iterator(__pyx_v_interfaces, 0, __pyx_mstate_global->__pyx_n_u_values, (&__pyx_t_8), (&__pyx_t_9)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1);
    __pyx_t_1 = __pyx_t_6;
    __pyx_t_6 = 0;
    while (1) {
      __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_8, &__pyx_t_7, NULL, &__pyx_t_6, NULL, __pyx_t_9);
      if (unlikely(__pyx_t_10 == 0)) break;
      if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 659, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_XDECREF_SET(__pyx_v_interface, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "dbus_fast/message_bus.py":660
 *             node = intr.Node.default(path)
 *             for interface in interfaces.values():
 *                 node.interfaces.append(interface.introspect())             # <<<<<<<<<<<<<<
 *         else:
 *             node = intr.Node(path)
*/
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_interfaces); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 660, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = __pyx_v_interface;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_introspect, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 660, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_11 = __Pyx_PyObject_Append(__pyx_t_6, __pyx_t_3); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 660, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":657
 *         assert_object_path_valid(path)
 * 
 *         if (interfaces := self._path_exports.get(path)) is not None:             # <<<<<<<<<<<<<<
 *             node = intr.Node.default(path)
 *             for interface in interfaces.values():
*/
    goto __pyx_L3;
  }

  /* "dbus_fast/message_bus.py":662
 *                 node.interfaces.append(interface.introspect())
 *         else:
 *             node = intr.Node(path)             # <<<<<<<<<<<<<<
 * 
 *         children = set()
*/
  /*else*/ {
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_intr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 662, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_Node); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 662, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_path};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 662, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_v_node = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "dbus_fast/message_bus.py":664
 *             node = intr.Node(path)
 * 
 *         children = set()             # <<<<<<<<<<<<<<
 * 
 *         for export_path in self._path_exports:
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_children = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":666
 *         children = set()
 * 
 *         for export_path in self._path_exports:             # <<<<<<<<<<<<<<
 *             if not export_path.startswith(path):
 *                 continue
*/
  __pyx_t_8 = 0;
  if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 666, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_dict_iterator(__pyx_v_self->_path_exports, 1, ((PyObject *)NULL), (&__pyx_t_7), (&__pyx_t_9)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_2;
  __pyx_t_2 = 0;
  while (1) {
    __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_7, &__pyx_t_8, &__pyx_t_2, NULL, NULL, __pyx_t_9);
    if (unlikely(__pyx_t_10 == 0)) break;
    if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_export_path, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":667
 * 
 *         for export_path in self._path_exports:
 *             if not export_path.startswith(path):             # <<<<<<<<<<<<<<
 *                 continue
 * 
*/
    __pyx_t_3 = __pyx_v_export_path;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_path};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 667, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 667, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_12 = (!__pyx_t_5);
    if (__pyx_t_12) {

      /* "dbus_fast/message_bus.py":668
 *         for export_path in self._path_exports:
 *             if not export_path.startswith(path):
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             child_path = export_path.split(path, maxsplit=1)[1]
*/
      goto __pyx_L6_continue;

      /* "dbus_fast/message_bus.py":667
 * 
 *         for export_path in self._path_exports:
 *             if not export_path.startswith(path):             # <<<<<<<<<<<<<<
 *                 continue
 * 
*/
    }

    /* "dbus_fast/message_bus.py":670
 *                 continue
 * 
 *             child_path = export_path.split(path, maxsplit=1)[1]             # <<<<<<<<<<<<<<
 *             if path != "/" and child_path and child_path[0] != "/":
 *                 continue
*/
    __pyx_t_3 = __pyx_v_export_path;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, __pyx_v_path};
      __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 670, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_maxsplit, __pyx_mstate_global->__pyx_int_1, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 670, __pyx_L1_error)
      __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_split, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 670, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_t_2, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 670, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF_SET(__pyx_v_child_path, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "dbus_fast/message_bus.py":671
 * 
 *             child_path = export_path.split(path, maxsplit=1)[1]
 *             if path != "/" and child_path and child_path[0] != "/":             # <<<<<<<<<<<<<<
 *                 continue
 * 
*/
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_path, __pyx_mstate_global->__pyx_kp_u__6, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 671, __pyx_L1_error)
    if (__pyx_t_5) {
    } else {
      __pyx_t_12 = __pyx_t_5;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_child_path); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 671, __pyx_L1_error)
    if (__pyx_t_5) {
    } else {
      __pyx_t_12 = __pyx_t_5;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_child_path, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_mstate_global->__pyx_kp_u__6, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 671, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_12 = __pyx_t_5;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_12) {

      /* "dbus_fast/message_bus.py":672
 *             child_path = export_path.split(path, maxsplit=1)[1]
 *             if path != "/" and child_path and child_path[0] != "/":
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             child_path = child_path.lstrip("/")
*/
      goto __pyx_L6_continue;

      /* "dbus_fast/message_bus.py":671
 * 
 *             child_path = export_path.split(path, maxsplit=1)[1]
 *             if path != "/" and child_path and child_path[0] != "/":             # <<<<<<<<<<<<<<
 *                 continue
 * 
*/
    }

    /* "dbus_fast/message_bus.py":674
 *                 continue
 * 
 *             child_path = child_path.lstrip("/")             # <<<<<<<<<<<<<<
 *             child_name = child_path.split("/", maxsplit=1)[0]
 * 
*/
    __pyx_t_2 = __pyx_v_child_path;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__6};
      __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lstrip, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_DECREF_SET(__pyx_v_child_path, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "dbus_fast/message_bus.py":675
 * 
 *             child_path = child_path.lstrip("/")
 *             child_name = child_path.split("/", maxsplit=1)[0]             # <<<<<<<<<<<<<<
 * 
 *             children.add(child_name)
*/
    __pyx_t_2 = __pyx_v_child_path;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u__6};
      __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 675, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_maxsplit, __pyx_mstate_global->__pyx_int_1, __pyx_t_3, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 675, __pyx_L1_error)
      __pyx_t_6 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_split, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 675, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_6, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 675, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_child_name, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "dbus_fast/message_bus.py":677
 *             child_name = child_path.split("/", maxsplit=1)[0]
 * 
 *             children.add(child_name)             # <<<<<<<<<<<<<<
 * 
 *         node.nodes = [intr.Node(name) for name in children if name]
*/
    __pyx_t_11 = PySet_Add(__pyx_v_children, __pyx_v_child_name); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 677, __pyx_L1_error)
    __pyx_L6_continue:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":679
 *             children.add(child_name)
 * 
 *         node.nodes = [intr.Node(name) for name in children if name]             # <<<<<<<<<<<<<<
 * 
 *         return node
*/
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 679, __pyx_L15_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = 0;
    __pyx_t_6 = __Pyx_set_iterator(__pyx_v_children, 1, (&__pyx_t_8), (&__pyx_t_9)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 679, __pyx_L15_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_3);
    __pyx_t_3 = __pyx_t_6;
    __pyx_t_6 = 0;
    while (1) {
      __pyx_t_10 = __Pyx_set_iter_next(__pyx_t_3, __pyx_t_8, &__pyx_t_7, &__pyx_t_6, __pyx_t_9);
      if (unlikely(__pyx_t_10 == 0)) break;
      if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 679, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_name, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_7genexpr__pyx_v_name); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 679, __pyx_L15_error)
      if (__pyx_t_12) {
        __pyx_t_2 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_intr); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 679, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_Node); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 679, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_4 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_14))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_14);
          assert(__pyx_t_2);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_14, __pyx__function);
          __pyx_t_4 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_7genexpr__pyx_v_name};
          __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_14, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 679, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 679, __pyx_L15_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_name); __pyx_7genexpr__pyx_v_name = 0;
    goto __pyx_L19_exit_scope;
    __pyx_L15_error:;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_name); __pyx_7genexpr__pyx_v_name = 0;
    goto __pyx_L1_error;
    __pyx_L19_exit_scope:;
  } /* exit inner scope */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_mstate_global->__pyx_n_u_nodes, __pyx_t_1) < (0)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":681
 *         node.nodes = [intr.Node(name) for name in children if name]
 * 
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     def _setup_socket(self) -> None:
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "dbus_fast/message_bus.py":654
 *         )
 * 
 *     def _introspect_export_path(self, path: str) -> intr.Node:             # <<<<<<<<<<<<<<
 *         assert_object_path_valid(path)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._introspect_export_path", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XDECREF(__pyx_v_interface);
  __Pyx_XDECREF(__pyx_v_children);
  __Pyx_XDECREF(__pyx_v_export_path);
  __Pyx_XDECREF(__pyx_v_child_path);
  __Pyx_XDECREF(__pyx_v_child_name);
  __Pyx_XDECREF(__pyx_v_interfaces);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":683
 *         return node
 * 
 *     def _setup_socket(self) -> None:             # <<<<<<<<<<<<<<
 *         last_err: Exception | None = None
 * 
*/

static PyObject *__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__setup_socket(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_v_last_err = 0;
  PyObject *__pyx_v_transport = NULL;
  PyObject *__pyx_v_options = NULL;
  PyObject *__pyx_v_filename = NULL;
  PyObject *__pyx_v_ip_addr = NULL;
  PyObject *__pyx_v_ip_port = NULL;
  PyObject *__pyx_v_stack = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  size_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  int __pyx_t_22;
  int __pyx_t_23;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_setup_socket", 0);

  /* "dbus_fast/message_bus.py":684
 * 
 *     def _setup_socket(self) -> None:
 *         last_err: Exception | None = None             # <<<<<<<<<<<<<<
 * 
 *         for transport, options in self._bus_address:
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_last_err = ((PyObject*)Py_None);

  /* "dbus_fast/message_bus.py":686
 *         last_err: Exception | None = None
 * 
 *         for transport, options in self._bus_address:             # <<<<<<<<<<<<<<
 *             filename: bytes | str | None = None
 *             ip_addr = ""
*/
  if (likely(PyList_CheckExact(__pyx_v_self->_bus_address)) || PyTuple_CheckExact(__pyx_v_self->_bus_address)) {
    __pyx_t_1 = __pyx_v_self->_bus_address; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_self->_bus_address); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 686, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 686, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_2;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 686, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2);
        #endif
        ++__pyx_t_2;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 686, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 686, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 686, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_6);
      } else {
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 686, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 686, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_6);
      }
      #else
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < (0)) __PYX_ERR(0, 686, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 686, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_transport, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_options, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "dbus_fast/message_bus.py":687
 * 
 *         for transport, options in self._bus_address:
 *             filename: bytes | str | None = None             # <<<<<<<<<<<<<<
 *             ip_addr = ""
 *             ip_port = 0
*/
    __Pyx_INCREF(Py_None);
    __Pyx_XDECREF_SET(__pyx_v_filename, Py_None);

    /* "dbus_fast/message_bus.py":688
 *         for transport, options in self._bus_address:
 *             filename: bytes | str | None = None
 *             ip_addr = ""             # <<<<<<<<<<<<<<
 *             ip_port = 0
 * 
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u__7);
    __Pyx_XDECREF_SET(__pyx_v_ip_addr, __pyx_mstate_global->__pyx_kp_u__7);

    /* "dbus_fast/message_bus.py":689
 *             filename: bytes | str | None = None
 *             ip_addr = ""
 *             ip_port = 0             # <<<<<<<<<<<<<<
 * 
 *             with ExitStack() as stack:
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
    __Pyx_XDECREF_SET(__pyx_v_ip_port, __pyx_mstate_global->__pyx_int_0);

    /* "dbus_fast/message_bus.py":691
 *             ip_port = 0
 * 
 *             with ExitStack() as stack:             # <<<<<<<<<<<<<<
 *                 if transport == "unix":
 *                     self._sock = stack.enter_context(
*/
    /*with:*/ {
      __pyx_t_6 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_ExitStack); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 691, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_9 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 691, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_t_10 = __Pyx_PyObject_LookupSpecial(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 691, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_6 = NULL;
      __pyx_t_7 = __Pyx_PyObject_LookupSpecial(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 691, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = 1;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_9 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 691, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __pyx_t_7 = __pyx_t_5;
      __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      /*try:*/ {
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          /*try:*/ {
            __Pyx_XDECREF_SET(__pyx_v_stack, __pyx_t_7);
            __pyx_t_7 = 0;

            /* "dbus_fast/message_bus.py":692
 * 
 *             with ExitStack() as stack:
 *                 if transport == "unix":             # <<<<<<<<<<<<<<
 *                     self._sock = stack.enter_context(
 *                         socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
*/
            __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_v_transport, __pyx_mstate_global->__pyx_n_u_unix, Py_EQ)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 692, __pyx_L13_error)
            if (__pyx_t_14) {

              /* "dbus_fast/message_bus.py":693
 *             with ExitStack() as stack:
 *                 if transport == "unix":
 *                     self._sock = stack.enter_context(             # <<<<<<<<<<<<<<
 *                         socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
 *                     )
*/
              __pyx_t_4 = __pyx_v_stack;
              __Pyx_INCREF(__pyx_t_4);

              /* "dbus_fast/message_bus.py":694
 *                 if transport == "unix":
 *                     self._sock = stack.enter_context(
 *                         socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)             # <<<<<<<<<<<<<<
 *                     )
 *                     self._stream = stack.enter_context(self._sock.makefile("rwb"))
*/
              __pyx_t_6 = NULL;
              __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 694, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_15);
              __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 694, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_16);
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 694, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_15);
              __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_AF_UNIX); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 694, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_17);
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 694, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_15);
              __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_SOCK_STREAM); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 694, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_18);
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
              __pyx_t_9 = 1;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_16))) {
                __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_16);
                assert(__pyx_t_6);
                PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_16);
                __Pyx_INCREF(__pyx_t_6);
                __Pyx_INCREF(__pyx__function);
                __Pyx_DECREF_SET(__pyx_t_16, __pyx__function);
                __pyx_t_9 = 0;
              }
              #endif
              {
                PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_17, __pyx_t_18};
                __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_16, __pyx_callargs+__pyx_t_9, (3-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
                __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
                __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
                __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
                if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 694, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_5);
              }
              __pyx_t_9 = 0;
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
                __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_enter_context, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 693, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_7);
              }

              /* "dbus_fast/message_bus.py":693
 *             with ExitStack() as stack:
 *                 if transport == "unix":
 *                     self._sock = stack.enter_context(             # <<<<<<<<<<<<<<
 *                         socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
 *                     )
*/
              __Pyx_GIVEREF(__pyx_t_7);
              __Pyx_GOTREF(__pyx_v_self->_sock);
              __Pyx_DECREF(__pyx_v_self->_sock);
              __pyx_v_self->_sock = __pyx_t_7;
              __pyx_t_7 = 0;

              /* "dbus_fast/message_bus.py":696
 *                         socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
 *                     )
 *                     self._stream = stack.enter_context(self._sock.makefile("rwb"))             # <<<<<<<<<<<<<<
 *                     self._fd = self._sock.fileno()
 * 
*/
              __pyx_t_5 = __pyx_v_stack;
              __Pyx_INCREF(__pyx_t_5);
              __pyx_t_16 = __pyx_v_self->_sock;
              __Pyx_INCREF(__pyx_t_16);
              __pyx_t_9 = 0;
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_16, __pyx_mstate_global->__pyx_n_u_rwb};
                __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_makefile, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 696, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_4);
              }
              __pyx_t_9 = 0;
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
                __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_enter_context, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 696, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_7);
              }
              __Pyx_GIVEREF(__pyx_t_7);
              __Pyx_GOTREF(__pyx_v_self->_stream);
              __Pyx_DECREF(__pyx_v_self->_stream);
              __pyx_v_self->_stream = __pyx_t_7;
              __pyx_t_7 = 0;

              /* "dbus_fast/message_bus.py":697
 *                     )
 *                     self._stream = stack.enter_context(self._sock.makefile("rwb"))
 *                     self._fd = self._sock.fileno()             # <<<<<<<<<<<<<<
 * 
 *                     if "path" in options:
*/
              __pyx_t_4 = __pyx_v_self->_sock;
              __Pyx_INCREF(__pyx_t_4);
              __pyx_t_9 = 0;
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
                __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_fileno, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 697, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_7);
              }
              __Pyx_GIVEREF(__pyx_t_7);
              __Pyx_GOTREF(__pyx_v_self->_fd);
              __Pyx_DECREF(__pyx_v_self->_fd);
              __pyx_v_self->_fd = __pyx_t_7;
              __pyx_t_7 = 0;

              /* "dbus_fast/message_bus.py":699
 *                     self._fd = self._sock.fileno()
 * 
 *                     if "path" in options:             # <<<<<<<<<<<<<<
 *                         filename = options["path"]
 *                     elif "abstract" in options:
*/
              __pyx_t_14 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_path, __pyx_v_options, Py_EQ)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 699, __pyx_L13_error)
              if (__pyx_t_14) {

                /* "dbus_fast/message_bus.py":700
 * 
 *                     if "path" in options:
 *                         filename = options["path"]             # <<<<<<<<<<<<<<
 *                     elif "abstract" in options:
 *                         filename = b"\0" + options["abstract"].encode()
*/
                __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_options, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 700, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_7);
                __Pyx_DECREF_SET(__pyx_v_filename, __pyx_t_7);
                __pyx_t_7 = 0;

                /* "dbus_fast/message_bus.py":699
 *                     self._fd = self._sock.fileno()
 * 
 *                     if "path" in options:             # <<<<<<<<<<<<<<
 *                         filename = options["path"]
 *                     elif "abstract" in options:
*/
                goto __pyx_L22;
              }

              /* "dbus_fast/message_bus.py":701
 *                     if "path" in options:
 *                         filename = options["path"]
 *                     elif "abstract" in options:             # <<<<<<<<<<<<<<
 *                         filename = b"\0" + options["abstract"].encode()
 *                     else:
*/
              __pyx_t_14 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_abstract, __pyx_v_options, Py_EQ)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 701, __pyx_L13_error)
              if (likely(__pyx_t_14)) {

                /* "dbus_fast/message_bus.py":702
 *                         filename = options["path"]
 *                     elif "abstract" in options:
 *                         filename = b"\0" + options["abstract"].encode()             # <<<<<<<<<<<<<<
 *                     else:
 *                         raise InvalidAddressError(
*/
                __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_options, __pyx_mstate_global->__pyx_n_u_abstract); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 702, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_5);
                __pyx_t_4 = __pyx_t_5;
                __Pyx_INCREF(__pyx_t_4);
                __pyx_t_9 = 0;
                {
                  PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
                  __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_encode, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 702, __pyx_L13_error)
                  __Pyx_GOTREF(__pyx_t_7);
                }
                __pyx_t_5 = PyNumber_Add(__pyx_mstate_global->__pyx_kp_b__8, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 702, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_5);
                __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_DECREF_SET(__pyx_v_filename, __pyx_t_5);
                __pyx_t_5 = 0;

                /* "dbus_fast/message_bus.py":701
 *                     if "path" in options:
 *                         filename = options["path"]
 *                     elif "abstract" in options:             # <<<<<<<<<<<<<<
 *                         filename = b"\0" + options["abstract"].encode()
 *                     else:
*/
                goto __pyx_L22;
              }

              /* "dbus_fast/message_bus.py":704
 *                         filename = b"\0" + options["abstract"].encode()
 *                     else:
 *                         raise InvalidAddressError(             # <<<<<<<<<<<<<<
 *                             "got unix transport with unknown path specifier"
 *                         )
*/
              /*else*/ {
                __pyx_t_7 = NULL;
                __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_InvalidAddressError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 704, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_4);
                __pyx_t_9 = 1;
                #if CYTHON_UNPACK_METHODS
                if (unlikely(PyMethod_Check(__pyx_t_4))) {
                  __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
                  assert(__pyx_t_7);
                  PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
                  __Pyx_INCREF(__pyx_t_7);
                  __Pyx_INCREF(__pyx__function);
                  __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
                  __pyx_t_9 = 0;
                }
                #endif
                {
                  PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u_got_unix_transport_with_unknown};
                  __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 704, __pyx_L13_error)
                  __Pyx_GOTREF(__pyx_t_5);
                }
                __Pyx_Raise(__pyx_t_5, 0, 0, 0);
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                __PYX_ERR(0, 704, __pyx_L13_error)
              }
              __pyx_L22:;

              /* "dbus_fast/message_bus.py":708
 *                         )
 * 
 *                     try:             # <<<<<<<<<<<<<<
 *                         self._sock.connect(filename)
 *                         self._sock.setblocking(False)
*/
              {
                __Pyx_PyThreadState_declare
                __Pyx_PyThreadState_assign
                __Pyx_ExceptionSave(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
                __Pyx_XGOTREF(__pyx_t_19);
                __Pyx_XGOTREF(__pyx_t_20);
                __Pyx_XGOTREF(__pyx_t_21);
                /*try:*/ {

                  /* "dbus_fast/message_bus.py":709
 * 
 *                     try:
 *                         self._sock.connect(filename)             # <<<<<<<<<<<<<<
 *                         self._sock.setblocking(False)
 *                     except Exception as e:
*/
                  __pyx_t_4 = __pyx_v_self->_sock;
                  __Pyx_INCREF(__pyx_t_4);
                  __pyx_t_9 = 0;
                  {
                    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_filename};
                    __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_connect, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 709, __pyx_L23_error)
                    __Pyx_GOTREF(__pyx_t_5);
                  }
                  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

                  /* "dbus_fast/message_bus.py":710
 *                     try:
 *                         self._sock.connect(filename)
 *                         self._sock.setblocking(False)             # <<<<<<<<<<<<<<
 *                     except Exception as e:
 *                         last_err = e
*/
                  __pyx_t_4 = __pyx_v_self->_sock;
                  __Pyx_INCREF(__pyx_t_4);
                  __pyx_t_9 = 0;
                  {
                    PyObject *__pyx_callargs[2] = {__pyx_t_4, Py_False};
                    __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_setblocking, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 710, __pyx_L23_error)
                    __Pyx_GOTREF(__pyx_t_5);
                  }
                  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

                  /* "dbus_fast/message_bus.py":708
 *                         )
 * 
 *                     try:             # <<<<<<<<<<<<<<
 *                         self._sock.connect(filename)
 *                         self._sock.setblocking(False)
*/
                }

                /* "dbus_fast/message_bus.py":714
 *                         last_err = e
 *                     else:
 *                         stack.pop_all()  # responsibility to close sockets is deferred             # <<<<<<<<<<<<<<
 *                         return
 * 
*/
                /*else:*/ {
                  __pyx_t_4 = __pyx_v_stack;
                  __Pyx_INCREF(__pyx_t_4);
                  __pyx_t_9 = 0;
                  {
                    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
                    __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_pop_all, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 714, __pyx_L25_except_error)
                    __Pyx_GOTREF(__pyx_t_5);
                  }
                  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

                  /* "dbus_fast/message_bus.py":715
 *                     else:
 *                         stack.pop_all()  # responsibility to close sockets is deferred
 *                         return             # <<<<<<<<<<<<<<
 * 
 *                 elif transport == "tcp":
*/
                  __Pyx_XDECREF(__pyx_r);
                  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                  goto __pyx_L26_except_return;
                }
                __pyx_L23_error:;
                __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
                __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

                /* "dbus_fast/message_bus.py":711
 *                         self._sock.connect(filename)
 *                         self._sock.setblocking(False)
 *                     except Exception as e:             # <<<<<<<<<<<<<<
 *                         last_err = e
 *                     else:
*/
                __pyx_t_22 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
                if (__pyx_t_22) {
                  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._setup_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
                  if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 711, __pyx_L25_except_error)
                  __Pyx_XGOTREF(__pyx_t_5);
                  __Pyx_XGOTREF(__pyx_t_4);
                  __Pyx_XGOTREF(__pyx_t_7);
                  __Pyx_INCREF(__pyx_t_4);
                  __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_4);
                  /*try:*/ {

                    /* "dbus_fast/message_bus.py":712
 *                         self._sock.setblocking(False)
 *                     except Exception as e:
 *                         last_err = e             # <<<<<<<<<<<<<<
 *                     else:
 *                         stack.pop_all()  # responsibility to close sockets is deferred
*/
                    __Pyx_INCREF(__pyx_v_e);
                    __Pyx_DECREF_SET(__pyx_v_last_err, __pyx_v_e);
                  }

                  /* "dbus_fast/message_bus.py":711
 *                         self._sock.connect(filename)
 *                         self._sock.setblocking(False)
 *                     except Exception as e:             # <<<<<<<<<<<<<<
 *                         last_err = e
 *                     else:
*/
                  /*finally:*/ {
                    /*normal exit:*/{
                      __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
                      goto __pyx_L37;
                    }
                    __pyx_L37:;
                  }
                  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                  goto __pyx_L24_exception_handled;
                }
                goto __pyx_L25_except_error;

                /* "dbus_fast/message_bus.py":708
 *                         )
 * 
 *                     try:             # <<<<<<<<<<<<<<
 *                         self._sock.connect(filename)
 *                         self._sock.setblocking(False)
*/
                __pyx_L25_except_error:;
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_XGIVEREF(__pyx_t_21);
                __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
                goto __pyx_L13_error;
                __pyx_L26_except_return:;
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_XGIVEREF(__pyx_t_21);
                __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
                goto __pyx_L17_try_return;
                __pyx_L24_exception_handled:;
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_XGIVEREF(__pyx_t_21);
                __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
              }

              /* "dbus_fast/message_bus.py":692
 * 
 *             with ExitStack() as stack:
 *                 if transport == "unix":             # <<<<<<<<<<<<<<
 *                     self._sock = stack.enter_context(
 *                         socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
*/
              goto __pyx_L21;
            }

            /* "dbus_fast/message_bus.py":717
 *                         return
 * 
 *                 elif transport == "tcp":             # <<<<<<<<<<<<<<
 *                     self._sock = stack.enter_context(
 *                         socket.socket(socket.AF_INET, socket.SOCK_STREAM)
*/
            __pyx_t_14 = (__Pyx_PyUnicode_Equals(__pyx_v_transport, __pyx_mstate_global->__pyx_n_u_tcp, Py_EQ)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 717, __pyx_L13_error)
            if (likely(__pyx_t_14)) {

              /* "dbus_fast/message_bus.py":718
 * 
 *                 elif transport == "tcp":
 *                     self._sock = stack.enter_context(             # <<<<<<<<<<<<<<
 *                         socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 *                     )
*/
              __pyx_t_4 = __pyx_v_stack;
              __Pyx_INCREF(__pyx_t_4);

              /* "dbus_fast/message_bus.py":719
 *                 elif transport == "tcp":
 *                     self._sock = stack.enter_context(
 *                         socket.socket(socket.AF_INET, socket.SOCK_STREAM)             # <<<<<<<<<<<<<<
 *                     )
 *                     self._stream = stack.enter_context(self._sock.makefile("rwb"))
*/
              __pyx_t_16 = NULL;
              __Pyx_GetModuleGlobalName(__pyx_t_18, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 719, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_18);
              __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_18, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 719, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_17);
              __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_GetModuleGlobalName(__pyx_t_18, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 719, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_18);
              __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_18, __pyx_mstate_global->__pyx_n_u_AF_INET); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 719, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_GetModuleGlobalName(__pyx_t_18, __pyx_mstate_global->__pyx_n_u_socket); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 719, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_18);
              __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_18, __pyx_mstate_global->__pyx_n_u_SOCK_STREAM); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 719, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_15);
              __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
              __pyx_t_9 = 1;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_17))) {
                __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_17);
                assert(__pyx_t_16);
                PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_17);
                __Pyx_INCREF(__pyx_t_16);
                __Pyx_INCREF(__pyx__function);
                __Pyx_DECREF_SET(__pyx_t_17, __pyx__function);
                __pyx_t_9 = 0;
              }
              #endif
              {
                PyObject *__pyx_callargs[3] = {__pyx_t_16, __pyx_t_6, __pyx_t_15};
                __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_17, __pyx_callargs+__pyx_t_9, (3-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
                __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
                if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 719, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_5);
              }
              __pyx_t_9 = 0;
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
                __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_enter_context, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 718, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_7);
              }

              /* "dbus_fast/message_bus.py":718
 * 
 *                 elif transport == "tcp":
 *                     self._sock = stack.enter_context(             # <<<<<<<<<<<<<<
 *                         socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 *                     )
*/
              __Pyx_GIVEREF(__pyx_t_7);
              __Pyx_GOTREF(__pyx_v_self->_sock);
              __Pyx_DECREF(__pyx_v_self->_sock);
              __pyx_v_self->_sock = __pyx_t_7;
              __pyx_t_7 = 0;

              /* "dbus_fast/message_bus.py":721
 *                         socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 *                     )
 *                     self._stream = stack.enter_context(self._sock.makefile("rwb"))             # <<<<<<<<<<<<<<
 *                     self._fd = self._sock.fileno()
 * 
*/
              __pyx_t_5 = __pyx_v_stack;
              __Pyx_INCREF(__pyx_t_5);
              __pyx_t_17 = __pyx_v_self->_sock;
              __Pyx_INCREF(__pyx_t_17);
              __pyx_t_9 = 0;
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_17, __pyx_mstate_global->__pyx_n_u_rwb};
                __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_makefile, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 721, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_4);
              }
              __pyx_t_9 = 0;
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
                __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_enter_context, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 721, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_7);
              }
              __Pyx_GIVEREF(__pyx_t_7);
              __Pyx_GOTREF(__pyx_v_self->_stream);
              __Pyx_DECREF(__pyx_v_self->_stream);
              __pyx_v_self->_stream = __pyx_t_7;
              __pyx_t_7 = 0;

              /* "dbus_fast/message_bus.py":722
 *                     )
 *                     self._stream = stack.enter_context(self._sock.makefile("rwb"))
 *                     self._fd = self._sock.fileno()             # <<<<<<<<<<<<<<
 * 
 *                     if "host" in options:
*/
              __pyx_t_4 = __pyx_v_self->_sock;
              __Pyx_INCREF(__pyx_t_4);
              __pyx_t_9 = 0;
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
                __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_fileno, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 722, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_7);
              }
              __Pyx_GIVEREF(__pyx_t_7);
              __Pyx_GOTREF(__pyx_v_self->_fd);
              __Pyx_DECREF(__pyx_v_self->_fd);
              __pyx_v_self->_fd = __pyx_t_7;
              __pyx_t_7 = 0;

              /* "dbus_fast/message_bus.py":724
 *                     self._fd = self._sock.fileno()
 * 
 *                     if "host" in options:             # <<<<<<<<<<<<<<
 *                         ip_addr = options["host"]
 *                     if "port" in options:
*/
              __pyx_t_14 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_host, __pyx_v_options, Py_EQ)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 724, __pyx_L13_error)
              if (__pyx_t_14) {

                /* "dbus_fast/message_bus.py":725
 * 
 *                     if "host" in options:
 *                         ip_addr = options["host"]             # <<<<<<<<<<<<<<
 *                     if "port" in options:
 *                         ip_port = int(options["port"])
*/
                __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_options, __pyx_mstate_global->__pyx_n_u_host); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 725, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_7);
                __Pyx_DECREF_SET(__pyx_v_ip_addr, __pyx_t_7);
                __pyx_t_7 = 0;

                /* "dbus_fast/message_bus.py":724
 *                     self._fd = self._sock.fileno()
 * 
 *                     if "host" in options:             # <<<<<<<<<<<<<<
 *                         ip_addr = options["host"]
 *                     if "port" in options:
*/
              }

              /* "dbus_fast/message_bus.py":726
 *                     if "host" in options:
 *                         ip_addr = options["host"]
 *                     if "port" in options:             # <<<<<<<<<<<<<<
 *                         ip_port = int(options["port"])
 * 
*/
              __pyx_t_14 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_port, __pyx_v_options, Py_EQ)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 726, __pyx_L13_error)
              if (__pyx_t_14) {

                /* "dbus_fast/message_bus.py":727
 *                         ip_addr = options["host"]
 *                     if "port" in options:
 *                         ip_port = int(options["port"])             # <<<<<<<<<<<<<<
 * 
 *                     try:
*/
                __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_options, __pyx_mstate_global->__pyx_n_u_port); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 727, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_7);
                __pyx_t_4 = __Pyx_PyNumber_Int(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 727, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_DECREF_SET(__pyx_v_ip_port, ((PyObject*)__pyx_t_4));
                __pyx_t_4 = 0;

                /* "dbus_fast/message_bus.py":726
 *                     if "host" in options:
 *                         ip_addr = options["host"]
 *                     if "port" in options:             # <<<<<<<<<<<<<<
 *                         ip_port = int(options["port"])
 * 
*/
              }

              /* "dbus_fast/message_bus.py":729
 *                         ip_port = int(options["port"])
 * 
 *                     try:             # <<<<<<<<<<<<<<
 *                         self._sock.connect((ip_addr, ip_port))
 *                         self._sock.setblocking(False)
*/
              {
                __Pyx_PyThreadState_declare
                __Pyx_PyThreadState_assign
                __Pyx_ExceptionSave(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19);
                __Pyx_XGOTREF(__pyx_t_21);
                __Pyx_XGOTREF(__pyx_t_20);
                __Pyx_XGOTREF(__pyx_t_19);
                /*try:*/ {

                  /* "dbus_fast/message_bus.py":730
 * 
 *                     try:
 *                         self._sock.connect((ip_addr, ip_port))             # <<<<<<<<<<<<<<
 *                         self._sock.setblocking(False)
 *                     except Exception as e:
*/
                  __pyx_t_7 = __pyx_v_self->_sock;
                  __Pyx_INCREF(__pyx_t_7);
                  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 730, __pyx_L40_error)
                  __Pyx_GOTREF(__pyx_t_5);
                  __Pyx_INCREF(__pyx_v_ip_addr);
                  __Pyx_GIVEREF(__pyx_v_ip_addr);
                  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_ip_addr) != (0)) __PYX_ERR(0, 730, __pyx_L40_error);
                  __Pyx_INCREF(__pyx_v_ip_port);
                  __Pyx_GIVEREF(__pyx_v_ip_port);
                  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_ip_port) != (0)) __PYX_ERR(0, 730, __pyx_L40_error);
                  __pyx_t_9 = 0;
                  {
                    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
                    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_connect, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 730, __pyx_L40_error)
                    __Pyx_GOTREF(__pyx_t_4);
                  }
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

                  /* "dbus_fast/message_bus.py":731
 *                     try:
 *                         self._sock.connect((ip_addr, ip_port))
 *                         self._sock.setblocking(False)             # <<<<<<<<<<<<<<
 *                     except Exception as e:
 *                         last_err = e
*/
                  __pyx_t_5 = __pyx_v_self->_sock;
                  __Pyx_INCREF(__pyx_t_5);
                  __pyx_t_9 = 0;
                  {
                    PyObject *__pyx_callargs[2] = {__pyx_t_5, Py_False};
                    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_setblocking, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 731, __pyx_L40_error)
                    __Pyx_GOTREF(__pyx_t_4);
                  }
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

                  /* "dbus_fast/message_bus.py":729
 *                         ip_port = int(options["port"])
 * 
 *                     try:             # <<<<<<<<<<<<<<
 *                         self._sock.connect((ip_addr, ip_port))
 *                         self._sock.setblocking(False)
*/
                }

                /* "dbus_fast/message_bus.py":735
 *                         last_err = e
 *                     else:
 *                         stack.pop_all()             # <<<<<<<<<<<<<<
 *                         return
 * 
*/
                /*else:*/ {
                  __pyx_t_5 = __pyx_v_stack;
                  __Pyx_INCREF(__pyx_t_5);
                  __pyx_t_9 = 0;
                  {
                    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
                    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_pop_all, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 735, __pyx_L42_except_error)
                    __Pyx_GOTREF(__pyx_t_4);
                  }
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

                  /* "dbus_fast/message_bus.py":736
 *                     else:
 *                         stack.pop_all()
 *                         return             # <<<<<<<<<<<<<<
 * 
 *                 else:
*/
                  __Pyx_XDECREF(__pyx_r);
                  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                  goto __pyx_L43_except_return;
                }
                __pyx_L40_error:;
                __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
                __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

                /* "dbus_fast/message_bus.py":732
 *                         self._sock.connect((ip_addr, ip_port))
 *                         self._sock.setblocking(False)
 *                     except Exception as e:             # <<<<<<<<<<<<<<
 *                         last_err = e
 *                     else:
*/
                __pyx_t_22 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
                if (__pyx_t_22) {
                  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._setup_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
                  if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7) < 0) __PYX_ERR(0, 732, __pyx_L42_except_error)
                  __Pyx_XGOTREF(__pyx_t_4);
                  __Pyx_XGOTREF(__pyx_t_5);
                  __Pyx_XGOTREF(__pyx_t_7);
                  __Pyx_INCREF(__pyx_t_5);
                  __Pyx_XDECREF_SET(__pyx_v_e, __pyx_t_5);
                  /*try:*/ {

                    /* "dbus_fast/message_bus.py":733
 *                         self._sock.setblocking(False)
 *                     except Exception as e:
 *                         last_err = e             # <<<<<<<<<<<<<<
 *                     else:
 *                         stack.pop_all()
*/
                    __Pyx_INCREF(__pyx_v_e);
                    __Pyx_DECREF_SET(__pyx_v_last_err, __pyx_v_e);
                  }

                  /* "dbus_fast/message_bus.py":732
 *                         self._sock.connect((ip_addr, ip_port))
 *                         self._sock.setblocking(False)
 *                     except Exception as e:             # <<<<<<<<<<<<<<
 *                         last_err = e
 *                     else:
*/
                  /*finally:*/ {
                    /*normal exit:*/{
                      __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
                      goto __pyx_L54;
                    }
                    __pyx_L54:;
                  }
                  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                  goto __pyx_L41_exception_handled;
                }
                goto __pyx_L42_except_error;

                /* "dbus_fast/message_bus.py":729
 *                         ip_port = int(options["port"])
 * 
 *                     try:             # <<<<<<<<<<<<<<
 *                         self._sock.connect((ip_addr, ip_port))
 *                         self._sock.setblocking(False)
*/
                __pyx_L42_except_error:;
                __Pyx_XGIVEREF(__pyx_t_21);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_20, __pyx_t_19);
                goto __pyx_L13_error;
                __pyx_L43_except_return:;
                __Pyx_XGIVEREF(__pyx_t_21);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_20, __pyx_t_19);
                goto __pyx_L17_try_return;
                __pyx_L41_exception_handled:;
                __Pyx_XGIVEREF(__pyx_t_21);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_20, __pyx_t_19);
              }

              /* "dbus_fast/message_bus.py":717
 *                         return
 * 
 *                 elif transport == "tcp":             # <<<<<<<<<<<<<<
 *                     self._sock = stack.enter_context(
 *                         socket.socket(socket.AF_INET, socket.SOCK_STREAM)
*/
              goto __pyx_L21;
            }

            /* "dbus_fast/message_bus.py":739
 * 
 *                 else:
 *                     raise InvalidAddressError(             # <<<<<<<<<<<<<<
 *                         f"got unknown address transport: {transport}"
 *                     )
*/
            /*else*/ {
              __pyx_t_5 = NULL;
              __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_InvalidAddressError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 739, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_4);

              /* "dbus_fast/message_bus.py":740
 *                 else:
 *                     raise InvalidAddressError(
 *                         f"got unknown address transport: {transport}"             # <<<<<<<<<<<<<<
 *                     )
 * 
*/
              __pyx_t_17 = __Pyx_PyObject_FormatSimple(__pyx_v_transport, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 740, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_17);
              __pyx_t_15 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_got_unknown_address_transport, __pyx_t_17); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 740, __pyx_L13_error)
              __Pyx_GOTREF(__pyx_t_15);
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
              __pyx_t_9 = 1;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_4))) {
                __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
                assert(__pyx_t_5);
                PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
                __Pyx_INCREF(__pyx_t_5);
                __Pyx_INCREF(__pyx__function);
                __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
                __pyx_t_9 = 0;
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_15};
                __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 739, __pyx_L13_error)
                __Pyx_GOTREF(__pyx_t_7);
              }
              __Pyx_Raise(__pyx_t_7, 0, 0, 0);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
              __PYX_ERR(0, 739, __pyx_L13_error)
            }
            __pyx_L21:;

            /* "dbus_fast/message_bus.py":691
 *             ip_port = 0
 * 
 *             with ExitStack() as stack:             # <<<<<<<<<<<<<<
 *                 if transport == "unix":
 *                     self._sock = stack.enter_context(
*/
          }
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          goto __pyx_L20_try_end;
          __pyx_L13_error:;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          /*except:*/ {
            __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._setup_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_4, &__pyx_t_15) < 0) __PYX_ERR(0, 691, __pyx_L15_except_error)
            __Pyx_XGOTREF(__pyx_t_7);
            __Pyx_XGOTREF(__pyx_t_4);
            __Pyx_XGOTREF(__pyx_t_15);
            __pyx_t_5 = PyTuple_Pack(3, __pyx_t_7, __pyx_t_4, __pyx_t_15); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 691, __pyx_L15_except_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_5, NULL);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 691, __pyx_L15_except_error)
            __Pyx_GOTREF(__pyx_t_19);
            __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_19);
            __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
            if (__pyx_t_14 < (0)) __PYX_ERR(0, 691, __pyx_L15_except_error)
            __pyx_t_23 = (!__pyx_t_14);
            if (unlikely(__pyx_t_23)) {
              __Pyx_GIVEREF(__pyx_t_7);
              __Pyx_GIVEREF(__pyx_t_4);
              __Pyx_XGIVEREF(__pyx_t_15);
              __Pyx_ErrRestoreWithState(__pyx_t_7, __pyx_t_4, __pyx_t_15);
              __pyx_t_7 = 0;  __pyx_t_4 = 0;  __pyx_t_15 = 0; 
              __PYX_ERR(0, 691, __pyx_L15_except_error)
            }
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            goto __pyx_L14_exception_handled;
          }
          __pyx_L15_except_error:;
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
          goto __pyx_L1_error;
          __pyx_L17_try_return:;
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
          goto __pyx_L10_return;
          __pyx_L14_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
          __pyx_L20_try_end:;
        }
      }
      /*finally:*/ {
        /*normal exit:*/{
          if (__pyx_t_10) {
            __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_mstate_global->__pyx_tuple[0], NULL);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 691, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          }
          goto __pyx_L12;
        }
        __pyx_L10_return: {
          __pyx_t_13 = __pyx_r;
          __pyx_r = 0;
          if (__pyx_t_10) {
            __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_mstate_global->__pyx_tuple[0], NULL);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 691, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          }
          __pyx_r = __pyx_t_13;
          __pyx_t_13 = 0;
          goto __pyx_L0;
        }
        __pyx_L12:;
      }
      goto __pyx_L58;
      __pyx_L7_error:;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L1_error;
      __pyx_L58:;
    }

    /* "dbus_fast/message_bus.py":686
 *         last_err: Exception | None = None
 * 
 *         for transport, options in self._bus_address:             # <<<<<<<<<<<<<<
 *             filename: bytes | str | None = None
 *             ip_addr = ""
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":743
 *                     )
 * 
 *         if last_err is None:  # pragma: no branch             # <<<<<<<<<<<<<<
 *             # Should not normally happen, but just in case
 *             raise TypeError("empty list of bus addresses given")  # pragma: no cover
*/
  __pyx_t_23 = (__pyx_v_last_err == ((PyObject*)Py_None));
  if (unlikely(__pyx_t_23)) {

    /* "dbus_fast/message_bus.py":745
 *         if last_err is None:  # pragma: no branch
 *             # Should not normally happen, but just in case
 *             raise TypeError("empty list of bus addresses given")  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         raise last_err
*/
    __pyx_t_15 = NULL;
    __pyx_t_9 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_15, __pyx_mstate_global->__pyx_kp_u_empty_list_of_bus_addresses_give};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 745, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 745, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":743
 *                     )
 * 
 *         if last_err is None:  # pragma: no branch             # <<<<<<<<<<<<<<
 *             # Should not normally happen, but just in case
 *             raise TypeError("empty list of bus addresses given")  # pragma: no cover
*/
  }

  /* "dbus_fast/message_bus.py":747
 *             raise TypeError("empty list of bus addresses given")  # pragma: no cover
 * 
 *         raise last_err             # <<<<<<<<<<<<<<
 * 
 *     def _reply_notify(
*/
  __Pyx_Raise(__pyx_v_last_err, 0, 0, 0);
  __PYX_ERR(0, 747, __pyx_L1_error)

  /* "dbus_fast/message_bus.py":683
 *         return node
 * 
 *     def _setup_socket(self) -> None:             # <<<<<<<<<<<<<<
 *         last_err: Exception | None = None
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._setup_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_last_err);
  __Pyx_XDECREF(__pyx_v_transport);
  __Pyx_XDECREF(__pyx_v_options);
  __Pyx_XDECREF(__pyx_v_filename);
  __Pyx_XDECREF(__pyx_v_ip_addr);
  __Pyx_XDECREF(__pyx_v_ip_port);
  __Pyx_XDECREF(__pyx_v_stack);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":749
 *         raise last_err
 * 
 *     def _reply_notify(             # <<<<<<<<<<<<<<
 *         self,
 *         msg: Message,
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_35_reply_notify(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_34_reply_notify, "Callback on reply.");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_35_reply_notify = {"_reply_notify", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_35_reply_notify, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_34_reply_notify};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_35_reply_notify(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  PyObject *__pyx_v_callback = 0;
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply = 0;
  PyObject *__pyx_v_err = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_reply_notify (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_callback,&__pyx_mstate_global->__pyx_n_u_reply,&__pyx_mstate_global->__pyx_n_u_err,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 749, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 749, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 749, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 749, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 749, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_reply_notify", 0) < (0)) __PYX_ERR(0, 749, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 4; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_reply_notify", 1, 4, 4, i); __PYX_ERR(0, 749, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 749, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 749, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 749, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 749, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_callback = values[1];
    __pyx_v_reply = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[2]);
    __pyx_v_err = ((PyObject*)values[3]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_reply_notify", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 749, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._reply_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 0, "msg", 0))) __PYX_ERR(0, 751, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_reply), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 1, "reply", 0))) __PYX_ERR(0, 753, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 754, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_34_reply_notify(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_msg, __pyx_v_callback, __pyx_v_reply, __pyx_v_err);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_34_reply_notify(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_callback, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply, PyObject *__pyx_v_err) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_reply_notify", 0);

  /* "dbus_fast/message_bus.py":757
 *     ) -> None:
 *         """Callback on reply."""
 *         if reply and msg.destination and reply.sender:             # <<<<<<<<<<<<<<
 *             self._name_owners[msg.destination] = reply.sender
 *         callback(reply, err)
*/
  __pyx_t_2 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_reply)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 757, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_msg->destination); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 757, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_reply->sender); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 757, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":758
 *         """Callback on reply."""
 *         if reply and msg.destination and reply.sender:
 *             self._name_owners[msg.destination] = reply.sender             # <<<<<<<<<<<<<<
 *         callback(reply, err)
 * 
*/
    __pyx_t_3 = __pyx_v_reply->sender;
    __Pyx_INCREF(__pyx_t_3);
    if (unlikely(__pyx_v_self->_name_owners == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 758, __pyx_L1_error)
    }
    if (unlikely((PyDict_SetItem(__pyx_v_self->_name_owners, __pyx_v_msg->destination, __pyx_t_3) < 0))) __PYX_ERR(0, 758, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "dbus_fast/message_bus.py":757
 *     ) -> None:
 *         """Callback on reply."""
 *         if reply and msg.destination and reply.sender:             # <<<<<<<<<<<<<<
 *             self._name_owners[msg.destination] = reply.sender
 *         callback(reply, err)
*/
  }

  /* "dbus_fast/message_bus.py":759
 *         if reply and msg.destination and reply.sender:
 *             self._name_owners[msg.destination] = reply.sender
 *         callback(reply, err)             # <<<<<<<<<<<<<<
 * 
 *     def _call(
*/
  __pyx_t_4 = NULL;
  __Pyx_INCREF(__pyx_v_callback);
  __pyx_t_5 = __pyx_v_callback; 
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)__pyx_v_reply), __pyx_v_err};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "dbus_fast/message_bus.py":749
 *         raise last_err
 * 
 *     def _reply_notify(             # <<<<<<<<<<<<<<
 *         self,
 *         msg: Message,
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._reply_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":761
 *         callback(reply, err)
 * 
 *     def _call(             # <<<<<<<<<<<<<<
 *         self,
 *         msg: Message,
*/

static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_37_call(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__call(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_callback, int __pyx_skip_dispatch) {
  int __pyx_v_reply_expected;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  unsigned int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_call", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_call); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 761, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_37_call)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_3, ((PyObject *)__pyx_v_msg), __pyx_v_callback};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 761, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "dbus_fast/message_bus.py":766
 *         callback: Callable[[Message | None, Exception | None], None] | None,
 *     ) -> None:
 *         if not msg.serial:             # <<<<<<<<<<<<<<
 *             msg.serial = self.next_serial()
 * 
*/
  __pyx_t_6 = (!(__pyx_v_msg->serial != 0));
  if (__pyx_t_6) {

    /* "dbus_fast/message_bus.py":767
 *     ) -> None:
 *         if not msg.serial:
 *             msg.serial = self.next_serial()             # <<<<<<<<<<<<<<
 * 
 *         # Make sure the return reply handler is installed
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self->__pyx_vtab)->next_serial(__pyx_v_self, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyLong_As_unsigned_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (unsigned int)-1) && PyErr_Occurred())) __PYX_ERR(0, 767, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_msg->serial = __pyx_t_7;

    /* "dbus_fast/message_bus.py":766
 *         callback: Callable[[Message | None, Exception | None], None] | None,
 *     ) -> None:
 *         if not msg.serial:             # <<<<<<<<<<<<<<
 *             msg.serial = self.next_serial()
 * 
*/
  }

  /* "dbus_fast/message_bus.py":773
 *         # where the reply is lost in case the backend can
 *         # send it right away.
 *         if (reply_expected := _expects_reply(msg)) and callback is not None:             # <<<<<<<<<<<<<<
 *             self._method_return_handlers[msg.serial] = partial(
 *                 self._reply_notify, msg, callback
*/
  __pyx_t_8 = __pyx_f_9dbus_fast_11message_bus__expects_reply(__pyx_v_msg); if (unlikely(__pyx_t_8 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 773, __pyx_L1_error)
  __pyx_v_reply_expected = __pyx_t_8;
  __pyx_t_9 = __pyx_t_8;
  if (__pyx_t_9) {
  } else {
    __pyx_t_6 = __pyx_t_9;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_9 = (__pyx_v_callback != Py_None);
  __pyx_t_6 = __pyx_t_9;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_6) {

    /* "dbus_fast/message_bus.py":774
 *         # send it right away.
 *         if (reply_expected := _expects_reply(msg)) and callback is not None:
 *             self._method_return_handlers[msg.serial] = partial(             # <<<<<<<<<<<<<<
 *                 self._reply_notify, msg, callback
 *             )
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_partial); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 774, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);

    /* "dbus_fast/message_bus.py":775
 *         if (reply_expected := _expects_reply(msg)) and callback is not None:
 *             self._method_return_handlers[msg.serial] = partial(
 *                 self._reply_notify, msg, callback             # <<<<<<<<<<<<<<
 *             )
 * 
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_reply_notify); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 775, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_t_3, ((PyObject *)__pyx_v_msg), __pyx_v_callback};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 774, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }

    /* "dbus_fast/message_bus.py":774
 *         # send it right away.
 *         if (reply_expected := _expects_reply(msg)) and callback is not None:
 *             self._method_return_handlers[msg.serial] = partial(             # <<<<<<<<<<<<<<
 *                 self._reply_notify, msg, callback
 *             )
*/
    if (unlikely(__pyx_v_self->_method_return_handlers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 774, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PyLong_From_unsigned_int(__pyx_v_msg->serial); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 774, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely((PyDict_SetItem(__pyx_v_self->_method_return_handlers, __pyx_t_4, __pyx_t_1) < 0))) __PYX_ERR(0, 774, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":773
 *         # where the reply is lost in case the backend can
 *         # send it right away.
 *         if (reply_expected := _expects_reply(msg)) and callback is not None:             # <<<<<<<<<<<<<<
 *             self._method_return_handlers[msg.serial] = partial(
 *                 self._reply_notify, msg, callback
*/
  }

  /* "dbus_fast/message_bus.py":778
 *             )
 * 
 *         self.send(msg)             # <<<<<<<<<<<<<<
 * 
 *         if not reply_expected and callback is not None:
*/
  __pyx_t_4 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, ((PyObject *)__pyx_v_msg)};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":780
 *         self.send(msg)
 * 
 *         if not reply_expected and callback is not None:             # <<<<<<<<<<<<<<
 *             callback(None, None)
 * 
*/
  __pyx_t_9 = (!__pyx_v_reply_expected);
  if (__pyx_t_9) {
  } else {
    __pyx_t_6 = __pyx_t_9;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = (__pyx_v_callback != Py_None);
  __pyx_t_6 = __pyx_t_9;
  __pyx_L8_bool_binop_done:;
  if (__pyx_t_6) {

    /* "dbus_fast/message_bus.py":781
 * 
 *         if not reply_expected and callback is not None:
 *             callback(None, None)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_v_callback, __pyx_mstate_global->__pyx_tuple[1], NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 781, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":780
 *         self.send(msg)
 * 
 *         if not reply_expected and callback is not None:             # <<<<<<<<<<<<<<
 *             callback(None, None)
 * 
*/
  }

  /* "dbus_fast/message_bus.py":761
 *         callback(reply, err)
 * 
 *     def _call(             # <<<<<<<<<<<<<<
 *         self,
 *         msg: Message,
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._call", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_37_call(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_37_call = {"_call", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_37_call, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_37_call(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  PyObject *__pyx_v_callback = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_call (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_callback,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 761, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 761, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 761, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_call", 0) < (0)) __PYX_ERR(0, 761, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_call", 1, 2, 2, i); __PYX_ERR(0, 761, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 761, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 761, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_callback = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_call", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 761, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._call", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 0, "msg", 0))) __PYX_ERR(0, 763, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_36_call(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_msg, __pyx_v_callback);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_36_call(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_callback) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_call", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__call(__pyx_v_self, __pyx_v_msg, __pyx_v_callback, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._call", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":783
 *             callback(None, None)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _check_callback_type(callback: Callable) -> None:
 *         """Raise a TypeError if the user gives an invalid callback as a parameter"""
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_39_check_callback_type(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_38_check_callback_type, "Raise a TypeError if the user gives an invalid callback as a parameter");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_39_check_callback_type = {"_check_callback_type", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_39_check_callback_type, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_38_check_callback_type};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_39_check_callback_type(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_callback = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_check_callback_type (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_callback,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 783, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 783, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_check_callback_type", 0) < (0)) __PYX_ERR(0, 783, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_check_callback_type", 1, 1, 1, i); __PYX_ERR(0, 783, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 783, __pyx_L3_error)
    }
    __pyx_v_callback = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_check_callback_type", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 783, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._check_callback_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_38_check_callback_type(__pyx_v_callback);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_38_check_callback_type(PyObject *__pyx_v_callback) {
  PyObject *__pyx_v_text = NULL;
  PyObject *__pyx_v_fn_signature = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_check_callback_type", 0);

  /* "dbus_fast/message_bus.py":787
 *         """Raise a TypeError if the user gives an invalid callback as a parameter"""
 * 
 *         text = "a callback must be callable with two parameters"             # <<<<<<<<<<<<<<
 * 
 *         if not callable(callback):
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u_a_callback_must_be_callable_with);
  __pyx_v_text = __pyx_mstate_global->__pyx_kp_u_a_callback_must_be_callable_with;

  /* "dbus_fast/message_bus.py":789
 *         text = "a callback must be callable with two parameters"
 * 
 *         if not callable(callback):             # <<<<<<<<<<<<<<
 *             raise TypeError(text)
 * 
*/
  __pyx_t_1 = __Pyx_PyCallable_Check(__pyx_v_callback); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 789, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (unlikely(__pyx_t_2)) {

    /* "dbus_fast/message_bus.py":790
 * 
 *         if not callable(callback):
 *             raise TypeError(text)             # <<<<<<<<<<<<<<
 * 
 *         fn_signature = inspect.signature(callback)
*/
    __pyx_t_4 = NULL;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_text};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 790, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 790, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":789
 *         text = "a callback must be callable with two parameters"
 * 
 *         if not callable(callback):             # <<<<<<<<<<<<<<
 *             raise TypeError(text)
 * 
*/
  }

  /* "dbus_fast/message_bus.py":792
 *             raise TypeError(text)
 * 
 *         fn_signature = inspect.signature(callback)             # <<<<<<<<<<<<<<
 *         if len(fn_signature.parameters) != 2:
 *             raise TypeError(text)
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_inspect); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_signature); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_callback};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 792, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_v_fn_signature = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "dbus_fast/message_bus.py":793
 * 
 *         fn_signature = inspect.signature(callback)
 *         if len(fn_signature.parameters) != 2:             # <<<<<<<<<<<<<<
 *             raise TypeError(text)
 * 
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_fn_signature, __pyx_mstate_global->__pyx_n_u_parameters); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = (__pyx_t_8 != 2);
  if (unlikely(__pyx_t_2)) {

    /* "dbus_fast/message_bus.py":794
 *         fn_signature = inspect.signature(callback)
 *         if len(fn_signature.parameters) != 2:
 *             raise TypeError(text)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
    __pyx_t_7 = NULL;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_text};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 794, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 794, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":793
 * 
 *         fn_signature = inspect.signature(callback)
 *         if len(fn_signature.parameters) != 2:             # <<<<<<<<<<<<<<
 *             raise TypeError(text)
 * 
*/
  }

  /* "dbus_fast/message_bus.py":783
 *             callback(None, None)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _check_callback_type(callback: Callable) -> None:
 *         """Raise a TypeError if the user gives an invalid callback as a parameter"""
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._check_callback_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_v_fn_signature);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":796
 *             raise TypeError(text)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _check_method_return(
 *         msg: Message | None, err: Exception | None, signature: str
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_41_check_method_return(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_41_check_method_return = {"_check_method_return", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_41_check_method_return, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_41_check_method_return(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  PyObject *__pyx_v_err = 0;
  PyObject *__pyx_v_signature = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_check_method_return (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_err,&__pyx_mstate_global->__pyx_n_u_signature,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 796, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 796, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 796, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 796, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_check_method_return", 0) < (0)) __PYX_ERR(0, 796, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_check_method_return", 1, 3, 3, i); __PYX_ERR(0, 796, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 796, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 796, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 796, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_err = ((PyObject*)values[1]);
    __pyx_v_signature = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_check_method_return", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 796, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._check_method_return", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 1, "msg", 0))) __PYX_ERR(0, 798, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 798, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_signature), (&PyUnicode_Type), 0, "signature", 2))) __PYX_ERR(0, 798, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_40_check_method_return(__pyx_v_msg, __pyx_v_err, __pyx_v_signature);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_40_check_method_return(struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_err, PyObject *__pyx_v_signature) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_check_method_return", 0);

  /* "dbus_fast/message_bus.py":800
 *         msg: Message | None, err: Exception | None, signature: str
 *     ) -> None:
 *         if err:             # <<<<<<<<<<<<<<
 *             raise err
 *         if msg is None:
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_err); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 800, __pyx_L1_error)
  if (unlikely(__pyx_t_1)) {

    /* "dbus_fast/message_bus.py":801
 *     ) -> None:
 *         if err:
 *             raise err             # <<<<<<<<<<<<<<
 *         if msg is None:
 *             raise DBusError(
*/
    __Pyx_Raise(__pyx_v_err, 0, 0, 0);
    __PYX_ERR(0, 801, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":800
 *         msg: Message | None, err: Exception | None, signature: str
 *     ) -> None:
 *         if err:             # <<<<<<<<<<<<<<
 *             raise err
 *         if msg is None:
*/
  }

  /* "dbus_fast/message_bus.py":802
 *         if err:
 *             raise err
 *         if msg is None:             # <<<<<<<<<<<<<<
 *             raise DBusError(
 *                 ErrorType.INTERNAL_ERROR, "invalid message type for method call", msg
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_msg) == Py_None);
  if (unlikely(__pyx_t_1)) {

    /* "dbus_fast/message_bus.py":803
 *             raise err
 *         if msg is None:
 *             raise DBusError(             # <<<<<<<<<<<<<<
 *                 ErrorType.INTERNAL_ERROR, "invalid message type for method call", msg
 *             )
*/
    __pyx_t_3 = NULL;
    __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_DBusError);
    __pyx_t_4 = __pyx_v_9dbus_fast_11message_bus_DBusError; 

    /* "dbus_fast/message_bus.py":804
 *         if msg is None:
 *             raise DBusError(
 *                 ErrorType.INTERNAL_ERROR, "invalid message type for method call", msg             # <<<<<<<<<<<<<<
 *             )
 *         if msg.message_type == MessageType.METHOD_RETURN and msg.signature == signature:
*/
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_INTERNAL_ERROR); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_7 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_t_6, __pyx_mstate_global->__pyx_kp_u_invalid_message_type_for_method, ((PyObject *)__pyx_v_msg)};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_7, (4-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 803, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":802
 *         if err:
 *             raise err
 *         if msg is None:             # <<<<<<<<<<<<<<
 *             raise DBusError(
 *                 ErrorType.INTERNAL_ERROR, "invalid message type for method call", msg
*/
  }

  /* "dbus_fast/message_bus.py":806
 *                 ErrorType.INTERNAL_ERROR, "invalid message type for method call", msg
 *             )
 *         if msg.message_type == MessageType.METHOD_RETURN and msg.signature == signature:             # <<<<<<<<<<<<<<
 *             return
 *         if msg.message_type == MessageType.ERROR:
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_9dbus_fast_11message_bus_MessageType, __pyx_mstate_global->__pyx_n_u_METHOD_RETURN); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_msg->message_type, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 806, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 806, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_8) {
  } else {
    __pyx_t_1 = __pyx_t_8;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->signature, __pyx_v_signature, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 806, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_8;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":807
 *             )
 *         if msg.message_type == MessageType.METHOD_RETURN and msg.signature == signature:
 *             return             # <<<<<<<<<<<<<<
 *         if msg.message_type == MessageType.ERROR:
 *             raise DBusError._from_message(msg)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":806
 *                 ErrorType.INTERNAL_ERROR, "invalid message type for method call", msg
 *             )
 *         if msg.message_type == MessageType.METHOD_RETURN and msg.signature == signature:             # <<<<<<<<<<<<<<
 *             return
 *         if msg.message_type == MessageType.ERROR:
*/
  }

  /* "dbus_fast/message_bus.py":808
 *         if msg.message_type == MessageType.METHOD_RETURN and msg.signature == signature:
 *             return
 *         if msg.message_type == MessageType.ERROR:             # <<<<<<<<<<<<<<
 *             raise DBusError._from_message(msg)
 *         raise DBusError(
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_9dbus_fast_11message_bus_MessageType, __pyx_mstate_global->__pyx_n_u_ERROR); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_msg->message_type, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 808, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 808, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_1)) {

    /* "dbus_fast/message_bus.py":809
 *             return
 *         if msg.message_type == MessageType.ERROR:
 *             raise DBusError._from_message(msg)             # <<<<<<<<<<<<<<
 *         raise DBusError(
 *             ErrorType.INTERNAL_ERROR, "invalid message type for method call", msg
*/
    __pyx_t_4 = __pyx_v_9dbus_fast_11message_bus_DBusError;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, ((PyObject *)__pyx_v_msg)};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_message, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 809, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 809, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":808
 *         if msg.message_type == MessageType.METHOD_RETURN and msg.signature == signature:
 *             return
 *         if msg.message_type == MessageType.ERROR:             # <<<<<<<<<<<<<<
 *             raise DBusError._from_message(msg)
 *         raise DBusError(
*/
  }

  /* "dbus_fast/message_bus.py":810
 *         if msg.message_type == MessageType.ERROR:
 *             raise DBusError._from_message(msg)
 *         raise DBusError(             # <<<<<<<<<<<<<<
 *             ErrorType.INTERNAL_ERROR, "invalid message type for method call", msg
 *         )
*/
  __pyx_t_4 = NULL;
  __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_DBusError);
  __pyx_t_6 = __pyx_v_9dbus_fast_11message_bus_DBusError; 

  /* "dbus_fast/message_bus.py":811
 *             raise DBusError._from_message(msg)
 *         raise DBusError(
 *             ErrorType.INTERNAL_ERROR, "invalid message type for method call", msg             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_INTERNAL_ERROR); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
    __pyx_t_7 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_t_5, __pyx_mstate_global->__pyx_kp_u_invalid_message_type_for_method, ((PyObject *)__pyx_v_msg)};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (4-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 810, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(0, 810, __pyx_L1_error)

  /* "dbus_fast/message_bus.py":796
 *             raise TypeError(text)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _check_method_return(
 *         msg: Message | None, err: Exception | None, signature: str
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._check_method_return", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":814
 *         )
 * 
 *     def _process_message(self, msg: _Message) -> None:             # <<<<<<<<<<<<<<
 *         """Process a message received from the message bus."""
 *         handled = False
*/

static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_43_process_message(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static void __pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__process_message(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, int __pyx_skip_dispatch) {
  int __pyx_v_handled;
  PyObject *__pyx_v_user_handler = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_v_send_reply = NULL;
  PyObject *__pyx_v_return_handler = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_new_owner = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  char const *__pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28[4];
  char const *__pyx_t_29;
  int __pyx_t_30;
  PyObject *__pyx_t_31[6];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_process_message", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_process_message); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 814, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_43_process_message)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_msg)};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 814, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "dbus_fast/message_bus.py":816
 *     def _process_message(self, msg: _Message) -> None:
 *         """Process a message received from the message bus."""
 *         handled = False             # <<<<<<<<<<<<<<
 *         for user_handler in self._user_message_handlers:
 *             try:
*/
  __pyx_v_handled = 0;

  /* "dbus_fast/message_bus.py":817
 *         """Process a message received from the message bus."""
 *         handled = False
 *         for user_handler in self._user_message_handlers:             # <<<<<<<<<<<<<<
 *             try:
 *                 if result := user_handler(msg):
*/
  if (unlikely(__pyx_v_self->_user_message_handlers == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 817, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->_user_message_handlers; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_6 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 817, __pyx_L1_error)
      #endif
      if (__pyx_t_6 >= __pyx_temp) break;
    }
    __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_6;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 817, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_user_handler, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":818
 *         handled = False
 *         for user_handler in self._user_message_handlers:
 *             try:             # <<<<<<<<<<<<<<
 *                 if result := user_handler(msg):
 *                     if type(result) is Message:
*/
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      /*try:*/ {

        /* "dbus_fast/message_bus.py":819
 *         for user_handler in self._user_message_handlers:
 *             try:
 *                 if result := user_handler(msg):             # <<<<<<<<<<<<<<
 *                     if type(result) is Message:
 *                         self.send(result)
*/
        __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_user_handler);
        __pyx_t_3 = __pyx_v_user_handler; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          assert(__pyx_t_4);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, ((PyObject *)__pyx_v_msg)};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 819, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_result, __pyx_t_2);
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 819, __pyx_L5_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_10) {

          /* "dbus_fast/message_bus.py":820
 *             try:
 *                 if result := user_handler(msg):
 *                     if type(result) is Message:             # <<<<<<<<<<<<<<
 *                         self.send(result)
 *                     handled = True
*/
          __pyx_t_10 = (((PyObject *)Py_TYPE(__pyx_v_result)) == ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message));
          if (__pyx_t_10) {

            /* "dbus_fast/message_bus.py":821
 *                 if result := user_handler(msg):
 *                     if type(result) is Message:
 *                         self.send(result)             # <<<<<<<<<<<<<<
 *                     handled = True
 *                     break
*/
            __pyx_t_3 = ((PyObject *)__pyx_v_self);
            __Pyx_INCREF(__pyx_t_3);
            __pyx_t_5 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_result};
              __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 821, __pyx_L5_error)
              __Pyx_GOTREF(__pyx_t_2);
            }
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

            /* "dbus_fast/message_bus.py":820
 *             try:
 *                 if result := user_handler(msg):
 *                     if type(result) is Message:             # <<<<<<<<<<<<<<
 *                         self.send(result)
 *                     handled = True
*/
          }

          /* "dbus_fast/message_bus.py":822
 *                     if type(result) is Message:
 *                         self.send(result)
 *                     handled = True             # <<<<<<<<<<<<<<
 *                     break
 *             except DBusError as e:
*/
          __pyx_v_handled = 1;

          /* "dbus_fast/message_bus.py":823
 *                         self.send(result)
 *                     handled = True
 *                     break             # <<<<<<<<<<<<<<
 *             except DBusError as e:
 *                 if msg.message_type is MESSAGE_TYPE_CALL:
*/
          goto __pyx_L10_try_break;

          /* "dbus_fast/message_bus.py":819
 *         for user_handler in self._user_message_handlers:
 *             try:
 *                 if result := user_handler(msg):             # <<<<<<<<<<<<<<
 *                     if type(result) is Message:
 *                         self.send(result)
*/
        }

        /* "dbus_fast/message_bus.py":818
 *         handled = False
 *         for user_handler in self._user_message_handlers:
 *             try:             # <<<<<<<<<<<<<<
 *                 if result := user_handler(msg):
 *                     if type(result) is Message:
*/
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "dbus_fast/message_bus.py":824
 *                     handled = True
 *                     break
 *             except DBusError as e:             # <<<<<<<<<<<<<<
 *                 if msg.message_type is MESSAGE_TYPE_CALL:
 *                     self.send(e._as_message(msg))
*/
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_v_9dbus_fast_11message_bus_DBusError);
      if (__pyx_t_11) {
        __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._process_message", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4) < 0) __PYX_ERR(0, 824, __pyx_L7_except_error)
        __Pyx_XGOTREF(__pyx_t_2);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __pyx_v_e = __pyx_t_3;
        /*try:*/ {

          /* "dbus_fast/message_bus.py":825
 *                     break
 *             except DBusError as e:
 *                 if msg.message_type is MESSAGE_TYPE_CALL:             # <<<<<<<<<<<<<<
 *                     self.send(e._as_message(msg))
 *                     handled = True
*/
          __pyx_t_10 = (__pyx_v_msg->message_type == __pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_CALL);
          if (__pyx_t_10) {

            /* "dbus_fast/message_bus.py":826
 *             except DBusError as e:
 *                 if msg.message_type is MESSAGE_TYPE_CALL:
 *                     self.send(e._as_message(msg))             # <<<<<<<<<<<<<<
 *                     handled = True
 *                     break
*/
            __pyx_t_13 = ((PyObject *)__pyx_v_self);
            __Pyx_INCREF(__pyx_t_13);
            __pyx_t_15 = __pyx_v_e;
            __Pyx_INCREF(__pyx_t_15);
            __pyx_t_5 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_15, ((PyObject *)__pyx_v_msg)};
              __pyx_t_14 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_as_message, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 826, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_14);
            }
            __pyx_t_5 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_14};
              __pyx_t_12 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 826, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_12);
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "dbus_fast/message_bus.py":827
 *                 if msg.message_type is MESSAGE_TYPE_CALL:
 *                     self.send(e._as_message(msg))
 *                     handled = True             # <<<<<<<<<<<<<<
 *                     break
 *                 _LOGGER.exception("A message handler raised an exception: %s", e)
*/
            __pyx_v_handled = 1;

            /* "dbus_fast/message_bus.py":828
 *                     self.send(e._as_message(msg))
 *                     handled = True
 *                     break             # <<<<<<<<<<<<<<
 *                 _LOGGER.exception("A message handler raised an exception: %s", e)
 *             except Exception as e:
*/
            goto __pyx_L18_break;

            /* "dbus_fast/message_bus.py":825
 *                     break
 *             except DBusError as e:
 *                 if msg.message_type is MESSAGE_TYPE_CALL:             # <<<<<<<<<<<<<<
 *                     self.send(e._as_message(msg))
 *                     handled = True
*/
          }

          /* "dbus_fast/message_bus.py":829
 *                     handled = True
 *                     break
 *                 _LOGGER.exception("A message handler raised an exception: %s", e)             # <<<<<<<<<<<<<<
 *             except Exception as e:
 *                 _LOGGER.exception("A message handler raised an exception: %s", e)
*/
          __pyx_t_14 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_LOGGER); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 829, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_exception); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 829, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_5 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_15))) {
            __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_15);
            assert(__pyx_t_14);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_14);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_15, __pyx__function);
            __pyx_t_5 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_14, __pyx_mstate_global->__pyx_kp_u_A_message_handler_raised_an_exce, __pyx_v_e};
            __pyx_t_12 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_15, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 829, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_12);
          }
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        }

        /* "dbus_fast/message_bus.py":824
 *                     handled = True
 *                     break
 *             except DBusError as e:             # <<<<<<<<<<<<<<
 *                 if msg.message_type is MESSAGE_TYPE_CALL:
 *                     self.send(e._as_message(msg))
*/
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
            goto __pyx_L21;
          }
          __pyx_L20_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
             __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
            if ( unlikely(__Pyx_GetException(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_22);
            __Pyx_XGOTREF(__pyx_t_23);
            __pyx_t_11 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
            }
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_22, __pyx_t_23);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_ErrRestore(__pyx_t_18, __pyx_t_19, __pyx_t_20);
            __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
            __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
            goto __pyx_L7_except_error;
          }
          __pyx_L18_break: {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
            goto __pyx_L16_except_break;
          }
          __pyx_L21:;
        }
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L6_exception_handled;
        __pyx_L16_except_break:;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L10_try_break;
      }

      /* "dbus_fast/message_bus.py":830
 *                     break
 *                 _LOGGER.exception("A message handler raised an exception: %s", e)
 *             except Exception as e:             # <<<<<<<<<<<<<<
 *                 _LOGGER.exception("A message handler raised an exception: %s", e)
 *                 if msg.message_type is MESSAGE_TYPE_CALL:
*/
      __pyx_t_16 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
      if (__pyx_t_16) {
        __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._process_message", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_3, &__pyx_t_2) < 0) __PYX_ERR(0, 830, __pyx_L7_except_error)
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __pyx_v_e = __pyx_t_3;
        /*try:*/ {

          /* "dbus_fast/message_bus.py":831
 *                 _LOGGER.exception("A message handler raised an exception: %s", e)
 *             except Exception as e:
 *                 _LOGGER.exception("A message handler raised an exception: %s", e)             # <<<<<<<<<<<<<<
 *                 if msg.message_type is MESSAGE_TYPE_CALL:
 *                     self.send(
*/
          __pyx_t_15 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_mstate_global->__pyx_n_u_LOGGER); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 831, __pyx_L32_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_mstate_global->__pyx_n_u_exception); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 831, __pyx_L32_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_5 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_13))) {
            __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_13);
            assert(__pyx_t_15);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
            __Pyx_INCREF(__pyx_t_15);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
            __pyx_t_5 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_15, __pyx_mstate_global->__pyx_kp_u_A_message_handler_raised_an_exce, __pyx_v_e};
            __pyx_t_12 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 831, __pyx_L32_error)
            __Pyx_GOTREF(__pyx_t_12);
          }
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "dbus_fast/message_bus.py":832
 *             except Exception as e:
 *                 _LOGGER.exception("A message handler raised an exception: %s", e)
 *                 if msg.message_type is MESSAGE_TYPE_CALL:             # <<<<<<<<<<<<<<
 *                     self.send(
 *                         Message.new_error(
*/
          __pyx_t_10 = (__pyx_v_msg->message_type == __pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_CALL);
          if (__pyx_t_10) {

            /* "dbus_fast/message_bus.py":833
 *                 _LOGGER.exception("A message handler raised an exception: %s", e)
 *                 if msg.message_type is MESSAGE_TYPE_CALL:
 *                     self.send(             # <<<<<<<<<<<<<<
 *                         Message.new_error(
 *                             msg,
*/
            __pyx_t_13 = ((PyObject *)__pyx_v_self);
            __Pyx_INCREF(__pyx_t_13);

            /* "dbus_fast/message_bus.py":834
 *                 if msg.message_type is MESSAGE_TYPE_CALL:
 *                     self.send(
 *                         Message.new_error(             # <<<<<<<<<<<<<<
 *                             msg,
 *                             ErrorType.INTERNAL_ERROR,
*/
            __pyx_t_14 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
            __Pyx_INCREF(__pyx_t_14);

            /* "dbus_fast/message_bus.py":836
 *                         Message.new_error(
 *                             msg,
 *                             ErrorType.INTERNAL_ERROR,             # <<<<<<<<<<<<<<
 *                             f"An internal error occurred: {e}.\n{traceback.format_exc()}",
 *                         )
*/
            __Pyx_GetModuleGlobalName(__pyx_t_24, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 836, __pyx_L32_error)
            __Pyx_GOTREF(__pyx_t_24);
            __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_t_24, __pyx_mstate_global->__pyx_n_u_INTERNAL_ERROR); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 836, __pyx_L32_error)
            __Pyx_GOTREF(__pyx_t_25);
            __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;

            /* "dbus_fast/message_bus.py":837
 *                             msg,
 *                             ErrorType.INTERNAL_ERROR,
 *                             f"An internal error occurred: {e}.\n{traceback.format_exc()}",             # <<<<<<<<<<<<<<
 *                         )
 *                     )
*/
            __pyx_t_24 = __Pyx_PyObject_FormatSimple(__pyx_v_e, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 837, __pyx_L32_error)
            __Pyx_GOTREF(__pyx_t_24);
            __Pyx_GetModuleGlobalName(__pyx_t_26, __pyx_mstate_global->__pyx_n_u_traceback); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 837, __pyx_L32_error)
            __Pyx_GOTREF(__pyx_t_26);
            __pyx_t_27 = __Pyx_PyObject_GetAttrStr(__pyx_t_26, __pyx_mstate_global->__pyx_n_u_format_exc); if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 837, __pyx_L32_error)
            __Pyx_GOTREF(__pyx_t_27);
            __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;
            __pyx_t_26 = __Pyx_PyObject_CallNoArg(__pyx_t_27); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 837, __pyx_L32_error)
            __Pyx_GOTREF(__pyx_t_26);
            __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;
            __pyx_t_27 = __Pyx_PyObject_FormatSimple(__pyx_t_26, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 837, __pyx_L32_error)
            __Pyx_GOTREF(__pyx_t_27);
            __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;
            __pyx_t_28[0] = __pyx_mstate_global->__pyx_kp_u_An_internal_error_occurred;
            __pyx_t_28[1] = __pyx_t_24;
            __pyx_t_28[2] = __pyx_mstate_global->__pyx_kp_u__9;
            __pyx_t_28[3] = __pyx_t_27;
            __pyx_t_26 = __Pyx_PyUnicode_Join(__pyx_t_28, 4, 28 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_24) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_27), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_24) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_27));
            if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 837, __pyx_L32_error)
            __Pyx_GOTREF(__pyx_t_26);
            __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
            __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;
            __pyx_t_5 = 0;
            {
              PyObject *__pyx_callargs[4] = {__pyx_t_14, ((PyObject *)__pyx_v_msg), __pyx_t_25, __pyx_t_26};
              __pyx_t_15 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new_error, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
              __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;
              if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 834, __pyx_L32_error)
              __Pyx_GOTREF(__pyx_t_15);
            }
            __pyx_t_5 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_15};
              __pyx_t_12 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 833, __pyx_L32_error)
              __Pyx_GOTREF(__pyx_t_12);
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "dbus_fast/message_bus.py":840
 *                         )
 *                     )
 *                     handled = True             # <<<<<<<<<<<<<<
 *                     break
 * 
*/
            __pyx_v_handled = 1;

            /* "dbus_fast/message_bus.py":841
 *                     )
 *                     handled = True
 *                     break             # <<<<<<<<<<<<<<
 * 
 *         if msg.message_type is MESSAGE_TYPE_SIGNAL:
*/
            goto __pyx_L30_break;

            /* "dbus_fast/message_bus.py":832
 *             except Exception as e:
 *                 _LOGGER.exception("A message handler raised an exception: %s", e)
 *                 if msg.message_type is MESSAGE_TYPE_CALL:             # <<<<<<<<<<<<<<
 *                     self.send(
 *                         Message.new_error(
*/
          }
        }

        /* "dbus_fast/message_bus.py":830
 *                     break
 *                 _LOGGER.exception("A message handler raised an exception: %s", e)
 *             except Exception as e:             # <<<<<<<<<<<<<<
 *                 _LOGGER.exception("A message handler raised an exception: %s", e)
 *                 if msg.message_type is MESSAGE_TYPE_CALL:
*/
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
            goto __pyx_L33;
          }
          __pyx_L32_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_23 = 0; __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
            __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
            __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
            __Pyx_XDECREF(__pyx_t_27); __pyx_t_27 = 0;
             __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_19, &__pyx_t_18);
            if ( unlikely(__Pyx_GetException(&__pyx_t_23, &__pyx_t_22, &__pyx_t_21) < 0)) __Pyx_ErrFetch(&__pyx_t_23, &__pyx_t_22, &__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_23);
            __Pyx_XGOTREF(__pyx_t_22);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_18);
            __pyx_t_16 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_29 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
            }
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_19, __pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_ErrRestore(__pyx_t_23, __pyx_t_22, __pyx_t_21);
            __pyx_t_23 = 0; __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0;
            __pyx_lineno = __pyx_t_16; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_29;
            goto __pyx_L7_except_error;
          }
          __pyx_L30_break: {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
            goto __pyx_L28_except_break;
          }
          __pyx_L33:;
        }
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L6_exception_handled;
        __pyx_L28_except_break:;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L10_try_break;
      }
      goto __pyx_L7_except_error;

      /* "dbus_fast/message_bus.py":818
 *         handled = False
 *         for user_handler in self._user_message_handlers:
 *             try:             # <<<<<<<<<<<<<<
 *                 if result := user_handler(msg):
 *                     if type(result) is Message:
*/
      __pyx_L7_except_error:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L1_error;
      __pyx_L10_try_break:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L4_break;
      __pyx_L6_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      __pyx_L12_try_end:;
    }

    /* "dbus_fast/message_bus.py":817
 *         """Process a message received from the message bus."""
 *         handled = False
 *         for user_handler in self._user_message_handlers:             # <<<<<<<<<<<<<<
 *             try:
 *                 if result := user_handler(msg):
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L39_for_end;
  __pyx_L4_break:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L39_for_end;
  __pyx_L39_for_end:;

  /* "dbus_fast/message_bus.py":843
 *                     break
 * 
 *         if msg.message_type is MESSAGE_TYPE_SIGNAL:             # <<<<<<<<<<<<<<
 *             if (
 *                 msg.member == "NameOwnerChanged"
*/
  __pyx_t_10 = (__pyx_v_msg->message_type == __pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_SIGNAL);
  if (__pyx_t_10) {

    /* "dbus_fast/message_bus.py":845
 *         if msg.message_type is MESSAGE_TYPE_SIGNAL:
 *             if (
 *                 msg.member == "NameOwnerChanged"             # <<<<<<<<<<<<<<
 *                 and msg.sender == "org.freedesktop.DBus"
 *                 and msg.path == "/org/freedesktop/DBus"
*/
    __pyx_t_30 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->member, __pyx_mstate_global->__pyx_n_u_NameOwnerChanged, Py_EQ)); if (unlikely((__pyx_t_30 < 0))) __PYX_ERR(0, 845, __pyx_L1_error)
    if (__pyx_t_30) {
    } else {
      __pyx_t_10 = __pyx_t_30;
      goto __pyx_L42_bool_binop_done;
    }

    /* "dbus_fast/message_bus.py":846
 *             if (
 *                 msg.member == "NameOwnerChanged"
 *                 and msg.sender == "org.freedesktop.DBus"             # <<<<<<<<<<<<<<
 *                 and msg.path == "/org/freedesktop/DBus"
 *                 and msg.interface == "org.freedesktop.DBus"
*/
    __pyx_t_30 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->sender, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus, Py_EQ)); if (unlikely((__pyx_t_30 < 0))) __PYX_ERR(0, 846, __pyx_L1_error)
    if (__pyx_t_30) {
    } else {
      __pyx_t_10 = __pyx_t_30;
      goto __pyx_L42_bool_binop_done;
    }

    /* "dbus_fast/message_bus.py":847
 *                 msg.member == "NameOwnerChanged"
 *                 and msg.sender == "org.freedesktop.DBus"
 *                 and msg.path == "/org/freedesktop/DBus"             # <<<<<<<<<<<<<<
 *                 and msg.interface == "org.freedesktop.DBus"
 *             ):
*/
    __pyx_t_30 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->path, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_2, Py_EQ)); if (unlikely((__pyx_t_30 < 0))) __PYX_ERR(0, 847, __pyx_L1_error)
    if (__pyx_t_30) {
    } else {
      __pyx_t_10 = __pyx_t_30;
      goto __pyx_L42_bool_binop_done;
    }

    /* "dbus_fast/message_bus.py":848
 *                 and msg.sender == "org.freedesktop.DBus"
 *                 and msg.path == "/org/freedesktop/DBus"
 *                 and msg.interface == "org.freedesktop.DBus"             # <<<<<<<<<<<<<<
 *             ):
 *                 name = msg.body[0]
*/
    __pyx_t_30 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus, Py_EQ)); if (unlikely((__pyx_t_30 < 0))) __PYX_ERR(0, 848, __pyx_L1_error)
    __pyx_t_10 = __pyx_t_30;
    __pyx_L42_bool_binop_done:;

    /* "dbus_fast/message_bus.py":844
 * 
 *         if msg.message_type is MESSAGE_TYPE_SIGNAL:
 *             if (             # <<<<<<<<<<<<<<
 *                 msg.member == "NameOwnerChanged"
 *                 and msg.sender == "org.freedesktop.DBus"
*/
    if (__pyx_t_10) {

      /* "dbus_fast/message_bus.py":850
 *                 and msg.interface == "org.freedesktop.DBus"
 *             ):
 *                 name = msg.body[0]             # <<<<<<<<<<<<<<
 *                 if new_owner := msg.body[2]:
 *                     self._name_owners[name] = new_owner
*/
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_msg->body, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_name = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "dbus_fast/message_bus.py":851
 *             ):
 *                 name = msg.body[0]
 *                 if new_owner := msg.body[2]:             # <<<<<<<<<<<<<<
 *                     self._name_owners[name] = new_owner
 *                 elif name in self._name_owners:
*/
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_msg->body, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 851, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_v_new_owner = __pyx_t_1;
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 851, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_10) {

        /* "dbus_fast/message_bus.py":852
 *                 name = msg.body[0]
 *                 if new_owner := msg.body[2]:
 *                     self._name_owners[name] = new_owner             # <<<<<<<<<<<<<<
 *                 elif name in self._name_owners:
 *                     del self._name_owners[name]
*/
        if (unlikely(__pyx_v_self->_name_owners == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 852, __pyx_L1_error)
        }
        if (unlikely((PyDict_SetItem(__pyx_v_self->_name_owners, __pyx_v_name, __pyx_v_new_owner) < 0))) __PYX_ERR(0, 852, __pyx_L1_error)

        /* "dbus_fast/message_bus.py":851
 *             ):
 *                 name = msg.body[0]
 *                 if new_owner := msg.body[2]:             # <<<<<<<<<<<<<<
 *                     self._name_owners[name] = new_owner
 *                 elif name in self._name_owners:
*/
        goto __pyx_L46;
      }

      /* "dbus_fast/message_bus.py":853
 *                 if new_owner := msg.body[2]:
 *                     self._name_owners[name] = new_owner
 *                 elif name in self._name_owners:             # <<<<<<<<<<<<<<
 *                     del self._name_owners[name]
 *             return
*/
      if (unlikely(__pyx_v_self->_name_owners == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 853, __pyx_L1_error)
      }
      __pyx_t_10 = (__Pyx_PyDict_ContainsTF(__pyx_v_name, __pyx_v_self->_name_owners, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 853, __pyx_L1_error)
      if (__pyx_t_10) {

        /* "dbus_fast/message_bus.py":854
 *                     self._name_owners[name] = new_owner
 *                 elif name in self._name_owners:
 *                     del self._name_owners[name]             # <<<<<<<<<<<<<<
 *             return
 * 
*/
        if (unlikely(__pyx_v_self->_name_owners == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 854, __pyx_L1_error)
        }
        if (unlikely((PyDict_DelItem(__pyx_v_self->_name_owners, __pyx_v_name) < 0))) __PYX_ERR(0, 854, __pyx_L1_error)

        /* "dbus_fast/message_bus.py":853
 *                 if new_owner := msg.body[2]:
 *                     self._name_owners[name] = new_owner
 *                 elif name in self._name_owners:             # <<<<<<<<<<<<<<
 *                     del self._name_owners[name]
 *             return
*/
      }
      __pyx_L46:;

      /* "dbus_fast/message_bus.py":844
 * 
 *         if msg.message_type is MESSAGE_TYPE_SIGNAL:
 *             if (             # <<<<<<<<<<<<<<
 *                 msg.member == "NameOwnerChanged"
 *                 and msg.sender == "org.freedesktop.DBus"
*/
    }

    /* "dbus_fast/message_bus.py":855
 *                 elif name in self._name_owners:
 *                     del self._name_owners[name]
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if msg.message_type is MESSAGE_TYPE_CALL:
*/
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":843
 *                     break
 * 
 *         if msg.message_type is MESSAGE_TYPE_SIGNAL:             # <<<<<<<<<<<<<<
 *             if (
 *                 msg.member == "NameOwnerChanged"
*/
  }

  /* "dbus_fast/message_bus.py":857
 *             return
 * 
 *         if msg.message_type is MESSAGE_TYPE_CALL:             # <<<<<<<<<<<<<<
 *             if not handled:
 *                 handler = self._find_message_handler(msg)
*/
  __pyx_t_10 = (__pyx_v_msg->message_type == __pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_CALL);
  if (__pyx_t_10) {

    /* "dbus_fast/message_bus.py":858
 * 
 *         if msg.message_type is MESSAGE_TYPE_CALL:
 *             if not handled:             # <<<<<<<<<<<<<<
 *                 handler = self._find_message_handler(msg)
 *                 if not _expects_reply(msg):
*/
    __pyx_t_10 = (!__pyx_v_handled);
    if (__pyx_t_10) {

      /* "dbus_fast/message_bus.py":859
 *         if msg.message_type is MESSAGE_TYPE_CALL:
 *             if not handled:
 *                 handler = self._find_message_handler(msg)             # <<<<<<<<<<<<<<
 *                 if not _expects_reply(msg):
 *                     if handler:
*/
      __pyx_t_1 = ((struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self->__pyx_vtab)->_find_message_handler(__pyx_v_self, __pyx_v_msg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_handler = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "dbus_fast/message_bus.py":860
 *             if not handled:
 *                 handler = self._find_message_handler(msg)
 *                 if not _expects_reply(msg):             # <<<<<<<<<<<<<<
 *                     if handler:
 *                         handler(msg, BLOCK_UNEXPECTED_REPLY)  # type: ignore[arg-type]
*/
      __pyx_t_10 = __pyx_f_9dbus_fast_11message_bus__expects_reply(__pyx_v_msg); if (unlikely(__pyx_t_10 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 860, __pyx_L1_error)
      __pyx_t_30 = (!__pyx_t_10);
      if (__pyx_t_30) {

        /* "dbus_fast/message_bus.py":861
 *                 handler = self._find_message_handler(msg)
 *                 if not _expects_reply(msg):
 *                     if handler:             # <<<<<<<<<<<<<<
 *                         handler(msg, BLOCK_UNEXPECTED_REPLY)  # type: ignore[arg-type]
 *                     else:
*/
        __pyx_t_30 = __Pyx_PyObject_IsTrue(__pyx_v_handler); if (unlikely((__pyx_t_30 < 0))) __PYX_ERR(0, 861, __pyx_L1_error)
        if (__pyx_t_30) {

          /* "dbus_fast/message_bus.py":862
 *                 if not _expects_reply(msg):
 *                     if handler:
 *                         handler(msg, BLOCK_UNEXPECTED_REPLY)  # type: ignore[arg-type]             # <<<<<<<<<<<<<<
 *                     else:
 *                         _LOGGER.error(
*/
          __pyx_t_2 = NULL;
          __Pyx_INCREF(__pyx_v_handler);
          __pyx_t_3 = __pyx_v_handler; 
          __pyx_t_5 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
            assert(__pyx_t_2);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
            __pyx_t_5 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_2, ((PyObject *)__pyx_v_msg), __pyx_v_9dbus_fast_11message_bus_BLOCK_UNEXPECTED_REPLY};
            __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 862, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "dbus_fast/message_bus.py":861
 *                 handler = self._find_message_handler(msg)
 *                 if not _expects_reply(msg):
 *                     if handler:             # <<<<<<<<<<<<<<
 *                         handler(msg, BLOCK_UNEXPECTED_REPLY)  # type: ignore[arg-type]
 *                     else:
*/
          goto __pyx_L50;
        }

        /* "dbus_fast/message_bus.py":864
 *                         handler(msg, BLOCK_UNEXPECTED_REPLY)  # type: ignore[arg-type]
 *                     else:
 *                         _LOGGER.error(             # <<<<<<<<<<<<<<
 *                             '"%s.%s" with signature "%s" could not be found',
 *                             msg.interface,
*/
        /*else*/ {
          __pyx_t_3 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_LOGGER); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 864, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_error); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 864, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "dbus_fast/message_bus.py":868
 *                             msg.interface,
 *                             msg.member,
 *                             msg.signature,             # <<<<<<<<<<<<<<
 *                         )
 *                     return
*/
          __pyx_t_5 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
            assert(__pyx_t_3);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
            __pyx_t_5 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[5] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_s_s_with_signature_s_could_not, __pyx_v_msg->interface, __pyx_v_msg->member, __pyx_v_msg->signature};
            __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (5-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 864, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __pyx_L50:;

        /* "dbus_fast/message_bus.py":870
 *                             msg.signature,
 *                         )
 *                     return             # <<<<<<<<<<<<<<
 * 
 *                 send_reply = SendReply(self, msg)
*/
        goto __pyx_L0;

        /* "dbus_fast/message_bus.py":860
 *             if not handled:
 *                 handler = self._find_message_handler(msg)
 *                 if not _expects_reply(msg):             # <<<<<<<<<<<<<<
 *                     if handler:
 *                         handler(msg, BLOCK_UNEXPECTED_REPLY)  # type: ignore[arg-type]
*/
      }

      /* "dbus_fast/message_bus.py":872
 *                     return
 * 
 *                 send_reply = SendReply(self, msg)             # <<<<<<<<<<<<<<
 *                 with send_reply:
 *                     if handler:
*/
      __pyx_t_4 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_SendReply); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 872, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        assert(__pyx_t_4);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)__pyx_v_self), ((PyObject *)__pyx_v_msg)};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 872, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_v_send_reply = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "dbus_fast/message_bus.py":873
 * 
 *                 send_reply = SendReply(self, msg)
 *                 with send_reply:             # <<<<<<<<<<<<<<
 *                     if handler:
 *                         handler(msg, send_reply)
*/
      /*with:*/ {
        __pyx_t_9 = __Pyx_PyObject_LookupSpecial(__pyx_v_send_reply, __pyx_mstate_global->__pyx_n_u_exit); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 873, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_3 = NULL;
        __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_v_send_reply, __pyx_mstate_global->__pyx_n_u_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 873, __pyx_L51_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 873, __pyx_L51_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        /*try:*/ {
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_7, &__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_8);
            __Pyx_XGOTREF(__pyx_t_7);
            __Pyx_XGOTREF(__pyx_t_18);
            /*try:*/ {

              /* "dbus_fast/message_bus.py":874
 *                 send_reply = SendReply(self, msg)
 *                 with send_reply:
 *                     if handler:             # <<<<<<<<<<<<<<
 *                         handler(msg, send_reply)
 *                     else:
*/
              __pyx_t_30 = __Pyx_PyObject_IsTrue(__pyx_v_handler); if (unlikely((__pyx_t_30 < 0))) __PYX_ERR(0, 874, __pyx_L55_error)
              if (__pyx_t_30) {

                /* "dbus_fast/message_bus.py":875
 *                 with send_reply:
 *                     if handler:
 *                         handler(msg, send_reply)             # <<<<<<<<<<<<<<
 *                     else:
 *                         send_reply(
*/
                __pyx_t_4 = NULL;
                __Pyx_INCREF(__pyx_v_handler);
                __pyx_t_3 = __pyx_v_handler; 
                __pyx_t_5 = 1;
                #if CYTHON_UNPACK_METHODS
                if (unlikely(PyMethod_Check(__pyx_t_3))) {
                  __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
                  assert(__pyx_t_4);
                  PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
                  __Pyx_INCREF(__pyx_t_4);
                  __Pyx_INCREF(__pyx__function);
                  __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
                  __pyx_t_5 = 0;
                }
                #endif
                {
                  PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)__pyx_v_msg), __pyx_v_send_reply};
                  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 875, __pyx_L55_error)
                  __Pyx_GOTREF(__pyx_t_1);
                }
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

                /* "dbus_fast/message_bus.py":874
 *                 send_reply = SendReply(self, msg)
 *                 with send_reply:
 *                     if handler:             # <<<<<<<<<<<<<<
 *                         handler(msg, send_reply)
 *                     else:
*/
                goto __pyx_L61;
              }

              /* "dbus_fast/message_bus.py":877
 *                         handler(msg, send_reply)
 *                     else:
 *                         send_reply(             # <<<<<<<<<<<<<<
 *                             Message.new_error(
 *                                 msg,
*/
              /*else*/ {
                __pyx_t_3 = NULL;
                __Pyx_INCREF(__pyx_v_send_reply);
                __pyx_t_4 = __pyx_v_send_reply; 

                /* "dbus_fast/message_bus.py":878
 *                     else:
 *                         send_reply(
 *                             Message.new_error(             # <<<<<<<<<<<<<<
 *                                 msg,
 *                                 ErrorType.UNKNOWN_METHOD,
*/
                __pyx_t_12 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
                __Pyx_INCREF(__pyx_t_12);

                /* "dbus_fast/message_bus.py":880
 *                             Message.new_error(
 *                                 msg,
 *                                 ErrorType.UNKNOWN_METHOD,             # <<<<<<<<<<<<<<
 *                                 f"{msg.interface}.{msg.member} with signature "
 *                                 f'"{msg.signature}" could not be found',
*/
                __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 880, __pyx_L55_error)
                __Pyx_GOTREF(__pyx_t_15);
                __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_UNKNOWN_METHOD); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 880, __pyx_L55_error)
                __Pyx_GOTREF(__pyx_t_13);
                __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

                /* "dbus_fast/message_bus.py":881
 *                                 msg,
 *                                 ErrorType.UNKNOWN_METHOD,
 *                                 f"{msg.interface}.{msg.member} with signature "             # <<<<<<<<<<<<<<
 *                                 f'"{msg.signature}" could not be found',
 *                             )
*/
                __pyx_t_15 = __Pyx_PyObject_FormatSimple(__pyx_v_msg->interface, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 881, __pyx_L55_error)
                __Pyx_GOTREF(__pyx_t_15);
                __pyx_t_26 = __Pyx_PyObject_FormatSimple(__pyx_v_msg->member, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 881, __pyx_L55_error)
                __Pyx_GOTREF(__pyx_t_26);

                /* "dbus_fast/message_bus.py":882
 *                                 ErrorType.UNKNOWN_METHOD,
 *                                 f"{msg.interface}.{msg.member} with signature "
 *                                 f'"{msg.signature}" could not be found',             # <<<<<<<<<<<<<<
 *                             )
 *                         )
*/
                __pyx_t_25 = __Pyx_PyUnicode_Unicode(__pyx_v_msg->signature); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 882, __pyx_L55_error)
                __Pyx_GOTREF(__pyx_t_25);
                __pyx_t_31[0] = __pyx_t_15;
                __pyx_t_31[1] = __pyx_mstate_global->__pyx_kp_u__10;
                __pyx_t_31[2] = __pyx_t_26;
                __pyx_t_31[3] = __pyx_mstate_global->__pyx_kp_u_with_signature;
                __pyx_t_31[4] = __pyx_t_25;
                __pyx_t_31[5] = __pyx_mstate_global->__pyx_kp_u_could_not_be_found;

                /* "dbus_fast/message_bus.py":881
 *                                 msg,
 *                                 ErrorType.UNKNOWN_METHOD,
 *                                 f"{msg.interface}.{msg.member} with signature "             # <<<<<<<<<<<<<<
 *                                 f'"{msg.signature}" could not be found',
 *                             )
*/
                __pyx_t_14 = __Pyx_PyUnicode_Join(__pyx_t_31, 6, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_15) + 1 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_26) + 17 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_25) + 20, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_15) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_26) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_25));
                if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 881, __pyx_L55_error)
                __Pyx_GOTREF(__pyx_t_14);
                __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
                __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;
                __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                __pyx_t_5 = 0;
                {
                  PyObject *__pyx_callargs[4] = {__pyx_t_12, ((PyObject *)__pyx_v_msg), __pyx_t_13, __pyx_t_14};
                  __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new_error, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 878, __pyx_L55_error)
                  __Pyx_GOTREF(__pyx_t_2);
                }
                __pyx_t_5 = 1;
                #if CYTHON_UNPACK_METHODS
                if (unlikely(PyMethod_Check(__pyx_t_4))) {
                  __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
                  assert(__pyx_t_3);
                  PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
                  __Pyx_INCREF(__pyx_t_3);
                  __Pyx_INCREF(__pyx__function);
                  __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
                  __pyx_t_5 = 0;
                }
                #endif
                {
                  PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
                  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 877, __pyx_L55_error)
                  __Pyx_GOTREF(__pyx_t_1);
                }
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              }
              __pyx_L61:;

              /* "dbus_fast/message_bus.py":873
 * 
 *                 send_reply = SendReply(self, msg)
 *                 with send_reply:             # <<<<<<<<<<<<<<
 *                     if handler:
 *                         handler(msg, send_reply)
*/
            }
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
            goto __pyx_L60_try_end;
            __pyx_L55_error:;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
            __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
            __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
            __Pyx_XDECREF(__pyx_t_27); __pyx_t_27 = 0;
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            /*except:*/ {
              __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._process_message", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_2) < 0) __PYX_ERR(0, 873, __pyx_L57_except_error)
              __Pyx_XGOTREF(__pyx_t_1);
              __Pyx_XGOTREF(__pyx_t_4);
              __Pyx_XGOTREF(__pyx_t_2);
              __pyx_t_3 = PyTuple_Pack(3, __pyx_t_1, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 873, __pyx_L57_except_error)
              __Pyx_GOTREF(__pyx_t_3);
              __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_3, NULL);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 873, __pyx_L57_except_error)
              __Pyx_GOTREF(__pyx_t_19);
              __pyx_t_30 = __Pyx_PyObject_IsTrue(__pyx_t_19);
              __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
              if (__pyx_t_30 < (0)) __PYX_ERR(0, 873, __pyx_L57_except_error)
              __pyx_t_10 = (!__pyx_t_30);
              if (unlikely(__pyx_t_10)) {
                __Pyx_GIVEREF(__pyx_t_1);
                __Pyx_GIVEREF(__pyx_t_4);
                __Pyx_XGIVEREF(__pyx_t_2);
                __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_4, __pyx_t_2);
                __pyx_t_1 = 0;  __pyx_t_4 = 0;  __pyx_t_2 = 0; 
                __PYX_ERR(0, 873, __pyx_L57_except_error)
              }
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              goto __pyx_L56_exception_handled;
            }
            __pyx_L57_except_error:;
            __Pyx_XGIVEREF(__pyx_t_8);
            __Pyx_XGIVEREF(__pyx_t_7);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_18);
            goto __pyx_L1_error;
            __pyx_L56_exception_handled:;
            __Pyx_XGIVEREF(__pyx_t_8);
            __Pyx_XGIVEREF(__pyx_t_7);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_18);
            __pyx_L60_try_end:;
          }
        }
        /*finally:*/ {
          /*normal exit:*/{
            if (__pyx_t_9) {
              __pyx_t_18 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_mstate_global->__pyx_tuple[0], NULL);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 873, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_18);
              __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            }
            goto __pyx_L54;
          }
          __pyx_L54:;
        }
        goto __pyx_L65;
        __pyx_L51_error:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L1_error;
        __pyx_L65:;
      }

      /* "dbus_fast/message_bus.py":858
 * 
 *         if msg.message_type is MESSAGE_TYPE_CALL:
 *             if not handled:             # <<<<<<<<<<<<<<
 *                 handler = self._find_message_handler(msg)
 *                 if not _expects_reply(msg):
*/
    }

    /* "dbus_fast/message_bus.py":885
 *                             )
 *                         )
 *             return             # <<<<<<<<<<<<<<
 * 
 *         # An ERROR or a METHOD_RETURN
*/
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":857
 *             return
 * 
 *         if msg.message_type is MESSAGE_TYPE_CALL:             # <<<<<<<<<<<<<<
 *             if not handled:
 *                 handler = self._find_message_handler(msg)
*/
  }

  /* "dbus_fast/message_bus.py":888
 * 
 *         # An ERROR or a METHOD_RETURN
 *         return_handler = self._method_return_handlers.get(msg.reply_serial)             # <<<<<<<<<<<<<<
 *         if return_handler is not None:
 *             if not handled:
*/
  if (unlikely(__pyx_v_self->_method_return_handlers == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
    __PYX_ERR(0, 888, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyLong_From_unsigned_int(__pyx_v_msg->reply_serial); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyDict_GetItemDefault(__pyx_v_self->_method_return_handlers, __pyx_t_2, Py_None); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_return_handler = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "dbus_fast/message_bus.py":889
 *         # An ERROR or a METHOD_RETURN
 *         return_handler = self._method_return_handlers.get(msg.reply_serial)
 *         if return_handler is not None:             # <<<<<<<<<<<<<<
 *             if not handled:
 *                 return_handler(msg, None)
*/
  __pyx_t_10 = (__pyx_v_return_handler != Py_None);
  if (__pyx_t_10) {

    /* "dbus_fast/message_bus.py":890
 *         return_handler = self._method_return_handlers.get(msg.reply_serial)
 *         if return_handler is not None:
 *             if not handled:             # <<<<<<<<<<<<<<
 *                 return_handler(msg, None)
 *             del self._method_return_handlers[msg.reply_serial]
*/
    __pyx_t_10 = (!__pyx_v_handled);
    if (__pyx_t_10) {

      /* "dbus_fast/message_bus.py":891
 *         if return_handler is not None:
 *             if not handled:
 *                 return_handler(msg, None)             # <<<<<<<<<<<<<<
 *             del self._method_return_handlers[msg.reply_serial]
 * 
*/
      __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_return_handler);
      __pyx_t_1 = __pyx_v_return_handler; 
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_2, ((PyObject *)__pyx_v_msg), Py_None};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 891, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "dbus_fast/message_bus.py":890
 *         return_handler = self._method_return_handlers.get(msg.reply_serial)
 *         if return_handler is not None:
 *             if not handled:             # <<<<<<<<<<<<<<
 *                 return_handler(msg, None)
 *             del self._method_return_handlers[msg.reply_serial]
*/
    }

    /* "dbus_fast/message_bus.py":892
 *             if not handled:
 *                 return_handler(msg, None)
 *             del self._method_return_handlers[msg.reply_serial]             # <<<<<<<<<<<<<<
 * 
 *     def _callback_method_handler(
*/
    if (unlikely(__pyx_v_self->_method_return_handlers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 892, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PyLong_From_unsigned_int(__pyx_v_msg->reply_serial); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 892, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely((PyDict_DelItem(__pyx_v_self->_method_return_handlers, __pyx_t_4) < 0))) __PYX_ERR(0, 892, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "dbus_fast/message_bus.py":889
 *         # An ERROR or a METHOD_RETURN
 *         return_handler = self._method_return_handlers.get(msg.reply_serial)
 *         if return_handler is not None:             # <<<<<<<<<<<<<<
 *             if not handled:
 *                 return_handler(msg, None)
*/
  }

  /* "dbus_fast/message_bus.py":814
 *         )
 * 
 *     def _process_message(self, msg: _Message) -> None:             # <<<<<<<<<<<<<<
 *         """Process a message received from the message bus."""
 *         handled = False
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_XDECREF(__pyx_t_27);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._process_message", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_user_handler);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XDECREF(__pyx_v_send_reply);
  __Pyx_XDECREF(__pyx_v_return_handler);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_new_owner);
  __Pyx_RefNannyFinishContext();
}

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_43_process_message(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_42_process_message, "Process a message received from the message bus.");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_43_process_message = {"_process_message", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_43_process_message, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_42_process_message};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_43_process_message(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_process_message (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 814, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 814, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_process_message", 0) < (0)) __PYX_ERR(0, 814, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_process_message", 1, 1, 1, i); __PYX_ERR(0, 814, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 814, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_process_message", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 814, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._process_message", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 1, "msg", 0))) __PYX_ERR(0, 814, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_42_process_message(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_msg);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_42_process_message(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_process_message", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__process_message(__pyx_v_self, __pyx_v_msg, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 814, __pyx_L1_error)
  __pyx_t_1 = __Pyx_void_to_None(NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._process_message", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":894
 *             del self._method_return_handlers[msg.reply_serial]
 * 
 *     def _callback_method_handler(             # <<<<<<<<<<<<<<
 *         self,
 *         interface: ServiceInterface,
*/

static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_45_callback_method_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static void __pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__callback_method_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, struct __pyx_obj_9dbus_fast_7service__Method *__pyx_v_method, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_body_fds = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_callback_method_handler", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_callback_method_handler); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_45_callback_method_handler)) {
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[5] = {__pyx_t_3, ((PyObject *)__pyx_v_interface), ((PyObject *)__pyx_v_method), ((PyObject *)__pyx_v_msg), __pyx_v_send_reply};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (5-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 894, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "dbus_fast/message_bus.py":902
 *     ) -> None:
 *         """This is the callback that will be called when a method call is."""
 *         args = ServiceInterface._c_msg_body_to_args(msg) if msg.unix_fds else msg.body             # <<<<<<<<<<<<<<
 *         result = method.fn(interface, *args)
 *         if send_reply is BLOCK_UNEXPECTED_REPLY or _expects_reply(msg) is False:
*/
  if (__pyx_v_msg->unix_fds == Py_None) __pyx_t_6 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_msg->unix_fds);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 902, __pyx_L1_error)
    __pyx_t_6 = (__pyx_temp != 0);
  }

  if (__pyx_t_6) {
    __pyx_t_2 = __pyx_vtabptr_9dbus_fast_7service_ServiceInterface->_c_msg_body_to_args(__pyx_v_msg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 902, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
  } else {
    __Pyx_INCREF(__pyx_v_msg->body);
    __pyx_t_1 = __pyx_v_msg->body;
  }
  __pyx_v_args = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":903
 *         """This is the callback that will be called when a method call is."""
 *         args = ServiceInterface._c_msg_body_to_args(msg) if msg.unix_fds else msg.body
 *         result = method.fn(interface, *args)             # <<<<<<<<<<<<<<
 *         if send_reply is BLOCK_UNEXPECTED_REPLY or _expects_reply(msg) is False:
 *             return
*/
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_interface);
  __Pyx_GIVEREF((PyObject *)__pyx_v_interface);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_interface)) != (0)) __PYX_ERR(0, 903, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PySequence_Tuple(__pyx_v_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_v_method->fn, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":904
 *         args = ServiceInterface._c_msg_body_to_args(msg) if msg.unix_fds else msg.body
 *         result = method.fn(interface, *args)
 *         if send_reply is BLOCK_UNEXPECTED_REPLY or _expects_reply(msg) is False:             # <<<<<<<<<<<<<<
 *             return
 *         body_fds = ServiceInterface._c_fn_result_to_body(
*/
  __pyx_t_7 = (__pyx_v_send_reply == __pyx_v_9dbus_fast_11message_bus_BLOCK_UNEXPECTED_REPLY);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_6 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_7 = __pyx_f_9dbus_fast_11message_bus__expects_reply(__pyx_v_msg); if (unlikely(__pyx_t_7 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 904, __pyx_L1_error)
  __pyx_t_8 = (__pyx_t_7 == 0);
  __pyx_t_6 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_6) {

    /* "dbus_fast/message_bus.py":905
 *         result = method.fn(interface, *args)
 *         if send_reply is BLOCK_UNEXPECTED_REPLY or _expects_reply(msg) is False:
 *             return             # <<<<<<<<<<<<<<
 *         body_fds = ServiceInterface._c_fn_result_to_body(
 *             result,
*/
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":904
 *         args = ServiceInterface._c_msg_body_to_args(msg) if msg.unix_fds else msg.body
 *         result = method.fn(interface, *args)
 *         if send_reply is BLOCK_UNEXPECTED_REPLY or _expects_reply(msg) is False:             # <<<<<<<<<<<<<<
 *             return
 *         body_fds = ServiceInterface._c_fn_result_to_body(
*/
  }

  /* "dbus_fast/message_bus.py":908
 *         body_fds = ServiceInterface._c_fn_result_to_body(
 *             result,
 *             method.out_signature_tree,             # <<<<<<<<<<<<<<
 *             self._negotiate_unix_fd,
 *         )
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_method->out_signature_tree);
  __Pyx_INCREF(__pyx_t_2);

  /* "dbus_fast/message_bus.py":906
 *         if send_reply is BLOCK_UNEXPECTED_REPLY or _expects_reply(msg) is False:
 *             return
 *         body_fds = ServiceInterface._c_fn_result_to_body(             # <<<<<<<<<<<<<<
 *             result,
 *             method.out_signature_tree,
*/
  __pyx_t_4 = __pyx_vtabptr_9dbus_fast_7service_ServiceInterface->_c_fn_result_to_body(__pyx_v_result, ((struct __pyx_obj_9dbus_fast_9signature_SignatureTree *)__pyx_t_2), __pyx_v_self->_negotiate_unix_fd); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_body_fds = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "dbus_fast/message_bus.py":911
 *             self._negotiate_unix_fd,
 *         )
 *         send_reply(             # <<<<<<<<<<<<<<
 *             Message(
 *                 message_type=MessageType.METHOD_RETURN,
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_send_reply);
  __pyx_t_1 = __pyx_v_send_reply; 

  /* "dbus_fast/message_bus.py":912
 *         )
 *         send_reply(
 *             Message(             # <<<<<<<<<<<<<<
 *                 message_type=MessageType.METHOD_RETURN,
 *                 reply_serial=msg.serial,
*/
  __pyx_t_9 = NULL;

  /* "dbus_fast/message_bus.py":913
 *         send_reply(
 *             Message(
 *                 message_type=MessageType.METHOD_RETURN,             # <<<<<<<<<<<<<<
 *                 reply_serial=msg.serial,
 *                 destination=msg.sender,
*/
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_9dbus_fast_11message_bus_MessageType, __pyx_mstate_global->__pyx_n_u_METHOD_RETURN); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);

  /* "dbus_fast/message_bus.py":914
 *             Message(
 *                 message_type=MessageType.METHOD_RETURN,
 *                 reply_serial=msg.serial,             # <<<<<<<<<<<<<<
 *                 destination=msg.sender,
 *                 signature=method.out_signature,
*/
  __pyx_t_11 = __Pyx_PyLong_From_unsigned_int(__pyx_v_msg->serial); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);

  /* "dbus_fast/message_bus.py":917
 *                 destination=msg.sender,
 *                 signature=method.out_signature,
 *                 body=body_fds[0],             # <<<<<<<<<<<<<<
 *                 unix_fds=body_fds[1],
 *             )
*/
  if (unlikely(__pyx_v_body_fds == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 917, __pyx_L1_error)
  }
  __pyx_t_12 = __Pyx_GetItemInt_Tuple(__pyx_v_body_fds, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);

  /* "dbus_fast/message_bus.py":918
 *                 signature=method.out_signature,
 *                 body=body_fds[0],
 *                 unix_fds=body_fds[1],             # <<<<<<<<<<<<<<
 *             )
 *         )
*/
  if (unlikely(__pyx_v_body_fds == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 918, __pyx_L1_error)
  }
  __pyx_t_13 = __Pyx_GetItemInt_Tuple(__pyx_v_body_fds, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 6 : 0)] = {__pyx_t_9, NULL};
    __pyx_t_14 = __Pyx_MakeVectorcallBuilderKwds(6); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_message_type, __pyx_t_10, __pyx_t_14, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 912, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_reply_serial, __pyx_t_11, __pyx_t_14, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 912, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_destination, __pyx_v_msg->sender, __pyx_t_14, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 912, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_signature, __pyx_v_method->out_signature, __pyx_t_14, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 912, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_t_12, __pyx_t_14, __pyx_callargs+1, 4) < (0)) __PYX_ERR(0, 912, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_unix_fds, __pyx_t_13, __pyx_t_14, __pyx_callargs+1, 5) < (0)) __PYX_ERR(0, 912, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_14);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 912, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_3);
  }
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_t_3)};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF((PyObject *)__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "dbus_fast/message_bus.py":894
 *             del self._method_return_handlers[msg.reply_serial]
 * 
 *     def _callback_method_handler(             # <<<<<<<<<<<<<<
 *         self,
 *         interface: ServiceInterface,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._callback_method_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_body_fds);
  __Pyx_RefNannyFinishContext();
}

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_45_callback_method_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_44_callback_method_handler, "This is the callback that will be called when a method call is.");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_45_callback_method_handler = {"_callback_method_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_45_callback_method_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_44_callback_method_handler};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_45_callback_method_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface = 0;
  struct __pyx_obj_9dbus_fast_7service__Method *__pyx_v_method = 0;
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  PyObject *__pyx_v_send_reply = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_callback_method_handler (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_interface,&__pyx_mstate_global->__pyx_n_u_method,&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_send_reply,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 894, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 894, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 894, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 894, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 894, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_callback_method_handler", 0) < (0)) __PYX_ERR(0, 894, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 4; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_callback_method_handler", 1, 4, 4, i); __PYX_ERR(0, 894, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 894, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 894, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 894, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 894, __pyx_L3_error)
    }
    __pyx_v_interface = ((struct __pyx_obj_9dbus_fast_7service_ServiceInterface *)values[0]);
    __pyx_v_method = ((struct __pyx_obj_9dbus_fast_7service__Method *)values[1]);
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[2]);
    __pyx_v_send_reply = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_callback_method_handler", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 894, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._callback_method_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_interface), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface, 0, "interface", 0))) __PYX_ERR(0, 896, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_method), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service__Method, 0, "method", 0))) __PYX_ERR(0, 897, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 0, "msg", 0))) __PYX_ERR(0, 898, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_44_callback_method_handler(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_interface, __pyx_v_method, __pyx_v_msg, __pyx_v_send_reply);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_44_callback_method_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, struct __pyx_obj_9dbus_fast_7service__Method *__pyx_v_method, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_callback_method_handler", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__callback_method_handler(__pyx_v_self, __pyx_v_interface, __pyx_v_method, __pyx_v_msg, __pyx_v_send_reply, 1); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 894, __pyx_L1_error)
  __pyx_t_1 = __Pyx_void_to_None(NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._callback_method_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":922
 *         )
 * 
 *     def _make_method_handler(             # <<<<<<<<<<<<<<
 *         self, interface: ServiceInterface, method: _Method
 *     ) -> HandlerType:
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_47_make_method_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_47_make_method_handler = {"_make_method_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_47_make_method_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_47_make_method_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface = 0;
  struct __pyx_obj_9dbus_fast_7service__Method *__pyx_v_method = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_make_method_handler (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_interface,&__pyx_mstate_global->__pyx_n_u_method,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 922, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 922, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 922, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_make_method_handler", 0) < (0)) __PYX_ERR(0, 922, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_make_method_handler", 1, 2, 2, i); __PYX_ERR(0, 922, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 922, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 922, __pyx_L3_error)
    }
    __pyx_v_interface = ((struct __pyx_obj_9dbus_fast_7service_ServiceInterface *)values[0]);
    __pyx_v_method = ((struct __pyx_obj_9dbus_fast_7service__Method *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_make_method_handler", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 922, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._make_method_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_interface), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface, 0, "interface", 0))) __PYX_ERR(0, 923, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_method), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service__Method, 0, "method", 0))) __PYX_ERR(0, 923, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_46_make_method_handler(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_interface, __pyx_v_method);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_46_make_method_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, struct __pyx_obj_9dbus_fast_7service__Method *__pyx_v_method) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_make_method_handler", 0);

  /* "dbus_fast/message_bus.py":925
 *         self, interface: ServiceInterface, method: _Method
 *     ) -> HandlerType:
 *         return partial(self._callback_method_handler, interface, method)             # <<<<<<<<<<<<<<
 * 
 *     def _find_message_handler(self, msg: _Message) -> HandlerType | None:
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_partial); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_callback_method_handler); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_t_4, ((PyObject *)__pyx_v_interface), ((PyObject *)__pyx_v_method)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "dbus_fast/message_bus.py":922
 *         )
 * 
 *     def _make_method_handler(             # <<<<<<<<<<<<<<
 *         self, interface: ServiceInterface, method: _Method
 *     ) -> HandlerType:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._make_method_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":927
 *         return partial(self._callback_method_handler, interface, method)
 * 
 *     def _find_message_handler(self, msg: _Message) -> HandlerType | None:             # <<<<<<<<<<<<<<
 *         """Find the message handler for for METHOD_CALL messages."""
 *         if TYPE_CHECKING:
*/

static PyObject *__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__find_message_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg) {
  struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface = 0;
  PyObject *__pyx_v_interfaces = 0;
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_find_message_handler", 0);

  /* "dbus_fast/message_bus.py":929
 *     def _find_message_handler(self, msg: _Message) -> HandlerType | None:
 *         """Find the message handler for for METHOD_CALL messages."""
 *         if TYPE_CHECKING:             # <<<<<<<<<<<<<<
 *             assert msg.member is not None
 *             assert msg.path is not None
*/
  if (__pyx_v_9dbus_fast_11message_bus_TYPE_CHECKING) {

    /* "dbus_fast/message_bus.py":930
 *         """Find the message handler for for METHOD_CALL messages."""
 *         if TYPE_CHECKING:
 *             assert msg.member is not None             # <<<<<<<<<<<<<<
 *             assert msg.path is not None
 * 
*/
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      __pyx_t_1 = (__pyx_v_msg->member != Py_None);
      if (unlikely(!__pyx_t_1)) {
        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
        __PYX_ERR(0, 930, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 930, __pyx_L1_error)
    #endif

    /* "dbus_fast/message_bus.py":931
 *         if TYPE_CHECKING:
 *             assert msg.member is not None
 *             assert msg.path is not None             # <<<<<<<<<<<<<<
 * 
 *         if msg.interface is not None and "org.freedesktop.DBus." in msg.interface:
*/
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      __pyx_t_1 = (__pyx_v_msg->path != Py_None);
      if (unlikely(!__pyx_t_1)) {
        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
        __PYX_ERR(0, 931, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 931, __pyx_L1_error)
    #endif

    /* "dbus_fast/message_bus.py":929
 *     def _find_message_handler(self, msg: _Message) -> HandlerType | None:
 *         """Find the message handler for for METHOD_CALL messages."""
 *         if TYPE_CHECKING:             # <<<<<<<<<<<<<<
 *             assert msg.member is not None
 *             assert msg.path is not None
*/
  }

  /* "dbus_fast/message_bus.py":933
 *             assert msg.path is not None
 * 
 *         if msg.interface is not None and "org.freedesktop.DBus." in msg.interface:             # <<<<<<<<<<<<<<
 *             if (
 *                 msg.interface == "org.freedesktop.DBus.Introspectable"
*/
  __pyx_t_2 = (__pyx_v_msg->interface != Py_None);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_3, __pyx_v_msg->interface, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 933, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":935
 *         if msg.interface is not None and "org.freedesktop.DBus." in msg.interface:
 *             if (
 *                 msg.interface == "org.freedesktop.DBus.Introspectable"             # <<<<<<<<<<<<<<
 *                 and msg.member == "Introspect"
 *                 and msg.signature == ""
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_Introspecta, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 935, __pyx_L1_error)
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L8_bool_binop_done;
    }

    /* "dbus_fast/message_bus.py":936
 *             if (
 *                 msg.interface == "org.freedesktop.DBus.Introspectable"
 *                 and msg.member == "Introspect"             # <<<<<<<<<<<<<<
 *                 and msg.signature == ""
 *             ):
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->member, __pyx_mstate_global->__pyx_n_u_Introspect, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 936, __pyx_L1_error)
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L8_bool_binop_done;
    }

    /* "dbus_fast/message_bus.py":937
 *                 msg.interface == "org.freedesktop.DBus.Introspectable"
 *                 and msg.member == "Introspect"
 *                 and msg.signature == ""             # <<<<<<<<<<<<<<
 *             ):
 *                 return self._default_introspect_handler
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->signature, __pyx_mstate_global->__pyx_kp_u__7, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 937, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_2;
    __pyx_L8_bool_binop_done:;

    /* "dbus_fast/message_bus.py":934
 * 
 *         if msg.interface is not None and "org.freedesktop.DBus." in msg.interface:
 *             if (             # <<<<<<<<<<<<<<
 *                 msg.interface == "org.freedesktop.DBus.Introspectable"
 *                 and msg.member == "Introspect"
*/
    if (__pyx_t_1) {

      /* "dbus_fast/message_bus.py":939
 *                 and msg.signature == ""
 *             ):
 *                 return self._default_introspect_handler             # <<<<<<<<<<<<<<
 * 
 *             if msg.interface == "org.freedesktop.DBus.Properties":
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_default_introspect_handler); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 939, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;

      /* "dbus_fast/message_bus.py":934
 * 
 *         if msg.interface is not None and "org.freedesktop.DBus." in msg.interface:
 *             if (             # <<<<<<<<<<<<<<
 *                 msg.interface == "org.freedesktop.DBus.Introspectable"
 *                 and msg.member == "Introspect"
*/
    }

    /* "dbus_fast/message_bus.py":941
 *                 return self._default_introspect_handler
 * 
 *             if msg.interface == "org.freedesktop.DBus.Properties":             # <<<<<<<<<<<<<<
 *                 return self._default_properties_handler
 * 
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_Properties, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 941, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "dbus_fast/message_bus.py":942
 * 
 *             if msg.interface == "org.freedesktop.DBus.Properties":
 *                 return self._default_properties_handler             # <<<<<<<<<<<<<<
 * 
 *             if msg.interface == "org.freedesktop.DBus.Peer":
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_default_properties_handler); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 942, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;

      /* "dbus_fast/message_bus.py":941
 *                 return self._default_introspect_handler
 * 
 *             if msg.interface == "org.freedesktop.DBus.Properties":             # <<<<<<<<<<<<<<
 *                 return self._default_properties_handler
 * 
*/
    }

    /* "dbus_fast/message_bus.py":944
 *                 return self._default_properties_handler
 * 
 *             if msg.interface == "org.freedesktop.DBus.Peer":             # <<<<<<<<<<<<<<
 *                 if msg.member == "Ping" and msg.signature == "":
 *                     return self._default_ping_handler
*/
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_Peer, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 944, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "dbus_fast/message_bus.py":945
 * 
 *             if msg.interface == "org.freedesktop.DBus.Peer":
 *                 if msg.member == "Ping" and msg.signature == "":             # <<<<<<<<<<<<<<
 *                     return self._default_ping_handler
 *                 if msg.member == "GetMachineId" and msg.signature == "":
*/
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->member, __pyx_mstate_global->__pyx_n_u_Ping, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 945, __pyx_L1_error)
      if (__pyx_t_2) {
      } else {
        __pyx_t_1 = __pyx_t_2;
        goto __pyx_L14_bool_binop_done;
      }
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->signature, __pyx_mstate_global->__pyx_kp_u__7, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 945, __pyx_L1_error)
      __pyx_t_1 = __pyx_t_2;
      __pyx_L14_bool_binop_done:;
      if (__pyx_t_1) {

        /* "dbus_fast/message_bus.py":946
 *             if msg.interface == "org.freedesktop.DBus.Peer":
 *                 if msg.member == "Ping" and msg.signature == "":
 *                     return self._default_ping_handler             # <<<<<<<<<<<<<<
 *                 if msg.member == "GetMachineId" and msg.signature == "":
 *                     return self._default_get_machine_id_handler
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_default_ping_handler); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 946, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "dbus_fast/message_bus.py":945
 * 
 *             if msg.interface == "org.freedesktop.DBus.Peer":
 *                 if msg.member == "Ping" and msg.signature == "":             # <<<<<<<<<<<<<<
 *                     return self._default_ping_handler
 *                 if msg.member == "GetMachineId" and msg.signature == "":
*/
      }

      /* "dbus_fast/message_bus.py":947
 *                 if msg.member == "Ping" and msg.signature == "":
 *                     return self._default_ping_handler
 *                 if msg.member == "GetMachineId" and msg.signature == "":             # <<<<<<<<<<<<<<
 *                     return self._default_get_machine_id_handler
 * 
*/
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->member, __pyx_mstate_global->__pyx_n_u_GetMachineId, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 947, __pyx_L1_error)
      if (__pyx_t_2) {
      } else {
        __pyx_t_1 = __pyx_t_2;
        goto __pyx_L17_bool_binop_done;
      }
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->signature, __pyx_mstate_global->__pyx_kp_u__7, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 947, __pyx_L1_error)
      __pyx_t_1 = __pyx_t_2;
      __pyx_L17_bool_binop_done:;
      if (__pyx_t_1) {

        /* "dbus_fast/message_bus.py":948
 *                     return self._default_ping_handler
 *                 if msg.member == "GetMachineId" and msg.signature == "":
 *                     return self._default_get_machine_id_handler             # <<<<<<<<<<<<<<
 * 
 *             if (
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_default_get_machine_id_handler); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 948, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "dbus_fast/message_bus.py":947
 *                 if msg.member == "Ping" and msg.signature == "":
 *                     return self._default_ping_handler
 *                 if msg.member == "GetMachineId" and msg.signature == "":             # <<<<<<<<<<<<<<
 *                     return self._default_get_machine_id_handler
 * 
*/
      }

      /* "dbus_fast/message_bus.py":944
 *                 return self._default_properties_handler
 * 
 *             if msg.interface == "org.freedesktop.DBus.Peer":             # <<<<<<<<<<<<<<
 *                 if msg.member == "Ping" and msg.signature == "":
 *                     return self._default_ping_handler
*/
    }

    /* "dbus_fast/message_bus.py":951
 * 
 *             if (
 *                 msg.interface == "org.freedesktop.DBus.ObjectManager"             # <<<<<<<<<<<<<<
 *                 and msg.member == "GetManagedObjects"
 *             ):
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_ObjectManag, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 951, __pyx_L1_error)
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L20_bool_binop_done;
    }

    /* "dbus_fast/message_bus.py":952
 *             if (
 *                 msg.interface == "org.freedesktop.DBus.ObjectManager"
 *                 and msg.member == "GetManagedObjects"             # <<<<<<<<<<<<<<
 *             ):
 *                 return self._default_get_managed_objects_handler
*/
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_msg->member, __pyx_mstate_global->__pyx_n_u_GetManagedObjects, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 952, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_2;
    __pyx_L20_bool_binop_done:;

    /* "dbus_fast/message_bus.py":950
 *                     return self._default_get_machine_id_handler
 * 
 *             if (             # <<<<<<<<<<<<<<
 *                 msg.interface == "org.freedesktop.DBus.ObjectManager"
 *                 and msg.member == "GetManagedObjects"
*/
    if (__pyx_t_1) {

      /* "dbus_fast/message_bus.py":954
 *                 and msg.member == "GetManagedObjects"
 *             ):
 *                 return self._default_get_managed_objects_handler             # <<<<<<<<<<<<<<
 * 
 *         if (interfaces := self._path_exports.get(msg.path)) is None:
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_default_get_managed_objects_han); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 954, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;

      /* "dbus_fast/message_bus.py":950
 *                     return self._default_get_machine_id_handler
 * 
 *             if (             # <<<<<<<<<<<<<<
 *                 msg.interface == "org.freedesktop.DBus.ObjectManager"
 *                 and msg.member == "GetManagedObjects"
*/
    }

    /* "dbus_fast/message_bus.py":933
 *             assert msg.path is not None
 * 
 *         if msg.interface is not None and "org.freedesktop.DBus." in msg.interface:             # <<<<<<<<<<<<<<
 *             if (
 *                 msg.interface == "org.freedesktop.DBus.Introspectable"
*/
  }

  /* "dbus_fast/message_bus.py":956
 *                 return self._default_get_managed_objects_handler
 * 
 *         if (interfaces := self._path_exports.get(msg.path)) is None:             # <<<<<<<<<<<<<<
 *             return None
 * 
*/
  if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
    __PYX_ERR(0, 956, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyDict_GetItemDefault(__pyx_v_self->_path_exports, __pyx_v_msg->path, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!(likely(PyDict_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_3))) __PYX_ERR(0, 956, __pyx_L1_error)
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_interfaces = ((PyObject*)__pyx_t_3);
  __pyx_t_1 = (__pyx_t_3 == ((PyObject*)Py_None));
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":957
 * 
 *         if (interfaces := self._path_exports.get(msg.path)) is None:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         if msg.interface is None:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":956
 *                 return self._default_get_managed_objects_handler
 * 
 *         if (interfaces := self._path_exports.get(msg.path)) is None:             # <<<<<<<<<<<<<<
 *             return None
 * 
*/
  }

  /* "dbus_fast/message_bus.py":959
 *             return None
 * 
 *         if msg.interface is None:             # <<<<<<<<<<<<<<
 *             return self._find_any_message_handler_matching_signature(interfaces, msg)
 * 
*/
  __pyx_t_1 = (__pyx_v_msg->interface == Py_None);
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":960
 * 
 *         if msg.interface is None:
 *             return self._find_any_message_handler_matching_signature(interfaces, msg)             # <<<<<<<<<<<<<<
 * 
 *         if (interface := interfaces.get(msg.interface)) is not None and (
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = ((struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self->__pyx_vtab)->_find_any_message_handler_matching_signature(__pyx_v_self, __pyx_v_interfaces, __pyx_v_msg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 960, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":959
 *             return None
 * 
 *         if msg.interface is None:             # <<<<<<<<<<<<<<
 *             return self._find_any_message_handler_matching_signature(interfaces, msg)
 * 
*/
  }

  /* "dbus_fast/message_bus.py":962
 *             return self._find_any_message_handler_matching_signature(interfaces, msg)
 * 
 *         if (interface := interfaces.get(msg.interface)) is not None and (             # <<<<<<<<<<<<<<
 *             handler := ServiceInterface._get_enabled_handler_by_name_signature(
 *                 interface, self, msg.member, msg.signature
*/
  if (unlikely(__pyx_v_interfaces == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
    __PYX_ERR(0, 962, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyDict_GetItemDefault(__pyx_v_interfaces, __pyx_v_msg->interface, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface))))) __PYX_ERR(0, 962, __pyx_L1_error)
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_interface = ((struct __pyx_obj_9dbus_fast_7service_ServiceInterface *)__pyx_t_3);
  __pyx_t_2 = (((PyObject *)__pyx_t_3) != Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L25_bool_binop_done;
  }

  /* "dbus_fast/message_bus.py":964
 *         if (interface := interfaces.get(msg.interface)) is not None and (
 *             handler := ServiceInterface._get_enabled_handler_by_name_signature(
 *                 interface, self, msg.member, msg.signature             # <<<<<<<<<<<<<<
 *             )
 *         ) is not None:
*/
  __pyx_t_3 = __pyx_v_msg->member;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = __pyx_v_msg->signature;
  __Pyx_INCREF(__pyx_t_4);

  /* "dbus_fast/message_bus.py":963
 * 
 *         if (interface := interfaces.get(msg.interface)) is not None and (
 *             handler := ServiceInterface._get_enabled_handler_by_name_signature(             # <<<<<<<<<<<<<<
 *                 interface, self, msg.member, msg.signature
 *             )
*/
  __pyx_t_5 = __pyx_vtabptr_9dbus_fast_7service_ServiceInterface->_get_enabled_handler_by_name_signature(__pyx_v_interface, ((PyObject *)__pyx_v_self), __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 963, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_v_handler = __pyx_t_5;

  /* "dbus_fast/message_bus.py":966
 *                 interface, self, msg.member, msg.signature
 *             )
 *         ) is not None:             # <<<<<<<<<<<<<<
 *             return handler
 * 
*/
  __pyx_t_2 = (__pyx_t_5 != Py_None);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L25_bool_binop_done:;

  /* "dbus_fast/message_bus.py":962
 *             return self._find_any_message_handler_matching_signature(interfaces, msg)
 * 
 *         if (interface := interfaces.get(msg.interface)) is not None and (             # <<<<<<<<<<<<<<
 *             handler := ServiceInterface._get_enabled_handler_by_name_signature(
 *                 interface, self, msg.member, msg.signature
*/
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":967
 *             )
 *         ) is not None:
 *             return handler             # <<<<<<<<<<<<<<
 * 
 *         return None
*/
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(!__pyx_v_handler)) { __Pyx_RaiseUnboundLocalError("handler"); __PYX_ERR(0, 967, __pyx_L1_error) }
    __Pyx_INCREF(__pyx_v_handler);
    __pyx_r = __pyx_v_handler;
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":962
 *             return self._find_any_message_handler_matching_signature(interfaces, msg)
 * 
 *         if (interface := interfaces.get(msg.interface)) is not None and (             # <<<<<<<<<<<<<<
 *             handler := ServiceInterface._get_enabled_handler_by_name_signature(
 *                 interface, self, msg.member, msg.signature
*/
  }

  /* "dbus_fast/message_bus.py":969
 *             return handler
 * 
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     def _find_any_message_handler_matching_signature(
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "dbus_fast/message_bus.py":927
 *         return partial(self._callback_method_handler, interface, method)
 * 
 *     def _find_message_handler(self, msg: _Message) -> HandlerType | None:             # <<<<<<<<<<<<<<
 *         """Find the message handler for for METHOD_CALL messages."""
 *         if TYPE_CHECKING:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._find_message_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_interface);
  __Pyx_XDECREF(__pyx_v_interfaces);
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":971
 *         return None
 * 
 *     def _find_any_message_handler_matching_signature(             # <<<<<<<<<<<<<<
 *         self, interfaces: dict[str, ServiceInterface], msg: _Message
 *     ) -> HandlerType | None:
*/

static PyObject *__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__find_any_message_handler_matching_signature(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_interfaces, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg) {
  PyObject *__pyx_v_interface = NULL;
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_find_any_message_handler_matching_signature", 0);

  /* "dbus_fast/message_bus.py":976
 *         # No interface, so we need to search all interfaces for the method
 *         # with a matching signature
 *         for interface in interfaces.values():             # <<<<<<<<<<<<<<
 *             if (
 *                 handler := ServiceInterface._get_enabled_handler_by_name_signature(
*/
  __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_v_interfaces, 1, __pyx_mstate_global->__pyx_n_u_values, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, NULL, &__pyx_t_5, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_interface, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "dbus_fast/message_bus.py":979
 *             if (
 *                 handler := ServiceInterface._get_enabled_handler_by_name_signature(
 *                     interface, self, msg.member, msg.signature             # <<<<<<<<<<<<<<
 *                 )
 *             ) is not None:
*/
    if (!(likely(((__pyx_v_interface) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_interface, __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface))))) __PYX_ERR(0, 979, __pyx_L1_error)
    __pyx_t_5 = __pyx_v_msg->member;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_7 = __pyx_v_msg->signature;
    __Pyx_INCREF(__pyx_t_7);

    /* "dbus_fast/message_bus.py":978
 *         for interface in interfaces.values():
 *             if (
 *                 handler := ServiceInterface._get_enabled_handler_by_name_signature(             # <<<<<<<<<<<<<<
 *                     interface, self, msg.member, msg.signature
 *                 )
*/
    __pyx_t_8 = __pyx_vtabptr_9dbus_fast_7service_ServiceInterface->_get_enabled_handler_by_name_signature(((struct __pyx_obj_9dbus_fast_7service_ServiceInterface *)__pyx_v_interface), ((PyObject *)__pyx_v_self), __pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_t_8);
    __Pyx_XDECREF_SET(__pyx_v_handler, __pyx_t_8);

    /* "dbus_fast/message_bus.py":981
 *                     interface, self, msg.member, msg.signature
 *                 )
 *             ) is not None:             # <<<<<<<<<<<<<<
 *                 return handler
 *         return None
*/
    __pyx_t_9 = (__pyx_t_8 != Py_None);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "dbus_fast/message_bus.py":977
 *         # with a matching signature
 *         for interface in interfaces.values():
 *             if (             # <<<<<<<<<<<<<<
 *                 handler := ServiceInterface._get_enabled_handler_by_name_signature(
 *                     interface, self, msg.member, msg.signature
*/
    if (__pyx_t_9) {

      /* "dbus_fast/message_bus.py":982
 *                 )
 *             ) is not None:
 *                 return handler             # <<<<<<<<<<<<<<
 *         return None
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_handler);
      __pyx_r = __pyx_v_handler;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "dbus_fast/message_bus.py":977
 *         # with a matching signature
 *         for interface in interfaces.values():
 *             if (             # <<<<<<<<<<<<<<
 *                 handler := ServiceInterface._get_enabled_handler_by_name_signature(
 *                     interface, self, msg.member, msg.signature
*/
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":983
 *             ) is not None:
 *                 return handler
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     def _default_introspect_handler(self, msg: Message, send_reply: SendReply) -> None:
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "dbus_fast/message_bus.py":971
 *         return None
 * 
 *     def _find_any_message_handler_matching_signature(             # <<<<<<<<<<<<<<
 *         self, interfaces: dict[str, ServiceInterface], msg: _Message
 *     ) -> HandlerType | None:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._find_any_message_handler_matching_signature", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_interface);
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":985
 *         return None
 * 
 *     def _default_introspect_handler(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         if TYPE_CHECKING:
 *             assert msg.path is not None
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_49_default_introspect_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_49_default_introspect_handler = {"_default_introspect_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_49_default_introspect_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_49_default_introspect_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  PyObject *__pyx_v_send_reply = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_default_introspect_handler (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_send_reply,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 985, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 985, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 985, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_default_introspect_handler", 0) < (0)) __PYX_ERR(0, 985, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_default_introspect_handler", 1, 2, 2, i); __PYX_ERR(0, 985, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 985, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 985, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_send_reply = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_default_introspect_handler", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 985, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_introspect_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 0, "msg", 0))) __PYX_ERR(0, 985, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_48_default_introspect_handler(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_msg, __pyx_v_send_reply);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_48_default_introspect_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply) {
  PyObject *__pyx_v_introspection = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_default_introspect_handler", 0);

  /* "dbus_fast/message_bus.py":986
 * 
 *     def _default_introspect_handler(self, msg: Message, send_reply: SendReply) -> None:
 *         if TYPE_CHECKING:             # <<<<<<<<<<<<<<
 *             assert msg.path is not None
 *         introspection = self._introspect_export_path(msg.path).tostring()
*/
  if (__pyx_v_9dbus_fast_11message_bus_TYPE_CHECKING) {

    /* "dbus_fast/message_bus.py":987
 *     def _default_introspect_handler(self, msg: Message, send_reply: SendReply) -> None:
 *         if TYPE_CHECKING:
 *             assert msg.path is not None             # <<<<<<<<<<<<<<
 *         introspection = self._introspect_export_path(msg.path).tostring()
 *         send_reply(Message.new_method_return(msg, "s", [introspection]))
*/
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      __pyx_t_1 = (__pyx_v_msg->path != Py_None);
      if (unlikely(!__pyx_t_1)) {
        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
        __PYX_ERR(0, 987, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 987, __pyx_L1_error)
    #endif

    /* "dbus_fast/message_bus.py":986
 * 
 *     def _default_introspect_handler(self, msg: Message, send_reply: SendReply) -> None:
 *         if TYPE_CHECKING:             # <<<<<<<<<<<<<<
 *             assert msg.path is not None
 *         introspection = self._introspect_export_path(msg.path).tostring()
*/
  }

  /* "dbus_fast/message_bus.py":988
 *         if TYPE_CHECKING:
 *             assert msg.path is not None
 *         introspection = self._introspect_export_path(msg.path).tostring()             # <<<<<<<<<<<<<<
 *         send_reply(Message.new_method_return(msg, "s", [introspection]))
 * 
*/
  __pyx_t_5 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_msg->path};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_introspect_export_path, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 988, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_t_3 = __pyx_t_4;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_tostring, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 988, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v_introspection = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":989
 *             assert msg.path is not None
 *         introspection = self._introspect_export_path(msg.path).tostring()
 *         send_reply(Message.new_method_return(msg, "s", [introspection]))             # <<<<<<<<<<<<<<
 * 
 *     def _default_ping_handler(self, msg: Message, send_reply: SendReply) -> None:
*/
  __pyx_t_4 = NULL;
  __Pyx_INCREF(__pyx_v_send_reply);
  __pyx_t_3 = __pyx_v_send_reply; 
  __pyx_t_7 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(__pyx_v_introspection);
  __Pyx_GIVEREF(__pyx_v_introspection);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_v_introspection) != (0)) __PYX_ERR(0, 989, __pyx_L1_error);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_7, ((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_n_u_s, __pyx_t_8};
    __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new_method_return, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":985
 *         return None
 * 
 *     def _default_introspect_handler(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         if TYPE_CHECKING:
 *             assert msg.path is not None
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_introspect_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_introspection);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":991
 *         send_reply(Message.new_method_return(msg, "s", [introspection]))
 * 
 *     def _default_ping_handler(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         send_reply(Message.new_method_return(msg))
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_51_default_ping_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_51_default_ping_handler = {"_default_ping_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_51_default_ping_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_51_default_ping_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  PyObject *__pyx_v_send_reply = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_default_ping_handler (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_send_reply,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 991, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 991, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 991, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_default_ping_handler", 0) < (0)) __PYX_ERR(0, 991, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_default_ping_handler", 1, 2, 2, i); __PYX_ERR(0, 991, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 991, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 991, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_send_reply = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_default_ping_handler", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 991, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_ping_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 0, "msg", 0))) __PYX_ERR(0, 991, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_50_default_ping_handler(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_msg, __pyx_v_send_reply);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_50_default_ping_handler(CYTHON_UNUSED struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_default_ping_handler", 0);

  /* "dbus_fast/message_bus.py":992
 * 
 *     def _default_ping_handler(self, msg: Message, send_reply: SendReply) -> None:
 *         send_reply(Message.new_method_return(msg))             # <<<<<<<<<<<<<<
 * 
 *     def _send_machine_id_reply(self, msg: Message, send_reply: SendReply) -> None:
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_send_reply);
  __pyx_t_3 = __pyx_v_send_reply; 
  __pyx_t_5 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, ((PyObject *)__pyx_v_msg)};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new_method_return, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":991
 *         send_reply(Message.new_method_return(msg, "s", [introspection]))
 * 
 *     def _default_ping_handler(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         send_reply(Message.new_method_return(msg))
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_ping_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":994
 *         send_reply(Message.new_method_return(msg))
 * 
 *     def _send_machine_id_reply(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         send_reply(Message.new_method_return(msg, "s", [self._machine_id]))
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_53_send_machine_id_reply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_53_send_machine_id_reply = {"_send_machine_id_reply", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_53_send_machine_id_reply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_53_send_machine_id_reply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  PyObject *__pyx_v_send_reply = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_send_machine_id_reply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_send_reply,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 994, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 994, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 994, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_send_machine_id_reply", 0) < (0)) __PYX_ERR(0, 994, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_send_machine_id_reply", 1, 2, 2, i); __PYX_ERR(0, 994, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 994, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 994, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_send_reply = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_send_machine_id_reply", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 994, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._send_machine_id_reply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 0, "msg", 0))) __PYX_ERR(0, 994, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_52_send_machine_id_reply(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_msg, __pyx_v_send_reply);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_52_send_machine_id_reply(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_send_machine_id_reply", 0);

  /* "dbus_fast/message_bus.py":995
 * 
 *     def _send_machine_id_reply(self, msg: Message, send_reply: SendReply) -> None:
 *         send_reply(Message.new_method_return(msg, "s", [self._machine_id]))             # <<<<<<<<<<<<<<
 * 
 *     def _default_get_machine_id_handler(
*/
  __pyx_t_2 = NULL;
  __Pyx_INCREF(__pyx_v_send_reply);
  __pyx_t_3 = __pyx_v_send_reply; 
  __pyx_t_5 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_self->_machine_id);
  __Pyx_GIVEREF(__pyx_v_self->_machine_id);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_self->_machine_id) != (0)) __PYX_ERR(0, 995, __pyx_L1_error);
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_5, ((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_n_u_s, __pyx_t_6};
    __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new_method_return, __pyx_callargs+__pyx_t_7, (4-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 995, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_t_7 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_7 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 995, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":994
 *         send_reply(Message.new_method_return(msg))
 * 
 *     def _send_machine_id_reply(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         send_reply(Message.new_method_return(msg, "s", [self._machine_id]))
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._send_machine_id_reply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":997
 *         send_reply(Message.new_method_return(msg, "s", [self._machine_id]))
 * 
 *     def _default_get_machine_id_handler(             # <<<<<<<<<<<<<<
 *         self, msg: Message, send_reply: SendReply
 *     ) -> None:
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_55_default_get_machine_id_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_55_default_get_machine_id_handler = {"_default_get_machine_id_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_55_default_get_machine_id_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_55_default_get_machine_id_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  PyObject *__pyx_v_send_reply = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_default_get_machine_id_handler (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_send_reply,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 997, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 997, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 997, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_default_get_machine_id_handler", 0) < (0)) __PYX_ERR(0, 997, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_default_get_machine_id_handler", 1, 2, 2, i); __PYX_ERR(0, 997, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 997, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 997, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_send_reply = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_default_get_machine_id_handler", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 997, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_get_machine_id_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 0, "msg", 0))) __PYX_ERR(0, 998, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_54_default_get_machine_id_handler(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_msg, __pyx_v_send_reply);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1004
 *             return
 * 
 *         def reply_handler(reply: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             if err or reply is None:
 *                 # the bus has been disconnected, cannot send a reply
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_31_default_get_machine_id_handler_1reply_handler(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_31_default_get_machine_id_handler_1reply_handler = {"reply_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_31_default_get_machine_id_handler_1reply_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_31_default_get_machine_id_handler_1reply_handler(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply = 0;
  PyObject *__pyx_v_err = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("reply_handler (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_reply,&__pyx_mstate_global->__pyx_n_u_err,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1004, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1004, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1004, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "reply_handler", 0) < (0)) __PYX_ERR(0, 1004, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("reply_handler", 1, 2, 2, i); __PYX_ERR(0, 1004, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1004, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1004, __pyx_L3_error)
    }
    __pyx_v_reply = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_err = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("reply_handler", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1004, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_get_machine_id_handler.reply_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_reply), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 1, "reply", 0))) __PYX_ERR(0, 1004, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 1004, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_31_default_get_machine_id_handler_reply_handler(__pyx_self, __pyx_v_reply, __pyx_v_err);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_31_default_get_machine_id_handler_reply_handler(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_reply, PyObject *__pyx_v_err) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reply_handler", 0);
  __pyx_outer_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "dbus_fast/message_bus.py":1005
 * 
 *         def reply_handler(reply: Message | None, err: Exception | None) -> None:
 *             if err or reply is None:             # <<<<<<<<<<<<<<
 *                 # the bus has been disconnected, cannot send a reply
 *                 return
*/
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_err); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1005, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (((PyObject *)__pyx_v_reply) == Py_None);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1007
 *             if err or reply is None:
 *                 # the bus has been disconnected, cannot send a reply
 *                 return             # <<<<<<<<<<<<<<
 * 
 *             if reply.message_type == MessageType.METHOD_RETURN:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":1005
 * 
 *         def reply_handler(reply: Message | None, err: Exception | None) -> None:
 *             if err or reply is None:             # <<<<<<<<<<<<<<
 *                 # the bus has been disconnected, cannot send a reply
 *                 return
*/
  }

  /* "dbus_fast/message_bus.py":1009
 *                 return
 * 
 *             if reply.message_type == MessageType.METHOD_RETURN:             # <<<<<<<<<<<<<<
 *                 self._machine_id = reply.body[0]
 *                 self._send_machine_id_reply(msg, send_reply)
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_9dbus_fast_11message_bus_MessageType, __pyx_mstate_global->__pyx_n_u_METHOD_RETURN); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_reply->message_type, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1009, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1009, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1010
 * 
 *             if reply.message_type == MessageType.METHOD_RETURN:
 *                 self._machine_id = reply.body[0]             # <<<<<<<<<<<<<<
 *                 self._send_machine_id_reply(msg, send_reply)
 *             elif (
*/
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_reply->body, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1010, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 1010, __pyx_L1_error) }
    __Pyx_GIVEREF(__pyx_t_4);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_self->_machine_id);
    __Pyx_DECREF(__pyx_cur_scope->__pyx_v_self->_machine_id);
    __pyx_cur_scope->__pyx_v_self->_machine_id = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "dbus_fast/message_bus.py":1011
 *             if reply.message_type == MessageType.METHOD_RETURN:
 *                 self._machine_id = reply.body[0]
 *                 self._send_machine_id_reply(msg, send_reply)             # <<<<<<<<<<<<<<
 *             elif (
 *                 reply.message_type == MessageType.ERROR and reply.error_name is not None
*/
    if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 1011, __pyx_L1_error) }
    __pyx_t_3 = ((PyObject *)__pyx_cur_scope->__pyx_v_self);
    __Pyx_INCREF(__pyx_t_3);
    if (unlikely(!__pyx_cur_scope->__pyx_v_msg)) { __Pyx_RaiseClosureNameError("msg"); __PYX_ERR(0, 1011, __pyx_L1_error) }
    if (unlikely(!__pyx_cur_scope->__pyx_v_send_reply)) { __Pyx_RaiseClosureNameError("send_reply"); __PYX_ERR(0, 1011, __pyx_L1_error) }
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, ((PyObject *)__pyx_cur_scope->__pyx_v_msg), __pyx_cur_scope->__pyx_v_send_reply};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send_machine_id_reply, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1011, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "dbus_fast/message_bus.py":1009
 *                 return
 * 
 *             if reply.message_type == MessageType.METHOD_RETURN:             # <<<<<<<<<<<<<<
 *                 self._machine_id = reply.body[0]
 *                 self._send_machine_id_reply(msg, send_reply)
*/
    goto __pyx_L6;
  }

  /* "dbus_fast/message_bus.py":1013
 *                 self._send_machine_id_reply(msg, send_reply)
 *             elif (
 *                 reply.message_type == MessageType.ERROR and reply.error_name is not None             # <<<<<<<<<<<<<<
 *             ):
 *                 send_reply(Message.new_error(msg, reply.error_name, str(reply.body)))
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_9dbus_fast_11message_bus_MessageType, __pyx_mstate_global->__pyx_n_u_ERROR); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_reply->message_type, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1013, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1013, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_reply->error_name != Py_None);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L7_bool_binop_done:;

  /* "dbus_fast/message_bus.py":1012
 *                 self._machine_id = reply.body[0]
 *                 self._send_machine_id_reply(msg, send_reply)
 *             elif (             # <<<<<<<<<<<<<<
 *                 reply.message_type == MessageType.ERROR and reply.error_name is not None
 *             ):
*/
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1015
 *                 reply.message_type == MessageType.ERROR and reply.error_name is not None
 *             ):
 *                 send_reply(Message.new_error(msg, reply.error_name, str(reply.body)))             # <<<<<<<<<<<<<<
 *             else:
 *                 send_reply(
*/
    __pyx_t_4 = NULL;
    if (unlikely(!__pyx_cur_scope->__pyx_v_send_reply)) { __Pyx_RaiseClosureNameError("send_reply"); __PYX_ERR(0, 1015, __pyx_L1_error) }
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_send_reply);
    __pyx_t_6 = __pyx_cur_scope->__pyx_v_send_reply; 
    __pyx_t_8 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
    __Pyx_INCREF(__pyx_t_8);
    if (unlikely(!__pyx_cur_scope->__pyx_v_msg)) { __Pyx_RaiseClosureNameError("msg"); __PYX_ERR(0, 1015, __pyx_L1_error) }
    __pyx_t_9 = __Pyx_PyObject_Unicode(__pyx_v_reply->body); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_8, ((PyObject *)__pyx_cur_scope->__pyx_v_msg), __pyx_v_reply->error_name, __pyx_t_9};
      __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new_error, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1015, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_7};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1015, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "dbus_fast/message_bus.py":1012
 *                 self._machine_id = reply.body[0]
 *                 self._send_machine_id_reply(msg, send_reply)
 *             elif (             # <<<<<<<<<<<<<<
 *                 reply.message_type == MessageType.ERROR and reply.error_name is not None
 *             ):
*/
    goto __pyx_L6;
  }

  /* "dbus_fast/message_bus.py":1017
 *                 send_reply(Message.new_error(msg, reply.error_name, str(reply.body)))
 *             else:
 *                 send_reply(             # <<<<<<<<<<<<<<
 *                     Message.new_error(msg, ErrorType.FAILED, "could not get machine_id")
 *                 )
*/
  /*else*/ {
    __pyx_t_6 = NULL;
    if (unlikely(!__pyx_cur_scope->__pyx_v_send_reply)) { __Pyx_RaiseClosureNameError("send_reply"); __PYX_ERR(0, 1017, __pyx_L1_error) }
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_send_reply);
    __pyx_t_7 = __pyx_cur_scope->__pyx_v_send_reply; 

    /* "dbus_fast/message_bus.py":1018
 *             else:
 *                 send_reply(
 *                     Message.new_error(msg, ErrorType.FAILED, "could not get machine_id")             # <<<<<<<<<<<<<<
 *                 )
 * 
*/
    __pyx_t_9 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
    __Pyx_INCREF(__pyx_t_9);
    if (unlikely(!__pyx_cur_scope->__pyx_v_msg)) { __Pyx_RaiseClosureNameError("msg"); __PYX_ERR(0, 1018, __pyx_L1_error) }
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_FAILED); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_9, ((PyObject *)__pyx_cur_scope->__pyx_v_msg), __pyx_t_10, __pyx_mstate_global->__pyx_kp_u_could_not_get_machine_id};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new_error, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1018, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1017, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L6:;

  /* "dbus_fast/message_bus.py":1004
 *             return
 * 
 *         def reply_handler(reply: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             if err or reply is None:
 *                 # the bus has been disconnected, cannot send a reply
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_get_machine_id_handler.reply_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":997
 *         send_reply(Message.new_method_return(msg, "s", [self._machine_id]))
 * 
 *     def _default_get_machine_id_handler(             # <<<<<<<<<<<<<<
 *         self, msg: Message, send_reply: SendReply
 *     ) -> None:
*/

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_54_default_get_machine_id_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *__pyx_cur_scope;
  PyObject *__pyx_v_reply_handler = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_default_get_machine_id_handler", 0);
  __pyx_cur_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 997, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_msg = __pyx_v_msg;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_msg);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_msg);
  __pyx_cur_scope->__pyx_v_send_reply = __pyx_v_send_reply;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_send_reply);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_send_reply);

  /* "dbus_fast/message_bus.py":1000
 *         self, msg: Message, send_reply: SendReply
 *     ) -> None:
 *         if self._machine_id:             # <<<<<<<<<<<<<<
 *             self._send_machine_id_reply(msg, send_reply)
 *             return
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_self->_machine_id); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1000, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1001
 *     ) -> None:
 *         if self._machine_id:
 *             self._send_machine_id_reply(msg, send_reply)             # <<<<<<<<<<<<<<
 *             return
 * 
*/
    __pyx_t_3 = ((PyObject *)__pyx_cur_scope->__pyx_v_self);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, ((PyObject *)__pyx_cur_scope->__pyx_v_msg), __pyx_cur_scope->__pyx_v_send_reply};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send_machine_id_reply, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1001, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":1002
 *         if self._machine_id:
 *             self._send_machine_id_reply(msg, send_reply)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         def reply_handler(reply: Message | None, err: Exception | None) -> None:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":1000
 *         self, msg: Message, send_reply: SendReply
 *     ) -> None:
 *         if self._machine_id:             # <<<<<<<<<<<<<<
 *             self._send_machine_id_reply(msg, send_reply)
 *             return
*/
  }

  /* "dbus_fast/message_bus.py":1004
 *             return
 * 
 *         def reply_handler(reply: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             if err or reply is None:
 *                 # the bus has been disconnected, cannot send a reply
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_reply, __pyx_mstate_global->__pyx_kp_u_Message_None) < (0)) __PYX_ERR(0, 1004, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 1004, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 1004, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_31_default_get_machine_id_handler_1reply_handler, 0, __pyx_mstate_global->__pyx_n_u_default_get_machine_id_handler_2, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[4])); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_reply_handler = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "dbus_fast/message_bus.py":1022
 * 
 *         self._call(
 *             Message(             # <<<<<<<<<<<<<<
 *                 destination="org.freedesktop.DBus",
 *                 path="/org/freedesktop/DBus",
*/
  __pyx_t_2 = NULL;
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_2, NULL};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1022, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_destination, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus, __pyx_t_5, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 1022, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_path, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_2, __pyx_t_5, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 1022, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_Peer, __pyx_t_5, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 1022, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_member, __pyx_mstate_global->__pyx_n_u_GetMachineId, __pyx_t_5, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 1022, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1022, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_3);
  }

  /* "dbus_fast/message_bus.py":1021
 *                 )
 * 
 *         self._call(             # <<<<<<<<<<<<<<
 *             Message(
 *                 destination="org.freedesktop.DBus",
*/
  __pyx_t_5 = ((struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_call(__pyx_cur_scope->__pyx_v_self, ((struct __pyx_obj_9dbus_fast_7message_Message *)__pyx_t_3), __pyx_v_reply_handler, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF((PyObject *)__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "dbus_fast/message_bus.py":997
 *         send_reply(Message.new_method_return(msg, "s", [self._machine_id]))
 * 
 *     def _default_get_machine_id_handler(             # <<<<<<<<<<<<<<
 *         self, msg: Message, send_reply: SendReply
 *     ) -> None:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_get_machine_id_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_reply_handler);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1031
 *         )
 * 
 *     def _default_get_managed_objects_handler(             # <<<<<<<<<<<<<<
 *         self, msg: Message, send_reply: SendReply
 *     ) -> None:
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_57_default_get_managed_objects_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_57_default_get_managed_objects_handler = {"_default_get_managed_objects_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_57_default_get_managed_objects_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_57_default_get_managed_objects_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  PyObject *__pyx_v_send_reply = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_default_get_managed_objects_handler (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_send_reply,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1031, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1031, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1031, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_default_get_managed_objects_handler", 0) < (0)) __PYX_ERR(0, 1031, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_default_get_managed_objects_handler", 1, 2, 2, i); __PYX_ERR(0, 1031, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1031, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1031, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_send_reply = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_default_get_managed_objects_handler", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1031, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_get_managed_objects_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 0, "msg", 0))) __PYX_ERR(0, 1032, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_56_default_get_managed_objects_handler(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_msg, __pyx_v_send_reply);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1037
 *         error_handled = False
 * 
 *         def is_result_complete() -> bool:             # <<<<<<<<<<<<<<
 *             if not result:
 *                 return True
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_1is_result_complete(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_1is_result_complete = {"is_result_complete", (PyCFunction)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_1is_result_complete, METH_NOARGS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_1is_result_complete(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_result_complete (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_is_result_complete(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_is_result_complete(PyObject *__pyx_self) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *__pyx_outer_scope;
  CYTHON_UNUSED PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_interfaces = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_result_complete", 0);
  __pyx_outer_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "dbus_fast/message_bus.py":1038
 * 
 *         def is_result_complete() -> bool:
 *             if not result:             # <<<<<<<<<<<<<<
 *                 return True
 *             for n, interfaces in result.items():
*/
  if (unlikely(!__pyx_cur_scope->__pyx_v_result)) { __Pyx_RaiseClosureNameError("result"); __PYX_ERR(0, 1038, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_result); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1038, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "dbus_fast/message_bus.py":1039
 *         def is_result_complete() -> bool:
 *             if not result:
 *                 return True             # <<<<<<<<<<<<<<
 *             for n, interfaces in result.items():
 *                 for value in interfaces.values():
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":1038
 * 
 *         def is_result_complete() -> bool:
 *             if not result:             # <<<<<<<<<<<<<<
 *                 return True
 *             for n, interfaces in result.items():
*/
  }

  /* "dbus_fast/message_bus.py":1040
 *             if not result:
 *                 return True
 *             for n, interfaces in result.items():             # <<<<<<<<<<<<<<
 *                 for value in interfaces.values():
 *                     if value is None:
*/
  __pyx_t_4 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_v_result)) { __Pyx_RaiseClosureNameError("result"); __PYX_ERR(0, 1040, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_v_result == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 1040, __pyx_L1_error)
  }
  __pyx_t_7 = __Pyx_dict_iterator(__pyx_cur_scope->__pyx_v_result, 1, __pyx_mstate_global->__pyx_n_u_items, (&__pyx_t_5), (&__pyx_t_6)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1040, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_3);
  __pyx_t_3 = __pyx_t_7;
  __pyx_t_7 = 0;
  while (1) {
    __pyx_t_9 = __Pyx_dict_iter_next(__pyx_t_3, __pyx_t_5, &__pyx_t_4, &__pyx_t_7, &__pyx_t_8, NULL, __pyx_t_6);
    if (unlikely(__pyx_t_9 == 0)) break;
    if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 1040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_XDECREF_SET(__pyx_v_n, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_XDECREF_SET(__pyx_v_interfaces, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "dbus_fast/message_bus.py":1041
 *                 return True
 *             for n, interfaces in result.items():
 *                 for value in interfaces.values():             # <<<<<<<<<<<<<<
 *                     if value is None:
 *                         return False
*/
    __pyx_t_10 = 0;
    if (unlikely(__pyx_v_interfaces == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
      __PYX_ERR(0, 1041, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_dict_iterator(__pyx_v_interfaces, 0, __pyx_mstate_global->__pyx_n_u_values, (&__pyx_t_11), (&__pyx_t_9)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1041, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8);
    __pyx_t_8 = __pyx_t_7;
    __pyx_t_7 = 0;
    while (1) {
      __pyx_t_12 = __Pyx_dict_iter_next(__pyx_t_8, __pyx_t_11, &__pyx_t_10, NULL, &__pyx_t_7, NULL, __pyx_t_9);
      if (unlikely(__pyx_t_12 == 0)) break;
      if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 1041, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "dbus_fast/message_bus.py":1042
 *             for n, interfaces in result.items():
 *                 for value in interfaces.values():
 *                     if value is None:             # <<<<<<<<<<<<<<
 *                         return False
 * 
*/
      __pyx_t_2 = (__pyx_v_value == Py_None);
      if (__pyx_t_2) {

        /* "dbus_fast/message_bus.py":1043
 *                 for value in interfaces.values():
 *                     if value is None:
 *                         return False             # <<<<<<<<<<<<<<
 * 
 *             return True
*/
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(Py_False);
        __pyx_r = Py_False;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L0;

        /* "dbus_fast/message_bus.py":1042
 *             for n, interfaces in result.items():
 *                 for value in interfaces.values():
 *                     if value is None:             # <<<<<<<<<<<<<<
 *                         return False
 * 
*/
      }
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "dbus_fast/message_bus.py":1045
 *                         return False
 * 
 *             return True             # <<<<<<<<<<<<<<
 * 
 *         if TYPE_CHECKING:
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "dbus_fast/message_bus.py":1037
 *         error_handled = False
 * 
 *         def is_result_complete() -> bool:             # <<<<<<<<<<<<<<
 *             if not result:
 *                 return True
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_get_managed_objects_handler.is_result_complete", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_interfaces);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1065
 *             return
 * 
 *         def get_all_properties_callback(             # <<<<<<<<<<<<<<
 *             interface: ServiceInterface, values: Any, node: str, err: Exception | None
 *         ) -> None:
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_3get_all_properties_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_3get_all_properties_callback = {"get_all_properties_callback", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_3get_all_properties_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_3get_all_properties_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface = 0;
  PyObject *__pyx_v_values = 0;
  PyObject *__pyx_v_node = 0;
  PyObject *__pyx_v_err = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_all_properties_callback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_interface,&__pyx_mstate_global->__pyx_n_u_values,&__pyx_mstate_global->__pyx_n_u_node,&__pyx_mstate_global->__pyx_n_u_err,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1065, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 1065, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1065, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1065, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1065, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_all_properties_callback", 0) < (0)) __PYX_ERR(0, 1065, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 4; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_all_properties_callback", 1, 4, 4, i); __PYX_ERR(0, 1065, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1065, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1065, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1065, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 1065, __pyx_L3_error)
    }
    __pyx_v_interface = ((struct __pyx_obj_9dbus_fast_7service_ServiceInterface *)values[0]);
    __pyx_v_values = values[1];
    __pyx_v_node = ((PyObject*)values[2]);
    __pyx_v_err = ((PyObject*)values[3]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_all_properties_callback", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 1065, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_get_managed_objects_handler.get_all_properties_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_interface), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface, 0, "interface", 0))) __PYX_ERR(0, 1066, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_node), (&PyUnicode_Type), 0, "node", 2))) __PYX_ERR(0, 1066, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 1066, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_2get_all_properties_callback(__pyx_self, __pyx_v_interface, __pyx_v_values, __pyx_v_node, __pyx_v_err);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_2get_all_properties_callback(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, PyObject *__pyx_v_values, PyObject *__pyx_v_node, PyObject *__pyx_v_err) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_all_properties_callback", 0);
  __pyx_outer_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "dbus_fast/message_bus.py":1069
 *         ) -> None:
 *             nonlocal error_handled
 *             if err is not None:             # <<<<<<<<<<<<<<
 *                 if not error_handled:
 *                     error_handled = True
*/
  __pyx_t_1 = (__pyx_v_err != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1070
 *             nonlocal error_handled
 *             if err is not None:
 *                 if not error_handled:             # <<<<<<<<<<<<<<
 *                     error_handled = True
 *                     send_reply.send_error(err)
*/
    __pyx_t_1 = (!__pyx_cur_scope->__pyx_v_error_handled);
    if (__pyx_t_1) {

      /* "dbus_fast/message_bus.py":1071
 *             if err is not None:
 *                 if not error_handled:
 *                     error_handled = True             # <<<<<<<<<<<<<<
 *                     send_reply.send_error(err)
 *                 return
*/
      __pyx_cur_scope->__pyx_v_error_handled = 1;

      /* "dbus_fast/message_bus.py":1072
 *                 if not error_handled:
 *                     error_handled = True
 *                     send_reply.send_error(err)             # <<<<<<<<<<<<<<
 *                 return
 * 
*/
      if (unlikely(!__pyx_cur_scope->__pyx_v_send_reply)) { __Pyx_RaiseClosureNameError("send_reply"); __PYX_ERR(0, 1072, __pyx_L1_error) }
      __pyx_t_3 = __pyx_cur_scope->__pyx_v_send_reply;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_err};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1072, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "dbus_fast/message_bus.py":1070
 *             nonlocal error_handled
 *             if err is not None:
 *                 if not error_handled:             # <<<<<<<<<<<<<<
 *                     error_handled = True
 *                     send_reply.send_error(err)
*/
    }

    /* "dbus_fast/message_bus.py":1073
 *                     error_handled = True
 *                     send_reply.send_error(err)
 *                 return             # <<<<<<<<<<<<<<
 * 
 *             result[node][interface.name] = values
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":1069
 *         ) -> None:
 *             nonlocal error_handled
 *             if err is not None:             # <<<<<<<<<<<<<<
 *                 if not error_handled:
 *                     error_handled = True
*/
  }

  /* "dbus_fast/message_bus.py":1075
 *                 return
 * 
 *             result[node][interface.name] = values             # <<<<<<<<<<<<<<
 * 
 *             if is_result_complete():
*/
  if (unlikely(!__pyx_cur_scope->__pyx_v_result)) { __Pyx_RaiseClosureNameError("result"); __PYX_ERR(0, 1075, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_v_result == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1075, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_cur_scope->__pyx_v_result, __pyx_v_node); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyObject_SetItem(__pyx_t_2, __pyx_v_interface->name, __pyx_v_values) < 0))) __PYX_ERR(0, 1075, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":1077
 *             result[node][interface.name] = values
 * 
 *             if is_result_complete():             # <<<<<<<<<<<<<<
 *                 send_reply(Message.new_method_return(msg, result_signature, [result]))
 * 
*/
  if (unlikely(!__pyx_cur_scope->__pyx_v_is_result_complete)) { __Pyx_RaiseClosureNameError("is_result_complete"); __PYX_ERR(0, 1077, __pyx_L1_error) }
  __pyx_t_2 = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_is_result_complete(__pyx_cur_scope->__pyx_v_is_result_complete); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1077, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1078
 * 
 *             if is_result_complete():
 *                 send_reply(Message.new_method_return(msg, result_signature, [result]))             # <<<<<<<<<<<<<<
 * 
 *         for node in nodes:
*/
    __pyx_t_3 = NULL;
    if (unlikely(!__pyx_cur_scope->__pyx_v_send_reply)) { __Pyx_RaiseClosureNameError("send_reply"); __PYX_ERR(0, 1078, __pyx_L1_error) }
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_send_reply);
    __pyx_t_5 = __pyx_cur_scope->__pyx_v_send_reply; 
    __pyx_t_7 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
    __Pyx_INCREF(__pyx_t_7);
    if (unlikely(!__pyx_cur_scope->__pyx_v_msg)) { __Pyx_RaiseClosureNameError("msg"); __PYX_ERR(0, 1078, __pyx_L1_error) }
    if (unlikely(!__pyx_cur_scope->__pyx_v_result_signature)) { __Pyx_RaiseClosureNameError("result_signature"); __PYX_ERR(0, 1078, __pyx_L1_error) }
    if (unlikely(!__pyx_cur_scope->__pyx_v_result)) { __Pyx_RaiseClosureNameError("result"); __PYX_ERR(0, 1078, __pyx_L1_error) }
    __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1078, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_result);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_result);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_cur_scope->__pyx_v_result) != (0)) __PYX_ERR(0, 1078, __pyx_L1_error);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_7, ((PyObject *)__pyx_cur_scope->__pyx_v_msg), __pyx_cur_scope->__pyx_v_result_signature, __pyx_t_8};
      __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new_method_return, __pyx_callargs+__pyx_t_4, (4-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_6};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":1077
 *             result[node][interface.name] = values
 * 
 *             if is_result_complete():             # <<<<<<<<<<<<<<
 *                 send_reply(Message.new_method_return(msg, result_signature, [result]))
 * 
*/
  }

  /* "dbus_fast/message_bus.py":1065
 *             return
 * 
 *         def get_all_properties_callback(             # <<<<<<<<<<<<<<
 *             interface: ServiceInterface, values: Any, node: str, err: Exception | None
 *         ) -> None:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_get_managed_objects_handler.get_all_properties_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1031
 *         )
 * 
 *     def _default_get_managed_objects_handler(             # <<<<<<<<<<<<<<
 *         self, msg: Message, send_reply: SendReply
 *     ) -> None:
*/

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_56_default_get_managed_objects_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *__pyx_cur_scope;
  PyObject *__pyx_v_nodes = NULL;
  PyObject *__pyx_v_get_all_properties_callback = 0;
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_v_interface = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_node = NULL;
  PyObject *__pyx_8genexpr2__pyx_v_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  size_t __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  Py_ssize_t __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_default_get_managed_objects_handler", 0);
  __pyx_cur_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1031, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_msg = __pyx_v_msg;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_msg);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_msg);
  __pyx_cur_scope->__pyx_v_send_reply = __pyx_v_send_reply;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_send_reply);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_send_reply);

  /* "dbus_fast/message_bus.py":1034
 *         self, msg: Message, send_reply: SendReply
 *     ) -> None:
 *         result_signature = "a{oa{sa{sv}}}"             # <<<<<<<<<<<<<<
 *         error_handled = False
 * 
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u_a_oa_sa_sv);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_kp_u_a_oa_sa_sv);
  __pyx_cur_scope->__pyx_v_result_signature = __pyx_mstate_global->__pyx_kp_u_a_oa_sa_sv;

  /* "dbus_fast/message_bus.py":1035
 *     ) -> None:
 *         result_signature = "a{oa{sa{sv}}}"
 *         error_handled = False             # <<<<<<<<<<<<<<
 * 
 *         def is_result_complete() -> bool:
*/
  __pyx_cur_scope->__pyx_v_error_handled = 0;

  /* "dbus_fast/message_bus.py":1037
 *         error_handled = False
 * 
 *         def is_result_complete() -> bool:             # <<<<<<<<<<<<<<
 *             if not result:
 *                 return True
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_bool) < (0)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_1is_result_complete, 0, __pyx_mstate_global->__pyx_n_u_default_get_managed_objects_han_2, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_is_result_complete = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":1047
 *             return True
 * 
 *         if TYPE_CHECKING:             # <<<<<<<<<<<<<<
 *             assert msg.path is not None
 * 
*/
  if (__pyx_v_9dbus_fast_11message_bus_TYPE_CHECKING) {

    /* "dbus_fast/message_bus.py":1048
 * 
 *         if TYPE_CHECKING:
 *             assert msg.path is not None             # <<<<<<<<<<<<<<
 * 
 *         nodes = [
*/
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      __pyx_t_3 = (__pyx_cur_scope->__pyx_v_msg->path != Py_None);
      if (unlikely(!__pyx_t_3)) {
        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
        __PYX_ERR(0, 1048, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 1048, __pyx_L1_error)
    #endif

    /* "dbus_fast/message_bus.py":1047
 *             return True
 * 
 *         if TYPE_CHECKING:             # <<<<<<<<<<<<<<
 *             assert msg.path is not None
 * 
*/
  }

  /* "dbus_fast/message_bus.py":1050
 *             assert msg.path is not None
 * 
 *         nodes = [             # <<<<<<<<<<<<<<
 *             node
 *             for node in self._path_exports
*/
  { /* enter inner scope */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1050, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "dbus_fast/message_bus.py":1052
 *         nodes = [
 *             node
 *             for node in self._path_exports             # <<<<<<<<<<<<<<
 *             if msg.path == "/" or node.startswith(msg.path + "/")
 *         ]
*/
    __pyx_t_4 = 0;
    if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 1052, __pyx_L6_error)
    }
    __pyx_t_7 = __Pyx_dict_iterator(__pyx_v_self->_path_exports, 1, ((PyObject *)NULL), (&__pyx_t_5), (&__pyx_t_6)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1052, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_1);
    __pyx_t_1 = __pyx_t_7;
    __pyx_t_7 = 0;
    while (1) {
      __pyx_t_8 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_5, &__pyx_t_4, &__pyx_t_7, NULL, NULL, __pyx_t_6);
      if (unlikely(__pyx_t_8 == 0)) break;
      if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 1052, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_node, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "dbus_fast/message_bus.py":1053
 *             node
 *             for node in self._path_exports
 *             if msg.path == "/" or node.startswith(msg.path + "/")             # <<<<<<<<<<<<<<
 *         ]
 * 
*/
      __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_cur_scope->__pyx_v_msg->path, __pyx_mstate_global->__pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 1053, __pyx_L6_error)
      if (!__pyx_t_9) {
      } else {
        __pyx_t_3 = __pyx_t_9;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_10 = __pyx_8genexpr1__pyx_v_node;
      __Pyx_INCREF(__pyx_t_10);
      __pyx_t_11 = PyNumber_Add(__pyx_cur_scope->__pyx_v_msg->path, __pyx_mstate_global->__pyx_kp_u__6); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1053, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_11};
        __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_startswith, __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1053, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 1053, __pyx_L6_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_3 = __pyx_t_9;
      __pyx_L10_bool_binop_done:;
      if (__pyx_t_3) {

        /* "dbus_fast/message_bus.py":1051
 * 
 *         nodes = [
 *             node             # <<<<<<<<<<<<<<
 *             for node in self._path_exports
 *             if msg.path == "/" or node.startswith(msg.path + "/")
*/
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_8genexpr1__pyx_v_node))) __PYX_ERR(0, 1050, __pyx_L6_error)

        /* "dbus_fast/message_bus.py":1053
 *             node
 *             for node in self._path_exports
 *             if msg.path == "/" or node.startswith(msg.path + "/")             # <<<<<<<<<<<<<<
 *         ]
 * 
*/
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_node); __pyx_8genexpr1__pyx_v_node = 0;
    goto __pyx_L12_exit_scope;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_node); __pyx_8genexpr1__pyx_v_node = 0;
    goto __pyx_L1_error;
    __pyx_L12_exit_scope:;
  } /* exit inner scope */
  __pyx_v_nodes = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":1057
 * 
 *         # first build up the result object to know when it's complete
 *         result: dict[str, dict[str, Any]] = {             # <<<<<<<<<<<<<<
 *             node: dict.fromkeys(self._path_exports[node]) for node in nodes
 *         }
*/
  { /* enter inner scope */
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1057, __pyx_L15_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "dbus_fast/message_bus.py":1058
 *         # first build up the result object to know when it's complete
 *         result: dict[str, dict[str, Any]] = {
 *             node: dict.fromkeys(self._path_exports[node]) for node in nodes             # <<<<<<<<<<<<<<
 *         }
 * 
*/
    __pyx_t_1 = __pyx_v_nodes; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_5 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1058, __pyx_L15_error)
        #endif
        if (__pyx_t_5 >= __pyx_temp) break;
      }
      __pyx_t_7 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_5;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1058, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XDECREF_SET(__pyx_8genexpr2__pyx_v_node, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_11 = ((PyObject *)(&PyDict_Type));
      __Pyx_INCREF(__pyx_t_11);
      if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 1058, __pyx_L15_error)
      }
      __pyx_t_10 = __Pyx_PyDict_GetItem(__pyx_v_self->_path_exports, __pyx_8genexpr2__pyx_v_node); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1058, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_12 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_10};
        __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_fromkeys, __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1058, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      if (unlikely(PyDict_SetItem(__pyx_t_2, (PyObject*)__pyx_8genexpr2__pyx_v_node, (PyObject*)__pyx_t_7))) __PYX_ERR(0, 1058, __pyx_L15_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_node); __pyx_8genexpr2__pyx_v_node = 0;
    goto __pyx_L19_exit_scope;
    __pyx_L15_error:;
    __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_node); __pyx_8genexpr2__pyx_v_node = 0;
    goto __pyx_L1_error;
    __pyx_L19_exit_scope:;
  } /* exit inner scope */
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_result = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":1061
 *         }
 * 
 *         if is_result_complete():             # <<<<<<<<<<<<<<
 *             send_reply(Message.new_method_return(msg, result_signature, [result]))
 *             return
*/
  __pyx_t_2 = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_is_result_complete(__pyx_cur_scope->__pyx_v_is_result_complete); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1061, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "dbus_fast/message_bus.py":1062
 * 
 *         if is_result_complete():
 *             send_reply(Message.new_method_return(msg, result_signature, [result]))             # <<<<<<<<<<<<<<
 *             return
 * 
*/
    __pyx_t_1 = NULL;
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_send_reply);
    __pyx_t_7 = __pyx_cur_scope->__pyx_v_send_reply; 
    __pyx_t_11 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
    __Pyx_INCREF(__pyx_t_11);
    __pyx_t_13 = PyList_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_result);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_result);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_13, 0, __pyx_cur_scope->__pyx_v_result) != (0)) __PYX_ERR(0, 1062, __pyx_L1_error);
    __pyx_t_12 = 0;
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_11, ((PyObject *)__pyx_cur_scope->__pyx_v_msg), __pyx_cur_scope->__pyx_v_result_signature, __pyx_t_13};
      __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new_method_return, __pyx_callargs+__pyx_t_12, (4-__pyx_t_12) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1062, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
    }
    __pyx_t_12 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_1);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_12 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_10};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1062, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":1063
 *         if is_result_complete():
 *             send_reply(Message.new_method_return(msg, result_signature, [result]))
 *             return             # <<<<<<<<<<<<<<
 * 
 *         def get_all_properties_callback(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":1061
 *         }
 * 
 *         if is_result_complete():             # <<<<<<<<<<<<<<
 *             send_reply(Message.new_method_return(msg, result_signature, [result]))
 *             return
*/
  }

  /* "dbus_fast/message_bus.py":1065
 *             return
 * 
 *         def get_all_properties_callback(             # <<<<<<<<<<<<<<
 *             interface: ServiceInterface, values: Any, node: str, err: Exception | None
 *         ) -> None:
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_n_u_ServiceInterface) < (0)) __PYX_ERR(0, 1065, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_values, __pyx_mstate_global->__pyx_n_u_Any) < (0)) __PYX_ERR(0, 1065, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_node, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 1065, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 1065, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 1065, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_36_default_get_managed_objects_handler_3get_all_properties_callback, 0, __pyx_mstate_global->__pyx_n_u_default_get_managed_objects_han_3, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_get_all_properties_callback = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "dbus_fast/message_bus.py":1080
 *                 send_reply(Message.new_method_return(msg, result_signature, [result]))
 * 
 *         for node in nodes:             # <<<<<<<<<<<<<<
 *             for interface in self._path_exports[node].values():
 *                 ServiceInterface._get_all_property_values(
*/
  __pyx_t_7 = __pyx_v_nodes; __Pyx_INCREF(__pyx_t_7);
  __pyx_t_5 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1080, __pyx_L1_error)
      #endif
      if (__pyx_t_5 >= __pyx_temp) break;
    }
    __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_7, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_5;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1080, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_node, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":1081
 * 
 *         for node in nodes:
 *             for interface in self._path_exports[node].values():             # <<<<<<<<<<<<<<
 *                 ServiceInterface._get_all_property_values(
 *                     interface, get_all_properties_callback, node
*/
    __pyx_t_4 = 0;
    if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1081, __pyx_L1_error)
    }
    __pyx_t_10 = __Pyx_PyDict_GetItem(__pyx_v_self->_path_exports, __pyx_v_node); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1081, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    if (unlikely(__pyx_t_10 == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
      __PYX_ERR(0, 1081, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_dict_iterator(__pyx_t_10, 0, __pyx_mstate_global->__pyx_n_u_values, (&__pyx_t_14), (&__pyx_t_6)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1081, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_2);
    __pyx_t_2 = __pyx_t_1;
    __pyx_t_1 = 0;
    while (1) {
      __pyx_t_8 = __Pyx_dict_iter_next(__pyx_t_2, __pyx_t_14, &__pyx_t_4, NULL, &__pyx_t_1, NULL, __pyx_t_6);
      if (unlikely(__pyx_t_8 == 0)) break;
      if (unlikely(__pyx_t_8 == -1)) __PYX_ERR(0, 1081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_interface, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "dbus_fast/message_bus.py":1082
 *         for node in nodes:
 *             for interface in self._path_exports[node].values():
 *                 ServiceInterface._get_all_property_values(             # <<<<<<<<<<<<<<
 *                     interface, get_all_properties_callback, node
 *                 )
*/
      __pyx_t_10 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface);
      __Pyx_INCREF(__pyx_t_10);

      /* "dbus_fast/message_bus.py":1083
 *             for interface in self._path_exports[node].values():
 *                 ServiceInterface._get_all_property_values(
 *                     interface, get_all_properties_callback, node             # <<<<<<<<<<<<<<
 *                 )
 * 
*/
      __pyx_t_12 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_10, __pyx_v_interface, __pyx_v_get_all_properties_callback, __pyx_v_node};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_all_property_values, __pyx_callargs+__pyx_t_12, (4-__pyx_t_12) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1082, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":1080
 *                 send_reply(Message.new_method_return(msg, result_signature, [result]))
 * 
 *         for node in nodes:             # <<<<<<<<<<<<<<
 *             for interface in self._path_exports[node].values():
 *                 ServiceInterface._get_all_property_values(
*/
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "dbus_fast/message_bus.py":1031
 *         )
 * 
 *     def _default_get_managed_objects_handler(             # <<<<<<<<<<<<<<
 *         self, msg: Message, send_reply: SendReply
 *     ) -> None:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_get_managed_objects_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_nodes);
  __Pyx_XDECREF(__pyx_v_get_all_properties_callback);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XDECREF(__pyx_v_interface);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_node);
  __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_node);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1086
 *                 )
 * 
 *     def _default_properties_handler(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         methods = {"Get": "ss", "Set": "ssv", "GetAll": "s"}
 *         if msg.member not in methods or methods[msg.member] != msg.signature:
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_59_default_properties_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_59_default_properties_handler = {"_default_properties_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_59_default_properties_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_59_default_properties_handler(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  PyObject *__pyx_v_send_reply = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_default_properties_handler (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_send_reply,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1086, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1086, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_default_properties_handler", 0) < (0)) __PYX_ERR(0, 1086, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_default_properties_handler", 1, 2, 2, i); __PYX_ERR(0, 1086, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1086, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1086, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_send_reply = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_default_properties_handler", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1086, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_properties_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 0, "msg", 0))) __PYX_ERR(0, 1086, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_58_default_properties_handler(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_msg, __pyx_v_send_reply);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1152
 *                     )
 * 
 *                 def get_property_callback(             # <<<<<<<<<<<<<<
 *                     interface: ServiceInterface,
 *                     prop: _Property,
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_1get_property_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_1get_property_callback = {"get_property_callback", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_1get_property_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_1get_property_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface = 0;
  PyObject *__pyx_v_prop = 0;
  PyObject *__pyx_v_prop_value = 0;
  PyObject *__pyx_v_err = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_property_callback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_interface,&__pyx_mstate_global->__pyx_n_u_prop,&__pyx_mstate_global->__pyx_n_u_prop_value,&__pyx_mstate_global->__pyx_n_u_err,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1152, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 1152, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1152, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1152, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1152, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_property_callback", 0) < (0)) __PYX_ERR(0, 1152, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 4; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_property_callback", 1, 4, 4, i); __PYX_ERR(0, 1152, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1152, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1152, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1152, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 1152, __pyx_L3_error)
    }
    __pyx_v_interface = ((struct __pyx_obj_9dbus_fast_7service_ServiceInterface *)values[0]);
    __pyx_v_prop = values[1];
    __pyx_v_prop_value = values[2];
    __pyx_v_err = ((PyObject*)values[3]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_property_callback", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 1152, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_properties_handler.get_property_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_interface), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface, 0, "interface", 0))) __PYX_ERR(0, 1153, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 1156, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_get_property_callback(__pyx_self, __pyx_v_interface, __pyx_v_prop, __pyx_v_prop_value, __pyx_v_err);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_get_property_callback(PyObject *__pyx_self, CYTHON_UNUSED struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, PyObject *__pyx_v_prop, PyObject *__pyx_v_prop_value, PyObject *__pyx_v_err) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *__pyx_outer_scope;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_v_unix_fds = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  int __pyx_t_18;
  char const *__pyx_t_19;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_property_callback", 0);
  __pyx_outer_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "dbus_fast/message_bus.py":1158
 *                     err: Exception | None,
 *                 ) -> None:
 *                     try:             # <<<<<<<<<<<<<<
 *                         if err is not None:
 *                             send_reply.send_error(err)
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "dbus_fast/message_bus.py":1159
 *                 ) -> None:
 *                     try:
 *                         if err is not None:             # <<<<<<<<<<<<<<
 *                             send_reply.send_error(err)
 *                             return
*/
      __pyx_t_4 = (__pyx_v_err != ((PyObject*)Py_None));
      if (__pyx_t_4) {

        /* "dbus_fast/message_bus.py":1160
 *                     try:
 *                         if err is not None:
 *                             send_reply.send_error(err)             # <<<<<<<<<<<<<<
 *                             return
 * 
*/
        if (unlikely(!__pyx_cur_scope->__pyx_v_send_reply)) { __Pyx_RaiseClosureNameError("send_reply"); __PYX_ERR(0, 1160, __pyx_L3_error) }
        __pyx_t_6 = __pyx_cur_scope->__pyx_v_send_reply;
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_err};
          __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send_error, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1160, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "dbus_fast/message_bus.py":1161
 *                         if err is not None:
 *                             send_reply.send_error(err)
 *                             return             # <<<<<<<<<<<<<<
 * 
 *                         body, unix_fds = replace_fds_with_idx(
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L7_try_return;

        /* "dbus_fast/message_bus.py":1159
 *                 ) -> None:
 *                     try:
 *                         if err is not None:             # <<<<<<<<<<<<<<
 *                             send_reply.send_error(err)
 *                             return
*/
      }

      /* "dbus_fast/message_bus.py":1163
 *                             return
 * 
 *                         body, unix_fds = replace_fds_with_idx(             # <<<<<<<<<<<<<<
 *                             prop.signature, [prop_value]
 *                         )
*/
      __pyx_t_6 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_replace_fds_with_idx); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1163, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);

      /* "dbus_fast/message_bus.py":1164
 * 
 *                         body, unix_fds = replace_fds_with_idx(
 *                             prop.signature, [prop_value]             # <<<<<<<<<<<<<<
 *                         )
 * 
*/
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_prop, __pyx_mstate_global->__pyx_n_u_signature); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1164, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = PyList_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1164, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_v_prop_value);
      __Pyx_GIVEREF(__pyx_v_prop_value);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_10, 0, __pyx_v_prop_value) != (0)) __PYX_ERR(0, 1164, __pyx_L3_error);
      __pyx_t_7 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
        __pyx_t_7 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_9, __pyx_t_10};
        __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1163, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
        PyObject* sequence = __pyx_t_5;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1163, __pyx_L3_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0);
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_10 = PyTuple_GET_ITEM(sequence, 1);
          __Pyx_INCREF(__pyx_t_10);
        } else {
          __pyx_t_8 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1163, __pyx_L3_error)
          __Pyx_XGOTREF(__pyx_t_8);
          __pyx_t_10 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1163, __pyx_L3_error)
          __Pyx_XGOTREF(__pyx_t_10);
        }
        #else
        __pyx_t_8 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1163, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_10 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1163, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        #endif
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_9 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1163, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_9);
        index = 0; __pyx_t_8 = __pyx_t_11(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L10_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_8);
        index = 1; __pyx_t_10 = __pyx_t_11(__pyx_t_9); if (unlikely(!__pyx_t_10)) goto __pyx_L10_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_10);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_9), 2) < (0)) __PYX_ERR(0, 1163, __pyx_L3_error)
        __pyx_t_11 = NULL;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L11_unpacking_done;
        __pyx_L10_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_11 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1163, __pyx_L3_error)
        __pyx_L11_unpacking_done:;
      }

      /* "dbus_fast/message_bus.py":1163
 *                             return
 * 
 *                         body, unix_fds = replace_fds_with_idx(             # <<<<<<<<<<<<<<
 *                             prop.signature, [prop_value]
 *                         )
*/
      __pyx_v_body = __pyx_t_8;
      __pyx_t_8 = 0;
      __pyx_v_unix_fds = __pyx_t_10;
      __pyx_t_10 = 0;

      /* "dbus_fast/message_bus.py":1167
 *                         )
 * 
 *                         send_reply(             # <<<<<<<<<<<<<<
 *                             Message.new_method_return(
 *                                 msg,
*/
      __pyx_t_10 = NULL;
      if (unlikely(!__pyx_cur_scope->__pyx_v_send_reply)) { __Pyx_RaiseClosureNameError("send_reply"); __PYX_ERR(0, 1167, __pyx_L3_error) }
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_send_reply);
      __pyx_t_8 = __pyx_cur_scope->__pyx_v_send_reply; 

      /* "dbus_fast/message_bus.py":1168
 * 
 *                         send_reply(
 *                             Message.new_method_return(             # <<<<<<<<<<<<<<
 *                                 msg,
 *                                 "v",
*/
      __pyx_t_6 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
      __Pyx_INCREF(__pyx_t_6);

      /* "dbus_fast/message_bus.py":1169
 *                         send_reply(
 *                             Message.new_method_return(
 *                                 msg,             # <<<<<<<<<<<<<<
 *                                 "v",
 *                                 [Variant(prop.signature, body[0])],
*/
      if (unlikely(!__pyx_cur_scope->__pyx_v_msg)) { __Pyx_RaiseClosureNameError("msg"); __PYX_ERR(0, 1169, __pyx_L3_error) }

      /* "dbus_fast/message_bus.py":1171
 *                                 msg,
 *                                 "v",
 *                                 [Variant(prop.signature, body[0])],             # <<<<<<<<<<<<<<
 *                                 unix_fds=unix_fds,
 *                             )
*/
      __pyx_t_13 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_mstate_global->__pyx_n_u_Variant); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1171, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_prop, __pyx_mstate_global->__pyx_n_u_signature); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1171, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_16 = __Pyx_GetItemInt(__pyx_v_body, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1171, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_7 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
        assert(__pyx_t_13);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_14, __pyx__function);
        __pyx_t_7 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_13, __pyx_t_15, __pyx_t_16};
        __pyx_t_12 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_14, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1171, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
      }
      __pyx_t_14 = PyList_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1171, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_GIVEREF(__pyx_t_12);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_14, 0, __pyx_t_12) != (0)) __PYX_ERR(0, 1171, __pyx_L3_error);
      __pyx_t_12 = 0;

      /* "dbus_fast/message_bus.py":1172
 *                                 "v",
 *                                 [Variant(prop.signature, body[0])],
 *                                 unix_fds=unix_fds,             # <<<<<<<<<<<<<<
 *                             )
 *                         )
*/
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[4 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_6, ((PyObject *)__pyx_cur_scope->__pyx_v_msg), __pyx_mstate_global->__pyx_n_u_v, __pyx_t_14};
        __pyx_t_12 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1168, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_unix_fds, __pyx_v_unix_fds, __pyx_t_12, __pyx_callargs+4, 0) < (0)) __PYX_ERR(0, 1168, __pyx_L3_error)
        __pyx_t_9 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_new_method_return, __pyx_callargs+__pyx_t_7, (4-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_12);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1168, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_9);
      }
      __pyx_t_7 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
        assert(__pyx_t_10);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
        __pyx_t_7 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_9};
        __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1167, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "dbus_fast/message_bus.py":1158
 *                     err: Exception | None,
 *                 ) -> None:
 *                     try:             # <<<<<<<<<<<<<<
 *                         if err is not None:
 *                             send_reply.send_error(err)
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "dbus_fast/message_bus.py":1175
 *                             )
 *                         )
 *                     except Exception as e:             # <<<<<<<<<<<<<<
 *                         send_reply.send_error(e)
 * 
*/
    __pyx_t_17 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
    if (__pyx_t_17) {
      __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_properties_handler.get_property_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 1175, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_8);
      __pyx_v_e = __pyx_t_8;
      /*try:*/ {

        /* "dbus_fast/message_bus.py":1176
 *                         )
 *                     except Exception as e:
 *                         send_reply.send_error(e)             # <<<<<<<<<<<<<<
 * 
 *                 ServiceInterface._get_property_value(
*/
        if (unlikely(!__pyx_cur_scope->__pyx_v_send_reply)) { __Pyx_RaiseClosureNameError("send_reply"); __PYX_ERR(0, 1176, __pyx_L17_error) }
        __pyx_t_12 = __pyx_cur_scope->__pyx_v_send_reply;
        __Pyx_INCREF(__pyx_t_12);
        __pyx_t_7 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_v_e};
          __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send_error, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1176, __pyx_L17_error)
          __Pyx_GOTREF(__pyx_t_10);
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }

      /* "dbus_fast/message_bus.py":1175
 *                             )
 *                         )
 *                     except Exception as e:             # <<<<<<<<<<<<<<
 *                         send_reply.send_error(e)
 * 
*/
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          goto __pyx_L18;
        }
        __pyx_L17_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_23, &__pyx_t_24, &__pyx_t_25);
          if ( unlikely(__Pyx_GetException(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22) < 0)) __Pyx_ErrFetch(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __Pyx_XGOTREF(__pyx_t_24);
          __Pyx_XGOTREF(__pyx_t_25);
          __pyx_t_17 = __pyx_lineno; __pyx_t_18 = __pyx_clineno; __pyx_t_19 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_23);
          __Pyx_XGIVEREF(__pyx_t_24);
          __Pyx_XGIVEREF(__pyx_t_25);
          __Pyx_ExceptionReset(__pyx_t_23, __pyx_t_24, __pyx_t_25);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_XGIVEREF(__pyx_t_22);
          __Pyx_ErrRestore(__pyx_t_20, __pyx_t_21, __pyx_t_22);
          __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
          __pyx_lineno = __pyx_t_17; __pyx_clineno = __pyx_t_18; __pyx_filename = __pyx_t_19;
          goto __pyx_L5_except_error;
        }
        __pyx_L18:;
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "dbus_fast/message_bus.py":1158
 *                     err: Exception | None,
 *                 ) -> None:
 *                     try:             # <<<<<<<<<<<<<<
 *                         if err is not None:
 *                             send_reply.send_error(err)
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "dbus_fast/message_bus.py":1152
 *                     )
 * 
 *                 def get_property_callback(             # <<<<<<<<<<<<<<
 *                     interface: ServiceInterface,
 *                     prop: _Property,
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_properties_handler.get_property_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XDECREF(__pyx_v_unix_fds);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1195
 *                 assert prop.prop_setter
 * 
 *                 def set_property_callback(             # <<<<<<<<<<<<<<
 *                     interface: ServiceInterface, prop: _Property, err: Exception | None
 *                 ) -> None:
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_3set_property_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_3set_property_callback = {"set_property_callback", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_3set_property_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_3set_property_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface = 0;
  CYTHON_UNUSED PyObject *__pyx_v_prop = 0;
  PyObject *__pyx_v_err = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_property_callback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_interface,&__pyx_mstate_global->__pyx_n_u_prop,&__pyx_mstate_global->__pyx_n_u_err,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1195, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1195, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1195, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1195, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "set_property_callback", 0) < (0)) __PYX_ERR(0, 1195, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("set_property_callback", 1, 3, 3, i); __PYX_ERR(0, 1195, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1195, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1195, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1195, __pyx_L3_error)
    }
    __pyx_v_interface = ((struct __pyx_obj_9dbus_fast_7service_ServiceInterface *)values[0]);
    __pyx_v_prop = values[1];
    __pyx_v_err = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_property_callback", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1195, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_properties_handler.set_property_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_interface), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface, 0, "interface", 0))) __PYX_ERR(0, 1196, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 1196, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_2set_property_callback(__pyx_self, __pyx_v_interface, __pyx_v_prop, __pyx_v_err);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_2set_property_callback(PyObject *__pyx_self, CYTHON_UNUSED struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, CYTHON_UNUSED PyObject *__pyx_v_prop, PyObject *__pyx_v_err) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_property_callback", 0);
  __pyx_outer_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "dbus_fast/message_bus.py":1198
 *                     interface: ServiceInterface, prop: _Property, err: Exception | None
 *                 ) -> None:
 *                     if err is not None:             # <<<<<<<<<<<<<<
 *                         send_reply.send_error(err)
 *                         return
*/
  __pyx_t_1 = (__pyx_v_err != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1199
 *                 ) -> None:
 *                     if err is not None:
 *                         send_reply.send_error(err)             # <<<<<<<<<<<<<<
 *                         return
 *                     send_reply(Message.new_method_return(msg))
*/
    if (unlikely(!__pyx_cur_scope->__pyx_v_send_reply)) { __Pyx_RaiseClosureNameError("send_reply"); __PYX_ERR(0, 1199, __pyx_L1_error) }
    __pyx_t_3 = __pyx_cur_scope->__pyx_v_send_reply;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_err};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":1200
 *                     if err is not None:
 *                         send_reply.send_error(err)
 *                         return             # <<<<<<<<<<<<<<
 *                     send_reply(Message.new_method_return(msg))
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":1198
 *                     interface: ServiceInterface, prop: _Property, err: Exception | None
 *                 ) -> None:
 *                     if err is not None:             # <<<<<<<<<<<<<<
 *                         send_reply.send_error(err)
 *                         return
*/
  }

  /* "dbus_fast/message_bus.py":1201
 *                         send_reply.send_error(err)
 *                         return
 *                     send_reply(Message.new_method_return(msg))             # <<<<<<<<<<<<<<
 * 
 *                 body = replace_idx_with_fds(
*/
  __pyx_t_3 = NULL;
  if (unlikely(!__pyx_cur_scope->__pyx_v_send_reply)) { __Pyx_RaiseClosureNameError("send_reply"); __PYX_ERR(0, 1201, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_send_reply);
  __pyx_t_5 = __pyx_cur_scope->__pyx_v_send_reply; 
  __pyx_t_7 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
  __Pyx_INCREF(__pyx_t_7);
  if (unlikely(!__pyx_cur_scope->__pyx_v_msg)) { __Pyx_RaiseClosureNameError("msg"); __PYX_ERR(0, 1201, __pyx_L1_error) }
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, ((PyObject *)__pyx_cur_scope->__pyx_v_msg)};
    __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new_method_return, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1201, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  }
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_6};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1201, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":1195
 *                 assert prop.prop_setter
 * 
 *                 def set_property_callback(             # <<<<<<<<<<<<<<
 *                     interface: ServiceInterface, prop: _Property, err: Exception | None
 *                 ) -> None:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_properties_handler.set_property_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1212
 *         elif msg.member == "GetAll":
 * 
 *             def get_all_properties_callback(             # <<<<<<<<<<<<<<
 *                 interface: ServiceInterface,
 *                 values: Any,
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_5get_all_properties_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_5get_all_properties_callback = {"get_all_properties_callback", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_5get_all_properties_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_5get_all_properties_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface = 0;
  PyObject *__pyx_v_values = 0;
  CYTHON_UNUSED PyObject *__pyx_v_user_data = 0;
  PyObject *__pyx_v_err = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_all_properties_callback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_interface,&__pyx_mstate_global->__pyx_n_u_values,&__pyx_mstate_global->__pyx_n_u_user_data,&__pyx_mstate_global->__pyx_n_u_err,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1212, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 1212, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1212, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1212, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1212, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_all_properties_callback", 0) < (0)) __PYX_ERR(0, 1212, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 4; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_all_properties_callback", 1, 4, 4, i); __PYX_ERR(0, 1212, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1212, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1212, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1212, __pyx_L3_error)
      values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 1212, __pyx_L3_error)
    }
    __pyx_v_interface = ((struct __pyx_obj_9dbus_fast_7service_ServiceInterface *)values[0]);
    __pyx_v_values = values[1];
    __pyx_v_user_data = values[2];
    __pyx_v_err = ((PyObject*)values[3]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_all_properties_callback", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 1212, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_properties_handler.get_all_properties_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_interface), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface, 0, "interface", 0))) __PYX_ERR(0, 1213, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 1216, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_4get_all_properties_callback(__pyx_self, __pyx_v_interface, __pyx_v_values, __pyx_v_user_data, __pyx_v_err);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_4get_all_properties_callback(PyObject *__pyx_self, CYTHON_UNUSED struct __pyx_obj_9dbus_fast_7service_ServiceInterface *__pyx_v_interface, PyObject *__pyx_v_values, CYTHON_UNUSED PyObject *__pyx_v_user_data, PyObject *__pyx_v_err) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *__pyx_outer_scope;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_v_unix_fds = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_all_properties_callback", 0);
  __pyx_outer_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "dbus_fast/message_bus.py":1218
 *                 err: Exception | None,
 *             ) -> None:
 *                 if err is not None:             # <<<<<<<<<<<<<<
 *                     send_reply.send_error(err)
 *                     return
*/
  __pyx_t_1 = (__pyx_v_err != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1219
 *             ) -> None:
 *                 if err is not None:
 *                     send_reply.send_error(err)             # <<<<<<<<<<<<<<
 *                     return
 *                 body, unix_fds = replace_fds_with_idx("a{sv}", [values])
*/
    if (unlikely(!__pyx_cur_scope->__pyx_v_send_reply)) { __Pyx_RaiseClosureNameError("send_reply"); __PYX_ERR(0, 1219, __pyx_L1_error) }
    __pyx_t_3 = __pyx_cur_scope->__pyx_v_send_reply;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_err};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_send_error, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":1220
 *                 if err is not None:
 *                     send_reply.send_error(err)
 *                     return             # <<<<<<<<<<<<<<
 *                 body, unix_fds = replace_fds_with_idx("a{sv}", [values])
 *                 send_reply(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":1218
 *                 err: Exception | None,
 *             ) -> None:
 *                 if err is not None:             # <<<<<<<<<<<<<<
 *                     send_reply.send_error(err)
 *                     return
*/
  }

  /* "dbus_fast/message_bus.py":1221
 *                     send_reply.send_error(err)
 *                     return
 *                 body, unix_fds = replace_fds_with_idx("a{sv}", [values])             # <<<<<<<<<<<<<<
 *                 send_reply(
 *                     Message.new_method_return(msg, "a{sv}", body, unix_fds=unix_fds)
*/
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_replace_fds_with_idx); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_values);
  __Pyx_GIVEREF(__pyx_v_values);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_v_values) != (0)) __PYX_ERR(0, 1221, __pyx_L1_error);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_a_sv, __pyx_t_6};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1221, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);
      __Pyx_INCREF(__pyx_t_6);
    } else {
      __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1221, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1221, __pyx_L1_error)
      __Pyx_XGOTREF(__pyx_t_6);
    }
    #else
    __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3);
    index = 0; __pyx_t_5 = __pyx_t_7(__pyx_t_3); if (unlikely(!__pyx_t_5)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    index = 1; __pyx_t_6 = __pyx_t_7(__pyx_t_3); if (unlikely(!__pyx_t_6)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_3), 2) < (0)) __PYX_ERR(0, 1221, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1221, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_body = __pyx_t_5;
  __pyx_t_5 = 0;
  __pyx_v_unix_fds = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "dbus_fast/message_bus.py":1222
 *                     return
 *                 body, unix_fds = replace_fds_with_idx("a{sv}", [values])
 *                 send_reply(             # <<<<<<<<<<<<<<
 *                     Message.new_method_return(msg, "a{sv}", body, unix_fds=unix_fds)
 *                 )
*/
  __pyx_t_6 = NULL;
  if (unlikely(!__pyx_cur_scope->__pyx_v_send_reply)) { __Pyx_RaiseClosureNameError("send_reply"); __PYX_ERR(0, 1222, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_send_reply);
  __pyx_t_5 = __pyx_cur_scope->__pyx_v_send_reply; 

  /* "dbus_fast/message_bus.py":1223
 *                 body, unix_fds = replace_fds_with_idx("a{sv}", [values])
 *                 send_reply(
 *                     Message.new_method_return(msg, "a{sv}", body, unix_fds=unix_fds)             # <<<<<<<<<<<<<<
 *                 )
 * 
*/
  __pyx_t_8 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
  __Pyx_INCREF(__pyx_t_8);
  if (unlikely(!__pyx_cur_scope->__pyx_v_msg)) { __Pyx_RaiseClosureNameError("msg"); __PYX_ERR(0, 1223, __pyx_L1_error) }
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[4 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_8, ((PyObject *)__pyx_cur_scope->__pyx_v_msg), __pyx_mstate_global->__pyx_kp_u_a_sv, __pyx_v_body};
    __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_unix_fds, __pyx_v_unix_fds, __pyx_t_9, __pyx_callargs+4, 0) < (0)) __PYX_ERR(0, 1223, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_new_method_return, __pyx_callargs+__pyx_t_4, (4-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_6);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_6);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_3};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":1212
 *         elif msg.member == "GetAll":
 * 
 *             def get_all_properties_callback(             # <<<<<<<<<<<<<<
 *                 interface: ServiceInterface,
 *                 values: Any,
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_properties_handler.get_all_properties_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XDECREF(__pyx_v_unix_fds);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1086
 *                 )
 * 
 *     def _default_properties_handler(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         methods = {"Get": "ss", "Set": "ssv", "GetAll": "s"}
 *         if msg.member not in methods or methods[msg.member] != msg.signature:
*/

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_58_default_properties_handler(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_send_reply) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *__pyx_cur_scope;
  PyObject *__pyx_v_methods = NULL;
  PyObject *__pyx_v_interface_name = NULL;
  PyObject *__pyx_v_prop_name = NULL;
  PyObject *__pyx_v_properties = NULL;
  PyObject *__pyx_v_match = NULL;
  PyObject *__pyx_v_prop = NULL;
  PyObject *__pyx_v_get_property_callback = 0;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_set_property_callback = 0;
  PyObject *__pyx_v_body = NULL;
  PyObject *__pyx_v_get_all_properties_callback = 0;
  PyObject *__pyx_v_interface = NULL;
  PyObject *__pyx_8genexpr3__pyx_v_prop = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[5];
  PyObject *__pyx_t_10 = NULL;
  size_t __pyx_t_11;
  PyObject *__pyx_t_12[3];
  Py_ssize_t __pyx_t_13;
  PyObject *(*__pyx_t_14)(PyObject *);
  int __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_default_properties_handler", 0);
  __pyx_cur_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1086, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_msg = __pyx_v_msg;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_msg);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_msg);
  __pyx_cur_scope->__pyx_v_send_reply = __pyx_v_send_reply;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_send_reply);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_send_reply);

  /* "dbus_fast/message_bus.py":1087
 * 
 *     def _default_properties_handler(self, msg: Message, send_reply: SendReply) -> None:
 *         methods = {"Get": "ss", "Set": "ssv", "GetAll": "s"}             # <<<<<<<<<<<<<<
 *         if msg.member not in methods or methods[msg.member] != msg.signature:
 *             raise DBusError(
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_Get, __pyx_mstate_global->__pyx_n_u_ss) < (0)) __PYX_ERR(0, 1087, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_Set, __pyx_mstate_global->__pyx_n_u_ssv) < (0)) __PYX_ERR(0, 1087, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_GetAll, __pyx_mstate_global->__pyx_n_u_s) < (0)) __PYX_ERR(0, 1087, __pyx_L1_error)
  __pyx_v_methods = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":1088
 *     def _default_properties_handler(self, msg: Message, send_reply: SendReply) -> None:
 *         methods = {"Get": "ss", "Set": "ssv", "GetAll": "s"}
 *         if msg.member not in methods or methods[msg.member] != msg.signature:             # <<<<<<<<<<<<<<
 *             raise DBusError(
 *                 ErrorType.UNKNOWN_METHOD,
*/
  __pyx_t_3 = (__Pyx_PyDict_ContainsTF(__pyx_cur_scope->__pyx_v_msg->member, __pyx_v_methods, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1088, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_methods, __pyx_cur_scope->__pyx_v_msg->member); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_cur_scope->__pyx_v_msg->signature, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1088, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "dbus_fast/message_bus.py":1089
 *         methods = {"Get": "ss", "Set": "ssv", "GetAll": "s"}
 *         if msg.member not in methods or methods[msg.member] != msg.signature:
 *             raise DBusError(             # <<<<<<<<<<<<<<
 *                 ErrorType.UNKNOWN_METHOD,
 *                 f'properties interface doesn\'t have method "{msg.member}" with signature "{msg.signature}"',
*/
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_DBusError);
    __pyx_t_5 = __pyx_v_9dbus_fast_11message_bus_DBusError; 

    /* "dbus_fast/message_bus.py":1090
 *         if msg.member not in methods or methods[msg.member] != msg.signature:
 *             raise DBusError(
 *                 ErrorType.UNKNOWN_METHOD,             # <<<<<<<<<<<<<<
 *                 f'properties interface doesn\'t have method "{msg.member}" with signature "{msg.signature}"',
 *             )
*/
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1090, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_UNKNOWN_METHOD); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1090, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "dbus_fast/message_bus.py":1091
 *             raise DBusError(
 *                 ErrorType.UNKNOWN_METHOD,
 *                 f'properties interface doesn\'t have method "{msg.member}" with signature "{msg.signature}"',             # <<<<<<<<<<<<<<
 *             )
 * 
*/
    __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_cur_scope->__pyx_v_msg->member, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = __Pyx_PyUnicode_Unicode(__pyx_cur_scope->__pyx_v_msg->signature); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_properties_interface_doesn_t_hav;
    __pyx_t_9[1] = __pyx_t_6;
    __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u_with_signature_2;
    __pyx_t_9[3] = __pyx_t_8;
    __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u__3;
    __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 42 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 18 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_11 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_11 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_7, __pyx_t_10};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1089, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1089, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":1088
 *     def _default_properties_handler(self, msg: Message, send_reply: SendReply) -> None:
 *         methods = {"Get": "ss", "Set": "ssv", "GetAll": "s"}
 *         if msg.member not in methods or methods[msg.member] != msg.signature:             # <<<<<<<<<<<<<<
 *             raise DBusError(
 *                 ErrorType.UNKNOWN_METHOD,
*/
  }

  /* "dbus_fast/message_bus.py":1094
 *             )
 * 
 *         interface_name = msg.body[0]             # <<<<<<<<<<<<<<
 *         if interface_name == "":
 *             raise DBusError(
*/
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_msg->body, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_interface_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":1095
 * 
 *         interface_name = msg.body[0]
 *         if interface_name == "":             # <<<<<<<<<<<<<<
 *             raise DBusError(
 *                 ErrorType.NOT_SUPPORTED,
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_interface_name, __pyx_mstate_global->__pyx_kp_u__7, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1095, __pyx_L1_error)
  if (unlikely(__pyx_t_2)) {

    /* "dbus_fast/message_bus.py":1096
 *         interface_name = msg.body[0]
 *         if interface_name == "":
 *             raise DBusError(             # <<<<<<<<<<<<<<
 *                 ErrorType.NOT_SUPPORTED,
 *                 "getting and setting properties with an empty interface string is not supported yet",
*/
    __pyx_t_5 = NULL;
    __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_DBusError);
    __pyx_t_10 = __pyx_v_9dbus_fast_11message_bus_DBusError; 

    /* "dbus_fast/message_bus.py":1097
 *         if interface_name == "":
 *             raise DBusError(
 *                 ErrorType.NOT_SUPPORTED,             # <<<<<<<<<<<<<<
 *                 "getting and setting properties with an empty interface string is not supported yet",
 *             )
*/
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_NOT_SUPPORTED); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_11 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_10);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);
      __pyx_t_11 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_4, __pyx_mstate_global->__pyx_kp_u_getting_and_setting_properties_w};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1096, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1096, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":1095
 * 
 *         interface_name = msg.body[0]
 *         if interface_name == "":             # <<<<<<<<<<<<<<
 *             raise DBusError(
 *                 ErrorType.NOT_SUPPORTED,
*/
  }

  /* "dbus_fast/message_bus.py":1101
 *             )
 * 
 *         if msg.path not in self._path_exports:             # <<<<<<<<<<<<<<
 *             raise DBusError(
 *                 ErrorType.UNKNOWN_OBJECT, f'no interfaces at path: "{msg.path}"'
*/
  if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1101, __pyx_L1_error)
  }
  __pyx_t_2 = (__Pyx_PyDict_ContainsTF(__pyx_cur_scope->__pyx_v_msg->path, __pyx_v_self->_path_exports, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1101, __pyx_L1_error)
  if (unlikely(__pyx_t_2)) {

    /* "dbus_fast/message_bus.py":1102
 * 
 *         if msg.path not in self._path_exports:
 *             raise DBusError(             # <<<<<<<<<<<<<<
 *                 ErrorType.UNKNOWN_OBJECT, f'no interfaces at path: "{msg.path}"'
 *             )
*/
    __pyx_t_10 = NULL;
    __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_DBusError);
    __pyx_t_4 = __pyx_v_9dbus_fast_11message_bus_DBusError; 

    /* "dbus_fast/message_bus.py":1103
 *         if msg.path not in self._path_exports:
 *             raise DBusError(
 *                 ErrorType.UNKNOWN_OBJECT, f'no interfaces at path: "{msg.path}"'             # <<<<<<<<<<<<<<
 *             )
 * 
*/
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_UNKNOWN_OBJECT); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_cur_scope->__pyx_v_msg->path, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_12[0] = __pyx_mstate_global->__pyx_kp_u_no_interfaces_at_path;
    __pyx_t_12[1] = __pyx_t_5;
    __pyx_t_12[2] = __pyx_mstate_global->__pyx_kp_u__3;
    __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_12, 3, 24 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5));
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_11 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_10);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_11 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_t_7, __pyx_t_8};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1102, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1102, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":1101
 *             )
 * 
 *         if msg.path not in self._path_exports:             # <<<<<<<<<<<<<<
 *             raise DBusError(
 *                 ErrorType.UNKNOWN_OBJECT, f'no interfaces at path: "{msg.path}"'
*/
  }

  /* "dbus_fast/message_bus.py":1106
 *             )
 * 
 *         if (interface := self._path_exports[msg.path].get(interface_name)) is None:             # <<<<<<<<<<<<<<
 *             if interface_name in [
 *                 "org.freedesktop.DBus.Properties",
*/
  if (unlikely(__pyx_v_self->_path_exports == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1106, __pyx_L1_error)
  }
  __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_self->_path_exports, __pyx_cur_scope->__pyx_v_msg->path); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_4 = __pyx_t_8;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_11 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_interface_name};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1106, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_interface = __pyx_t_1;
  __pyx_t_2 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "dbus_fast/message_bus.py":1107
 * 
 *         if (interface := self._path_exports[msg.path].get(interface_name)) is None:
 *             if interface_name in [             # <<<<<<<<<<<<<<
 *                 "org.freedesktop.DBus.Properties",
 *                 "org.freedesktop.DBus.Introspectable",
*/
    __Pyx_INCREF(__pyx_v_interface_name);
    __pyx_t_1 = __pyx_v_interface_name;
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_Properties, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1107, __pyx_L1_error)
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_Introspecta, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1107, __pyx_L1_error)
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_Peer, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1107, __pyx_L1_error)
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_ObjectManag, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1107, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_3;
    __pyx_L10_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __pyx_t_2;
    if (__pyx_t_3) {

      /* "dbus_fast/message_bus.py":1114
 *             ]:
 *                 # the standard interfaces do not have properties
 *                 if msg.member == "Get" or msg.member == "Set":             # <<<<<<<<<<<<<<
 *                     prop_name = msg.body[1]
 *                     raise DBusError(
*/
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_cur_scope->__pyx_v_msg->member, __pyx_mstate_global->__pyx_n_u_Get, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1114, __pyx_L1_error)
      if (!__pyx_t_2) {
      } else {
        __pyx_t_3 = __pyx_t_2;
        goto __pyx_L15_bool_binop_done;
      }
      __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_cur_scope->__pyx_v_msg->member, __pyx_mstate_global->__pyx_n_u_Set, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1114, __pyx_L1_error)
      __pyx_t_3 = __pyx_t_2;
      __pyx_L15_bool_binop_done:;
      if (unlikely(__pyx_t_3)) {

        /* "dbus_fast/message_bus.py":1115
 *                 # the standard interfaces do not have properties
 *                 if msg.member == "Get" or msg.member == "Set":
 *                     prop_name = msg.body[1]             # <<<<<<<<<<<<<<
 *                     raise DBusError(
 *                         ErrorType.UNKNOWN_PROPERTY,
*/
        __pyx_t_1 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_msg->body, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1115, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_prop_name = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "dbus_fast/message_bus.py":1116
 *                 if msg.member == "Get" or msg.member == "Set":
 *                     prop_name = msg.body[1]
 *                     raise DBusError(             # <<<<<<<<<<<<<<
 *                         ErrorType.UNKNOWN_PROPERTY,
 *                         f'interface "{interface_name}" does not have property "{prop_name}"',
*/
        __pyx_t_8 = NULL;
        __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_DBusError);
        __pyx_t_4 = __pyx_v_9dbus_fast_11message_bus_DBusError; 

        /* "dbus_fast/message_bus.py":1117
 *                     prop_name = msg.body[1]
 *                     raise DBusError(
 *                         ErrorType.UNKNOWN_PROPERTY,             # <<<<<<<<<<<<<<
 *                         f'interface "{interface_name}" does not have property "{prop_name}"',
 *                     )
*/
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1117, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_UNKNOWN_PROPERTY); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1117, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "dbus_fast/message_bus.py":1118
 *                     raise DBusError(
 *                         ErrorType.UNKNOWN_PROPERTY,
 *                         f'interface "{interface_name}" does not have property "{prop_name}"',             # <<<<<<<<<<<<<<
 *                     )
 *                 if msg.member == "GetAll":
*/
        __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_v_interface_name, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1118, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_prop_name, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1118, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_interface_2;
        __pyx_t_9[1] = __pyx_t_7;
        __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u_does_not_have_property;
        __pyx_t_9[3] = __pyx_t_5;
        __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u__3;
        __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 11 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7) + 26 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5));
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1118, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_11 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_8);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_11 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_t_10, __pyx_t_6};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1116, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __PYX_ERR(0, 1116, __pyx_L1_error)

        /* "dbus_fast/message_bus.py":1114
 *             ]:
 *                 # the standard interfaces do not have properties
 *                 if msg.member == "Get" or msg.member == "Set":             # <<<<<<<<<<<<<<
 *                     prop_name = msg.body[1]
 *                     raise DBusError(
*/
      }

      /* "dbus_fast/message_bus.py":1120
 *                         f'interface "{interface_name}" does not have property "{prop_name}"',
 *                     )
 *                 if msg.member == "GetAll":             # <<<<<<<<<<<<<<
 *                     send_reply(Message.new_method_return(msg, "a{sv}", [{}]))
 *                     return
*/
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_cur_scope->__pyx_v_msg->member, __pyx_mstate_global->__pyx_n_u_GetAll, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1120, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "dbus_fast/message_bus.py":1121
 *                     )
 *                 if msg.member == "GetAll":
 *                     send_reply(Message.new_method_return(msg, "a{sv}", [{}]))             # <<<<<<<<<<<<<<
 *                     return
 *                 assert False
*/
        __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_send_reply);
        __pyx_t_6 = __pyx_cur_scope->__pyx_v_send_reply; 
        __pyx_t_8 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message);
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_5 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1121, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1121, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_5);
        if (__Pyx_PyList_SET_ITEM(__pyx_t_7, 0, __pyx_t_5) != (0)) __PYX_ERR(0, 1121, __pyx_L1_error);
        __pyx_t_5 = 0;
        __pyx_t_11 = 0;
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_8, ((PyObject *)__pyx_cur_scope->__pyx_v_msg), __pyx_mstate_global->__pyx_kp_u_a_sv, __pyx_t_7};
          __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new_method_return, __pyx_callargs+__pyx_t_11, (4-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1121, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
        }
        __pyx_t_11 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
          assert(__pyx_t_4);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
          __pyx_t_11 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_10};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1121, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "dbus_fast/message_bus.py":1122
 *                 if msg.member == "GetAll":
 *                     send_reply(Message.new_method_return(msg, "a{sv}", [{}]))
 *                     return             # <<<<<<<<<<<<<<
 *                 assert False
 *             raise DBusError(
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L0;

        /* "dbus_fast/message_bus.py":1120
 *                         f'interface "{interface_name}" does not have property "{prop_name}"',
 *                     )
 *                 if msg.member == "GetAll":             # <<<<<<<<<<<<<<
 *                     send_reply(Message.new_method_return(msg, "a{sv}", [{}]))
 *                     return
*/
      }

      /* "dbus_fast/message_bus.py":1123
 *                     send_reply(Message.new_method_return(msg, "a{sv}", [{}]))
 *                     return
 *                 assert False             # <<<<<<<<<<<<<<
 *             raise DBusError(
 *                 ErrorType.UNKNOWN_INTERFACE,
*/
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(__pyx_assertions_enabled())) {
        if (unlikely(!0)) {
          __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
          __PYX_ERR(0, 1123, __pyx_L1_error)
        }
      }
      #else
      if ((1)); else __PYX_ERR(0, 1123, __pyx_L1_error)
      #endif

      /* "dbus_fast/message_bus.py":1107
 * 
 *         if (interface := self._path_exports[msg.path].get(interface_name)) is None:
 *             if interface_name in [             # <<<<<<<<<<<<<<
 *                 "org.freedesktop.DBus.Properties",
 *                 "org.freedesktop.DBus.Introspectable",
*/
    }

    /* "dbus_fast/message_bus.py":1124
 *                     return
 *                 assert False
 *             raise DBusError(             # <<<<<<<<<<<<<<
 *                 ErrorType.UNKNOWN_INTERFACE,
 *                 f'could not find an interface "{interface_name}" at path: "{msg.path}"',
*/
    __pyx_t_6 = NULL;
    __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_DBusError);
    __pyx_t_10 = __pyx_v_9dbus_fast_11message_bus_DBusError; 

    /* "dbus_fast/message_bus.py":1125
 *                 assert False
 *             raise DBusError(
 *                 ErrorType.UNKNOWN_INTERFACE,             # <<<<<<<<<<<<<<
 *                 f'could not find an interface "{interface_name}" at path: "{msg.path}"',
 *             )
*/
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_UNKNOWN_INTERFACE); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "dbus_fast/message_bus.py":1126
 *             raise DBusError(
 *                 ErrorType.UNKNOWN_INTERFACE,
 *                 f'could not find an interface "{interface_name}" at path: "{msg.path}"',             # <<<<<<<<<<<<<<
 *             )
 * 
*/
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_v_interface_name, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_cur_scope->__pyx_v_msg->path, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_could_not_find_an_interface;
    __pyx_t_9[1] = __pyx_t_4;
    __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u_at_path;
    __pyx_t_9[3] = __pyx_t_8;
    __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u__3;
    __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 29 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 12 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_11 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_10);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);
      __pyx_t_11 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_7, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1124, __pyx_L1_error)

    /* "dbus_fast/message_bus.py":1106
 *             )
 * 
 *         if (interface := self._path_exports[msg.path].get(interface_name)) is None:             # <<<<<<<<<<<<<<
 *             if interface_name in [
 *                 "org.freedesktop.DBus.Properties",
*/
  }

  /* "dbus_fast/message_bus.py":1129
 *             )
 * 
 *         properties = ServiceInterface._get_properties(interface)             # <<<<<<<<<<<<<<
 * 
 *         if msg.member == "Get" or msg.member == "Set":
*/
  __pyx_t_10 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface);
  __Pyx_INCREF(__pyx_t_10);
  __pyx_t_11 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_interface};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_properties, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_properties = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "dbus_fast/message_bus.py":1131
 *         properties = ServiceInterface._get_properties(interface)
 * 
 *         if msg.member == "Get" or msg.member == "Set":             # <<<<<<<<<<<<<<
 *             prop_name = msg.body[1]
 *             match = [
*/
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_cur_scope->__pyx_v_msg->member, __pyx_mstate_global->__pyx_n_u_Get, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1131, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_3 = __pyx_t_2;
    goto __pyx_L19_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_cur_scope->__pyx_v_msg->member, __pyx_mstate_global->__pyx_n_u_Set, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1131, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_2;
  __pyx_L19_bool_binop_done:;
  if (__pyx_t_3) {

    /* "dbus_fast/message_bus.py":1132
 * 
 *         if msg.member == "Get" or msg.member == "Set":
 *             prop_name = msg.body[1]             # <<<<<<<<<<<<<<
 *             match = [
 *                 prop
*/
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_msg->body, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_prop_name = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":1133
 *         if msg.member == "Get" or msg.member == "Set":
 *             prop_name = msg.body[1]
 *             match = [             # <<<<<<<<<<<<<<
 *                 prop
 *                 for prop in properties
*/
    { /* enter inner scope */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1133, __pyx_L23_error)
      __Pyx_GOTREF(__pyx_t_1);

      /* "dbus_fast/message_bus.py":1135
 *             match = [
 *                 prop
 *                 for prop in properties             # <<<<<<<<<<<<<<
 *                 if prop.name == prop_name and not prop.disabled
 *             ]
*/
      if (likely(PyList_CheckExact(__pyx_v_properties)) || PyTuple_CheckExact(__pyx_v_properties)) {
        __pyx_t_10 = __pyx_v_properties; __Pyx_INCREF(__pyx_t_10);
        __pyx_t_13 = 0;
        __pyx_t_14 = NULL;
      } else {
        __pyx_t_13 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_v_properties); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1135, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_14 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_10); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1135, __pyx_L23_error)
      }
      for (;;) {
        if (likely(!__pyx_t_14)) {
          if (likely(PyList_CheckExact(__pyx_t_10))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_10);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1135, __pyx_L23_error)
              #endif
              if (__pyx_t_13 >= __pyx_temp) break;
            }
            __pyx_t_5 = __Pyx_PyList_GetItemRefFast(__pyx_t_10, __pyx_t_13, __Pyx_ReferenceSharing_OwnStrongReference);
            ++__pyx_t_13;
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_10);
              #if !CYTHON_ASSUME_SAFE_SIZE
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1135, __pyx_L23_error)
              #endif
              if (__pyx_t_13 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_13));
            #else
            __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_10, __pyx_t_13);
            #endif
            ++__pyx_t_13;
          }
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1135, __pyx_L23_error)
        } else {
          __pyx_t_5 = __pyx_t_14(__pyx_t_10);
          if (unlikely(!__pyx_t_5)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 1135, __pyx_L23_error)
              PyErr_Clear();
            }
            break;
          }
        }
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_XDECREF_SET(__pyx_8genexpr3__pyx_v_prop, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "dbus_fast/message_bus.py":1136
 *                 prop
 *                 for prop in properties
 *                 if prop.name == prop_name and not prop.disabled             # <<<<<<<<<<<<<<
 *             ]
 *             if not match:
*/
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_8genexpr3__pyx_v_prop, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1136, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = PyObject_RichCompare(__pyx_t_5, __pyx_v_prop_name, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1136, __pyx_L23_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1136, __pyx_L23_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (__pyx_t_2) {
        } else {
          __pyx_t_3 = __pyx_t_2;
          goto __pyx_L27_bool_binop_done;
        }
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_8genexpr3__pyx_v_prop, __pyx_mstate_global->__pyx_n_u_disabled); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1136, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1136, __pyx_L23_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_15 = (!__pyx_t_2);
        __pyx_t_3 = __pyx_t_15;
        __pyx_L27_bool_binop_done:;
        if (__pyx_t_3) {

          /* "dbus_fast/message_bus.py":1134
 *             prop_name = msg.body[1]
 *             match = [
 *                 prop             # <<<<<<<<<<<<<<
 *                 for prop in properties
 *                 if prop.name == prop_name and not prop.disabled
*/
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_8genexpr3__pyx_v_prop))) __PYX_ERR(0, 1133, __pyx_L23_error)

          /* "dbus_fast/message_bus.py":1136
 *                 prop
 *                 for prop in properties
 *                 if prop.name == prop_name and not prop.disabled             # <<<<<<<<<<<<<<
 *             ]
 *             if not match:
*/
        }

        /* "dbus_fast/message_bus.py":1135
 *             match = [
 *                 prop
 *                 for prop in properties             # <<<<<<<<<<<<<<
 *                 if prop.name == prop_name and not prop.disabled
 *             ]
*/
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_prop); __pyx_8genexpr3__pyx_v_prop = 0;
      goto __pyx_L30_exit_scope;
      __pyx_L23_error:;
      __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_prop); __pyx_8genexpr3__pyx_v_prop = 0;
      goto __pyx_L1_error;
      __pyx_L30_exit_scope:;
    } /* exit inner scope */
    __pyx_v_match = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":1138
 *                 if prop.name == prop_name and not prop.disabled
 *             ]
 *             if not match:             # <<<<<<<<<<<<<<
 *                 raise DBusError(
 *                     ErrorType.UNKNOWN_PROPERTY,
*/
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_match);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 1138, __pyx_L1_error)
      __pyx_t_3 = (__pyx_temp != 0);
    }

    __pyx_t_15 = (!__pyx_t_3);
    if (unlikely(__pyx_t_15)) {

      /* "dbus_fast/message_bus.py":1139
 *             ]
 *             if not match:
 *                 raise DBusError(             # <<<<<<<<<<<<<<
 *                     ErrorType.UNKNOWN_PROPERTY,
 *                     f'interface "{interface_name}" does not have property "{prop_name}"',
*/
      __pyx_t_10 = NULL;
      __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_DBusError);
      __pyx_t_7 = __pyx_v_9dbus_fast_11message_bus_DBusError; 

      /* "dbus_fast/message_bus.py":1140
 *             if not match:
 *                 raise DBusError(
 *                     ErrorType.UNKNOWN_PROPERTY,             # <<<<<<<<<<<<<<
 *                     f'interface "{interface_name}" does not have property "{prop_name}"',
 *                 )
*/
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_UNKNOWN_PROPERTY); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "dbus_fast/message_bus.py":1141
 *                 raise DBusError(
 *                     ErrorType.UNKNOWN_PROPERTY,
 *                     f'interface "{interface_name}" does not have property "{prop_name}"',             # <<<<<<<<<<<<<<
 *                 )
 * 
*/
      __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_interface_name, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1141, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_prop_name, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1141, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_interface_2;
      __pyx_t_9[1] = __pyx_t_5;
      __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u_does_not_have_property;
      __pyx_t_9[3] = __pyx_t_8;
      __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u__3;
      __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 11 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 26 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1141, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_11 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_10);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_11 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_t_6, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1139, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 1139, __pyx_L1_error)

      /* "dbus_fast/message_bus.py":1138
 *                 if prop.name == prop_name and not prop.disabled
 *             ]
 *             if not match:             # <<<<<<<<<<<<<<
 *                 raise DBusError(
 *                     ErrorType.UNKNOWN_PROPERTY,
*/
    }

    /* "dbus_fast/message_bus.py":1144
 *                 )
 * 
 *             prop = match[0]             # <<<<<<<<<<<<<<
 *             if msg.member == "Get":
 *                 if not prop.access.readable():
*/
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_match, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_prop = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "dbus_fast/message_bus.py":1145
 * 
 *             prop = match[0]
 *             if msg.member == "Get":             # <<<<<<<<<<<<<<
 *                 if not prop.access.readable():
 *                     raise DBusError(
*/
    __pyx_t_15 = (__Pyx_PyUnicode_Equals(__pyx_cur_scope->__pyx_v_msg->member, __pyx_mstate_global->__pyx_n_u_Get, Py_EQ)); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 1145, __pyx_L1_error)
    if (__pyx_t_15) {

      /* "dbus_fast/message_bus.py":1146
 *             prop = match[0]
 *             if msg.member == "Get":
 *                 if not prop.access.readable():             # <<<<<<<<<<<<<<
 *                     raise DBusError(
 *                         ErrorType.UNKNOWN_PROPERTY,
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_prop, __pyx_mstate_global->__pyx_n_u_access); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __pyx_t_4;
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_11 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_readable, __pyx_callargs+__pyx_t_11, (1-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1146, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 1146, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_3 = (!__pyx_t_15);
      if (unlikely(__pyx_t_3)) {

        /* "dbus_fast/message_bus.py":1147
 *             if msg.member == "Get":
 *                 if not prop.access.readable():
 *                     raise DBusError(             # <<<<<<<<<<<<<<
 *                         ErrorType.UNKNOWN_PROPERTY,
 *                         "the property does not have read access",
*/
        __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_DBusError);
        __pyx_t_7 = __pyx_v_9dbus_fast_11message_bus_DBusError; 

        /* "dbus_fast/message_bus.py":1148
 *                 if not prop.access.readable():
 *                     raise DBusError(
 *                         ErrorType.UNKNOWN_PROPERTY,             # <<<<<<<<<<<<<<
 *                         "the property does not have read access",
 *                     )
*/
        __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1148, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_UNKNOWN_PROPERTY); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1148, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_11 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
          assert(__pyx_t_4);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
          __pyx_t_11 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_10, __pyx_mstate_global->__pyx_kp_u_the_property_does_not_have_read};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1147, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __PYX_ERR(0, 1147, __pyx_L1_error)

        /* "dbus_fast/message_bus.py":1146
 *             prop = match[0]
 *             if msg.member == "Get":
 *                 if not prop.access.readable():             # <<<<<<<<<<<<<<
 *                     raise DBusError(
 *                         ErrorType.UNKNOWN_PROPERTY,
*/
      }

      /* "dbus_fast/message_bus.py":1152
 *                     )
 * 
 *                 def get_property_callback(             # <<<<<<<<<<<<<<
 *                     interface: ServiceInterface,
 *                     prop: _Property,
*/
      __pyx_t_1 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_n_u_ServiceInterface) < (0)) __PYX_ERR(0, 1152, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_prop, __pyx_mstate_global->__pyx_n_u_Property) < (0)) __PYX_ERR(0, 1152, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_prop_value, __pyx_mstate_global->__pyx_n_u_Any) < (0)) __PYX_ERR(0, 1152, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 1152, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 1152, __pyx_L1_error)
      __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_1get_property_callback, 0, __pyx_mstate_global->__pyx_n_u_default_properties_handler_loca, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_get_property_callback = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "dbus_fast/message_bus.py":1178
 *                         send_reply.send_error(e)
 * 
 *                 ServiceInterface._get_property_value(             # <<<<<<<<<<<<<<
 *                     interface, prop, get_property_callback
 *                 )
*/
      __pyx_t_1 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface);
      __Pyx_INCREF(__pyx_t_1);

      /* "dbus_fast/message_bus.py":1179
 * 
 *                 ServiceInterface._get_property_value(
 *                     interface, prop, get_property_callback             # <<<<<<<<<<<<<<
 *                 )
 * 
*/
      __pyx_t_11 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_interface, __pyx_v_prop, __pyx_v_get_property_callback};
        __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_property_value, __pyx_callargs+__pyx_t_11, (4-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1178, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "dbus_fast/message_bus.py":1145
 * 
 *             prop = match[0]
 *             if msg.member == "Get":             # <<<<<<<<<<<<<<
 *                 if not prop.access.readable():
 *                     raise DBusError(
*/
      goto __pyx_L32;
    }

    /* "dbus_fast/message_bus.py":1182
 *                 )
 * 
 *             elif msg.member == "Set":             # <<<<<<<<<<<<<<
 *                 if not prop.access.writable():
 *                     raise DBusError(
*/
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_cur_scope->__pyx_v_msg->member, __pyx_mstate_global->__pyx_n_u_Set, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1182, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "dbus_fast/message_bus.py":1183
 * 
 *             elif msg.member == "Set":
 *                 if not prop.access.writable():             # <<<<<<<<<<<<<<
 *                     raise DBusError(
 *                         ErrorType.PROPERTY_READ_ONLY, "the property is readonly"
*/
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_prop, __pyx_mstate_global->__pyx_n_u_access); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1183, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_1 = __pyx_t_10;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_11 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_writable, __pyx_callargs+__pyx_t_11, (1-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1183, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1183, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_15 = (!__pyx_t_3);
      if (unlikely(__pyx_t_15)) {

        /* "dbus_fast/message_bus.py":1184
 *             elif msg.member == "Set":
 *                 if not prop.access.writable():
 *                     raise DBusError(             # <<<<<<<<<<<<<<
 *                         ErrorType.PROPERTY_READ_ONLY, "the property is readonly"
 *                     )
*/
        __pyx_t_10 = NULL;
        __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_DBusError);
        __pyx_t_1 = __pyx_v_9dbus_fast_11message_bus_DBusError; 

        /* "dbus_fast/message_bus.py":1185
 *                 if not prop.access.writable():
 *                     raise DBusError(
 *                         ErrorType.PROPERTY_READ_ONLY, "the property is readonly"             # <<<<<<<<<<<<<<
 *                     )
 *                 value = msg.body[2]
*/
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1185, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_PROPERTY_READ_ONLY); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1185, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_11 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
          assert(__pyx_t_10);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
          __pyx_t_11 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_t_6, __pyx_mstate_global->__pyx_kp_u_the_property_is_readonly};
          __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1184, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_Raise(__pyx_t_7, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __PYX_ERR(0, 1184, __pyx_L1_error)

        /* "dbus_fast/message_bus.py":1183
 * 
 *             elif msg.member == "Set":
 *                 if not prop.access.writable():             # <<<<<<<<<<<<<<
 *                     raise DBusError(
 *                         ErrorType.PROPERTY_READ_ONLY, "the property is readonly"
*/
      }

      /* "dbus_fast/message_bus.py":1187
 *                         ErrorType.PROPERTY_READ_ONLY, "the property is readonly"
 *                     )
 *                 value = msg.body[2]             # <<<<<<<<<<<<<<
 *                 if value.signature != prop.signature:
 *                     raise DBusError(
*/
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_msg->body, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1187, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_v_value = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "dbus_fast/message_bus.py":1188
 *                     )
 *                 value = msg.body[2]
 *                 if value.signature != prop.signature:             # <<<<<<<<<<<<<<
 *                     raise DBusError(
 *                         ErrorType.INVALID_SIGNATURE,
*/
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_signature); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1188, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_prop, __pyx_mstate_global->__pyx_n_u_signature); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1188, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = PyObject_RichCompare(__pyx_t_7, __pyx_t_1, Py_NE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1188, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 1188, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(__pyx_t_15)) {

        /* "dbus_fast/message_bus.py":1189
 *                 value = msg.body[2]
 *                 if value.signature != prop.signature:
 *                     raise DBusError(             # <<<<<<<<<<<<<<
 *                         ErrorType.INVALID_SIGNATURE,
 *                         f'wrong signature for property. expected "{prop.signature}"',
*/
        __pyx_t_1 = NULL;
        __Pyx_INCREF(__pyx_v_9dbus_fast_11message_bus_DBusError);
        __pyx_t_7 = __pyx_v_9dbus_fast_11message_bus_DBusError; 

        /* "dbus_fast/message_bus.py":1190
 *                 if value.signature != prop.signature:
 *                     raise DBusError(
 *                         ErrorType.INVALID_SIGNATURE,             # <<<<<<<<<<<<<<
 *                         f'wrong signature for property. expected "{prop.signature}"',
 *                     )
*/
        __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_ErrorType); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1190, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_INVALID_SIGNATURE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1190, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "dbus_fast/message_bus.py":1191
 *                     raise DBusError(
 *                         ErrorType.INVALID_SIGNATURE,
 *                         f'wrong signature for property. expected "{prop.signature}"',             # <<<<<<<<<<<<<<
 *                     )
 *                 assert prop.prop_setter
*/
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_prop, __pyx_mstate_global->__pyx_n_u_signature); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1191, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_t_10, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1191, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_12[0] = __pyx_mstate_global->__pyx_kp_u_wrong_signature_for_property_exp;
        __pyx_t_12[1] = __pyx_t_8;
        __pyx_t_12[2] = __pyx_mstate_global->__pyx_kp_u__3;
        __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_12, 3, 40 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1191, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_11 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
          assert(__pyx_t_1);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
          __pyx_t_11 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_t_4, __pyx_t_10};
          __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1189, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __PYX_ERR(0, 1189, __pyx_L1_error)

        /* "dbus_fast/message_bus.py":1188
 *                     )
 *                 value = msg.body[2]
 *                 if value.signature != prop.signature:             # <<<<<<<<<<<<<<
 *                     raise DBusError(
 *                         ErrorType.INVALID_SIGNATURE,
*/
      }

      /* "dbus_fast/message_bus.py":1193
 *                         f'wrong signature for property. expected "{prop.signature}"',
 *                     )
 *                 assert prop.prop_setter             # <<<<<<<<<<<<<<
 * 
 *                 def set_property_callback(
*/
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(__pyx_assertions_enabled())) {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_prop, __pyx_mstate_global->__pyx_n_u_prop_setter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1193, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 1193, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_15)) {
          __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
          __PYX_ERR(0, 1193, __pyx_L1_error)
        }
      }
      #else
      if ((1)); else __PYX_ERR(0, 1193, __pyx_L1_error)
      #endif

      /* "dbus_fast/message_bus.py":1195
 *                 assert prop.prop_setter
 * 
 *                 def set_property_callback(             # <<<<<<<<<<<<<<
 *                     interface: ServiceInterface, prop: _Property, err: Exception | None
 *                 ) -> None:
*/
      __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1195, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_n_u_ServiceInterface) < (0)) __PYX_ERR(0, 1195, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_prop, __pyx_mstate_global->__pyx_n_u_Property) < (0)) __PYX_ERR(0, 1195, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 1195, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 1195, __pyx_L1_error)
      __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_3set_property_callback, 0, __pyx_mstate_global->__pyx_n_u_default_properties_handler_loca_2, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[8])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1195, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_set_property_callback = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "dbus_fast/message_bus.py":1203
 *                     send_reply(Message.new_method_return(msg))
 * 
 *                 body = replace_idx_with_fds(             # <<<<<<<<<<<<<<
 *                     value.signature, [value.value], msg.unix_fds
 *                 )
*/
      __pyx_t_6 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_replace_idx_with_fds); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);

      /* "dbus_fast/message_bus.py":1204
 * 
 *                 body = replace_idx_with_fds(
 *                     value.signature, [value.value], msg.unix_fds             # <<<<<<<<<<<<<<
 *                 )
 *                 ServiceInterface._set_property_value(
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_signature); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_mstate_global->__pyx_n_u_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_t_1) != (0)) __PYX_ERR(0, 1204, __pyx_L1_error);
      __pyx_t_1 = 0;
      __pyx_t_11 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_10);
        assert(__pyx_t_6);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);
        __pyx_t_11 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_6, __pyx_t_4, __pyx_t_8, __pyx_cur_scope->__pyx_v_msg->unix_fds};
        __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_11, (4-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1203, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __pyx_v_body = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "dbus_fast/message_bus.py":1206
 *                     value.signature, [value.value], msg.unix_fds
 *                 )
 *                 ServiceInterface._set_property_value(             # <<<<<<<<<<<<<<
 *                     interface, prop, body[0], set_property_callback
 *                 )
*/
      __pyx_t_10 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface);
      __Pyx_INCREF(__pyx_t_10);

      /* "dbus_fast/message_bus.py":1207
 *                 )
 *                 ServiceInterface._set_property_value(
 *                     interface, prop, body[0], set_property_callback             # <<<<<<<<<<<<<<
 *                 )
 * 
*/
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_body, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_11 = 0;
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_10, __pyx_v_interface, __pyx_v_prop, __pyx_t_8, __pyx_v_set_property_callback};
        __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_set_property_value, __pyx_callargs+__pyx_t_11, (5-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1206, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "dbus_fast/message_bus.py":1182
 *                 )
 * 
 *             elif msg.member == "Set":             # <<<<<<<<<<<<<<
 *                 if not prop.access.writable():
 *                     raise DBusError(
*/
    }
    __pyx_L32:;

    /* "dbus_fast/message_bus.py":1131
 *         properties = ServiceInterface._get_properties(interface)
 * 
 *         if msg.member == "Get" or msg.member == "Set":             # <<<<<<<<<<<<<<
 *             prop_name = msg.body[1]
 *             match = [
*/
    goto __pyx_L18;
  }

  /* "dbus_fast/message_bus.py":1210
 *                 )
 * 
 *         elif msg.member == "GetAll":             # <<<<<<<<<<<<<<
 * 
 *             def get_all_properties_callback(
*/
  __pyx_t_15 = (__Pyx_PyUnicode_Equals(__pyx_cur_scope->__pyx_v_msg->member, __pyx_mstate_global->__pyx_n_u_GetAll, Py_EQ)); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 1210, __pyx_L1_error)
  if (__pyx_t_15) {

    /* "dbus_fast/message_bus.py":1212
 *         elif msg.member == "GetAll":
 * 
 *             def get_all_properties_callback(             # <<<<<<<<<<<<<<
 *                 interface: ServiceInterface,
 *                 values: Any,
*/
    __pyx_t_7 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_n_u_ServiceInterface) < (0)) __PYX_ERR(0, 1212, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_values, __pyx_mstate_global->__pyx_n_u_Any) < (0)) __PYX_ERR(0, 1212, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_user_data, __pyx_mstate_global->__pyx_n_u_Any) < (0)) __PYX_ERR(0, 1212, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 1212, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 1212, __pyx_L1_error)
    __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_27_default_properties_handler_5get_all_properties_callback, 0, __pyx_mstate_global->__pyx_n_u_default_properties_handler_loca_3, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[9])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_get_all_properties_callback = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "dbus_fast/message_bus.py":1226
 *                 )
 * 
 *             ServiceInterface._get_all_property_values(             # <<<<<<<<<<<<<<
 *                 interface, get_all_properties_callback
 *             )
*/
    __pyx_t_7 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7service_ServiceInterface);
    __Pyx_INCREF(__pyx_t_7);

    /* "dbus_fast/message_bus.py":1227
 * 
 *             ServiceInterface._get_all_property_values(
 *                 interface, get_all_properties_callback             # <<<<<<<<<<<<<<
 *             )
 * 
*/
    __pyx_t_11 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_interface, __pyx_v_get_all_properties_callback};
      __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_all_property_values, __pyx_callargs+__pyx_t_11, (3-__pyx_t_11) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1226, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "dbus_fast/message_bus.py":1210
 *                 )
 * 
 *         elif msg.member == "GetAll":             # <<<<<<<<<<<<<<
 * 
 *             def get_all_properties_callback(
*/
    goto __pyx_L18;
  }

  /* "dbus_fast/message_bus.py":1231
 * 
 *         else:
 *             assert False             # <<<<<<<<<<<<<<
 * 
 *     def _init_high_level_client(self) -> None:
*/
  /*else*/ {
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      if (unlikely(!0)) {
        __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_AssertionError))), 0, 0, 0);
        __PYX_ERR(0, 1231, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 1231, __pyx_L1_error)
    #endif
  }
  __pyx_L18:;

  /* "dbus_fast/message_bus.py":1086
 *                 )
 * 
 *     def _default_properties_handler(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         methods = {"Get": "ss", "Set": "ssv", "GetAll": "s"}
 *         if msg.member not in methods or methods[msg.member] != msg.signature:
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._default_properties_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_methods);
  __Pyx_XDECREF(__pyx_v_interface_name);
  __Pyx_XDECREF(__pyx_v_prop_name);
  __Pyx_XDECREF(__pyx_v_properties);
  __Pyx_XDECREF(__pyx_v_match);
  __Pyx_XDECREF(__pyx_v_prop);
  __Pyx_XDECREF(__pyx_v_get_property_callback);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_set_property_callback);
  __Pyx_XDECREF(__pyx_v_body);
  __Pyx_XDECREF(__pyx_v_get_all_properties_callback);
  __Pyx_XDECREF(__pyx_v_interface);
  __Pyx_XDECREF(__pyx_8genexpr3__pyx_v_prop);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1233
 *             assert False
 * 
 *     def _init_high_level_client(self) -> None:             # <<<<<<<<<<<<<<
 *         """The high level client is initialized when the first proxy object is
 *         gotten. Currently just sets up the match rules for the name owner cache
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_61_init_high_level_client(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_60_init_high_level_client, "The high level client is initialized when the first proxy object is\n        gotten. Currently just sets up the match rules for the name owner cache\n        so signals can be routed to the right objects.");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_61_init_high_level_client = {"_init_high_level_client", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_61_init_high_level_client, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_60_init_high_level_client};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_61_init_high_level_client(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_init_high_level_client (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("_init_high_level_client", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("_init_high_level_client", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_60_init_high_level_client(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1241
 *         self._high_level_client_initialized = True
 * 
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             if err:
 *                 _LOGGER.error(
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23_init_high_level_client_1add_match_notify(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_23_init_high_level_client_1add_match_notify = {"add_match_notify", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23_init_high_level_client_1add_match_notify, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23_init_high_level_client_1add_match_notify(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  PyObject *__pyx_v_err = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_match_notify (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_err,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1241, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1241, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1241, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "add_match_notify", 0) < (0)) __PYX_ERR(0, 1241, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("add_match_notify", 1, 2, 2, i); __PYX_ERR(0, 1241, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1241, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1241, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_err = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("add_match_notify", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1241, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._init_high_level_client.add_match_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 1, "msg", 0))) __PYX_ERR(0, 1241, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 1241, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_23_init_high_level_client_add_match_notify(__pyx_self, __pyx_v_msg, __pyx_v_err);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_23_init_high_level_client_add_match_notify(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_err) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7[4];
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add_match_notify", 0);
  __pyx_outer_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "dbus_fast/message_bus.py":1242
 * 
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:
 *             if err:             # <<<<<<<<<<<<<<
 *                 _LOGGER.error(
 *                     f'add match request failed. match="{self._name_owner_match_rule}", {err}'
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_err); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1242, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1243
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:
 *             if err:
 *                 _LOGGER.error(             # <<<<<<<<<<<<<<
 *                     f'add match request failed. match="{self._name_owner_match_rule}", {err}'
 *                 )
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_LOGGER); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_error); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "dbus_fast/message_bus.py":1244
 *             if err:
 *                 _LOGGER.error(
 *                     f'add match request failed. match="{self._name_owner_match_rule}", {err}'             # <<<<<<<<<<<<<<
 *                 )
 *             elif msg is not None and msg.message_type == MessageType.ERROR:
*/
    if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 1244, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_cur_scope->__pyx_v_self->_name_owner_match_rule, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_v_err, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7[0] = __pyx_mstate_global->__pyx_kp_u_add_match_request_failed_match;
    __pyx_t_7[1] = __pyx_t_4;
    __pyx_t_7[2] = __pyx_mstate_global->__pyx_kp_u__11;
    __pyx_t_7[3] = __pyx_t_6;
    __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_7, 4, 33 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6));
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_9 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1243, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":1242
 * 
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:
 *             if err:             # <<<<<<<<<<<<<<
 *                 _LOGGER.error(
 *                     f'add match request failed. match="{self._name_owner_match_rule}", {err}'
*/
    goto __pyx_L3;
  }

  /* "dbus_fast/message_bus.py":1246
 *                     f'add match request failed. match="{self._name_owner_match_rule}", {err}'
 *                 )
 *             elif msg is not None and msg.message_type == MessageType.ERROR:             # <<<<<<<<<<<<<<
 *                 _LOGGER.error(
 *                     f'add match request failed. match="{self._name_owner_match_rule}", {msg.body[0]}'
*/
  __pyx_t_10 = (((PyObject *)__pyx_v_msg) != Py_None);
  if (__pyx_t_10) {
  } else {
    __pyx_t_1 = __pyx_t_10;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_9dbus_fast_11message_bus_MessageType, __pyx_mstate_global->__pyx_n_u_ERROR); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_msg->message_type, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 1246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_1 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1247
 *                 )
 *             elif msg is not None and msg.message_type == MessageType.ERROR:
 *                 _LOGGER.error(             # <<<<<<<<<<<<<<
 *                     f'add match request failed. match="{self._name_owner_match_rule}", {msg.body[0]}'
 *                 )
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_LOGGER); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_error); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "dbus_fast/message_bus.py":1248
 *             elif msg is not None and msg.message_type == MessageType.ERROR:
 *                 _LOGGER.error(
 *                     f'add match request failed. match="{self._name_owner_match_rule}", {msg.body[0]}'             # <<<<<<<<<<<<<<
 *                 )
 * 
*/
    if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 1248, __pyx_L1_error) }
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_cur_scope->__pyx_v_self->_name_owner_match_rule, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_msg->body, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7[0] = __pyx_mstate_global->__pyx_kp_u_add_match_request_failed_match;
    __pyx_t_7[1] = __pyx_t_8;
    __pyx_t_7[2] = __pyx_mstate_global->__pyx_kp_u__11;
    __pyx_t_7[3] = __pyx_t_4;
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_7, 4, 33 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_9 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
      __pyx_t_9 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "dbus_fast/message_bus.py":1246
 *                     f'add match request failed. match="{self._name_owner_match_rule}", {err}'
 *                 )
 *             elif msg is not None and msg.message_type == MessageType.ERROR:             # <<<<<<<<<<<<<<
 *                 _LOGGER.error(
 *                     f'add match request failed. match="{self._name_owner_match_rule}", {msg.body[0]}'
*/
  }
  __pyx_L3:;

  /* "dbus_fast/message_bus.py":1241
 *         self._high_level_client_initialized = True
 * 
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             if err:
 *                 _LOGGER.error(
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._init_high_level_client.add_match_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1233
 *             assert False
 * 
 *     def _init_high_level_client(self) -> None:             # <<<<<<<<<<<<<<
 *         """The high level client is initialized when the first proxy object is
 *         gotten. Currently just sets up the match rules for the name owner cache
*/

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_60_init_high_level_client(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *__pyx_cur_scope;
  PyObject *__pyx_v_add_match_notify = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_init_high_level_client", 0);
  __pyx_cur_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1233, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);

  /* "dbus_fast/message_bus.py":1237
 *         gotten. Currently just sets up the match rules for the name owner cache
 *         so signals can be routed to the right objects."""
 *         if self._high_level_client_initialized:             # <<<<<<<<<<<<<<
 *             return
 *         self._high_level_client_initialized = True
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_self->_high_level_client_initialized); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1237, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1238
 *         so signals can be routed to the right objects."""
 *         if self._high_level_client_initialized:
 *             return             # <<<<<<<<<<<<<<
 *         self._high_level_client_initialized = True
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":1237
 *         gotten. Currently just sets up the match rules for the name owner cache
 *         so signals can be routed to the right objects."""
 *         if self._high_level_client_initialized:             # <<<<<<<<<<<<<<
 *             return
 *         self._high_level_client_initialized = True
*/
  }

  /* "dbus_fast/message_bus.py":1239
 *         if self._high_level_client_initialized:
 *             return
 *         self._high_level_client_initialized = True             # <<<<<<<<<<<<<<
 * 
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:
*/
  __Pyx_INCREF(Py_True);
  __Pyx_GIVEREF(Py_True);
  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_self->_high_level_client_initialized);
  __Pyx_DECREF(__pyx_cur_scope->__pyx_v_self->_high_level_client_initialized);
  __pyx_cur_scope->__pyx_v_self->_high_level_client_initialized = Py_True;

  /* "dbus_fast/message_bus.py":1241
 *         self._high_level_client_initialized = True
 * 
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             if err:
 *                 _LOGGER.error(
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_kp_u_Message_None) < (0)) __PYX_ERR(0, 1241, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 1241, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 1241, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_23_init_high_level_client_1add_match_notify, 0, __pyx_mstate_global->__pyx_n_u_init_high_level_client_locals_a, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[10])); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_add_match_notify = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "dbus_fast/message_bus.py":1252
 * 
 *         self._call(
 *             Message(             # <<<<<<<<<<<<<<
 *                 destination="org.freedesktop.DBus",
 *                 interface="org.freedesktop.DBus",
*/
  __pyx_t_2 = NULL;

  /* "dbus_fast/message_bus.py":1258
 *                 member="AddMatch",
 *                 signature="s",
 *                 body=[self._name_owner_match_rule],             # <<<<<<<<<<<<<<
 *             ),
 *             add_match_notify,
*/
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self->_name_owner_match_rule);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self->_name_owner_match_rule);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_cur_scope->__pyx_v_self->_name_owner_match_rule) != (0)) __PYX_ERR(0, 1258, __pyx_L1_error);
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 6 : 0)] = {__pyx_t_2, NULL};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1252, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_destination, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus, __pyx_t_6, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 1252, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus, __pyx_t_6, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 1252, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_path, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_2, __pyx_t_6, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 1252, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_member, __pyx_mstate_global->__pyx_n_u_AddMatch, __pyx_t_6, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 1252, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_signature, __pyx_mstate_global->__pyx_n_u_s, __pyx_t_6, __pyx_callargs+1, 4) < (0)) __PYX_ERR(0, 1252, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_t_4, __pyx_t_6, __pyx_callargs+1, 5) < (0)) __PYX_ERR(0, 1252, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1252, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_3);
  }

  /* "dbus_fast/message_bus.py":1251
 *                 )
 * 
 *         self._call(             # <<<<<<<<<<<<<<
 *             Message(
 *                 destination="org.freedesktop.DBus",
*/
  __pyx_t_6 = ((struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_call(__pyx_cur_scope->__pyx_v_self, ((struct __pyx_obj_9dbus_fast_7message_Message *)__pyx_t_3), __pyx_v_add_match_notify, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF((PyObject *)__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "dbus_fast/message_bus.py":1233
 *             assert False
 * 
 *     def _init_high_level_client(self) -> None:             # <<<<<<<<<<<<<<
 *         """The high level client is initialized when the first proxy object is
 *         gotten. Currently just sets up the match rules for the name owner cache
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._init_high_level_client", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_add_match_notify);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1263
 *         )
 * 
 *     def _add_match_rule(self, match_rule: str) -> None:             # <<<<<<<<<<<<<<
 *         """Add a match rule. Match rules added by this function are refcounted
 *         and must be removed by _remove_match_rule(). This is for use in the
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_63_add_match_rule(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_62_add_match_rule, "Add a match rule. Match rules added by this function are refcounted\n        and must be removed by _remove_match_rule(). This is for use in the\n        high level client only.");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_63_add_match_rule = {"_add_match_rule", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_63_add_match_rule, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_62_add_match_rule};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_63_add_match_rule(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_match_rule = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_add_match_rule (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_match_rule,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1263, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1263, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_add_match_rule", 0) < (0)) __PYX_ERR(0, 1263, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_add_match_rule", 1, 1, 1, i); __PYX_ERR(0, 1263, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1263, __pyx_L3_error)
    }
    __pyx_v_match_rule = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_add_match_rule", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1263, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._add_match_rule", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_match_rule), (&PyUnicode_Type), 0, "match_rule", 2))) __PYX_ERR(0, 1263, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_62_add_match_rule(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_match_rule);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1276
 *         self._match_rules[match_rule] = 1
 * 
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             if err:
 *                 _LOGGER.error(f'add match request failed. match="{match_rule}", {err}')
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_15_add_match_rule_1add_match_notify(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_15_add_match_rule_1add_match_notify = {"add_match_notify", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_15_add_match_rule_1add_match_notify, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_15_add_match_rule_1add_match_notify(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  PyObject *__pyx_v_err = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_match_notify (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_err,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1276, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1276, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1276, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "add_match_notify", 0) < (0)) __PYX_ERR(0, 1276, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("add_match_notify", 1, 2, 2, i); __PYX_ERR(0, 1276, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1276, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1276, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_err = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("add_match_notify", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1276, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._add_match_rule.add_match_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 1, "msg", 0))) __PYX_ERR(0, 1276, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 1276, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_15_add_match_rule_add_match_notify(__pyx_self, __pyx_v_msg, __pyx_v_err);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_15_add_match_rule_add_match_notify(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_err) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7[4];
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add_match_notify", 0);
  __pyx_outer_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "dbus_fast/message_bus.py":1277
 * 
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:
 *             if err:             # <<<<<<<<<<<<<<
 *                 _LOGGER.error(f'add match request failed. match="{match_rule}", {err}')
 *             elif msg is not None and msg.message_type == MessageType.ERROR:
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_err); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1277, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1278
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:
 *             if err:
 *                 _LOGGER.error(f'add match request failed. match="{match_rule}", {err}')             # <<<<<<<<<<<<<<
 *             elif msg is not None and msg.message_type == MessageType.ERROR:
 *                 _LOGGER.error(
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_LOGGER); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_error); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_v_match_rule)) { __Pyx_RaiseClosureNameError("match_rule"); __PYX_ERR(0, 1278, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyUnicode_Unicode(__pyx_cur_scope->__pyx_v_match_rule); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_v_err, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7[0] = __pyx_mstate_global->__pyx_kp_u_add_match_request_failed_match;
    __pyx_t_7[1] = __pyx_t_4;
    __pyx_t_7[2] = __pyx_mstate_global->__pyx_kp_u__11;
    __pyx_t_7[3] = __pyx_t_6;
    __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_7, 4, 33 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6));
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_9 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":1277
 * 
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:
 *             if err:             # <<<<<<<<<<<<<<
 *                 _LOGGER.error(f'add match request failed. match="{match_rule}", {err}')
 *             elif msg is not None and msg.message_type == MessageType.ERROR:
*/
    goto __pyx_L3;
  }

  /* "dbus_fast/message_bus.py":1279
 *             if err:
 *                 _LOGGER.error(f'add match request failed. match="{match_rule}", {err}')
 *             elif msg is not None and msg.message_type == MessageType.ERROR:             # <<<<<<<<<<<<<<
 *                 _LOGGER.error(
 *                     f'add match request failed. match="{match_rule}", {msg.body[0]}'
*/
  __pyx_t_10 = (((PyObject *)__pyx_v_msg) != Py_None);
  if (__pyx_t_10) {
  } else {
    __pyx_t_1 = __pyx_t_10;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_9dbus_fast_11message_bus_MessageType, __pyx_mstate_global->__pyx_n_u_ERROR); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_msg->message_type, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 1279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_1 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1280
 *                 _LOGGER.error(f'add match request failed. match="{match_rule}", {err}')
 *             elif msg is not None and msg.message_type == MessageType.ERROR:
 *                 _LOGGER.error(             # <<<<<<<<<<<<<<
 *                     f'add match request failed. match="{match_rule}", {msg.body[0]}'
 *                 )
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_LOGGER); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_error); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "dbus_fast/message_bus.py":1281
 *             elif msg is not None and msg.message_type == MessageType.ERROR:
 *                 _LOGGER.error(
 *                     f'add match request failed. match="{match_rule}", {msg.body[0]}'             # <<<<<<<<<<<<<<
 *                 )
 * 
*/
    if (unlikely(!__pyx_cur_scope->__pyx_v_match_rule)) { __Pyx_RaiseClosureNameError("match_rule"); __PYX_ERR(0, 1281, __pyx_L1_error) }
    __pyx_t_8 = __Pyx_PyUnicode_Unicode(__pyx_cur_scope->__pyx_v_match_rule); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_msg->body, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7[0] = __pyx_mstate_global->__pyx_kp_u_add_match_request_failed_match;
    __pyx_t_7[1] = __pyx_t_8;
    __pyx_t_7[2] = __pyx_mstate_global->__pyx_kp_u__11;
    __pyx_t_7[3] = __pyx_t_4;
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_7, 4, 33 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_9 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
      __pyx_t_9 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1280, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "dbus_fast/message_bus.py":1279
 *             if err:
 *                 _LOGGER.error(f'add match request failed. match="{match_rule}", {err}')
 *             elif msg is not None and msg.message_type == MessageType.ERROR:             # <<<<<<<<<<<<<<
 *                 _LOGGER.error(
 *                     f'add match request failed. match="{match_rule}", {msg.body[0]}'
*/
  }
  __pyx_L3:;

  /* "dbus_fast/message_bus.py":1276
 *         self._match_rules[match_rule] = 1
 * 
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             if err:
 *                 _LOGGER.error(f'add match request failed. match="{match_rule}", {err}')
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._add_match_rule.add_match_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1263
 *         )
 * 
 *     def _add_match_rule(self, match_rule: str) -> None:             # <<<<<<<<<<<<<<
 *         """Add a match rule. Match rules added by this function are refcounted
 *         and must be removed by _remove_match_rule(). This is for use in the
*/

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_62_add_match_rule(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_match_rule) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule *__pyx_cur_scope;
  PyObject *__pyx_v_add_match_notify = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_add_match_rule", 0);
  __pyx_cur_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1263, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_match_rule = __pyx_v_match_rule;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_match_rule);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_match_rule);

  /* "dbus_fast/message_bus.py":1267
 *         and must be removed by _remove_match_rule(). This is for use in the
 *         high level client only."""
 *         if match_rule == self._name_owner_match_rule:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_cur_scope->__pyx_v_match_rule, __pyx_v_self->_name_owner_match_rule, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1267, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1268
 *         high level client only."""
 *         if match_rule == self._name_owner_match_rule:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if match_rule in self._match_rules:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":1267
 *         and must be removed by _remove_match_rule(). This is for use in the
 *         high level client only."""
 *         if match_rule == self._name_owner_match_rule:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  }

  /* "dbus_fast/message_bus.py":1270
 *             return
 * 
 *         if match_rule in self._match_rules:             # <<<<<<<<<<<<<<
 *             self._match_rules[match_rule] += 1
 *             return
*/
  if (unlikely(__pyx_v_self->_match_rules == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1270, __pyx_L1_error)
  }
  __pyx_t_1 = (__Pyx_PyDict_ContainsTF(__pyx_cur_scope->__pyx_v_match_rule, __pyx_v_self->_match_rules, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1270, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1271
 * 
 *         if match_rule in self._match_rules:
 *             self._match_rules[match_rule] += 1             # <<<<<<<<<<<<<<
 *             return
 * 
*/
    if (unlikely(__pyx_v_self->_match_rules == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1271, __pyx_L1_error)
    }
    __Pyx_INCREF(__pyx_v_self->_match_rules);
    __pyx_t_2 = __pyx_v_self->_match_rules;
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_match_rule);
    __pyx_t_3 = __pyx_cur_scope->__pyx_v_match_rule;
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1271, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyLong_AddObjC(__pyx_t_4, __pyx_mstate_global->__pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1271, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1271, __pyx_L1_error)
    }
    if (unlikely((PyDict_SetItem(__pyx_t_2, __pyx_t_3, __pyx_t_5) < 0))) __PYX_ERR(0, 1271, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":1272
 *         if match_rule in self._match_rules:
 *             self._match_rules[match_rule] += 1
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._match_rules[match_rule] = 1
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":1270
 *             return
 * 
 *         if match_rule in self._match_rules:             # <<<<<<<<<<<<<<
 *             self._match_rules[match_rule] += 1
 *             return
*/
  }

  /* "dbus_fast/message_bus.py":1274
 *             return
 * 
 *         self._match_rules[match_rule] = 1             # <<<<<<<<<<<<<<
 * 
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:
*/
  if (unlikely(__pyx_v_self->_match_rules == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1274, __pyx_L1_error)
  }
  if (unlikely((PyDict_SetItem(__pyx_v_self->_match_rules, __pyx_cur_scope->__pyx_v_match_rule, __pyx_mstate_global->__pyx_int_1) < 0))) __PYX_ERR(0, 1274, __pyx_L1_error)

  /* "dbus_fast/message_bus.py":1276
 *         self._match_rules[match_rule] = 1
 * 
 *         def add_match_notify(msg: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             if err:
 *                 _LOGGER.error(f'add match request failed. match="{match_rule}", {err}')
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_kp_u_Message_None) < (0)) __PYX_ERR(0, 1276, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 1276, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 1276, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_15_add_match_rule_1add_match_notify, 0, __pyx_mstate_global->__pyx_n_u_add_match_rule_locals_add_match, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[11])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_add_match_notify = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "dbus_fast/message_bus.py":1285
 * 
 *         self._call(
 *             Message(             # <<<<<<<<<<<<<<
 *                 destination="org.freedesktop.DBus",
 *                 interface="org.freedesktop.DBus",
*/
  __pyx_t_5 = NULL;

  /* "dbus_fast/message_bus.py":1291
 *                 member="AddMatch",
 *                 signature="s",
 *                 body=[match_rule],             # <<<<<<<<<<<<<<
 *             ),
 *             add_match_notify,
*/
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_match_rule);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_match_rule);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_cur_scope->__pyx_v_match_rule) != (0)) __PYX_ERR(0, 1291, __pyx_L1_error);
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 6 : 0)] = {__pyx_t_5, NULL};
    __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1285, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_destination, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus, __pyx_t_8, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 1285, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus, __pyx_t_8, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 1285, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_path, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_2, __pyx_t_8, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 1285, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_member, __pyx_mstate_global->__pyx_n_u_AddMatch, __pyx_t_8, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 1285, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_signature, __pyx_mstate_global->__pyx_n_u_s, __pyx_t_8, __pyx_callargs+1, 4) < (0)) __PYX_ERR(0, 1285, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_t_6, __pyx_t_8, __pyx_callargs+1, 5) < (0)) __PYX_ERR(0, 1285, __pyx_L1_error)
    __pyx_t_4 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1285, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_4);
  }

  /* "dbus_fast/message_bus.py":1284
 *                 )
 * 
 *         self._call(             # <<<<<<<<<<<<<<
 *             Message(
 *                 destination="org.freedesktop.DBus",
*/
  __pyx_t_8 = ((struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self->__pyx_vtab)->_call(__pyx_v_self, ((struct __pyx_obj_9dbus_fast_7message_Message *)__pyx_t_4), __pyx_v_add_match_notify, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF((PyObject *)__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":1263
 *         )
 * 
 *     def _add_match_rule(self, match_rule: str) -> None:             # <<<<<<<<<<<<<<
 *         """Add a match rule. Match rules added by this function are refcounted
 *         and must be removed by _remove_match_rule(). This is for use in the
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._add_match_rule", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_add_match_notify);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1296
 *         )
 * 
 *     def _remove_match_rule(self, match_rule: str) -> None:             # <<<<<<<<<<<<<<
 *         """Remove a match rule added with _add_match_rule(). This is for use in
 *         the high level client only."""
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_65_remove_match_rule(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_64_remove_match_rule, "Remove a match rule added with _add_match_rule(). This is for use in\n        the high level client only.");
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_65_remove_match_rule = {"_remove_match_rule", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_65_remove_match_rule, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_64_remove_match_rule};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_65_remove_match_rule(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_match_rule = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_remove_match_rule (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_match_rule,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1296, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1296, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_remove_match_rule", 0) < (0)) __PYX_ERR(0, 1296, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_remove_match_rule", 1, 1, 1, i); __PYX_ERR(0, 1296, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1296, __pyx_L3_error)
    }
    __pyx_v_match_rule = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_remove_match_rule", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1296, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._remove_match_rule", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_match_rule), (&PyUnicode_Type), 0, "match_rule", 2))) __PYX_ERR(0, 1296, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_64_remove_match_rule(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v_match_rule);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1309
 *         del self._match_rules[match_rule]
 * 
 *         def remove_match_notify(msg: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             if self._disconnected:
 *                 return
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_18_remove_match_rule_1remove_match_notify(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_18_remove_match_rule_1remove_match_notify = {"remove_match_notify", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_18_remove_match_rule_1remove_match_notify, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_18_remove_match_rule_1remove_match_notify(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg = 0;
  PyObject *__pyx_v_err = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("remove_match_notify (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_msg,&__pyx_mstate_global->__pyx_n_u_err,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1309, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1309, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1309, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "remove_match_notify", 0) < (0)) __PYX_ERR(0, 1309, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("remove_match_notify", 1, 2, 2, i); __PYX_ERR(0, 1309, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1309, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1309, __pyx_L3_error)
    }
    __pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)values[0]);
    __pyx_v_err = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("remove_match_notify", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1309, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._remove_match_rule.remove_match_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_msg), __pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, 1, "msg", 0))) __PYX_ERR(0, 1309, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_err), (((PyTypeObject*)PyExc_Exception)), 1, "err", 0))) __PYX_ERR(0, 1309, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_18_remove_match_rule_remove_match_notify(__pyx_self, __pyx_v_msg, __pyx_v_err);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_18_remove_match_rule_remove_match_notify(PyObject *__pyx_self, struct __pyx_obj_9dbus_fast_7message_Message *__pyx_v_msg, PyObject *__pyx_v_err) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *__pyx_cur_scope;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7[4];
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("remove_match_notify", 0);
  __pyx_outer_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "dbus_fast/message_bus.py":1310
 * 
 *         def remove_match_notify(msg: Message | None, err: Exception | None) -> None:
 *             if self._disconnected:             # <<<<<<<<<<<<<<
 *                 return
 * 
*/
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 1310, __pyx_L1_error) }
  if (__pyx_cur_scope->__pyx_v_self->_disconnected) {

    /* "dbus_fast/message_bus.py":1311
 *         def remove_match_notify(msg: Message | None, err: Exception | None) -> None:
 *             if self._disconnected:
 *                 return             # <<<<<<<<<<<<<<
 * 
 *             if err:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":1310
 * 
 *         def remove_match_notify(msg: Message | None, err: Exception | None) -> None:
 *             if self._disconnected:             # <<<<<<<<<<<<<<
 *                 return
 * 
*/
  }

  /* "dbus_fast/message_bus.py":1313
 *                 return
 * 
 *             if err:             # <<<<<<<<<<<<<<
 *                 _LOGGER.error(
 *                     f'remove match request failed. match="{match_rule}", {err}'
*/
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_err); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1313, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1314
 * 
 *             if err:
 *                 _LOGGER.error(             # <<<<<<<<<<<<<<
 *                     f'remove match request failed. match="{match_rule}", {err}'
 *                 )
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_LOGGER); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_error); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "dbus_fast/message_bus.py":1315
 *             if err:
 *                 _LOGGER.error(
 *                     f'remove match request failed. match="{match_rule}", {err}'             # <<<<<<<<<<<<<<
 *                 )
 *             elif msg is not None and msg.message_type == MessageType.ERROR:
*/
    if (unlikely(!__pyx_cur_scope->__pyx_v_match_rule)) { __Pyx_RaiseClosureNameError("match_rule"); __PYX_ERR(0, 1315, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyUnicode_Unicode(__pyx_cur_scope->__pyx_v_match_rule); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_v_err, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7[0] = __pyx_mstate_global->__pyx_kp_u_remove_match_request_failed_matc;
    __pyx_t_7[1] = __pyx_t_4;
    __pyx_t_7[2] = __pyx_mstate_global->__pyx_kp_u__11;
    __pyx_t_7[3] = __pyx_t_6;
    __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_7, 4, 36 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6));
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_9 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1314, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":1313
 *                 return
 * 
 *             if err:             # <<<<<<<<<<<<<<
 *                 _LOGGER.error(
 *                     f'remove match request failed. match="{match_rule}", {err}'
*/
    goto __pyx_L4;
  }

  /* "dbus_fast/message_bus.py":1317
 *                     f'remove match request failed. match="{match_rule}", {err}'
 *                 )
 *             elif msg is not None and msg.message_type == MessageType.ERROR:             # <<<<<<<<<<<<<<
 *                 _LOGGER.error(
 *                     f'remove match request failed. match="{match_rule}", {msg.body[0]}'
*/
  __pyx_t_10 = (((PyObject *)__pyx_v_msg) != Py_None);
  if (__pyx_t_10) {
  } else {
    __pyx_t_1 = __pyx_t_10;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_9dbus_fast_11message_bus_MessageType, __pyx_mstate_global->__pyx_n_u_ERROR); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_msg->message_type, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1317, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 1317, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_1 = __pyx_t_10;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1318
 *                 )
 *             elif msg is not None and msg.message_type == MessageType.ERROR:
 *                 _LOGGER.error(             # <<<<<<<<<<<<<<
 *                     f'remove match request failed. match="{match_rule}", {msg.body[0]}'
 *                 )
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_LOGGER); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_error); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "dbus_fast/message_bus.py":1319
 *             elif msg is not None and msg.message_type == MessageType.ERROR:
 *                 _LOGGER.error(
 *                     f'remove match request failed. match="{match_rule}", {msg.body[0]}'             # <<<<<<<<<<<<<<
 *                 )
 * 
*/
    if (unlikely(!__pyx_cur_scope->__pyx_v_match_rule)) { __Pyx_RaiseClosureNameError("match_rule"); __PYX_ERR(0, 1319, __pyx_L1_error) }
    __pyx_t_8 = __Pyx_PyUnicode_Unicode(__pyx_cur_scope->__pyx_v_match_rule); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_msg->body, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_SharedReference); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7[0] = __pyx_mstate_global->__pyx_kp_u_remove_match_request_failed_matc;
    __pyx_t_7[1] = __pyx_t_8;
    __pyx_t_7[2] = __pyx_mstate_global->__pyx_kp_u__11;
    __pyx_t_7[3] = __pyx_t_4;
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_7, 4, 36 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_9 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
      __pyx_t_9 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "dbus_fast/message_bus.py":1317
 *                     f'remove match request failed. match="{match_rule}", {err}'
 *                 )
 *             elif msg is not None and msg.message_type == MessageType.ERROR:             # <<<<<<<<<<<<<<
 *                 _LOGGER.error(
 *                     f'remove match request failed. match="{match_rule}", {msg.body[0]}'
*/
  }
  __pyx_L4:;

  /* "dbus_fast/message_bus.py":1309
 *         del self._match_rules[match_rule]
 * 
 *         def remove_match_notify(msg: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             if self._disconnected:
 *                 return
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._remove_match_rule.remove_match_notify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.py":1296
 *         )
 * 
 *     def _remove_match_rule(self, match_rule: str) -> None:             # <<<<<<<<<<<<<<
 *         """Remove a match rule added with _add_match_rule(). This is for use in
 *         the high level client only."""
*/

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_64_remove_match_rule(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_match_rule) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *__pyx_cur_scope;
  PyObject *__pyx_v_remove_match_notify = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_remove_match_rule", 0);
  __pyx_cur_scope = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1296, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_match_rule = __pyx_v_match_rule;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_match_rule);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_match_rule);

  /* "dbus_fast/message_bus.py":1299
 *         """Remove a match rule added with _add_match_rule(). This is for use in
 *         the high level client only."""
 *         if match_rule == self._name_owner_match_rule:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_cur_scope->__pyx_v_match_rule, __pyx_cur_scope->__pyx_v_self->_name_owner_match_rule, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1299, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1300
 *         the high level client only."""
 *         if match_rule == self._name_owner_match_rule:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if match_rule in self._match_rules:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "dbus_fast/message_bus.py":1299
 *         """Remove a match rule added with _add_match_rule(). This is for use in
 *         the high level client only."""
 *         if match_rule == self._name_owner_match_rule:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  }

  /* "dbus_fast/message_bus.py":1302
 *             return
 * 
 *         if match_rule in self._match_rules:             # <<<<<<<<<<<<<<
 *             self._match_rules[match_rule] -= 1
 *             if self._match_rules[match_rule] > 0:
*/
  if (unlikely(__pyx_cur_scope->__pyx_v_self->_match_rules == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1302, __pyx_L1_error)
  }
  __pyx_t_1 = (__Pyx_PyDict_ContainsTF(__pyx_cur_scope->__pyx_v_match_rule, __pyx_cur_scope->__pyx_v_self->_match_rules, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1302, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "dbus_fast/message_bus.py":1303
 * 
 *         if match_rule in self._match_rules:
 *             self._match_rules[match_rule] -= 1             # <<<<<<<<<<<<<<
 *             if self._match_rules[match_rule] > 0:
 *                 return
*/
    if (unlikely(__pyx_cur_scope->__pyx_v_self->_match_rules == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1303, __pyx_L1_error)
    }
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self->_match_rules);
    __pyx_t_2 = __pyx_cur_scope->__pyx_v_self->_match_rules;
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_match_rule);
    __pyx_t_3 = __pyx_cur_scope->__pyx_v_match_rule;
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1303, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1303, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyLong_SubtractObjC(__pyx_t_4, __pyx_mstate_global->__pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1303, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1303, __pyx_L1_error)
    }
    if (unlikely((PyDict_SetItem(__pyx_t_2, __pyx_t_3, __pyx_t_5) < 0))) __PYX_ERR(0, 1303, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "dbus_fast/message_bus.py":1304
 *         if match_rule in self._match_rules:
 *             self._match_rules[match_rule] -= 1
 *             if self._match_rules[match_rule] > 0:             # <<<<<<<<<<<<<<
 *                 return
 * 
*/
    if (unlikely(__pyx_cur_scope->__pyx_v_self->_match_rules == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 1304, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_cur_scope->__pyx_v_self->_match_rules, __pyx_cur_scope->__pyx_v_match_rule); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, __pyx_mstate_global->__pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1304, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1304, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "dbus_fast/message_bus.py":1305
 *             self._match_rules[match_rule] -= 1
 *             if self._match_rules[match_rule] > 0:
 *                 return             # <<<<<<<<<<<<<<
 * 
 *         del self._match_rules[match_rule]
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "dbus_fast/message_bus.py":1304
 *         if match_rule in self._match_rules:
 *             self._match_rules[match_rule] -= 1
 *             if self._match_rules[match_rule] > 0:             # <<<<<<<<<<<<<<
 *                 return
 * 
*/
    }

    /* "dbus_fast/message_bus.py":1302
 *             return
 * 
 *         if match_rule in self._match_rules:             # <<<<<<<<<<<<<<
 *             self._match_rules[match_rule] -= 1
 *             if self._match_rules[match_rule] > 0:
*/
  }

  /* "dbus_fast/message_bus.py":1307
 *                 return
 * 
 *         del self._match_rules[match_rule]             # <<<<<<<<<<<<<<
 * 
 *         def remove_match_notify(msg: Message | None, err: Exception | None) -> None:
*/
  if (unlikely(__pyx_cur_scope->__pyx_v_self->_match_rules == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1307, __pyx_L1_error)
  }
  if (unlikely((PyDict_DelItem(__pyx_cur_scope->__pyx_v_self->_match_rules, __pyx_cur_scope->__pyx_v_match_rule) < 0))) __PYX_ERR(0, 1307, __pyx_L1_error)

  /* "dbus_fast/message_bus.py":1309
 *         del self._match_rules[match_rule]
 * 
 *         def remove_match_notify(msg: Message | None, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *             if self._disconnected:
 *                 return
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_kp_u_Message_None) < (0)) __PYX_ERR(0, 1309, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 1309, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_18_remove_match_rule_1remove_match_notify, 0, __pyx_mstate_global->__pyx_n_u_remove_match_rule_locals_remove, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[12])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_remove_match_notify = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "dbus_fast/message_bus.py":1323
 * 
 *         self._call(
 *             Message(             # <<<<<<<<<<<<<<
 *                 destination="org.freedesktop.DBus",
 *                 interface="org.freedesktop.DBus",
*/
  __pyx_t_4 = NULL;

  /* "dbus_fast/message_bus.py":1329
 *                 member="RemoveMatch",
 *                 signature="s",
 *                 body=[match_rule],             # <<<<<<<<<<<<<<
 *             ),
 *             remove_match_notify,
*/
  __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_match_rule);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_match_rule);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_cur_scope->__pyx_v_match_rule) != (0)) __PYX_ERR(0, 1329, __pyx_L1_error);
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 6 : 0)] = {__pyx_t_4, NULL};
    __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_destination, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus, __pyx_t_8, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 1323, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus, __pyx_t_8, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 1323, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_path, __pyx_mstate_global->__pyx_kp_u_org_freedesktop_DBus_2, __pyx_t_8, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 1323, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_member, __pyx_mstate_global->__pyx_n_u_RemoveMatch, __pyx_t_8, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 1323, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_signature, __pyx_mstate_global->__pyx_n_u_s, __pyx_t_8, __pyx_callargs+1, 4) < (0)) __PYX_ERR(0, 1323, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_body, __pyx_t_6, __pyx_t_8, __pyx_callargs+1, 5) < (0)) __PYX_ERR(0, 1323, __pyx_L1_error)
    __pyx_t_5 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1323, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_5);
  }

  /* "dbus_fast/message_bus.py":1322
 *                 )
 * 
 *         self._call(             # <<<<<<<<<<<<<<
 *             Message(
 *                 destination="org.freedesktop.DBus",
*/
  __pyx_t_8 = ((struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_call(__pyx_cur_scope->__pyx_v_self, ((struct __pyx_obj_9dbus_fast_7message_Message *)__pyx_t_5), __pyx_v_remove_match_notify, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF((PyObject *)__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":1296
 *         )
 * 
 *     def _remove_match_rule(self, match_rule: str) -> None:             # <<<<<<<<<<<<<<
 *         """Remove a match rule added with _add_match_rule(). This is for use in
 *         the high level client only."""
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._remove_match_rule", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_remove_match_notify);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":29
 * cdef class BaseMessageBus:
 * 
 *     cdef public object unique_name             # <<<<<<<<<<<<<<
 *     cdef public bint _disconnected
 *     cdef public object _user_disconnect
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->unique_name);
  __pyx_r = __pyx_v_self->unique_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->unique_name);
  __Pyx_DECREF(__pyx_v_self->unique_name);
  __pyx_v_self->unique_name = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->unique_name);
  __Pyx_DECREF(__pyx_v_self->unique_name);
  __pyx_v_self->unique_name = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":30
 * 
 *     cdef public object unique_name
 *     cdef public bint _disconnected             # <<<<<<<<<<<<<<
 *     cdef public object _user_disconnect
 *     cdef public cython.dict _method_return_handlers
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_disconnected_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_disconnected_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_disconnected___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_disconnected___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->_disconnected); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._disconnected.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_disconnected_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_disconnected_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_disconnected_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_disconnected_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 30, __pyx_L1_error)
  __pyx_v_self->_disconnected = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._disconnected.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":31
 *     cdef public object unique_name
 *     cdef public bint _disconnected
 *     cdef public object _user_disconnect             # <<<<<<<<<<<<<<
 *     cdef public cython.dict _method_return_handlers
 *     cdef public object _serial
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_user_disconnect);
  __pyx_r = __pyx_v_self->_user_disconnect;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->_user_disconnect);
  __Pyx_DECREF(__pyx_v_self->_user_disconnect);
  __pyx_v_self->_user_disconnect = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_user_disconnect);
  __Pyx_DECREF(__pyx_v_self->_user_disconnect);
  __pyx_v_self->_user_disconnect = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":32
 *     cdef public bint _disconnected
 *     cdef public object _user_disconnect
 *     cdef public cython.dict _method_return_handlers             # <<<<<<<<<<<<<<
 *     cdef public object _serial
 *     cdef public cython.dict _path_exports
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_method_return_handlers);
  __pyx_r = __pyx_v_self->_method_return_handlers;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(1, 32, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_method_return_handlers);
  __Pyx_DECREF(__pyx_v_self->_method_return_handlers);
  __pyx_v_self->_method_return_handlers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._method_return_handlers.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_method_return_handlers);
  __Pyx_DECREF(__pyx_v_self->_method_return_handlers);
  __pyx_v_self->_method_return_handlers = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":33
 *     cdef public object _user_disconnect
 *     cdef public cython.dict _method_return_handlers
 *     cdef public object _serial             # <<<<<<<<<<<<<<
 *     cdef public cython.dict _path_exports
 *     cdef public cython.list _user_message_handlers
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_serial___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_serial___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_serial);
  __pyx_r = __pyx_v_self->_serial;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->_serial);
  __Pyx_DECREF(__pyx_v_self->_serial);
  __pyx_v_self->_serial = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_serial);
  __Pyx_DECREF(__pyx_v_self->_serial);
  __pyx_v_self->_serial = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":34
 *     cdef public cython.dict _method_return_handlers
 *     cdef public object _serial
 *     cdef public cython.dict _path_exports             # <<<<<<<<<<<<<<
 *     cdef public cython.list _user_message_handlers
 *     cdef public cython.dict _name_owners
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_path_exports);
  __pyx_r = __pyx_v_self->_path_exports;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(1, 34, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_path_exports);
  __Pyx_DECREF(__pyx_v_self->_path_exports);
  __pyx_v_self->_path_exports = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._path_exports.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_path_exports);
  __Pyx_DECREF(__pyx_v_self->_path_exports);
  __pyx_v_self->_path_exports = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":35
 *     cdef public object _serial
 *     cdef public cython.dict _path_exports
 *     cdef public cython.list _user_message_handlers             # <<<<<<<<<<<<<<
 *     cdef public cython.dict _name_owners
 *     cdef public object _bus_address
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_user_message_handlers);
  __pyx_r = __pyx_v_self->_user_message_handlers;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(1, 35, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_user_message_handlers);
  __Pyx_DECREF(__pyx_v_self->_user_message_handlers);
  __pyx_v_self->_user_message_handlers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._user_message_handlers.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_user_message_handlers);
  __Pyx_DECREF(__pyx_v_self->_user_message_handlers);
  __pyx_v_self->_user_message_handlers = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":36
 *     cdef public cython.dict _path_exports
 *     cdef public cython.list _user_message_handlers
 *     cdef public cython.dict _name_owners             # <<<<<<<<<<<<<<
 *     cdef public object _bus_address
 *     cdef public object _name_owner_match_rule
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_name_owners);
  __pyx_r = __pyx_v_self->_name_owners;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(1, 36, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_name_owners);
  __Pyx_DECREF(__pyx_v_self->_name_owners);
  __pyx_v_self->_name_owners = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._name_owners.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_name_owners);
  __Pyx_DECREF(__pyx_v_self->_name_owners);
  __pyx_v_self->_name_owners = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":37
 *     cdef public cython.list _user_message_handlers
 *     cdef public cython.dict _name_owners
 *     cdef public object _bus_address             # <<<<<<<<<<<<<<
 *     cdef public object _name_owner_match_rule
 *     cdef public cython.dict _match_rules
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_bus_address);
  __pyx_r = __pyx_v_self->_bus_address;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->_bus_address);
  __Pyx_DECREF(__pyx_v_self->_bus_address);
  __pyx_v_self->_bus_address = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_bus_address);
  __Pyx_DECREF(__pyx_v_self->_bus_address);
  __pyx_v_self->_bus_address = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":38
 *     cdef public cython.dict _name_owners
 *     cdef public object _bus_address
 *     cdef public object _name_owner_match_rule             # <<<<<<<<<<<<<<
 *     cdef public cython.dict _match_rules
 *     cdef public object _high_level_client_initialized
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_name_owner_match_rule);
  __pyx_r = __pyx_v_self->_name_owner_match_rule;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->_name_owner_match_rule);
  __Pyx_DECREF(__pyx_v_self->_name_owner_match_rule);
  __pyx_v_self->_name_owner_match_rule = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_name_owner_match_rule);
  __Pyx_DECREF(__pyx_v_self->_name_owner_match_rule);
  __pyx_v_self->_name_owner_match_rule = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":39
 *     cdef public object _bus_address
 *     cdef public object _name_owner_match_rule
 *     cdef public cython.dict _match_rules             # <<<<<<<<<<<<<<
 *     cdef public object _high_level_client_initialized
 *     cdef public object _ProxyObject
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_match_rules);
  __pyx_r = __pyx_v_self->_match_rules;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(1, 39, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_match_rules);
  __Pyx_DECREF(__pyx_v_self->_match_rules);
  __pyx_v_self->_match_rules = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._match_rules.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_match_rules);
  __Pyx_DECREF(__pyx_v_self->_match_rules);
  __pyx_v_self->_match_rules = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":40
 *     cdef public object _name_owner_match_rule
 *     cdef public cython.dict _match_rules
 *     cdef public object _high_level_client_initialized             # <<<<<<<<<<<<<<
 *     cdef public object _ProxyObject
 *     cdef public object _machine_id
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_high_level_client_initialized);
  __pyx_r = __pyx_v_self->_high_level_client_initialized;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->_high_level_client_initialized);
  __Pyx_DECREF(__pyx_v_self->_high_level_client_initialized);
  __pyx_v_self->_high_level_client_initialized = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_high_level_client_initialized);
  __Pyx_DECREF(__pyx_v_self->_high_level_client_initialized);
  __pyx_v_self->_high_level_client_initialized = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":41
 *     cdef public cython.dict _match_rules
 *     cdef public object _high_level_client_initialized
 *     cdef public object _ProxyObject             # <<<<<<<<<<<<<<
 *     cdef public object _machine_id
 *     cdef public bint _negotiate_unix_fd
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_ProxyObject);
  __pyx_r = __pyx_v_self->_ProxyObject;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->_ProxyObject);
  __Pyx_DECREF(__pyx_v_self->_ProxyObject);
  __pyx_v_self->_ProxyObject = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_ProxyObject);
  __Pyx_DECREF(__pyx_v_self->_ProxyObject);
  __pyx_v_self->_ProxyObject = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":42
 *     cdef public object _high_level_client_initialized
 *     cdef public object _ProxyObject
 *     cdef public object _machine_id             # <<<<<<<<<<<<<<
 *     cdef public bint _negotiate_unix_fd
 *     cdef public object _sock
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_machine_id);
  __pyx_r = __pyx_v_self->_machine_id;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->_machine_id);
  __Pyx_DECREF(__pyx_v_self->_machine_id);
  __pyx_v_self->_machine_id = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_machine_id);
  __Pyx_DECREF(__pyx_v_self->_machine_id);
  __pyx_v_self->_machine_id = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":43
 *     cdef public object _ProxyObject
 *     cdef public object _machine_id
 *     cdef public bint _negotiate_unix_fd             # <<<<<<<<<<<<<<
 *     cdef public object _sock
 *     cdef public object _stream
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_18_negotiate_unix_fd_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_18_negotiate_unix_fd_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_18_negotiate_unix_fd___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_18_negotiate_unix_fd___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->_negotiate_unix_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._negotiate_unix_fd.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_18_negotiate_unix_fd_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_18_negotiate_unix_fd_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_18_negotiate_unix_fd_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_18_negotiate_unix_fd_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 43, __pyx_L1_error)
  __pyx_v_self->_negotiate_unix_fd = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus._negotiate_unix_fd.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":44
 *     cdef public object _machine_id
 *     cdef public bint _negotiate_unix_fd
 *     cdef public object _sock             # <<<<<<<<<<<<<<
 *     cdef public object _stream
 *     cdef public object _fd
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_5_sock___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_5_sock___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_sock);
  __pyx_r = __pyx_v_self->_sock;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->_sock);
  __Pyx_DECREF(__pyx_v_self->_sock);
  __pyx_v_self->_sock = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_sock);
  __Pyx_DECREF(__pyx_v_self->_sock);
  __pyx_v_self->_sock = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":45
 *     cdef public bint _negotiate_unix_fd
 *     cdef public object _sock
 *     cdef public object _stream             # <<<<<<<<<<<<<<
 *     cdef public object _fd
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_stream___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_stream___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_stream);
  __pyx_r = __pyx_v_self->_stream;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->_stream);
  __Pyx_DECREF(__pyx_v_self->_stream);
  __pyx_v_self->_stream = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_stream);
  __Pyx_DECREF(__pyx_v_self->_stream);
  __pyx_v_self->_stream = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "dbus_fast/message_bus.pxd":46
 *     cdef public object _sock
 *     cdef public object _stream
 *     cdef public object _fd             # <<<<<<<<<<<<<<
 * 
 *     cpdef void _process_message(self, Message msg) except *
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_3_fd___get__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_3_fd___get__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_fd);
  __pyx_r = __pyx_v_self->_fd;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_2__set__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_2__set__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->_fd);
  __Pyx_DECREF(__pyx_v_self->_fd);
  __pyx_v_self->_fd = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_4__del__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_4__del__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_fd);
  __Pyx_DECREF(__pyx_v_self->_fd);
  __pyx_v_self->_fd = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_67__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_67__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_67__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_67__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_66__reduce_cython__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_66__reduce_cython__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self._ProxyObject, self._bus_address, self._disconnected, self._fd, self._high_level_client_initialized, self._machine_id, self._match_rules, self._method_return_handlers, self._name_owner_match_rule, self._name_owners, self._negotiate_unix_fd, self._path_exports, self._serial, self._sock, self._stream, self._user_disconnect, self._user_message_handlers, self.unique_name)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->_disconnected); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_self->_negotiate_unix_fd); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(18); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_self->_ProxyObject);
  __Pyx_GIVEREF(__pyx_v_self->_ProxyObject);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_self->_ProxyObject) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_bus_address);
  __Pyx_GIVEREF(__pyx_v_self->_bus_address);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self->_bus_address) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_1) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_fd);
  __Pyx_GIVEREF(__pyx_v_self->_fd);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_v_self->_fd) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_high_level_client_initialized);
  __Pyx_GIVEREF(__pyx_v_self->_high_level_client_initialized);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_v_self->_high_level_client_initialized) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_machine_id);
  __Pyx_GIVEREF(__pyx_v_self->_machine_id);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 5, __pyx_v_self->_machine_id) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_match_rules);
  __Pyx_GIVEREF(__pyx_v_self->_match_rules);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 6, __pyx_v_self->_match_rules) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_method_return_handlers);
  __Pyx_GIVEREF(__pyx_v_self->_method_return_handlers);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 7, __pyx_v_self->_method_return_handlers) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_name_owner_match_rule);
  __Pyx_GIVEREF(__pyx_v_self->_name_owner_match_rule);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 8, __pyx_v_self->_name_owner_match_rule) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_name_owners);
  __Pyx_GIVEREF(__pyx_v_self->_name_owners);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 9, __pyx_v_self->_name_owners) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 10, __pyx_t_2) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_path_exports);
  __Pyx_GIVEREF(__pyx_v_self->_path_exports);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 11, __pyx_v_self->_path_exports) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_serial);
  __Pyx_GIVEREF(__pyx_v_self->_serial);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 12, __pyx_v_self->_serial) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_sock);
  __Pyx_GIVEREF(__pyx_v_self->_sock);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 13, __pyx_v_self->_sock) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_stream);
  __Pyx_GIVEREF(__pyx_v_self->_stream);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 14, __pyx_v_self->_stream) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_user_disconnect);
  __Pyx_GIVEREF(__pyx_v_self->_user_disconnect);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 15, __pyx_v_self->_user_disconnect) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->_user_message_handlers);
  __Pyx_GIVEREF(__pyx_v_self->_user_message_handlers);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 16, __pyx_v_self->_user_message_handlers) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->unique_name);
  __Pyx_GIVEREF(__pyx_v_self->unique_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 17, __pyx_v_self->unique_name) != (0)) __PYX_ERR(2, 5, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self._ProxyObject, self._bus_address, self._disconnected, self._fd, self._high_level_client_initialized, self._machine_id, self._match_rules, self._method_return_handlers, self._name_owner_match_rule, self._name_owners, self._negotiate_unix_fd, self._path_exports, self._serial, self._sock, self._stream, self._user_disconnect, self._user_message_handlers, self.unique_name)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/
  __pyx_t_3 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v__dict = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":7
 *     state = (self._ProxyObject, self._bus_address, self._disconnected, self._fd, self._high_level_client_initialized, self._machine_id, self._match_rules, self._method_return_handlers, self._name_owner_match_rule, self._name_owners, self._negotiate_unix_fd, self._path_exports, self._serial, self._sock, self._stream, self._user_disconnect, self._user_message_handlers, self.unique_name)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
  __pyx_t_5 = (__pyx_v__dict != Py_None);
  if (__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(2, 7, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_4) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v__dict) != (0)) __PYX_ERR(2, 8, __pyx_L1_error);
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self._ProxyObject is not None or self._bus_address is not None or self._fd is not None or self._high_level_client_initialized is not None or self._machine_id is not None or self._match_rules is not None or self._method_return_handlers is not None or self._name_owner_match_rule is not None or self._name_owners is not None or self._path_exports is not None or self._serial is not None or self._sock is not None or self._stream is not None or self._user_disconnect is not None or self._user_message_handlers is not None or self.unique_name is not None
*/
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self._ProxyObject, self._bus_address, self._disconnected, self._fd, self._high_level_client_initialized, self._machine_id, self._match_rules, self._method_return_handlers, self._name_owner_match_rule, self._name_owners, self._negotiate_unix_fd, self._path_exports, self._serial, self._sock, self._stream, self._user_disconnect, self._user_message_handlers, self.unique_name)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self._ProxyObject is not None or self._bus_address is not None or self._fd is not None or self._high_level_client_initialized is not None or self._machine_id is not None or self._match_rules is not None or self._method_return_handlers is not None or self._name_owner_match_rule is not None or self._name_owners is not None or self._path_exports is not None or self._serial is not None or self._sock is not None or self._stream is not None or self._user_disconnect is not None or self._user_message_handlers is not None or self.unique_name is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_BaseMessageBus, (type(self), 0x9d0a048, None), state
*/
  /*else*/ {
    __pyx_t_5 = (__pyx_v_self->_ProxyObject != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_bus_address != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_fd != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_high_level_client_initialized != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_machine_id != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_match_rules != ((PyObject*)Py_None));
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_method_return_handlers != ((PyObject*)Py_None));
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_name_owner_match_rule != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_name_owners != ((PyObject*)Py_None));
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_path_exports != ((PyObject*)Py_None));
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_serial != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_sock != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_stream != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_user_disconnect != Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_user_message_handlers != ((PyObject*)Py_None));
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->unique_name != Py_None);
    __pyx_t_4 = __pyx_t_5;
    __pyx_L6_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_4;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self._ProxyObject is not None or self._bus_address is not None or self._fd is not None or self._high_level_client_initialized is not None or self._machine_id is not None or self._match_rules is not None or self._method_return_handlers is not None or self._name_owner_match_rule is not None or self._name_owners is not None or self._path_exports is not None or self._serial is not None or self._sock is not None or self._stream is not None or self._user_disconnect is not None or self._user_message_handlers is not None or self.unique_name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_BaseMessageBus, (type(self), 0x9d0a048, None), state
 *     else:
*/
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self._ProxyObject is not None or self._bus_address is not None or self._fd is not None or self._high_level_client_initialized is not None or self._machine_id is not None or self._match_rules is not None or self._method_return_handlers is not None or self._name_owner_match_rule is not None or self._name_owners is not None or self._path_exports is not None or self._serial is not None or self._sock is not None or self._stream is not None or self._user_disconnect is not None or self._user_message_handlers is not None or self.unique_name is not None
 *     if use_setstate:
 *         return __pyx_unpickle_BaseMessageBus, (type(self), 0x9d0a048, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_BaseMessageBus, (type(self), 0x9d0a048, state)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_BaseMessageBus); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_164667464);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_164667464);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_mstate_global->__pyx_int_164667464) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, Py_None) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 13, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self._ProxyObject is not None or self._bus_address is not None or self._fd is not None or self._high_level_client_initialized is not None or self._machine_id is not None or self._match_rules is not None or self._method_return_handlers is not None or self._name_owner_match_rule is not None or self._name_owners is not None or self._path_exports is not None or self._serial is not None or self._sock is not None or self._stream is not None or self._user_disconnect is not None or self._user_message_handlers is not None or self.unique_name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_BaseMessageBus, (type(self), 0x9d0a048, None), state
 *     else:
*/
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_BaseMessageBus, (type(self), 0x9d0a048, None), state
 *     else:
 *         return __pyx_unpickle_BaseMessageBus, (type(self), 0x9d0a048, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_BaseMessageBus__set_state(self, __pyx_state)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_BaseMessageBus); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_164667464);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_164667464);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_mstate_global->__pyx_int_164667464) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_state) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3) != (0)) __PYX_ERR(2, 15, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_BaseMessageBus, (type(self), 0x9d0a048, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_BaseMessageBus__set_state(self, __pyx_state)
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_69__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_69__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_69__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_69__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(2, 16, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 16, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(2, 16, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(2, 16, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 16, __pyx_L3_error)
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 16, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_68__setstate_cython__(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_14BaseMessageBus_68__setstate_cython__(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_BaseMessageBus, (type(self), 0x9d0a048, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_BaseMessageBus__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_v___pyx_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(2, 17, __pyx_L1_error)
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(2, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_9dbus_fast_11message_bus___pyx_unpickle_BaseMessageBus__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_BaseMessageBus, (type(self), 0x9d0a048, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_BaseMessageBus__set_state(self, __pyx_state)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("dbus_fast.message_bus.BaseMessageBus.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_BaseMessageBus(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9d0a048, 0xe46e5e6, 0xe795340, b'_ProxyObject, _bus_address, _disconnected, _fd, _high_level_client_initialized, _machine_id, _match_rules, _method_return_handlers, _name_owner_match_rule, _name_owners, _negotiate_unix_fd, _path_exports, _serial, _sock, _stream, _user_disconnect, _user_message_handlers, unique_name')
*/

/* Python wrapper */
static PyObject *__pyx_pw_9dbus_fast_11message_bus_3__pyx_unpickle_BaseMessageBus(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9dbus_fast_11message_bus_3__pyx_unpickle_BaseMessageBus = {"__pyx_unpickle_BaseMessageBus", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_3__pyx_unpickle_BaseMessageBus, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9dbus_fast_11message_bus_3__pyx_unpickle_BaseMessageBus(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_BaseMessageBus (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(2, 4, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_BaseMessageBus", 0) < (0)) __PYX_ERR(2, 4, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_BaseMessageBus", 1, 3, 3, i); __PYX_ERR(2, 4, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 4, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(2, 4, __pyx_L3_error)
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(2, 4, __pyx_L3_error)
    __pyx_v___pyx_state = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_BaseMessageBus", 1, 3, 3, __pyx_nargs); __PYX_ERR(2, 4, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("dbus_fast.message_bus.__pyx_unpickle_BaseMessageBus", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(2, 4, __pyx_L1_error)
  __pyx_r = __pyx_pf_9dbus_fast_11message_bus_2__pyx_unpickle_BaseMessageBus(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9dbus_fast_11message_bus_2__pyx_unpickle_BaseMessageBus(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_BaseMessageBus", 0);

  /* "(tree fragment)":6
 * def __pyx_unpickle_BaseMessageBus(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9d0a048, 0xe46e5e6, 0xe795340, b'_ProxyObject, _bus_address, _disconnected, _fd, _high_level_client_initialized, _machine_id, _match_rules, _method_return_handlers, _name_owner_match_rule, _name_owners, _negotiate_unix_fd, _path_exports, _serial, _sock, _stream, _user_disconnect, _user_message_handlers, unique_name')             # <<<<<<<<<<<<<<
 *     __pyx_result = BaseMessageBus.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/
  __pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0x9d0a048, 0xe46e5e6, 0xe795340, __pyx_k_ProxyObject__bus_address__disco); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 6, __pyx_L1_error)

  /* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9d0a048, 0xe46e5e6, 0xe795340, b'_ProxyObject, _bus_address, _disconnected, _fd, _high_level_client_initialized, _machine_id, _match_rules, _method_return_handlers, _name_owner_match_rule, _name_owners, _negotiate_unix_fd, _path_exports, _serial, _sock, _stream, _user_disconnect, _user_message_handlers, unique_name')
 *     __pyx_result = BaseMessageBus.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_BaseMessageBus__set_state(<BaseMessageBus> __pyx_result, __pyx_state)
*/
  __pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v___pyx_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9d0a048, 0xe46e5e6, 0xe795340, b'_ProxyObject, _bus_address, _disconnected, _fd, _high_level_client_initialized, _machine_id, _match_rules, _method_return_handlers, _name_owner_match_rule, _name_owners, _negotiate_unix_fd, _path_exports, _serial, _sock, _stream, _user_disconnect, _user_message_handlers, unique_name')
 *     __pyx_result = BaseMessageBus.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_BaseMessageBus__set_state(<BaseMessageBus> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  __pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));
  if (__pyx_t_5) {

    /* "(tree fragment)":9
 *     __pyx_result = BaseMessageBus.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_BaseMessageBus__set_state(<BaseMessageBus> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_BaseMessageBus__set_state(BaseMessageBus __pyx_result, __pyx_state: tuple):
*/
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
      __PYX_ERR(2, 9, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_f_9dbus_fast_11message_bus___pyx_unpickle_BaseMessageBus__set_state(((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9d0a048, 0xe46e5e6, 0xe795340, b'_ProxyObject, _bus_address, _disconnected, _fd, _high_level_client_initialized, _machine_id, _match_rules, _method_return_handlers, _name_owner_match_rule, _name_owners, _negotiate_unix_fd, _path_exports, _serial, _sock, _stream, _user_disconnect, _user_message_handlers, unique_name')
 *     __pyx_result = BaseMessageBus.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_BaseMessageBus__set_state(<BaseMessageBus> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_BaseMessageBus__set_state(<BaseMessageBus> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_BaseMessageBus__set_state(BaseMessageBus __pyx_result, __pyx_state: tuple):
 *     __pyx_result._ProxyObject = __pyx_state[0]; __pyx_result._bus_address = __pyx_state[1]; __pyx_result._disconnected = __pyx_state[2]; __pyx_result._fd = __pyx_state[3]; __pyx_result._high_level_client_initialized = __pyx_state[4]; __pyx_result._machine_id = __pyx_state[5]; __pyx_result._match_rules = __pyx_state[6]; __pyx_result._method_return_handlers = __pyx_state[7]; __pyx_result._name_owner_match_rule = __pyx_state[8]; __pyx_result._name_owners = __pyx_state[9]; __pyx_result._negotiate_unix_fd = __pyx_state[10]; __pyx_result._path_exports = __pyx_state[11]; __pyx_result._serial = __pyx_state[12]; __pyx_result._sock = __pyx_state[13]; __pyx_result._stream = __pyx_state[14]; __pyx_result._user_disconnect = __pyx_state[15]; __pyx_result._user_message_handlers = __pyx_state[16]; __pyx_result.unique_name = __pyx_state[17]
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_BaseMessageBus(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9d0a048, 0xe46e5e6, 0xe795340, b'_ProxyObject, _bus_address, _disconnected, _fd, _high_level_client_initialized, _machine_id, _match_rules, _method_return_handlers, _name_owner_match_rule, _name_owners, _negotiate_unix_fd, _path_exports, _serial, _sock, _stream, _user_disconnect, _user_message_handlers, unique_name')
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("dbus_fast.message_bus.__pyx_unpickle_BaseMessageBus", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_BaseMessageBus__set_state(<BaseMessageBus> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_BaseMessageBus__set_state(BaseMessageBus __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result._ProxyObject = __pyx_state[0]; __pyx_result._bus_address = __pyx_state[1]; __pyx_result._disconnected = __pyx_state[2]; __pyx_result._fd = __pyx_state[3]; __pyx_result._high_level_client_initialized = __pyx_state[4]; __pyx_result._machine_id = __pyx_state[5]; __pyx_result._match_rules = __pyx_state[6]; __pyx_result._method_return_handlers = __pyx_state[7]; __pyx_result._name_owner_match_rule = __pyx_state[8]; __pyx_result._name_owners = __pyx_state[9]; __pyx_result._negotiate_unix_fd = __pyx_state[10]; __pyx_result._path_exports = __pyx_state[11]; __pyx_result._serial = __pyx_state[12]; __pyx_result._sock = __pyx_state[13]; __pyx_result._stream = __pyx_state[14]; __pyx_result._user_disconnect = __pyx_state[15]; __pyx_result._user_message_handlers = __pyx_state[16]; __pyx_result.unique_name = __pyx_state[17]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 18)
*/

static PyObject *__pyx_f_9dbus_fast_11message_bus___pyx_unpickle_BaseMessageBus__set_state(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_BaseMessageBus__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_BaseMessageBus__set_state(BaseMessageBus __pyx_result, __pyx_state: tuple):
 *     __pyx_result._ProxyObject = __pyx_state[0]; __pyx_result._bus_address = __pyx_state[1]; __pyx_result._disconnected = __pyx_state[2]; __pyx_result._fd = __pyx_state[3]; __pyx_result._high_level_client_initialized = __pyx_state[4]; __pyx_result._machine_id = __pyx_state[5]; __pyx_result._match_rules = __pyx_state[6]; __pyx_result._method_return_handlers = __pyx_state[7]; __pyx_result._name_owner_match_rule = __pyx_state[8]; __pyx_result._name_owners = __pyx_state[9]; __pyx_result._negotiate_unix_fd = __pyx_state[10]; __pyx_result._path_exports = __pyx_state[11]; __pyx_result._serial = __pyx_state[12]; __pyx_result._sock = __pyx_state[13]; __pyx_result._stream = __pyx_state[14]; __pyx_result._user_disconnect = __pyx_state[15]; __pyx_result._user_message_handlers = __pyx_state[16]; __pyx_result.unique_name = __pyx_state[17]             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 18)
*/
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_ProxyObject);
  __Pyx_DECREF(__pyx_v___pyx_result->_ProxyObject);
  __pyx_v___pyx_result->_ProxyObject = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_bus_address);
  __Pyx_DECREF(__pyx_v___pyx_result->_bus_address);
  __pyx_v___pyx_result->_bus_address = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->_disconnected = __pyx_t_2;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_fd);
  __Pyx_DECREF(__pyx_v___pyx_result->_fd);
  __pyx_v___pyx_result->_fd = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_high_level_client_initialized);
  __Pyx_DECREF(__pyx_v___pyx_result->_high_level_client_initialized);
  __pyx_v___pyx_result->_high_level_client_initialized = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_machine_id);
  __Pyx_DECREF(__pyx_v___pyx_result->_machine_id);
  __pyx_v___pyx_result->_machine_id = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_match_rules);
  __Pyx_DECREF(__pyx_v___pyx_result->_match_rules);
  __pyx_v___pyx_result->_match_rules = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 7, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_method_return_handlers);
  __Pyx_DECREF(__pyx_v___pyx_result->_method_return_handlers);
  __pyx_v___pyx_result->_method_return_handlers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 8, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_name_owner_match_rule);
  __Pyx_DECREF(__pyx_v___pyx_result->_name_owner_match_rule);
  __pyx_v___pyx_result->_name_owner_match_rule = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 9, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_name_owners);
  __Pyx_DECREF(__pyx_v___pyx_result->_name_owners);
  __pyx_v___pyx_result->_name_owners = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 10, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->_negotiate_unix_fd = __pyx_t_2;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 11, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_path_exports);
  __Pyx_DECREF(__pyx_v___pyx_result->_path_exports);
  __pyx_v___pyx_result->_path_exports = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 12, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_serial);
  __Pyx_DECREF(__pyx_v___pyx_result->_serial);
  __pyx_v___pyx_result->_serial = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 13, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_sock);
  __Pyx_DECREF(__pyx_v___pyx_result->_sock);
  __pyx_v___pyx_result->_sock = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 14, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_stream);
  __Pyx_DECREF(__pyx_v___pyx_result->_stream);
  __pyx_v___pyx_result->_stream = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 15, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_user_disconnect);
  __Pyx_DECREF(__pyx_v___pyx_result->_user_disconnect);
  __pyx_v___pyx_result->_user_disconnect = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 16, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_user_message_handlers);
  __Pyx_DECREF(__pyx_v___pyx_result->_user_message_handlers);
  __pyx_v___pyx_result->_user_message_handlers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 17, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->unique_name);
  __Pyx_DECREF(__pyx_v___pyx_result->unique_name);
  __pyx_v___pyx_result->unique_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_BaseMessageBus__set_state(BaseMessageBus __pyx_result, __pyx_state: tuple):
 *     __pyx_result._ProxyObject = __pyx_state[0]; __pyx_result._bus_address = __pyx_state[1]; __pyx_result._disconnected = __pyx_state[2]; __pyx_result._fd = __pyx_state[3]; __pyx_result._high_level_client_initialized = __pyx_state[4]; __pyx_result._machine_id = __pyx_state[5]; __pyx_result._match_rules = __pyx_state[6]; __pyx_result._method_return_handlers = __pyx_state[7]; __pyx_result._name_owner_match_rule = __pyx_state[8]; __pyx_result._name_owners = __pyx_state[9]; __pyx_result._negotiate_unix_fd = __pyx_state[10]; __pyx_result._path_exports = __pyx_state[11]; __pyx_result._serial = __pyx_state[12]; __pyx_result._sock = __pyx_state[13]; __pyx_result._stream = __pyx_state[14]; __pyx_result._user_disconnect = __pyx_state[15]; __pyx_result._user_message_handlers = __pyx_state[16]; __pyx_result.unique_name = __pyx_state[17]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 18)             # <<<<<<<<<<<<<<
*/
  __pyx_t_3 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 18); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(2, 13, __pyx_L1_error)

  /* "(tree fragment)":11
 *         __pyx_unpickle_BaseMessageBus__set_state(<BaseMessageBus> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_BaseMessageBus__set_state(BaseMessageBus __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result._ProxyObject = __pyx_state[0]; __pyx_result._bus_address = __pyx_state[1]; __pyx_result._disconnected = __pyx_state[2]; __pyx_result._fd = __pyx_state[3]; __pyx_result._high_level_client_initialized = __pyx_state[4]; __pyx_result._machine_id = __pyx_state[5]; __pyx_result._match_rules = __pyx_state[6]; __pyx_result._method_return_handlers = __pyx_state[7]; __pyx_result._name_owner_match_rule = __pyx_state[8]; __pyx_result._name_owners = __pyx_state[9]; __pyx_result._negotiate_unix_fd = __pyx_state[10]; __pyx_result._path_exports = __pyx_state[11]; __pyx_result._serial = __pyx_state[12]; __pyx_result._sock = __pyx_state[13]; __pyx_result._stream = __pyx_state[14]; __pyx_result._user_disconnect = __pyx_state[15]; __pyx_result._user_message_handlers = __pyx_state[16]; __pyx_result.unique_name = __pyx_state[17]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 18)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("dbus_fast.message_bus.__pyx_unpickle_BaseMessageBus__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
/* #### Code section: module_exttypes ### */
static struct __pyx_vtabstruct_9dbus_fast_11message_bus_BaseMessageBus __pyx_vtable_9dbus_fast_11message_bus_BaseMessageBus;

static PyObject *__pyx_tp_new_9dbus_fast_11message_bus_BaseMessageBus(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)o);
  p->__pyx_vtab = __pyx_vtabptr_9dbus_fast_11message_bus_BaseMessageBus;
  p->unique_name = Py_None; Py_INCREF(Py_None);
  p->_user_disconnect = Py_None; Py_INCREF(Py_None);
  p->_method_return_handlers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_serial = Py_None; Py_INCREF(Py_None);
  p->_path_exports = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_user_message_handlers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_name_owners = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_bus_address = Py_None; Py_INCREF(Py_None);
  p->_name_owner_match_rule = Py_None; Py_INCREF(Py_None);
  p->_match_rules = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_high_level_client_initialized = Py_None; Py_INCREF(Py_None);
  p->_ProxyObject = Py_None; Py_INCREF(Py_None);
  p->_machine_id = Py_None; Py_INCREF(Py_None);
  p->_sock = Py_None; Py_INCREF(Py_None);
  p->_stream = Py_None; Py_INCREF(Py_None);
  p->_fd = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_9dbus_fast_11message_bus_BaseMessageBus(PyObject *o) {
  struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *p = (struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9dbus_fast_11message_bus_BaseMessageBus) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->unique_name);
  Py_CLEAR(p->_user_disconnect);
  Py_CLEAR(p->_method_return_handlers);
  Py_CLEAR(p->_serial);
  Py_CLEAR(p->_path_exports);
  Py_CLEAR(p->_user_message_handlers);
  Py_CLEAR(p->_name_owners);
  Py_CLEAR(p->_bus_address);
  Py_CLEAR(p->_name_owner_match_rule);
  Py_CLEAR(p->_match_rules);
  Py_CLEAR(p->_high_level_client_initialized);
  Py_CLEAR(p->_ProxyObject);
  Py_CLEAR(p->_machine_id);
  Py_CLEAR(p->_sock);
  Py_CLEAR(p->_stream);
  Py_CLEAR(p->_fd);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_9dbus_fast_11message_bus_BaseMessageBus(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *p = (struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->unique_name) {
    e = (*v)(p->unique_name, a); if (e) return e;
  }
  if (p->_user_disconnect) {
    e = (*v)(p->_user_disconnect, a); if (e) return e;
  }
  if (p->_method_return_handlers) {
    e = (*v)(p->_method_return_handlers, a); if (e) return e;
  }
  if (p->_serial) {
    e = (*v)(p->_serial, a); if (e) return e;
  }
  if (p->_path_exports) {
    e = (*v)(p->_path_exports, a); if (e) return e;
  }
  if (p->_user_message_handlers) {
    e = (*v)(p->_user_message_handlers, a); if (e) return e;
  }
  if (p->_name_owners) {
    e = (*v)(p->_name_owners, a); if (e) return e;
  }
  if (p->_bus_address) {
    e = (*v)(p->_bus_address, a); if (e) return e;
  }
  if (p->_name_owner_match_rule) {
    e = (*v)(p->_name_owner_match_rule, a); if (e) return e;
  }
  if (p->_match_rules) {
    e = (*v)(p->_match_rules, a); if (e) return e;
  }
  if (p->_high_level_client_initialized) {
    e = (*v)(p->_high_level_client_initialized, a); if (e) return e;
  }
  if (p->_ProxyObject) {
    e = (*v)(p->_ProxyObject, a); if (e) return e;
  }
  if (p->_machine_id) {
    e = (*v)(p->_machine_id, a); if (e) return e;
  }
  if (p->_sock) {
    e = (*v)(p->_sock, a); if (e) return e;
  }
  if (p->_stream) {
    e = (*v)(p->_stream, a); if (e) return e;
  }
  if (p->_fd) {
    e = (*v)(p->_fd, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9dbus_fast_11message_bus_BaseMessageBus(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *p = (struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)o;
  tmp = ((PyObject*)p->unique_name);
  p->unique_name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_user_disconnect);
  p->_user_disconnect = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_method_return_handlers);
  p->_method_return_handlers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_serial);
  p->_serial = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_path_exports);
  p->_path_exports = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_user_message_handlers);
  p->_user_message_handlers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_name_owners);
  p->_name_owners = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_bus_address);
  p->_bus_address = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_name_owner_match_rule);
  p->_name_owner_match_rule = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_match_rules);
  p->_match_rules = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_high_level_client_initialized);
  p->_high_level_client_initialized = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_ProxyObject);
  p->_ProxyObject = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_machine_id);
  p->_machine_id = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_sock);
  p->_sock = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_stream);
  p->_stream = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_fd);
  p->_fd = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus_connected(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_9connected_1__get__(o);
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus_unique_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus_unique_name(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11unique_name_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__disconnected(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_disconnected_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__disconnected(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_disconnected_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__user_disconnect(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__user_disconnect(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_16_user_disconnect_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__method_return_handlers(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__method_return_handlers(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23_method_return_handlers_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__serial(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__serial(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_serial_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__path_exports(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__path_exports(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13_path_exports_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__user_message_handlers(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__user_message_handlers(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_user_message_handlers_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__name_owners(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__name_owners(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_name_owners_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__bus_address(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__bus_address(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_bus_address_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__name_owner_match_rule(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__name_owner_match_rule(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_22_name_owner_match_rule_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__match_rules(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__match_rules(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_match_rules_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__high_level_client_initialized(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__high_level_client_initialized(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_30_high_level_client_initialized_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__ProxyObject(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__ProxyObject(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_12_ProxyObject_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__machine_id(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__machine_id(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11_machine_id_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__negotiate_unix_fd(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_18_negotiate_unix_fd_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__negotiate_unix_fd(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_18_negotiate_unix_fd_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__sock(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__sock(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_5_sock_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__stream(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__stream(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7_stream_5__del__(o);
  }
}

static PyObject *__pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__fd(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_1__get__(o);
}

static int __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__fd(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_3__set__(o, v);
  }
  else {
    return __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_3_fd_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_9dbus_fast_11message_bus_BaseMessageBus[] = {
  {"unexport", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_5unexport, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_4unexport},
  {"introspect", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_7introspect, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_6introspect},
  {"_emit_interface_added", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_9_emit_interface_added, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_8_emit_interface_added},
  {"_emit_interface_removed", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_11_emit_interface_removed, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_10_emit_interface_removed},
  {"request_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_13request_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_12request_name},
  {"release_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_15release_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_14release_name},
  {"get_proxy_object", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_17get_proxy_object, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_16get_proxy_object},
  {"disconnect", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_19disconnect, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_18disconnect},
  {"add_message_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_23add_message_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_22add_message_handler},
  {"remove_message_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_25remove_message_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_24remove_message_handler},
  {"send", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_27send, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_26send},
  {"_finalize", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_29_finalize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_28_finalize},
  {"_interface_signal_notify", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_31_interface_signal_notify, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_introspect_export_path", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_33_introspect_export_path, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_reply_notify", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_35_reply_notify, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_34_reply_notify},
  {"_check_callback_type", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_39_check_callback_type, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_38_check_callback_type},
  {"_check_method_return", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_41_check_method_return, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_make_method_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_47_make_method_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_default_introspect_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_49_default_introspect_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_default_ping_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_51_default_ping_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_send_machine_id_reply", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_53_send_machine_id_reply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_default_get_machine_id_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_55_default_get_machine_id_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_default_get_managed_objects_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_57_default_get_managed_objects_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_default_properties_handler", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_59_default_properties_handler, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_init_high_level_client", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_61_init_high_level_client, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_60_init_high_level_client},
  {"_add_match_rule", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_63_add_match_rule, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_62_add_match_rule},
  {"_remove_match_rule", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_65_remove_match_rule, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9dbus_fast_11message_bus_14BaseMessageBus_64_remove_match_rule},
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_67__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_69__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_9dbus_fast_11message_bus_BaseMessageBus[] = {
  {"connected", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus_connected, 0, 0, 0},
  {"unique_name", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus_unique_name, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus_unique_name, 0, 0},
  {"_disconnected", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__disconnected, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__disconnected, 0, 0},
  {"_user_disconnect", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__user_disconnect, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__user_disconnect, 0, 0},
  {"_method_return_handlers", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__method_return_handlers, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__method_return_handlers, 0, 0},
  {"_serial", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__serial, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__serial, 0, 0},
  {"_path_exports", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__path_exports, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__path_exports, 0, 0},
  {"_user_message_handlers", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__user_message_handlers, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__user_message_handlers, 0, 0},
  {"_name_owners", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__name_owners, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__name_owners, 0, 0},
  {"_bus_address", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__bus_address, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__bus_address, 0, 0},
  {"_name_owner_match_rule", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__name_owner_match_rule, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__name_owner_match_rule, 0, 0},
  {"_match_rules", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__match_rules, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__match_rules, 0, 0},
  {"_high_level_client_initialized", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__high_level_client_initialized, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__high_level_client_initialized, 0, 0},
  {"_ProxyObject", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__ProxyObject, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__ProxyObject, 0, 0},
  {"_machine_id", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__machine_id, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__machine_id, 0, 0},
  {"_negotiate_unix_fd", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__negotiate_unix_fd, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__negotiate_unix_fd, 0, 0},
  {"_sock", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__sock, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__sock, 0, 0},
  {"_stream", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__stream, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__stream, 0, 0},
  {"_fd", __pyx_getprop_9dbus_fast_11message_bus_14BaseMessageBus__fd, __pyx_setprop_9dbus_fast_11message_bus_14BaseMessageBus__fd, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9dbus_fast_11message_bus_BaseMessageBus_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9dbus_fast_11message_bus_BaseMessageBus},
  {Py_tp_doc, (void *)PyDoc_STR("An abstract class to manage a connection to a DBus message bus.\n\n    The message bus class is the entry point into all the features of the\n    library. It sets up a connection to the DBus daemon and exposes an\n    interface to send and receive messages and expose services.\n\n    This class is not meant to be used directly by users. For more information,\n    see the documentation for the implementation of the message bus you plan to\n    use.\n\n    :param bus_type: The type of bus to connect to. Affects the search path for\n        the bus address.\n    :type bus_type: :class:`BusType <dbus_fast.BusType>`\n    :param bus_address: A specific bus address to connect to. Should not be\n        used under normal circumstances.\n    :type bus_address: str\n    :param ProxyObject: The proxy object implementation for this message bus.\n        Must be passed in by an implementation that supports the high-level client.\n    :type ProxyObject: Type[:class:`BaseProxyObject\n        <dbus_fast.proxy_object.BaseProxyObject>`]\n\n    :ivar unique_name: The unique name of the message bus connection. It will\n        be :class:`None` until the message bus connects.\n    :vartype unique_name: str\n    :ivar connected: True if this message bus is expected to be able to send\n        and receive messages.\n    :vartype connected: bool\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9dbus_fast_11message_bus_BaseMessageBus},
  {Py_tp_clear, (void *)__pyx_tp_clear_9dbus_fast_11message_bus_BaseMessageBus},
  {Py_tp_methods, (void *)__pyx_methods_9dbus_fast_11message_bus_BaseMessageBus},
  {Py_tp_getset, (void *)__pyx_getsets_9dbus_fast_11message_bus_BaseMessageBus},
  {Py_tp_init, (void *)__pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_9dbus_fast_11message_bus_BaseMessageBus},
  {0, 0},
};
static PyType_Spec __pyx_type_9dbus_fast_11message_bus_BaseMessageBus_spec = {
  "dbus_fast.message_bus.BaseMessageBus",
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9dbus_fast_11message_bus_BaseMessageBus_slots,
};
#else

static PyTypeObject __pyx_type_9dbus_fast_11message_bus_BaseMessageBus = {
  PyVarObject_HEAD_INIT(0, 0)
  "dbus_fast.message_bus.""BaseMessageBus", /*tp_name*/
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9dbus_fast_11message_bus_BaseMessageBus, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("An abstract class to manage a connection to a DBus message bus.\n\n    The message bus class is the entry point into all the features of the\n    library. It sets up a connection to the DBus daemon and exposes an\n    interface to send and receive messages and expose services.\n\n    This class is not meant to be used directly by users. For more information,\n    see the documentation for the implementation of the message bus you plan to\n    use.\n\n    :param bus_type: The type of bus to connect to. Affects the search path for\n        the bus address.\n    :type bus_type: :class:`BusType <dbus_fast.BusType>`\n    :param bus_address: A specific bus address to connect to. Should not be\n        used under normal circumstances.\n    :type bus_address: str\n    :param ProxyObject: The proxy object implementation for this message bus.\n        Must be passed in by an implementation that supports the high-level client.\n    :type ProxyObject: Type[:class:`BaseProxyObject\n        <dbus_fast.proxy_object.BaseProxyObject>`]\n\n    :ivar unique_name: The unique name of the message bus connection. It will\n        be :class:`None` until the message bus connects.\n    :vartype unique_name: str\n    :ivar connected: True if this message bus is expected to be able to send\n        and receive messages.\n    :vartype connected: bool\n    "), /*tp_doc*/
  __pyx_tp_traverse_9dbus_fast_11message_bus_BaseMessageBus, /*tp_traverse*/
  __pyx_tp_clear_9dbus_fast_11message_bus_BaseMessageBus, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9dbus_fast_11message_bus_BaseMessageBus, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_9dbus_fast_11message_bus_BaseMessageBus, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_9dbus_fast_11message_bus_14BaseMessageBus_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9dbus_fast_11message_bus_BaseMessageBus, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct__introspect(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct__introspect > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct__introspect[--__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct__introspect];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct__introspect(PyObject *o) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct__introspect) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_callback);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct__introspect < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect))))
  {
    __pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct__introspect[__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct__introspect++] = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct__introspect(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_callback) {
    e = (*v)(p->__pyx_v_callback, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct__introspect(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect *)o;
  tmp = ((PyObject*)p->__pyx_v_callback);
  p->__pyx_v_callback = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct__introspect_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct__introspect},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct__introspect},
  {Py_tp_clear, (void *)__pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct__introspect},
  {Py_tp_new, (void *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct__introspect},
  {0, 0},
};
static PyType_Spec __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct__introspect_spec = {
  "dbus_fast.message_bus.__pyx_scope_struct__introspect",
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct__introspect_slots,
};
#else

static PyTypeObject __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct__introspect = {
  PyVarObject_HEAD_INIT(0, 0)
  "dbus_fast.message_bus.""__pyx_scope_struct__introspect", /*tp_name*/
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct__introspect), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct__introspect, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct__introspect, /*tp_traverse*/
  __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct__introspect, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct__introspect, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added[--__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added(PyObject *o) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_path);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added))))
  {
    __pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added[__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added++] = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added},
  {Py_tp_clear, (void *)__pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added},
  {Py_tp_new, (void *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added},
  {0, 0},
};
static PyType_Spec __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added_spec = {
  "dbus_fast.message_bus.__pyx_scope_struct_1__emit_interface_added",
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added_slots,
};
#else

static PyTypeObject __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added = {
  PyVarObject_HEAD_INIT(0, 0)
  "dbus_fast.message_bus.""__pyx_scope_struct_1__emit_interface_added", /*tp_name*/
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added, /*tp_traverse*/
  __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name[--__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name(PyObject *o) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_callback);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name))))
  {
    __pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name[__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name++] = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_callback) {
    e = (*v)(p->__pyx_v_callback, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name *)o;
  tmp = ((PyObject*)p->__pyx_v_callback);
  p->__pyx_v_callback = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name},
  {Py_tp_clear, (void *)__pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name},
  {Py_tp_new, (void *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name},
  {0, 0},
};
static PyType_Spec __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name_spec = {
  "dbus_fast.message_bus.__pyx_scope_struct_2_request_name",
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name_slots,
};
#else

static PyTypeObject __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name = {
  PyVarObject_HEAD_INIT(0, 0)
  "dbus_fast.message_bus.""__pyx_scope_struct_2_request_name", /*tp_name*/
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name, /*tp_traverse*/
  __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name[--__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name(PyObject *o) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_callback);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name))))
  {
    __pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name[__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name++] = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_callback) {
    e = (*v)(p->__pyx_v_callback, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name *)o;
  tmp = ((PyObject*)p->__pyx_v_callback);
  p->__pyx_v_callback = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name},
  {Py_tp_clear, (void *)__pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name},
  {Py_tp_new, (void *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name},
  {0, 0},
};
static PyType_Spec __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name_spec = {
  "dbus_fast.message_bus.__pyx_scope_struct_3_release_name",
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name_slots,
};
#else

static PyTypeObject __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name = {
  PyVarObject_HEAD_INIT(0, 0)
  "dbus_fast.message_bus.""__pyx_scope_struct_3_release_name", /*tp_name*/
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name, /*tp_traverse*/
  __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler[--__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler(PyObject *o) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_msg);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_send_reply);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler))))
  {
    __pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler[__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler++] = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_msg) {
    e = (*v)(((PyObject *)p->__pyx_v_msg), a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_send_reply) {
    e = (*v)(p->__pyx_v_send_reply, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler *)o;
  tmp = ((PyObject*)p->__pyx_v_msg);
  p->__pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_send_reply);
  p->__pyx_v_send_reply = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler},
  {Py_tp_clear, (void *)__pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler},
  {Py_tp_new, (void *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler},
  {0, 0},
};
static PyType_Spec __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler_spec = {
  "dbus_fast.message_bus.__pyx_scope_struct_4__default_get_machine_id_handler",
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler_slots,
};
#else

static PyTypeObject __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler = {
  PyVarObject_HEAD_INIT(0, 0)
  "dbus_fast.message_bus.""__pyx_scope_struct_4__default_get_machine_id_handler", /*tp_name*/
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler, /*tp_traverse*/
  __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler[--__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler(PyObject *o) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_is_result_complete);
  Py_CLEAR(p->__pyx_v_msg);
  Py_CLEAR(p->__pyx_v_result);
  Py_CLEAR(p->__pyx_v_result_signature);
  Py_CLEAR(p->__pyx_v_send_reply);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler))))
  {
    __pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler[__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler++] = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_is_result_complete) {
    e = (*v)(p->__pyx_v_is_result_complete, a); if (e) return e;
  }
  if (p->__pyx_v_msg) {
    e = (*v)(((PyObject *)p->__pyx_v_msg), a); if (e) return e;
  }
  if (p->__pyx_v_result) {
    e = (*v)(p->__pyx_v_result, a); if (e) return e;
  }
  if (p->__pyx_v_send_reply) {
    e = (*v)(p->__pyx_v_send_reply, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler *)o;
  tmp = ((PyObject*)p->__pyx_v_is_result_complete);
  p->__pyx_v_is_result_complete = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_msg);
  p->__pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_result);
  p->__pyx_v_result = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_send_reply);
  p->__pyx_v_send_reply = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler},
  {Py_tp_clear, (void *)__pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler},
  {Py_tp_new, (void *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler},
  {0, 0},
};
static PyType_Spec __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler_spec = {
  "dbus_fast.message_bus.__pyx_scope_struct_5__default_get_managed_objects_handler",
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler_slots,
};
#else

static PyTypeObject __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler = {
  PyVarObject_HEAD_INIT(0, 0)
  "dbus_fast.message_bus.""__pyx_scope_struct_5__default_get_managed_objects_handler", /*tp_name*/
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler, /*tp_traverse*/
  __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler[--__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler(PyObject *o) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_msg);
  Py_CLEAR(p->__pyx_v_send_reply);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler))))
  {
    __pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler[__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler++] = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_msg) {
    e = (*v)(((PyObject *)p->__pyx_v_msg), a); if (e) return e;
  }
  if (p->__pyx_v_send_reply) {
    e = (*v)(p->__pyx_v_send_reply, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler *)o;
  tmp = ((PyObject*)p->__pyx_v_msg);
  p->__pyx_v_msg = ((struct __pyx_obj_9dbus_fast_7message_Message *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_send_reply);
  p->__pyx_v_send_reply = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler},
  {Py_tp_clear, (void *)__pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler},
  {Py_tp_new, (void *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler},
  {0, 0},
};
static PyType_Spec __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler_spec = {
  "dbus_fast.message_bus.__pyx_scope_struct_6__default_properties_handler",
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler_slots,
};
#else

static PyTypeObject __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler = {
  PyVarObject_HEAD_INIT(0, 0)
  "dbus_fast.message_bus.""__pyx_scope_struct_6__default_properties_handler", /*tp_name*/
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler, /*tp_traverse*/
  __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client[--__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client(PyObject *o) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client))))
  {
    __pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client[__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client++] = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client},
  {Py_tp_clear, (void *)__pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client},
  {Py_tp_new, (void *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client},
  {0, 0},
};
static PyType_Spec __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client_spec = {
  "dbus_fast.message_bus.__pyx_scope_struct_7__init_high_level_client",
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client_slots,
};
#else

static PyTypeObject __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client = {
  PyVarObject_HEAD_INIT(0, 0)
  "dbus_fast.message_bus.""__pyx_scope_struct_7__init_high_level_client", /*tp_name*/
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client, /*tp_traverse*/
  __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule[--__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule(PyObject *o) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  Py_CLEAR(p->__pyx_v_match_rule);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule))))
  {
    __pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule[__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule++] = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule},
  {Py_tp_new, (void *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule},
  {0, 0},
};
static PyType_Spec __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule_spec = {
  "dbus_fast.message_bus.__pyx_scope_struct_8__add_match_rule",
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER,
  __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule_slots,
};
#else

static PyTypeObject __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule = {
  PyVarObject_HEAD_INIT(0, 0)
  "dbus_fast.message_bus.""__pyx_scope_struct_8__add_match_rule", /*tp_name*/
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule[--__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule(PyObject *o) {
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_match_rule);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule, sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule))))
  {
    __pyx_mstate_global->__pyx_freelist_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule[__pyx_mstate_global->__pyx_freecount_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule++] = ((struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *p = (struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule},
  {Py_tp_clear, (void *)__pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule},
  {Py_tp_new, (void *)__pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule},
  {0, 0},
};
static PyType_Spec __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule_spec = {
  "dbus_fast.message_bus.__pyx_scope_struct_9__remove_match_rule",
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule_slots,
};
#else

static PyTypeObject __pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule = {
  PyVarObject_HEAD_INIT(0, 0)
  "dbus_fast.message_bus.""__pyx_scope_struct_9__remove_match_rule", /*tp_name*/
  sizeof(struct __pyx_obj_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule, /*tp_traverse*/
  __pyx_tp_clear_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_9dbus_fast_11message_bus_MessageType = Py_None; Py_INCREF(Py_None);
  __pyx_v_9dbus_fast_11message_bus_DBusError = Py_None; Py_INCREF(Py_None);
  __pyx_v_9dbus_fast_11message_bus_MessageFlag = Py_None; Py_INCREF(Py_None);
  __pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_CALL = Py_None; Py_INCREF(Py_None);
  __pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_SIGNAL = Py_None; Py_INCREF(Py_None);
  __pyx_v_9dbus_fast_11message_bus_NONE = Py_None; Py_INCREF(Py_None);
  __pyx_v_9dbus_fast_11message_bus_NO_REPLY_EXPECTED = Py_None; Py_INCREF(Py_None);
  __pyx_v_9dbus_fast_11message_bus_BLOCK_UNEXPECTED_REPLY = Py_None; Py_INCREF(Py_None);
  __pyx_v_9dbus_fast_11message_bus_assert_object_path_valid = Py_None; Py_INCREF(Py_None);
  __pyx_v_9dbus_fast_11message_bus_assert_bus_name_valid = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  {
    __pyx_t_1 = __Pyx_ApiExport_GetApiDict(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_export_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_int_unsigned_int_BLOCK);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_export_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_export_name = __pyx_export_signature + 37;
    void *const __pyx_export_pointers[] = {(void *)&__pyx_v_9dbus_fast_11message_bus_BLOCK_UNEXPECTED_REPLY, (void *)&__pyx_v_9dbus_fast_11message_bus_DBusError, (void *)&__pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_CALL, (void *)&__pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_SIGNAL, (void *)&__pyx_v_9dbus_fast_11message_bus_MessageFlag, (void *)&__pyx_v_9dbus_fast_11message_bus_MessageType, (void *)&__pyx_v_9dbus_fast_11message_bus_NONE, (void *)&__pyx_v_9dbus_fast_11message_bus_NO_REPLY_EXPECTED, (void *)&__pyx_v_9dbus_fast_11message_bus_assert_bus_name_valid, (void *)&__pyx_v_9dbus_fast_11message_bus_assert_object_path_valid, (void *)&__pyx_v_9dbus_fast_11message_bus_TYPE_CHECKING, (void *)&__pyx_v_9dbus_fast_11message_bus_NO_REPLY_EXPECTED_VALUE, (void *) NULL};
    void *const *__pyx_export_pointer = __pyx_export_pointers;
    const char *__pyx_export_current_signature = __pyx_export_signature;
    while (*__pyx_export_pointer) {
      if (__Pyx_ExportVoidPtr(__pyx_t_1, __pyx_export_name, *__pyx_export_pointer, __pyx_export_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_export_pointer;
      __pyx_export_name = strchr(__pyx_export_name, '\0') + 1;
      __pyx_export_signature = strchr(__pyx_export_signature, '\0') + 1;
      if (*__pyx_export_signature != '\0') __pyx_export_current_signature = __pyx_export_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  {
    __pyx_t_1 = __Pyx_ApiExport_GetApiDict(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_export_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_int_struct___pyx_obj_9dbus_fast);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_export_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_export_name = __pyx_export_signature + 53;
    void (*const __pyx_export_pointers[])(void) = {(void (*)(void))&__pyx_f_9dbus_fast_11message_bus__expects_reply, (void (*)(void)) NULL};
    void (*const *__pyx_export_pointer)(void) = __pyx_export_pointers;
    const char *__pyx_export_current_signature = __pyx_export_signature;
    while (*__pyx_export_pointer) {
      if (__Pyx_ExportFunction(__pyx_t_1, __pyx_export_name, *__pyx_export_pointer, __pyx_export_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_export_pointer;
      __pyx_export_name = strchr(__pyx_export_name, '\0') + 1;
      __pyx_export_signature = strchr(__pyx_export_signature, '\0') + 1;
      if (*__pyx_export_signature != '\0') __pyx_export_current_signature = __pyx_export_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_9dbus_fast_11message_bus_BaseMessageBus = &__pyx_vtable_9dbus_fast_11message_bus_BaseMessageBus;
  __pyx_vtable_9dbus_fast_11message_bus_BaseMessageBus._process_message = (void (*)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, struct __pyx_obj_9dbus_fast_7message_Message *, int __pyx_skip_dispatch))__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__process_message;
  __pyx_vtable_9dbus_fast_11message_bus_BaseMessageBus.__pyx_export = (PyObject *(*)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, PyObject *, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *, int __pyx_skip_dispatch))__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus_export;
  __pyx_vtable_9dbus_fast_11message_bus_BaseMessageBus._find_message_handler = (PyObject *(*)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, struct __pyx_obj_9dbus_fast_7message_Message *))__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__find_message_handler;
  __pyx_vtable_9dbus_fast_11message_bus_BaseMessageBus._find_any_message_handler_matching_signature = (PyObject *(*)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, PyObject *, struct __pyx_obj_9dbus_fast_7message_Message *))__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__find_any_message_handler_matching_signature;
  __pyx_vtable_9dbus_fast_11message_bus_BaseMessageBus._setup_socket = (PyObject *(*)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *))__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__setup_socket;
  __pyx_vtable_9dbus_fast_11message_bus_BaseMessageBus._call = (PyObject *(*)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, struct __pyx_obj_9dbus_fast_7message_Message *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__call;
  __pyx_vtable_9dbus_fast_11message_bus_BaseMessageBus.next_serial = (PyObject *(*)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, int __pyx_skip_dispatch))__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus_next_serial;
  __pyx_vtable_9dbus_fast_11message_bus_BaseMessageBus._callback_method_handler = (void (*)(struct __pyx_obj_9dbus_fast_11message_bus_BaseMessageBus *, struct __pyx_obj_9dbus_fast_7service_ServiceInterface *, struct __pyx_obj_9dbus_fast_7service__Method *, struct __pyx_obj_9dbus_fast_7message_Message *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9dbus_fast_11message_bus_14BaseMessageBus__callback_method_handler;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9dbus_fast_11message_bus_BaseMessageBus_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus)) __PYX_ERR(0, 76, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9dbus_fast_11message_bus_BaseMessageBus_spec, __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus = &__pyx_type_9dbus_fast_11message_bus_BaseMessageBus;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus->tp_dictoffset && __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_vtabptr_9dbus_fast_11message_bus_BaseMessageBus) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BaseMessageBus, (PyObject *) __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct__introspect_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect)) __PYX_ERR(0, 261, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct__introspect_spec, __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect) < (0)) __PYX_ERR(0, 261, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect = &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct__introspect;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect) < (0)) __PYX_ERR(0, 261, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect->tp_dictoffset && __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct__introspect->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added)) __PYX_ERR(0, 317, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added_spec, __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added) < (0)) __PYX_ERR(0, 317, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added = &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added) < (0)) __PYX_ERR(0, 317, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added->tp_dictoffset && __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_1__emit_interface_added->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name)) __PYX_ERR(0, 387, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name_spec, __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name) < (0)) __PYX_ERR(0, 387, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name = &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name) < (0)) __PYX_ERR(0, 387, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name->tp_dictoffset && __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_2_request_name->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name)) __PYX_ERR(0, 441, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name_spec, __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name) < (0)) __PYX_ERR(0, 441, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name = &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name) < (0)) __PYX_ERR(0, 441, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name->tp_dictoffset && __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_3_release_name->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler)) __PYX_ERR(0, 997, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler_spec, __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler) < (0)) __PYX_ERR(0, 997, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler = &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler) < (0)) __PYX_ERR(0, 997, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler->tp_dictoffset && __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_4__default_get_machine_id_handler->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler)) __PYX_ERR(0, 1031, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler_spec, __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler) < (0)) __PYX_ERR(0, 1031, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler = &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler) < (0)) __PYX_ERR(0, 1031, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler->tp_dictoffset && __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_5__default_get_managed_objects_handler->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler)) __PYX_ERR(0, 1086, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler_spec, __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler) < (0)) __PYX_ERR(0, 1086, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler = &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler) < (0)) __PYX_ERR(0, 1086, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler->tp_dictoffset && __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_6__default_properties_handler->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client)) __PYX_ERR(0, 1233, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client_spec, __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client) < (0)) __PYX_ERR(0, 1233, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client = &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client) < (0)) __PYX_ERR(0, 1233, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client->tp_dictoffset && __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_7__init_high_level_client->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule)) __PYX_ERR(0, 1263, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule_spec, __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule) < (0)) __PYX_ERR(0, 1263, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule = &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule) < (0)) __PYX_ERR(0, 1263, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule->tp_dictoffset && __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_8__add_match_rule->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule)) __PYX_ERR(0, 1296, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule_spec, __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule) < (0)) __PYX_ERR(0, 1296, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule = &__pyx_type_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule) < (0)) __PYX_ERR(0, 1296, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule->tp_dictoffset && __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9dbus_fast_11message_bus___pyx_scope_struct_9__remove_match_rule->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule("dbus_fast.signature"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9dbus_fast_9signature_SignatureType = __Pyx_ImportType_3_2_4(__pyx_t_1, "dbus_fast.signature", "SignatureType",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9dbus_fast_9signature_SignatureType), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_9signature_SignatureType),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9dbus_fast_9signature_SignatureType), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_9signature_SignatureType),
  #else
  sizeof(struct __pyx_obj_9dbus_fast_9signature_SignatureType), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_9signature_SignatureType),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9dbus_fast_9signature_SignatureType) __PYX_ERR(3, 6, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_9dbus_fast_9signature_SignatureTree = __Pyx_ImportType_3_2_4(__pyx_t_1, "dbus_fast.signature", "SignatureTree",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9dbus_fast_9signature_SignatureTree), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_9signature_SignatureTree),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9dbus_fast_9signature_SignatureTree), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_9signature_SignatureTree),
  #else
  sizeof(struct __pyx_obj_9dbus_fast_9signature_SignatureTree), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_9signature_SignatureTree),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9dbus_fast_9signature_SignatureTree) __PYX_ERR(3, 16, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_9dbus_fast_9signature_Variant = __Pyx_ImportType_3_2_4(__pyx_t_1, "dbus_fast.signature", "Variant",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9dbus_fast_9signature_Variant), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_9signature_Variant),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9dbus_fast_9signature_Variant), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_9signature_Variant),
  #else
  sizeof(struct __pyx_obj_9dbus_fast_9signature_Variant), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_9signature_Variant),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9dbus_fast_9signature_Variant) __PYX_ERR(3, 23, __pyx_L1_error)
  __pyx_vtabptr_9dbus_fast_9signature_Variant = (struct __pyx_vtabstruct_9dbus_fast_9signature_Variant*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_9dbus_fast_9signature_Variant); if (unlikely(!__pyx_vtabptr_9dbus_fast_9signature_Variant)) __PYX_ERR(3, 23, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("dbus_fast._private.marshaller"); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9dbus_fast_8_private_10marshaller_Marshaller = __Pyx_ImportType_3_2_4(__pyx_t_1, "dbus_fast._private.marshaller", "Marshaller",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller),
  #else
  sizeof(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_8_private_10marshaller_Marshaller),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9dbus_fast_8_private_10marshaller_Marshaller) __PYX_ERR(4, 16, __pyx_L1_error)
  __pyx_vtabptr_9dbus_fast_8_private_10marshaller_Marshaller = (struct __pyx_vtabstruct_9dbus_fast_8_private_10marshaller_Marshaller*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_9dbus_fast_8_private_10marshaller_Marshaller); if (unlikely(!__pyx_vtabptr_9dbus_fast_8_private_10marshaller_Marshaller)) __PYX_ERR(4, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("dbus_fast.message"); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9dbus_fast_7message_Message = __Pyx_ImportType_3_2_4(__pyx_t_1, "dbus_fast.message", "Message",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9dbus_fast_7message_Message), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_7message_Message),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9dbus_fast_7message_Message), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_7message_Message),
  #else
  sizeof(struct __pyx_obj_9dbus_fast_7message_Message), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_7message_Message),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9dbus_fast_7message_Message) __PYX_ERR(5, 36, __pyx_L1_error)
  __pyx_vtabptr_9dbus_fast_7message_Message = (struct __pyx_vtabstruct_9dbus_fast_7message_Message*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_9dbus_fast_7message_Message); if (unlikely(!__pyx_vtabptr_9dbus_fast_7message_Message)) __PYX_ERR(5, 36, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("dbus_fast.service"); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9dbus_fast_7service__Method = __Pyx_ImportType_3_2_4(__pyx_t_1, "dbus_fast.service", "_Method",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9dbus_fast_7service__Method), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_7service__Method),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9dbus_fast_7service__Method), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_7service__Method),
  #else
  sizeof(struct __pyx_obj_9dbus_fast_7service__Method), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_7service__Method),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9dbus_fast_7service__Method) __PYX_ERR(6, 9, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_9dbus_fast_7service_ServiceInterface = __Pyx_ImportType_3_2_4(__pyx_t_1, "dbus_fast.service", "ServiceInterface",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9dbus_fast_7service_ServiceInterface), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_7service_ServiceInterface),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9dbus_fast_7service_ServiceInterface), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_7service_ServiceInterface),
  #else
  sizeof(struct __pyx_obj_9dbus_fast_7service_ServiceInterface), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9dbus_fast_7service_ServiceInterface),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9dbus_fast_7service_ServiceInterface) __PYX_ERR(6, 28, __pyx_L1_error)
  __pyx_vtabptr_9dbus_fast_7service_ServiceInterface = (struct __pyx_vtabstruct_9dbus_fast_7service_ServiceInterface*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_9dbus_fast_7service_ServiceInterface); if (unlikely(!__pyx_vtabptr_9dbus_fast_7service_ServiceInterface)) __PYX_ERR(6, 28, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  {
    __pyx_t_1 = PyImport_ImportModule("dbus_fast._private.address"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_unquote);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 11;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_9dbus_fast_8_private_7address_unquote, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("dbus_fast._private.marshaller"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_PACKED_BOOL_FALSE_PACKE);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 15;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_9dbus_fast_8_private_10marshaller_PACKED_BOOL_FALSE, (void **)&__pyx_vp_9dbus_fast_8_private_10marshaller_PACKED_BOOL_TRUE, (void **)&__pyx_vp_9dbus_fast_8_private_10marshaller_PACKED_UINT32_ZERO, (void **)&__pyx_vp_9dbus_fast_8_private_10marshaller_PACK_UINT32, (void **)&__pyx_vp_9dbus_fast_8_private_10marshaller_get_signature_tree, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("dbus_fast.message"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_struct___pyx_obj_9dbus);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 85;
    void **const __pyx_import_pointers[] = {(void **)&__pyx_vp_9dbus_fast_7message_ErrorType, (void **)&__pyx_vp_9dbus_fast_7message_HEADER_DESTINATION, (void **)&__pyx_vp_9dbus_fast_7message_HEADER_ERROR_NAME, (void **)&__pyx_vp_9dbus_fast_7message_HEADER_INTERFACE, (void **)&__pyx_vp_9dbus_fast_7message_HEADER_MEMBER, (void **)&__pyx_vp_9dbus_fast_7message_HEADER_PATH, (void **)&__pyx_vp_9dbus_fast_7message_HEADER_REPLY_SERIAL, (void **)&__pyx_vp_9dbus_fast_7message_HEADER_SENDER, (void **)&__pyx_vp_9dbus_fast_7message_HEADER_SIGNATURE, (void **)&__pyx_vp_9dbus_fast_7message_HEADER_UNIX_FDS, (void **)&__pyx_vp_9dbus_fast_7message_LITTLE_ENDIAN, (void **)&__pyx_vp_9dbus_fast_7message_MESSAGE_FLAG, (void **)&__pyx_vp_9dbus_fast_7message_MESSAGE_FLAG_NONE, (void **)&__pyx_vp_9dbus_fast_7message_MESSAGE_TYPE_METHOD_CALL, (void **)&__pyx_vp_9dbus_fast_7message_MessageType, (void **)&__pyx_vp_9dbus_fast_7message_PROTOCOL_VERSION, (void **)&__pyx_vp_9dbus_fast_7message_get_signature_tree, (void **)&__pyx_vp_9dbus_fast_7message_SIGNATURE_TREE_G, (void **)&__pyx_vp_9dbus_fast_7message_SIGNATURE_TREE_O, (void **)&__pyx_vp_9dbus_fast_7message_SIGNATURE_TREE_S, (void **)&__pyx_vp_9dbus_fast_7message_SIGNATURE_TREE_U, (void **) NULL};
    void **const *__pyx_import_pointer = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportVoidPtr_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  {
    __pyx_t_1 = PyImport_ImportModule("dbus_fast._private.address"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_PyObject_int___pyx_skip);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 49;
    void (**const __pyx_import_pointers[])(void) = {(void (**)(void))&__pyx_f_9dbus_fast_8_private_7address_get_bus_address, (void (**)(void))&__pyx_f_9dbus_fast_8_private_7address_parse_address, (void (**)(void)) NULL};
    void (**const *__pyx_import_pointer)(void) = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportFunction_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_message_bus(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_message_bus},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "message_bus",
      0, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit_message_bus(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_message_bus(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#if CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
static PY_INT64_T __Pyx_GetCurrentInterpreterId(void) {
    {
        PyObject *module = PyImport_ImportModule("_interpreters"); // 3.13+ I think
        if (!module) {
            PyErr_Clear(); // just try the 3.8-3.12 version
            module = PyImport_ImportModule("_xxsubinterpreters");
            if (!module) goto bad;
        }
        PyObject *current = PyObject_CallMethod(module, "get_current", NULL);
        Py_DECREF(module);
        if (!current) goto bad;
        if (PyTuple_Check(current)) {
            PyObject *new_current = PySequence_GetItem(current, 0);
            Py_DECREF(current);
            current = new_current;
            if (!new_current) goto bad;
        }
        long long as_c_int = PyLong_AsLongLong(current);
        Py_DECREF(current);
        return as_c_int;
    }
  bad:
    PySys_WriteStderr("__Pyx_GetCurrentInterpreterId failed. Try setting the C define CYTHON_PEP489_MULTI_PHASE_INIT=0\n");
    return -1;
}
#endif
#if !CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    static PY_INT64_T main_interpreter_id = -1;
#if CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
    PY_INT64_T current_id = GraalPyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_GRAAL
    PY_INT64_T current_id = PyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
    PY_INT64_T current_id = __Pyx_GetCurrentInterpreterId();
#elif CYTHON_COMPILING_IN_LIMITED_API
    PY_INT64_T current_id = PyInterpreterState_GetID(PyInterpreterState_Get());
#else
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
#endif
    if (unlikely(current_id == -1)) {
        return -1;
    }
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return 0;
    } else if (unlikely(main_interpreter_id != current_id)) {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#endif
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    #if !CYTHON_USE_MODULE_STATE
    if (__Pyx_check_single_interpreter())
        return NULL;
    #endif
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_message_bus(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  unsigned int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'message_bus' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "message_bus" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_NOT_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit_message_bus", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_dbus_fast__message_bus) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name_2, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "dbus_fast.message_bus")) {
      if (unlikely((PyDict_SetItemString(modules, "dbus_fast.message_bus", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_variable_export_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_function_export_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_variable_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_function_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Execution code ---*/

  /* "dbus_fast/message_bus.py":5
 * from __future__ import annotations
 * 
 * import inspect             # <<<<<<<<<<<<<<
 * import io
 * import logging
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_inspect, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_inspect, __pyx_t_2) < (0)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":6
 * 
 * import inspect
 * import io             # <<<<<<<<<<<<<<
 * import logging
 * import socket
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_io, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_io, __pyx_t_2) < (0)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":7
 * import inspect
 * import io
 * import logging             # <<<<<<<<<<<<<<
 * import socket
 * import traceback
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_logging, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_logging, __pyx_t_2) < (0)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":8
 * import io
 * import logging
 * import socket             # <<<<<<<<<<<<<<
 * import traceback
 * import xml.etree.ElementTree as ET
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_socket, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_socket, __pyx_t_2) < (0)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":9
 * import logging
 * import socket
 * import traceback             # <<<<<<<<<<<<<<
 * import xml.etree.ElementTree as ET
 * from collections.abc import Callable
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_traceback, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 9, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_traceback, __pyx_t_2) < (0)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":10
 * import socket
 * import traceback
 * import xml.etree.ElementTree as ET             # <<<<<<<<<<<<<<
 * from collections.abc import Callable
 * from contextlib import ExitStack
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_xml_etree_ElementTree, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 10, __pyx_L1_error)
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_etree);
  Py_DECREF(__pyx_t_1);
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 10, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_ElementTree);
  Py_DECREF(__pyx_t_1);
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 10, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_ET, __pyx_t_2) < (0)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":11
 * import traceback
 * import xml.etree.ElementTree as ET
 * from collections.abc import Callable             # <<<<<<<<<<<<<<
 * from contextlib import ExitStack
 * from functools import partial
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Callable};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_collections_abc, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 11, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Callable};
    __pyx_t_4 = 0; {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 11, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_4], __pyx_t_5) < (0)) __PYX_ERR(0, 11, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":12
 * import xml.etree.ElementTree as ET
 * from collections.abc import Callable
 * from contextlib import ExitStack             # <<<<<<<<<<<<<<
 * from functools import partial
 * from typing import TYPE_CHECKING, Any
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ExitStack};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_contextlib, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 12, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ExitStack};
    __pyx_t_4 = 0; {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 12, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_4], __pyx_t_5) < (0)) __PYX_ERR(0, 12, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":13
 * from collections.abc import Callable
 * from contextlib import ExitStack
 * from functools import partial             # <<<<<<<<<<<<<<
 * from typing import TYPE_CHECKING, Any
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_partial};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_functools, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 13, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_partial};
    __pyx_t_4 = 0; {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 13, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_4], __pyx_t_5) < (0)) __PYX_ERR(0, 13, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":14
 * from contextlib import ExitStack
 * from functools import partial
 * from typing import TYPE_CHECKING, Any             # <<<<<<<<<<<<<<
 * 
 * from . import introspection as intr
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_TYPE_CHECKING,__pyx_mstate_global->__pyx_n_u_Any};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_typing, __pyx_imported_names, 2, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_TYPE_CHECKING,__pyx_mstate_global->__pyx_n_u_Any};
    for (__pyx_t_4=0; __pyx_t_4 < 2; __pyx_t_4++) {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      switch (__pyx_t_4) {
        case 0:
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 14, __pyx_L1_error)
        __pyx_v_9dbus_fast_11message_bus_TYPE_CHECKING = __pyx_t_6;
        break;
        default:;
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_4], __pyx_t_5) < (0)) __PYX_ERR(0, 14, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":16
 * from typing import TYPE_CHECKING, Any
 * 
 * from . import introspection as intr             # <<<<<<<<<<<<<<
 * from ._private.address import get_bus_address, parse_address
 * from ._private.util import replace_fds_with_idx, replace_idx_with_fds
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_introspection};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u__7, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_dbus_fast, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 16, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_introspection};
    __pyx_t_4 = 0; {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 16, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      switch (__pyx_t_4) {
        case 0:
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_intr, __pyx_t_5) < (0)) __PYX_ERR(0, 16, __pyx_L1_error)
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":17
 * 
 * from . import introspection as intr
 * from ._private.address import get_bus_address, parse_address             # <<<<<<<<<<<<<<
 * from ._private.util import replace_fds_with_idx, replace_idx_with_fds
 * from .constants import (
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_get_bus_address,__pyx_mstate_global->__pyx_n_u_parse_address};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_private_address, __pyx_imported_names, 2, __pyx_mstate_global->__pyx_kp_u_dbus_fast__private_address, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_get_bus_address,__pyx_mstate_global->__pyx_n_u_parse_address};
    for (__pyx_t_4=0; __pyx_t_4 < 2; __pyx_t_4++) {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 17, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_4], __pyx_t_5) < (0)) __PYX_ERR(0, 17, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":18
 * from . import introspection as intr
 * from ._private.address import get_bus_address, parse_address
 * from ._private.util import replace_fds_with_idx, replace_idx_with_fds             # <<<<<<<<<<<<<<
 * from .constants import (
 *     BusType,
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_replace_fds_with_idx,__pyx_mstate_global->__pyx_n_u_replace_idx_with_fds};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_private_util, __pyx_imported_names, 2, __pyx_mstate_global->__pyx_kp_u_dbus_fast__private_util, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 18, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_replace_fds_with_idx,__pyx_mstate_global->__pyx_n_u_replace_idx_with_fds};
    for (__pyx_t_4=0; __pyx_t_4 < 2; __pyx_t_4++) {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 18, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_4], __pyx_t_5) < (0)) __PYX_ERR(0, 18, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":19
 * from ._private.address import get_bus_address, parse_address
 * from ._private.util import replace_fds_with_idx, replace_idx_with_fds
 * from .constants import (             # <<<<<<<<<<<<<<
 *     BusType,
 *     ErrorType,
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_BusType,__pyx_mstate_global->__pyx_n_u_ErrorType,__pyx_mstate_global->__pyx_n_u_MessageFlag,__pyx_mstate_global->__pyx_n_u_MessageType,__pyx_mstate_global->__pyx_n_u_NameFlag,__pyx_mstate_global->__pyx_n_u_ReleaseNameReply,__pyx_mstate_global->__pyx_n_u_RequestNameReply};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_constants, __pyx_imported_names, 7, __pyx_mstate_global->__pyx_kp_u_dbus_fast_constants, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 19, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_BusType,__pyx_mstate_global->__pyx_n_u_ErrorType,__pyx_mstate_global->__pyx_n_u_MessageFlag,__pyx_mstate_global->__pyx_n_u_MessageType,__pyx_mstate_global->__pyx_n_u_NameFlag,__pyx_mstate_global->__pyx_n_u_ReleaseNameReply,__pyx_mstate_global->__pyx_n_u_RequestNameReply};
    for (__pyx_t_4=0; __pyx_t_4 < 7; __pyx_t_4++) {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 19, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      switch (__pyx_t_4) {
        case 2:
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_v_9dbus_fast_11message_bus_MessageFlag);
        __Pyx_DECREF_SET(__pyx_v_9dbus_fast_11message_bus_MessageFlag, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        break;
        case 3:
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_v_9dbus_fast_11message_bus_MessageType);
        __Pyx_DECREF_SET(__pyx_v_9dbus_fast_11message_bus_MessageType, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        break;
        default:;
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_4], __pyx_t_5) < (0)) __PYX_ERR(0, 19, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":28
 *     RequestNameReply,
 * )
 * from .errors import DBusError, InvalidAddressError             # <<<<<<<<<<<<<<
 * from .message import Message
 * from .proxy_object import BaseProxyObject
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_DBusError,__pyx_mstate_global->__pyx_n_u_InvalidAddressError};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_errors, __pyx_imported_names, 2, __pyx_mstate_global->__pyx_kp_u_dbus_fast_errors, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 28, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_DBusError,__pyx_mstate_global->__pyx_n_u_InvalidAddressError};
    for (__pyx_t_4=0; __pyx_t_4 < 2; __pyx_t_4++) {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 28, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      switch (__pyx_t_4) {
        case 0:
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_v_9dbus_fast_11message_bus_DBusError);
        __Pyx_DECREF_SET(__pyx_v_9dbus_fast_11message_bus_DBusError, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        break;
        default:;
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_4], __pyx_t_5) < (0)) __PYX_ERR(0, 28, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":29
 * )
 * from .errors import DBusError, InvalidAddressError
 * from .message import Message             # <<<<<<<<<<<<<<
 * from .proxy_object import BaseProxyObject
 * from .send_reply import SendReply
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Message};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_message, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_dbus_fast_message, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 29, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":30
 * from .errors import DBusError, InvalidAddressError
 * from .message import Message
 * from .proxy_object import BaseProxyObject             # <<<<<<<<<<<<<<
 * from .send_reply import SendReply
 * from .service import HandlerType, ServiceInterface, _Method, _Property
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_BaseProxyObject};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_proxy_object, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_dbus_fast_proxy_object, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 30, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_BaseProxyObject};
    __pyx_t_4 = 0; {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 30, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_4], __pyx_t_5) < (0)) __PYX_ERR(0, 30, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":31
 * from .message import Message
 * from .proxy_object import BaseProxyObject
 * from .send_reply import SendReply             # <<<<<<<<<<<<<<
 * from .service import HandlerType, ServiceInterface, _Method, _Property
 * from .signature import Variant
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_SendReply};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_send_reply, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_dbus_fast_send_reply, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 31, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_SendReply};
    __pyx_t_4 = 0; {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 31, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_4], __pyx_t_5) < (0)) __PYX_ERR(0, 31, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":32
 * from .proxy_object import BaseProxyObject
 * from .send_reply import SendReply
 * from .service import HandlerType, ServiceInterface, _Method, _Property             # <<<<<<<<<<<<<<
 * from .signature import Variant
 * from .validators import assert_bus_name_valid, assert_object_path_valid
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_HandlerType,__pyx_mstate_global->__pyx_n_u_ServiceInterface,__pyx_mstate_global->__pyx_n_u_Method,__pyx_mstate_global->__pyx_n_u_Property};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_service, __pyx_imported_names, 4, __pyx_mstate_global->__pyx_kp_u_dbus_fast_service, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 32, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_HandlerType,__pyx_mstate_global->__pyx_n_u_Property};
    for (__pyx_t_4=0; __pyx_t_4 < 2; __pyx_t_4++) {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 32, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_4], __pyx_t_5) < (0)) __PYX_ERR(0, 32, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":33
 * from .send_reply import SendReply
 * from .service import HandlerType, ServiceInterface, _Method, _Property
 * from .signature import Variant             # <<<<<<<<<<<<<<
 * from .validators import assert_bus_name_valid, assert_object_path_valid
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Variant};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_signature, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_dbus_fast_signature, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 33, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Variant};
    __pyx_t_4 = 0; {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 33, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_4], __pyx_t_5) < (0)) __PYX_ERR(0, 33, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":34
 * from .service import HandlerType, ServiceInterface, _Method, _Property
 * from .signature import Variant
 * from .validators import assert_bus_name_valid, assert_object_path_valid             # <<<<<<<<<<<<<<
 * 
 * MESSAGE_TYPE_CALL = MessageType.METHOD_CALL
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_assert_bus_name_valid,__pyx_mstate_global->__pyx_n_u_assert_object_path_valid};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_validators, __pyx_imported_names, 2, __pyx_mstate_global->__pyx_kp_u_dbus_fast_validators, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 34, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_assert_bus_name_valid,__pyx_mstate_global->__pyx_n_u_assert_object_path_valid};
    for (__pyx_t_4=0; __pyx_t_4 < 2; __pyx_t_4++) {
      __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 34, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      switch (__pyx_t_4) {
        case 0:
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_v_9dbus_fast_11message_bus_assert_bus_name_valid);
        __Pyx_DECREF_SET(__pyx_v_9dbus_fast_11message_bus_assert_bus_name_valid, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        break;
        case 1:
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_v_9dbus_fast_11message_bus_assert_object_path_valid);
        __Pyx_DECREF_SET(__pyx_v_9dbus_fast_11message_bus_assert_object_path_valid, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":36
 * from .validators import assert_bus_name_valid, assert_object_path_valid
 * 
 * MESSAGE_TYPE_CALL = MessageType.METHOD_CALL             # <<<<<<<<<<<<<<
 * MESSAGE_TYPE_SIGNAL = MessageType.SIGNAL
 * NO_REPLY_EXPECTED_VALUE = MessageFlag.NO_REPLY_EXPECTED.value
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_9dbus_fast_11message_bus_MessageType, __pyx_mstate_global->__pyx_n_u_METHOD_CALL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_CALL);
  __Pyx_DECREF_SET(__pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_CALL, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":37
 * 
 * MESSAGE_TYPE_CALL = MessageType.METHOD_CALL
 * MESSAGE_TYPE_SIGNAL = MessageType.SIGNAL             # <<<<<<<<<<<<<<
 * NO_REPLY_EXPECTED_VALUE = MessageFlag.NO_REPLY_EXPECTED.value
 * NO_REPLY_EXPECTED = MessageFlag.NO_REPLY_EXPECTED
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_9dbus_fast_11message_bus_MessageType, __pyx_mstate_global->__pyx_n_u_SIGNAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_SIGNAL);
  __Pyx_DECREF_SET(__pyx_v_9dbus_fast_11message_bus_MESSAGE_TYPE_SIGNAL, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "dbus_fast/message_bus.py":38
 * MESSAGE_TYPE_CALL = MessageType.METHOD_CALL
 * MESSAGE_TYPE_SIGNAL = MessageType.SIGNAL
 * NO_REPLY_EXPECTED_VALUE = MessageFlag.NO_REPLY_EXPECTED.value             # <<<<<<<<<<<<<<
 * NO_REPLY_EXPECTED = MessageFlag.NO_REPLY_EXPECTED
 * NONE = MessageFlag.NONE
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_9dbus_fast_11message_bus_MessageFlag, __pyx_mstate_global->__pyx_n_u_NO_REPLY_EXPECTED); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_value); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyLong_As_unsigned_int(__pyx_t_5); if (unlikely((__pyx_t_7 == (unsigned int)-1) && PyErr_Occurred())) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_9dbus_fast_11message_bus_NO_REPLY_EXPECTED_VALUE = __pyx_t_7;

  /* "dbus_fast/message_bus.py":39
 * MESSAGE_TYPE_SIGNAL = MessageType.SIGNAL
 * NO_REPLY_EXPECTED_VALUE = MessageFlag.NO_REPLY_EXPECTED.value
 * NO_REPLY_EXPECTED = MessageFlag.NO_REPLY_EXPECTED             # <<<<<<<<<<<<<<
 * NONE = MessageFlag.NONE
 * _LOGGER = logging.getLogger(__name__)
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_9dbus_fast_11message_bus_MessageFlag, __pyx_mstate_global->__pyx_n_u_NO_REPLY_EXPECTED); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XGOTREF(__pyx_v_9dbus_fast_11message_bus_NO_REPLY_EXPECTED);
  __Pyx_DECREF_SET(__pyx_v_9dbus_fast_11message_bus_NO_REPLY_EXPECTED, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "dbus_fast/message_bus.py":40
 * NO_REPLY_EXPECTED_VALUE = MessageFlag.NO_REPLY_EXPECTED.value
 * NO_REPLY_EXPECTED = MessageFlag.NO_REPLY_EXPECTED
 * NONE = MessageFlag.NONE             # <<<<<<<<<<<<<<
 * _LOGGER = logging.getLogger(__name__)
 * 
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_9dbus_fast_11message_bus_MessageFlag, __pyx_mstate_global->__pyx_n_u_NONE); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XGOTREF(__pyx_v_9dbus_fast_11message_bus_NONE);
  __Pyx_DECREF_SET(__pyx_v_9dbus_fast_11message_bus_NONE, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "dbus_fast/message_bus.py":41
 * NO_REPLY_EXPECTED = MessageFlag.NO_REPLY_EXPECTED
 * NONE = MessageFlag.NONE
 * _LOGGER = logging.getLogger(__name__)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_logging); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_getLogger); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_8};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 41, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_LOGGER, __pyx_t_5) < (0)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "dbus_fast/message_bus.py":44
 * 
 * 
 * _Message = Message             # <<<<<<<<<<<<<<
 * 
 * 
*/
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_Message_2, ((PyObject *)__pyx_mstate_global->__pyx_ptype_9dbus_fast_7message_Message)) < (0)) __PYX_ERR(0, 44, __pyx_L1_error)

  /* "dbus_fast/message_bus.py":58
 * 
 * 
 * def _block_unexpected_reply(reply: _Message) -> None:             # <<<<<<<<<<<<<<
 *     """Block a reply if it's not expected.
 * 
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_reply, __pyx_mstate_global->__pyx_n_u_Message_2) < (0)) __PYX_ERR(0, 58, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 58, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_1_block_unexpected_reply, 0, __pyx_mstate_global->__pyx_n_u_block_unexpected_reply, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[13])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_block_unexpected_reply, __pyx_t_9) < (0)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":73
 * 
 * 
 * BLOCK_UNEXPECTED_REPLY = _block_unexpected_reply             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_block_unexpected_reply); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_XGOTREF(__pyx_v_9dbus_fast_11message_bus_BLOCK_UNEXPECTED_REPLY);
  __Pyx_DECREF_SET(__pyx_v_9dbus_fast_11message_bus_BLOCK_UNEXPECTED_REPLY, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_9);
  __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":107
 * 
 *     __slots__ = (
 *         "_ProxyObject",             # <<<<<<<<<<<<<<
 *         "_bus_address",
 *         "_disconnected",
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_slots, __pyx_mstate_global->__pyx_tuple[2]) < (0)) __PYX_ERR(0, 106, __pyx_L1_error)

  /* "dbus_fast/message_bus.py":130
 *         self,
 *         bus_address: str | None = None,
 *         bus_type: BusType = BusType.SESSION,             # <<<<<<<<<<<<<<
 *         ProxyObject: type[BaseProxyObject] | None = None,
 *         negotiate_unix_fd: bool = False,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_BusType); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_SESSION); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_mstate_global->__pyx_k_ = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "dbus_fast/message_bus.py":184
 *         return True
 * 
 *     def export(self, path: str, interface: ServiceInterface) -> None:             # <<<<<<<<<<<<<<
 *         """Export the service interface on this message bus to make it available
 *         to other clients.
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_path, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 184, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_n_u_ServiceInterface) < (0)) __PYX_ERR(0, 184, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_3export, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus_export, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[14])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_export, __pyx_t_9) < (0)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":213
 *         self._emit_interface_added(path, interface)
 * 
 *     def unexport(             # <<<<<<<<<<<<<<
 *         self, path: str, interface: ServiceInterface | str | None = None
 *     ) -> None:
*/
  __pyx_t_9 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_path, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 213, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_kp_u_ServiceInterface_str_None) < (0)) __PYX_ERR(0, 213, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 213, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_5unexport, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus_unexport, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[15])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[3]);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_unexport, __pyx_t_5) < (0)) __PYX_ERR(0, 213, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "dbus_fast/message_bus.py":261
 *         self._emit_interface_removed(path, removed_interface_names)
 * 
 *     def introspect(             # <<<<<<<<<<<<<<
 *         self,
 *         bus_name: str,
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_bus_name, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 261, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_path, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 261, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_callback, __pyx_mstate_global->__pyx_kp_u_Callable_intr_Node_None_Exceptio) < (0)) __PYX_ERR(0, 261, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_check_callback_type, __pyx_mstate_global->__pyx_n_u_bool) < (0)) __PYX_ERR(0, 261, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_validate_property_names, __pyx_mstate_global->__pyx_n_u_bool) < (0)) __PYX_ERR(0, 261, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 261, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_7introspect, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus_introspect, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[16])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_mstate_global->__pyx_tuple[4]);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_introspect, __pyx_t_9) < (0)) __PYX_ERR(0, 261, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":317
 *         )
 * 
 *     def _emit_interface_added(self, path: str, interface: ServiceInterface) -> None:             # <<<<<<<<<<<<<<
 *         """Emit the ``org.freedesktop.DBus.ObjectManager.InterfacesAdded`` signal.
 * 
*/
  __pyx_t_9 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_path, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 317, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_n_u_ServiceInterface) < (0)) __PYX_ERR(0, 317, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 317, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_9_emit_interface_added, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__emit_interface_a, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[17])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_emit_interface_added, __pyx_t_5) < (0)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "dbus_fast/message_bus.py":363
 *         ServiceInterface._get_all_property_values(interface, get_properties_callback)
 * 
 *     def _emit_interface_removed(self, path: str, removed_interfaces: list[str]) -> None:             # <<<<<<<<<<<<<<
 *         """Emit the ``org.freedesktop.DBus.ObjectManager.InterfacesRemoved` signal.
 * 
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_path, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 363, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_removed_interfaces, __pyx_mstate_global->__pyx_kp_u_list_str) < (0)) __PYX_ERR(0, 363, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 363, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_11_emit_interface_removed, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__emit_interface_r, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[18])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_emit_interface_removed, __pyx_t_9) < (0)) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":390
 *         self,
 *         name: str,
 *         flags: NameFlag = NameFlag.NONE,             # <<<<<<<<<<<<<<
 *         callback: None
 *         | (Callable[[RequestNameReply | None, Exception | None], None]) = None,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_NameFlag); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_NONE); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_mstate_global->__pyx_k__4 = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "dbus_fast/message_bus.py":387
 *         )
 * 
 *     def request_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_NameFlag); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "dbus_fast/message_bus.py":390
 *         self,
 *         name: str,
 *         flags: NameFlag = NameFlag.NONE,             # <<<<<<<<<<<<<<
 *         callback: None
 *         | (Callable[[RequestNameReply | None, Exception | None], None]) = None,
*/
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_NONE); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "dbus_fast/message_bus.py":387
 *         )
 * 
 *     def request_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/
  __pyx_t_5 = PyTuple_Pack(3, __pyx_t_9, Py_None, Py_True); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_name, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 387, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_flags, __pyx_mstate_global->__pyx_n_u_NameFlag) < (0)) __PYX_ERR(0, 387, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_callback, __pyx_mstate_global->__pyx_kp_u_None_Callable_RequestNameReply_N) < (0)) __PYX_ERR(0, 387, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_check_callback_type, __pyx_mstate_global->__pyx_n_u_bool) < (0)) __PYX_ERR(0, 387, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 387, __pyx_L1_error)
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_13request_name, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus_request_name, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[19])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_8, __pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_request_name, __pyx_t_8) < (0)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":441
 *         self._call(message, reply_notify)
 * 
 *     def release_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/
  __pyx_t_8 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_name, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 441, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_callback, __pyx_mstate_global->__pyx_kp_u_None_Callable_ReleaseNameReply_N) < (0)) __PYX_ERR(0, 441, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_check_callback_type, __pyx_mstate_global->__pyx_n_u_bool) < (0)) __PYX_ERR(0, 441, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 441, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_15release_name, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus_release_name, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[20])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_9, __pyx_mstate_global->__pyx_tuple[5]);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_8);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_release_name, __pyx_t_9) < (0)) __PYX_ERR(0, 441, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":490
 *         self._call(message, reply_notify)
 * 
 *     def get_proxy_object(             # <<<<<<<<<<<<<<
 *         self, bus_name: str, path: str, introspection: intr.Node | str | ET.Element
 *     ) -> BaseProxyObject:
*/
  __pyx_t_9 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_bus_name, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 490, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_path, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 490, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_introspection, __pyx_mstate_global->__pyx_kp_u_intr_Node_str_ET_Element) < (0)) __PYX_ERR(0, 490, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_BaseProxyObject) < (0)) __PYX_ERR(0, 490, __pyx_L1_error)
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_17get_proxy_object, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus_get_proxy_object, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[21])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_get_proxy_object, __pyx_t_8) < (0)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":524
 *         return self._ProxyObject(bus_name, path, introspection, self)
 * 
 *     def disconnect(self) -> None:             # <<<<<<<<<<<<<<
 *         """Disconnect the message bus by closing the underlying connection asynchronously.
 * 
*/
  __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 524, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_19disconnect, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus_disconnect, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[22])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_8);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_disconnect, __pyx_t_9) < (0)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":536
 *                 _LOGGER.warning("could not shut down socket", exc_info=True)
 * 
 *     def next_serial(self) -> int:             # <<<<<<<<<<<<<<
 *         """Get the next serial for this bus. This can be used as the ``serial``
 *         attribute of a :class:`Message <dbus_fast.Message>` to manually handle
*/
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_21next_serial, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus_next_serial, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[23])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_next_serial, __pyx_t_9) < (0)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":547
 *         return self._serial
 * 
 *     def add_message_handler(             # <<<<<<<<<<<<<<
 *         self, handler: Callable[[Message], Message | bool | None]
 *     ) -> None:
*/
  __pyx_t_9 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_handler, __pyx_mstate_global->__pyx_kp_u_Callable_Message_Message_bool_No) < (0)) __PYX_ERR(0, 547, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 547, __pyx_L1_error)
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_23add_message_handler, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus_add_message_handl, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[24])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_add_message_handler, __pyx_t_8) < (0)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":572
 *         self._user_message_handlers.append(handler)
 * 
 *     def remove_message_handler(             # <<<<<<<<<<<<<<
 *         self, handler: Callable[[Message], Message | bool | None]
 *     ) -> None:
*/
  __pyx_t_8 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_handler, __pyx_mstate_global->__pyx_kp_u_Callable_Message_Message_bool_No) < (0)) __PYX_ERR(0, 572, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 572, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_25remove_message_handler, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus_remove_message_ha, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[25])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_8);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_remove_message_handler, __pyx_t_9) < (0)) __PYX_ERR(0, 572, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":587
 *                 return
 * 
 *     def send(self, msg: Message) -> None:             # <<<<<<<<<<<<<<
 *         """Asynchronously send a message on the message bus.
 * 
*/
  __pyx_t_9 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_n_u_Message) < (0)) __PYX_ERR(0, 587, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 587, __pyx_L1_error)
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_27send, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus_send, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[26])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_send, __pyx_t_8) < (0)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":597
 *         )
 * 
 *     def _finalize(self, err: Exception | None) -> None:             # <<<<<<<<<<<<<<
 *         """should be called after the socket disconnects with the disconnection
 *         error to clean up resources and put the bus in a disconnected state"""
*/
  __pyx_t_8 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 597, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 597, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_29_finalize, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__finalize, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[27])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_8);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_finalize, __pyx_t_9) < (0)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":630
 *         signature: str,
 *         body: list[Any],
 *         unix_fds: list[int] = [],             # <<<<<<<<<<<<<<
 *     ) -> None:
 *         path: str | None = None
*/
  __pyx_t_9 = PyList_New(0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_mstate_global->__pyx_k__5 = ((PyObject*)__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_9);
  __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":623
 *         self._user_message_handlers.clear()
 * 
 *     def _interface_signal_notify(             # <<<<<<<<<<<<<<
 *         self,
 *         interface: ServiceInterface,
*/
  __pyx_t_9 = PyList_New(0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = PyTuple_Pack(1, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyDict_NewPresized(7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_n_u_ServiceInterface) < (0)) __PYX_ERR(0, 623, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_interface_name, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 623, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_member, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 623, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_signature, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 623, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_body, __pyx_mstate_global->__pyx_kp_u_list_Any) < (0)) __PYX_ERR(0, 623, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_unix_fds, __pyx_mstate_global->__pyx_kp_u_list_int) < (0)) __PYX_ERR(0, 623, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 623, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_31_interface_signal_notify, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__interface_signal, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[28])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_8);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_interface_signal_notify, __pyx_t_5) < (0)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "dbus_fast/message_bus.py":654
 *         )
 * 
 *     def _introspect_export_path(self, path: str) -> intr.Node:             # <<<<<<<<<<<<<<
 *         assert_object_path_valid(path)
 * 
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_path, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 654, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_intr_Node) < (0)) __PYX_ERR(0, 654, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_33_introspect_export_path, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__introspect_expor, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[29])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_introspect_export_path, __pyx_t_9) < (0)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":749
 *         raise last_err
 * 
 *     def _reply_notify(             # <<<<<<<<<<<<<<
 *         self,
 *         msg: Message,
*/
  __pyx_t_9 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_n_u_Message) < (0)) __PYX_ERR(0, 749, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_callback, __pyx_mstate_global->__pyx_kp_u_Callable_Message_None_Exception) < (0)) __PYX_ERR(0, 749, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_reply, __pyx_mstate_global->__pyx_kp_u_Message_None) < (0)) __PYX_ERR(0, 749, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 749, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 749, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_35_reply_notify, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__reply_notify, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[30])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_reply_notify, __pyx_t_5) < (0)) __PYX_ERR(0, 749, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "dbus_fast/message_bus.py":761
 *         callback(reply, err)
 * 
 *     def _call(             # <<<<<<<<<<<<<<
 *         self,
 *         msg: Message,
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_n_u_Message) < (0)) __PYX_ERR(0, 761, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_callback, __pyx_mstate_global->__pyx_kp_u_Callable_Message_None_Exception_2) < (0)) __PYX_ERR(0, 761, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_37_call, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__call, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[31])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_call, __pyx_t_9) < (0)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":783
 *             callback(None, None)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _check_callback_type(callback: Callable) -> None:
 *         """Raise a TypeError if the user gives an invalid callback as a parameter"""
*/
  __pyx_t_9 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_callback, __pyx_mstate_global->__pyx_n_u_Callable) < (0)) __PYX_ERR(0, 783, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 783, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_39_check_callback_type, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__check_callback_t, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[32])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_check_callback_type_2, __pyx_t_5) < (0)) __PYX_ERR(0, 783, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_9 = NULL;
  __Pyx_GetNameInClass(__pyx_t_8, (PyObject*)__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_check_callback_type_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_8};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_check_callback_type_2, __pyx_t_5) < (0)) __PYX_ERR(0, 783, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "dbus_fast/message_bus.py":796
 *             raise TypeError(text)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _check_method_return(
 *         msg: Message | None, err: Exception | None, signature: str
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_kp_u_Message_None) < (0)) __PYX_ERR(0, 796, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_err, __pyx_mstate_global->__pyx_kp_u_Exception_None) < (0)) __PYX_ERR(0, 796, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_signature, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 796, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 796, __pyx_L1_error)
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_41_check_method_return, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__check_method_ret, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[33])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_check_method_return, __pyx_t_8) < (0)) __PYX_ERR(0, 796, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_5 = NULL;
  __Pyx_GetNameInClass(__pyx_t_9, (PyObject*)__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_check_method_return); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_9};
    __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 796, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_check_method_return, __pyx_t_8) < (0)) __PYX_ERR(0, 796, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":814
 *         )
 * 
 *     def _process_message(self, msg: _Message) -> None:             # <<<<<<<<<<<<<<
 *         """Process a message received from the message bus."""
 *         handled = False
*/
  __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_n_u_Message_2) < (0)) __PYX_ERR(0, 814, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_43_process_message, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__process_message, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[34])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_8);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_process_message, __pyx_t_9) < (0)) __PYX_ERR(0, 814, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":894
 *             del self._method_return_handlers[msg.reply_serial]
 * 
 *     def _callback_method_handler(             # <<<<<<<<<<<<<<
 *         self,
 *         interface: ServiceInterface,
*/
  __pyx_t_9 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_n_u_ServiceInterface) < (0)) __PYX_ERR(0, 894, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_method, __pyx_mstate_global->__pyx_n_u_Method) < (0)) __PYX_ERR(0, 894, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_n_u_Message) < (0)) __PYX_ERR(0, 894, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_send_reply, __pyx_mstate_global->__pyx_n_u_SendReply) < (0)) __PYX_ERR(0, 894, __pyx_L1_error)
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_45_callback_method_handler, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__callback_method, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[35])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_callback_method_handler, __pyx_t_8) < (0)) __PYX_ERR(0, 894, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":922
 *         )
 * 
 *     def _make_method_handler(             # <<<<<<<<<<<<<<
 *         self, interface: ServiceInterface, method: _Method
 *     ) -> HandlerType:
*/
  __pyx_t_8 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_interface, __pyx_mstate_global->__pyx_n_u_ServiceInterface) < (0)) __PYX_ERR(0, 922, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_method, __pyx_mstate_global->__pyx_n_u_Method) < (0)) __PYX_ERR(0, 922, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_HandlerType) < (0)) __PYX_ERR(0, 922, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_47_make_method_handler, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__make_method_hand, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[36])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_8);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_make_method_handler, __pyx_t_9) < (0)) __PYX_ERR(0, 922, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":985
 *         return None
 * 
 *     def _default_introspect_handler(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         if TYPE_CHECKING:
 *             assert msg.path is not None
*/
  __pyx_t_9 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_n_u_Message) < (0)) __PYX_ERR(0, 985, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_send_reply, __pyx_mstate_global->__pyx_n_u_SendReply) < (0)) __PYX_ERR(0, 985, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 985, __pyx_L1_error)
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_49_default_introspect_handler, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__default_introspe, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[37])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_default_introspect_handler, __pyx_t_8) < (0)) __PYX_ERR(0, 985, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":991
 *         send_reply(Message.new_method_return(msg, "s", [introspection]))
 * 
 *     def _default_ping_handler(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         send_reply(Message.new_method_return(msg))
 * 
*/
  __pyx_t_8 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_n_u_Message) < (0)) __PYX_ERR(0, 991, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_send_reply, __pyx_mstate_global->__pyx_n_u_SendReply) < (0)) __PYX_ERR(0, 991, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 991, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_51_default_ping_handler, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__default_ping_han, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[38])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_8);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_default_ping_handler, __pyx_t_9) < (0)) __PYX_ERR(0, 991, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":994
 *         send_reply(Message.new_method_return(msg))
 * 
 *     def _send_machine_id_reply(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         send_reply(Message.new_method_return(msg, "s", [self._machine_id]))
 * 
*/
  __pyx_t_9 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_n_u_Message) < (0)) __PYX_ERR(0, 994, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_send_reply, __pyx_mstate_global->__pyx_n_u_SendReply) < (0)) __PYX_ERR(0, 994, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 994, __pyx_L1_error)
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_53_send_machine_id_reply, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__send_machine_id, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[39])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_send_machine_id_reply, __pyx_t_8) < (0)) __PYX_ERR(0, 994, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":997
 *         send_reply(Message.new_method_return(msg, "s", [self._machine_id]))
 * 
 *     def _default_get_machine_id_handler(             # <<<<<<<<<<<<<<
 *         self, msg: Message, send_reply: SendReply
 *     ) -> None:
*/
  __pyx_t_8 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_n_u_Message) < (0)) __PYX_ERR(0, 997, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_send_reply, __pyx_mstate_global->__pyx_n_u_SendReply) < (0)) __PYX_ERR(0, 997, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 997, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_55_default_get_machine_id_handler, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__default_get_mach, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[40])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_8);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_default_get_machine_id_handler, __pyx_t_9) < (0)) __PYX_ERR(0, 997, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":1031
 *         )
 * 
 *     def _default_get_managed_objects_handler(             # <<<<<<<<<<<<<<
 *         self, msg: Message, send_reply: SendReply
 *     ) -> None:
*/
  __pyx_t_9 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_n_u_Message) < (0)) __PYX_ERR(0, 1031, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_send_reply, __pyx_mstate_global->__pyx_n_u_SendReply) < (0)) __PYX_ERR(0, 1031, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 1031, __pyx_L1_error)
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_57_default_get_managed_objects_handler, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__default_get_mana, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[41])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_default_get_managed_objects_han, __pyx_t_8) < (0)) __PYX_ERR(0, 1031, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":1086
 *                 )
 * 
 *     def _default_properties_handler(self, msg: Message, send_reply: SendReply) -> None:             # <<<<<<<<<<<<<<
 *         methods = {"Get": "ss", "Set": "ssv", "GetAll": "s"}
 *         if msg.member not in methods or methods[msg.member] != msg.signature:
*/
  __pyx_t_8 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_msg, __pyx_mstate_global->__pyx_n_u_Message) < (0)) __PYX_ERR(0, 1086, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_send_reply, __pyx_mstate_global->__pyx_n_u_SendReply) < (0)) __PYX_ERR(0, 1086, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 1086, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_59_default_properties_handler, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__default_properti, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[42])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_8);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_default_properties_handler, __pyx_t_9) < (0)) __PYX_ERR(0, 1086, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":1233
 *             assert False
 * 
 *     def _init_high_level_client(self) -> None:             # <<<<<<<<<<<<<<
 *         """The high level client is initialized when the first proxy object is
 *         gotten. Currently just sets up the match rules for the name owner cache
*/
  __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 1233, __pyx_L1_error)
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_61_init_high_level_client, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__init_high_level, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[43])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_init_high_level_client, __pyx_t_8) < (0)) __PYX_ERR(0, 1233, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":1263
 *         )
 * 
 *     def _add_match_rule(self, match_rule: str) -> None:             # <<<<<<<<<<<<<<
 *         """Add a match rule. Match rules added by this function are refcounted
 *         and must be removed by _remove_match_rule(). This is for use in the
*/
  __pyx_t_8 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_match_rule, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 1263, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 1263, __pyx_L1_error)
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_63_add_match_rule, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__add_match_rule, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[44])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_9);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_9, __pyx_t_8);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_add_match_rule, __pyx_t_9) < (0)) __PYX_ERR(0, 1263, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "dbus_fast/message_bus.py":1296
 *         )
 * 
 *     def _remove_match_rule(self, match_rule: str) -> None:             # <<<<<<<<<<<<<<
 *         """Remove a match rule added with _add_match_rule(). This is for use in
 *         the high level client only."""
*/
  __pyx_t_9 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_match_rule, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 1296, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(0, 1296, __pyx_L1_error)
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_65_remove_match_rule, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus__remove_match_rul, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[45])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_remove_match_rule, __pyx_t_8) < (0)) __PYX_ERR(0, 1296, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_67__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[46])); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_8) < (0)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_BaseMessageBus, (type(self), 0x9d0a048, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_BaseMessageBus__set_state(self, __pyx_state)
*/
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_14BaseMessageBus_69__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseMessageBus___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[47])); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9dbus_fast_11message_bus_BaseMessageBus, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_8) < (0)) __PYX_ERR(2, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_BaseMessageBus(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x9d0a048, 0xe46e5e6, 0xe795340, b'_ProxyObject, _bus_address, _disconnected, _fd, _high_level_client_initialized, _machine_id, _match_rules, _method_return_handlers, _name_owner_match_rule, _name_owners, _negotiate_unix_fd, _path_exports, _serial, _sock, _stream, _user_disconnect, _user_message_handlers, unique_name')
*/
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_9dbus_fast_11message_bus_3__pyx_unpickle_BaseMessageBus, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_BaseMessageBus, NULL, __pyx_mstate_global->__pyx_n_u_dbus_fast_message_bus, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[48])); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_BaseMessageBus, __pyx_t_8) < (0)) __PYX_ERR(2, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "dbus_fast/message_bus.py":1
 * # cython: freethreading_compatible = True             # <<<<<<<<<<<<<<
 * 
 * from __future__ import annotations
*/
  __pyx_t_8 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_test, __pyx_t_8) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init dbus_fast.message_bus", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init dbus_fast.message_bus");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin_staticmethod = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_staticmethod); if (!__pyx_builtin_staticmethod) __PYX_ERR(0, 783, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 582, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_get.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_get.method_name = &__pyx_mstate->__pyx_n_u_get;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "dbus_fast/message_bus.py":691
 *             ip_port = 0
 * 
 *             with ExitStack() as stack:             # <<<<<<<<<<<<<<
 *                 if transport == "unix":
 *                     self._sock = stack.enter_context(
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);

  /* "dbus_fast/message_bus.py":781
 * 
 *         if not reply_expected and callback is not None:
 *             callback(None, None)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(2, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(0, 781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);

  /* "dbus_fast/message_bus.py":107
 * 
 *     __slots__ = (
 *         "_ProxyObject",             # <<<<<<<<<<<<<<
 *         "_bus_address",
 *         "_disconnected",
*/
  __pyx_mstate_global->__pyx_tuple[2] = PyTuple_Pack(18, __pyx_mstate_global->__pyx_n_u_ProxyObject_2, __pyx_mstate_global->__pyx_n_u_bus_address_2, __pyx_mstate_global->__pyx_n_u_disconnected, __pyx_mstate_global->__pyx_n_u_fd, __pyx_mstate_global->__pyx_n_u_high_level_client_initialized, __pyx_mstate_global->__pyx_n_u_machine_id, __pyx_mstate_global->__pyx_n_u_match_rules, __pyx_mstate_global->__pyx_n_u_method_return_handlers, __pyx_mstate_global->__pyx_n_u_name_owner_match_rule, __pyx_mstate_global->__pyx_n_u_name_owners, __pyx_mstate_global->__pyx_n_u_negotiate_unix_fd_2, __pyx_mstate_global->__pyx_n_u_path_exports, __pyx_mstate_global->__pyx_n_u_serial, __pyx_mstate_global->__pyx_n_u_sock, __pyx_mstate_global->__pyx_n_u_stream, __pyx_mstate_global->__pyx_n_u_user_disconnect, __pyx_mstate_global->__pyx_n_u_user_message_handlers, __pyx_mstate_global->__pyx_n_u_unique_name); if (unlikely(!__pyx_mstate_global->__pyx_tuple[2])) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[2]);

  /* "dbus_fast/message_bus.py":213
 *         self._emit_interface_added(path, interface)
 * 
 *     def unexport(             # <<<<<<<<<<<<<<
 *         self, path: str, interface: ServiceInterface | str | None = None
 *     ) -> None:
*/
  __pyx_mstate_global->__pyx_tuple[3] = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[3])) __PYX_ERR(0, 213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[3]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[3]);

  /* "dbus_fast/message_bus.py":261
 *         self._emit_interface_removed(path, removed_interface_names)
 * 
 *     def introspect(             # <<<<<<<<<<<<<<
 *         self,
 *         bus_name: str,
*/
  __pyx_mstate_global->__pyx_tuple[4] = PyTuple_Pack(2, Py_True, Py_True); if (unlikely(!__pyx_mstate_global->__pyx_tuple[4])) __PYX_ERR(0, 261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[4]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[4]);

  /* "dbus_fast/message_bus.py":441
 *         self._call(message, reply_notify)
 * 
 *     def release_name(             # <<<<<<<<<<<<<<
 *         self,
 *         name: str,
*/
  __pyx_mstate_global->__pyx_tuple[5] = PyTuple_Pack(2, Py_None, Py_True); if (unlikely(!__pyx_mstate_global->__pyx_tuple[5])) __PYX_ERR(0, 441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[5]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[5]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<6; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 10; } index[] = {{41},{124},{69},{28},{112},{42},{50},{57},{52},{60},{16},{14},{4},{66},{66},{179},{29},{1},{3},{1},{4},{1},{1},{0},{2},{47},{58},{48},{13},{5},{33},{8},{12},{20},{29},{24},{26},{10},{26},{23},{19},{16},{17},{22},{20},{17},{19},{20},{7},{26},{33},{6},{2},{82},{46},{31},{11},{36},{59},{9},{28},{36},{9},{9},{9},{9},{24},{10},{20},{21},{21},{35},{34},{25},{31},{42},{36},{46},{117},{28},{67},{38},{24},{61},{15},{17},{18},{40},{7},{7},{8},{3},{14},{32},{34},{30},{20},{39},{35},{35},{46},{51},{42},{36},{42},{36},{38},{24},{38},{39},{38},{35},{31},{33},{28},{37},{34},{25},{21},{31},{25},{26},{27},{37},{27},{19},{23},{15},{7},{8},{9},{5},{2},{11},{9},{9},{6},{3},{6},{12},{17},{11},{14},{17},{15},{17},{10},{19},{7},{11},{13},{7},{11},{11},{8},{7},{4},{13},{17},{8},{16},{4},{4},{18},{4},{9},{11},{12},{20},{11},{16},{11},{11},{16},{7},{9},{6},{11},{9},{16},{3},{13},{17},{14},{14},{16},{7},{0},{8},{6},{8},{16},{15},{41},{19},{6},{11},{21},{24},{18},{23},{4},{4},{11},{12},{8},{8},{5},{8},{24},{19},{20},{20},{10},{10},{8},{5},{18},{5},{15},{7},{9},{10},{21},{5},{7},{31},{54},{36},{64},{73},{27},{21},{27},{58},{58},{64},{11},{8},{5},{8},{10},{13},{1},{21},{54},{23},{6},{9},{13},{9},{3},{5},{13},{10},{6},{5},{8},{9},{8},{6},{11},{3},{6},{9},{5},{12},{10},{13},{8},{8},{9},{3},{9},{27},{24},{15},{15},{23},{21},{19},{16},{12},{1},{7},{17},{30},{4},{1},{6},{23},{49},{7},{9},{14},{24},{10},{4},{10},{23},{32},{13},{2},{13},{18},{5},{7},{6},{11},{8},{20},{8},{5},{10},{12},{8},{6},{7},{12},{6},{23},{7},{10},{3},{1},{4},{8},{22},{12},{17},{18},{7},{9},{17},{10},{11},{4},{5},{3},{1},{10},{5},{13},{7},{4},{13},{3},{7},{4},{16},{13},{16},{4},{9},{11},{10},{10},{12},{12},{14},{12},{11},{10},{29},{14},{12},{8},{10},{17},{13},{12},{34},{11},{19},{18},{47},{22},{17},{23},{18},{20},{20},{5},{13},{13},{12},{12},{12},{34},{6},{16},{6},{3},{1},{4},{4},{10},{22},{10},{7},{7},{12},{21},{19},{11},{10},{12},{19},{8},{9},{9},{5},{6},{5},{2},{3},{10},{5},{12},{3},{7},{2},{3},{8},{4},{8},{9},{6},{1},{8},{11},{4},{8},{6},{12},{9},{16},{22},{1},{23},{10},{5},{6},{7},{8},{21},{99},{78},{239},{427},{18},{1},{67},{144},{94},{134},{91},{121},{81},{72},{24},{132},{48},{90},{80},{20},{11},{217},{153},{26},{69},{55},{84},{112},{77},{59},{63},{93},{49},{252},{530},{174},{143},{18},{83},{135},{119},{60},{65},{754},{66},{231},{63},{89},{32},{767},{138},{123},{24},{57},{111}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (6692 bytes) */
const char* const cstring = "(\265/\375`\004:\325\320\000Z\327T.H\340\354\352\0010\314\3634f\307\265X\213\265\230\315\363<\317\363<\317s\234\300\246\310\216\031aT\033\221\317\"\0137\222\201'_\355xY6ON\006oS\340\321Ov>\270\305'\263\210&/\254|#A;d7+\262\001\231\002\311\002\351\002\273F\214\321F[\0146\343K\230\315y\212k\227y\215501f\255\255\346\317\330\273j\263\2154\031\2156\216:\237\355\006e\267\312\375^\177:Jv\264\367p\237\355\303\231+\332\315\223\334g\347\365s\363\344L\023\250\354\333\364\345\336\353\311r\\/\321\256v\236\275\373\311\252\333\257\335\357M\356N\262{\263<\207\261\251\000\213\341\330\306\030l\307\210+\262\263R\265w\222\343jWW\003\246\332yV\253\023M;Ir\255ui\362t>\246O\307\332))\244\352M\\jG{\262\233O\3671\201\200bb\002A\355z\345IV\235\227\372tue\202\366\2335UY)))\236\205y\261t\351\332\343{\331\273\212c\345\324\324\247h\206\014>T\334)K\264\373\364sd\331F5\325\232\277\250\335\304\231d\327y\264\307\243\\]\365\217\211\262\271\265\373t\25475\352{\216\314\241\035\315i\277z\363\\i\037\317\367\2257W^\232'\347\251\354\272\323\355\373YQ\276z4%OseUV_9\317Tu\233\265W\257\265\271;j\362\220k\317\2558Y\242l\212#\365\252\357\025\004V\331O\223\343\264\252y\310\225\373\350\262\344\036<x\340\371 \236\006q\264\227\226+\313\343{]\365\232s\257\366H\317\372\350\036\222\337H\315\003\260RV+\375\262\222\240QV\254N\232<\265\327X\335\237<F5Km\2629\312M\364\332\375\352\271\256\354\035\325l\352\3238X\327\371\326\323\304\245\332w\357\371I\336X\257\275^a\260\222\340f\274\321\350J\232\352\352\373\312\325~3\317^\242)\317\352s\365u\365\235\335\321b\335\363~v\332\311\3529.A\2313P\242&\256<\331\264Lc,\025e\324(\031:\232\306\3164\275\351\016\032%\303\316N?o\374<\271\3535\332\\\343M\205q[\250\271\031i[\026c\305\330\350\034?q<\263\223+\367IU\234\366\235\272\256j\264{\235\256z\325\371\364u\355!\323\023F\277\250\251\252v\275\342:\275\262\267tUS\235\257\344]=9G\2657yV\223ur4gz\335yV\315\236$j\352~\323k\212\352\3634{\332wsU\273.Uu\272\373\2445\315RS\\Y\212\276\223\034\247\366\025\205\261T\224\333\254d\347p\223\351\034j\256""\253\351\323yz\252\312\222\251\026=\211~ASs\325u\362\247k\224\353\262{\223\253Z\355g\211r\036\335s\334\373\356\243\305_D\005`\346\242^*8\346\035\241\370\025\264\331\007\000\234q\177P\0313w'\334]\313\201\241\222]b\225\217\277\2664#\267\244\215\211ig\204fnHpG\241\212\027\204\374\220\360\317\200\"\260\346\345\343\304b\274\262\372.\036\030\252\213\177A\021l\301'o\207;rYZU\360\004\237\340\036\227\000j\026\337\021\324\274kW\332\014\214Y\345\272\264\253\320\005\305\\A1[T\314\374GA\376\210[\034\363H\350\004\267\274\252wE\361[\361\t\334\301\342\252\334\230\020\205i\336\305+q\016\214\340=\275\000\334\016\000\242\211\241\263\347\367\334\376\215\177^\341W\300\230E\367\200*>\305\021\336\325u\271\270v\243b\336\275?.w-Z\014\212\271\345\256m\251e\t\212n\313=i\007P\314\263\027\201{r\201\204V\204\004\230\346\323;zU\000D C-\030\301\307\377\010\277\337\242\023\027\003\272\257)\273CY\234\232Lf\217\243\2106\346\270d\266-#\326\304\304D\330\036kl6X\215\250\366\212\3311\030m\254\315\330\304\033\332\010c3\332\210\261\035\223\301`\266\332\370\332\264q\246\326`7\330$;\342\324\2109[$\022\211D\"\321\036eD\033\221(&\253\201\321egE\"\221\350D\2473{4\212\201U$\243\215\027\366\002\025\034\034\232m\214\33152\031\314~\2154.\361Ft@\337\260X\247\317\217\251\366P\225\367:\317o\276\325\356\331R\307z6]\367\336:re\275\017_I\223\347\375\272\375\306\235\335\373[O\375\301y\377\323\367\311\331\335\312\353!M\235\017\353\3676u?>\235.\325\371\356u\236\247\036\355\355\\G}\212\346|\231z\277\232\247\316\377p\037o\352\374\351}\372j\356\324\364\250i\246<\245\311\263\267/\227\326\370\225DY\334\336\336\327{\366Fq>E\373i\342J\334\376Iq\344O\357\276LU\265\373\260h\357;\355e\337e\271}/}_Sr{3W\336\314s%od?\317\224\354>=\311\276\321\223TI\264<\367>\3232\275\241\354\276\261\251\232\232$\352\333\253\312u:\316\212\340\323\363\001k%\271\272z\224\347P\200\221\215.1f\307td1\232\030\216L\014F\343\032g\\{\274\261`[{\255fc\253m\032\227\254VC\323y\321\266\rg\246\026\223\301j\265\261\206\353\264\230\371\372\361\335\354}sc\241&&\333/""\321\202\2156\336\310h7\257\321F\223\335\334\340\324\266M\026\033c\262\330\216\215\264\232\032\321\265_\262\031\333hC\033edd5[\204\321F\032\216M\214\311\300j\373\005\253\021sb\260b\007\227\344\246P\350\350\202\244\\\357\214\333\022q]\336W\370[p\316\233\340OH\351\365HTa\213!?8\371#\270\306\005y\371k\341\266`\025\354\302\201*@\231\337k\345\267\342\025\276\2602q%\264d\211Q\374\032\241\261\325~\215\366K\340\014h\023\344\257\205\326+\000\301\251\342E\374\275F~\352\277\3046\243Ug.\314\205\221\342\230I\261\002\3759\334\216\024\217\357\241\n\271\260\030\375\n\304-\260\307\373\2015$\362ER#\227\243\235yLrX\003\266\275\025n\255Ea\\\314-\340\311/Fn\020\367\004;\331\214U\277\247\335\300\340\003N \037\263(\324rs\\J\027\204\252=\265\343(\367b\0328\003\376\225~>\021F]\025WF\201\001\310g\014X\r\265T\337\304\365\330\275&\030\037c\3673\345\010\372\267\336\223\321\253\003\014\205\277\005Kt\020\342B*\034\334^\3131\372\t\356\204LN\277\236\270\205\267=\241\213\016U\212\273\032% \265\0357\304\344\177$\021b\211XA\307'[\007\273\367\201o7\332\223\211\004\202\220]\362\314\305\3078\005\305\020\242\374\240\300/\200\232Or\003Y'&\305;\230\300ks+D\217!\r\\\254\021\247\340\023\216\317A1\0038\001G\300\231\226\257\021\217b\005\004~\257\345\355F\210\200\317\177<\362\210*\216\275\341\273s\315vD\204\023\314\344\005rN,2\362z\t\357\206\256i\324b\230\202\255W\246\225r?Ls\000\000\0062f1D+\316\201\303y\024\302\342_\000\020Q\014\211/\205\233\nw@\022\240\377\361\237\305<\273\371\254\337\351'\022\370\033\376\206\235\277#\376>d2\266\200k/\352\035]\235V\343\024\264\240\363u\036\374P\336\305.(\336\316e\365W\246\177\222G2\203\222\337syGjV\255-\307\356'\343\362]f2,n\000\367w\366\276\270\037\250y\006$\001w?\327\317CL\022\343\034x\2038\266\257\003\004\371\215r(s\250\274\032\202\247x\204Q\237\004\263\274\262\026\025\357\274\"o\254e\203;\225\026\220\246\345\267\250\276\312\364\003\000h[\204(H\"\213\241Q\014\341\025\021\2111\013\223\300\035\177\346Vh\305\026\265\221z!\004E\030\205\273\032n\007\252\344\305\351\300\230G?""\026Y&n\305*\004>\001 \005\226\317\242\2776}\016\317V\251y\004CpA4\364\314\345\231\214\2221\300(x\004s\274\263\230E\344\213\274\"\0353X\204)^\r2\317d\010'?\025\014\001\351yK@f\376\366\334\025\367#5k\240\346\r\215\331\243cV\351\371\303c\326\005\346Q[AQ\266\263V\303\003\004cn\265\031\250!\227O\022/X}\0347\304\024\3440\3134t\202O\302\243\267\304U\275A:\032\301\226T8\303\264\276\251C*#\354\021\020\006G!f\"\020\225#\234\374\023\214\021\314rO\256\215\212{\340\220^\375\202i0\010\234\316\022\204\237\007g\300\334\317\301\n\247\230\202L@@&\357M8\234\351v3\355m\272p\301T3\325JAA\245^\257\264\256\2454-\361\360\224J9\245\022\255T\222\225J\024J%\327\004\020\320\004\2177\341\375\004\212N\344r\023\0336L`\3000a\301\302\204\3156ac3\361zML\230\230@\362\340\201\364\263\333\221n7\222\006\r\244\235\035\231\214$\212a\350!\004\002B\3210''\244\321B\231,\244@\001\207\223 I\t\r\032$`0\211q\224\200\201\211\360\340!\202\307\2130\315\210\336#n\267\210\014\031\"\"rF<v\367w\350G\315o\336\376-\303\317`\341[\310\3719\263o\002\214\3258\326\261\325\021\342\205(\2053\177QZ\255\214\020E8\223~H\275\036\311{\322\205\013\244\234\034\022\311\025\202\000\021\262l\270\333\205\246\031\366\036\356\354\204::\241\214L\350\n]\022(*\301\201\203\304\316\216\204\216\204N\304\207\017\021@@\021\0336D`\300\020ac\023\001\213\200\215\202D\242! \336\347\341|\234\331o\001\256+\261\254@k\023\262 \215\302\031\360\203,\001\007(\242\002\236\200\021L\177&#h\245\276\202\224\354\345\277\204\177\307e\025\371$60\001S\311\021\262\257\305c\227!\007\255\242\274\222;>\334\016\0072Y@\354{iDV.i\323\014,nh\370\215(\037\005\344\207T\210\006\014I\234,N\260M\307.\020\216\237:\221\374\202\342\215\270\205\021\334\375V~\252\037\214\n.\005`h\014\320_u\022\035\030\032\320a\340\204\022U(s$.\341\0218\300I\242\202w7H>\211\306\007\272\200\n\376n\004\3248\005e%?\225\232=t\005X\004\366\244\313\203:]\320\274|\036\354\"[\n#`\355\267sWp\247Y\306\206\3757\206\217A\374\244\214\361\363\262K\242T\301\315\265<#\231C\351-\031\311;\024\217\357\322\316\023r\r\344""\207\261\337+\345\247\\pa\033o\004\216\317\201\261\222_\242\3615L!\013S\004\001\277Z\n\034D;\360\017\264v\262\204\023w\035H\240\026\344\264\244\223\006\212\212W_|\031\027d\303T\243\362\020\335\006-\3127\261kpjO)\327d\346\212\356L\251\re\332\006\004h(\030p=.\346\013\213\270\206\372\254\210|\222m1K\310G\271\036\255WD\253\234\372\004~yW3\230\367b\004y\244\0173\002\177\304\346\265yh\360\2743\226W\342e\347\222p\274\"o\020O\365z\027g\200\006\013\344\340|\004\300\216\237J~yI@\346\023\014\344\026H\315;\240l\365O/P\206\341\250\203\027\213:vJ\321\310\210$IR\350\3430\0304$\022\212\005\204\202y\017\223d$\311\026\344PG\214\"\316\314\210\310(((HR(u7\327\035\352\234\223\323\363]0C{U\316\264\2728R\352\030\330\325\327\273\355LQ\202\306\242\346\306\307\364\300\374\367|a\020?\251\003\354t\035e\256\210\022x\"\375-w\2119\263\014\312\026\351\267\240!%w\230\034^\005\004\026)q\002\334\242\177\364\370\271,\303\274\315\206$2FE`]j\306Q\rU\351\"p\026m)'@\361^0\352C\343\314\206\316\311\010\337?\264\342[X\024xD\305\330{\3605\345.\t\202\236\036\322\"\307\263\320_\317\247\243C\200\370\356\332\261`|::\022)\215\3354\333rT\213\023\r\345\205\213\021A}\341cp\340O{\031\201\224\331\247\367\201\301^\271\202\273.9\260~\365*|\212\267\324\261>X%An\305\335\366\200\337\267\003A\301\026 _\3650\004\370\327\366P\365e\235\t\020n\271\376%\323\202Q\n\331\3255\\!d\030\227\301\242a\374\360Nn%\034y\357{\240\000\037\334\017\r\3517.\007\n\360\271\253c\300x\356\332\326\304N\340\313\312\375\355\315$\377\353R\203\276\t?Q\306\242>[w'\005\242V\276\3538\324\340\340\t\014m\370g\345&\257\322`\257\026\363w\033\0263\244\2527L\026\227\274\2150\246c\\\r\272\2406H\021\020\032\231\325a\343\245\330\362G\371\363lLlIIf\033\275\263M\273\230\230\010\335i\355`\004|\013\252D \364\247\032\257\177A\"\364\331\264\266e\031X\311\372\227H\024\030\3600\343\005\236\322\217]\312\000\325\360D\311h\221?\307#\177MI*$_\377\232\205\206\0363\334t\032\223M3C\215\263\203R<rvR\257n\241\300aO\025\006\2223\241\222j\322\221\324\025y@\315\327\267f\365\322\225AD""\354\203\311~\022w\030\366\263|\317i\324\004\334o\210\273%@ETU\016\352\027x\331\256:\341y\035\000d\325\235$\0132\312\320j\243\331\332\214\264\337\0022\300\2156\0046\270N\372\274C\007\226\013\265\245\354\225\365\275>#Q=9\314\237z\350\276\"@\034.`I\321\213\347dul\201\235\013\202A<\376~?-\025\370\n\332\371\311C=l\362W\201\244\310JE\345W\304\340lRnj>\026\237\365\267CR\236\204\2227\336\360\211\235\323Z\010U\2421tG\024D\200\226\020\273\002J\335@K-\345\25203\r\017@\343\027\020\200}\017c_\201\301\257\267i\rR>R4\302\331\034\0075\220\254@rk\217%\326&T\312SF2|k\003\330hm\253d\020q\336\333\244s\235\350\rbCg$:\203\363\340\213\206@\371\207\215\266\311\216\215g$@\004iT}\212(\267\017\023\236\236'\255\2241\324\252\261\274\344\0334\013\373\264\215\254\347\3250nI;\234\314\207\037\347|\214\342\320\206m{\016{\352A\232\254\006\230\243\t)\266\357 \001\323\343+\t\242\023\nem:\370eZ\357\2275\325\004\230l\337S\375\026\340:\2076\360\2212\016\271\031\01689&\341\"\350\333\037\t\002;\364\302gz\310(u\300q\342\006\204\275|+k\031\312HpK\013\275\333<\316\247\224\240k\n\321\221n\225\215\306R\276\213\200\177\220h\035\035U\316\240\331\225e\005\313\334\313:\211\343\224b\351\264^<50\226-\021'\311\264\322\004\033\217\177\260&\016\334\036zT\307\364:z\367i\215\317yd6Bj\201E\371\357\316\344\316I\220\177\001\000\201\222J\016u\204\230\362\000=\021\006\004\016\023\3526L\250\306D\342[\027xU'\001\224\366\200`\247\353\371\231g(\333L\325\316\333\002\0311(\3525c\031\310!\212\t\272\005\267<-*\202\205\r\235a\006'\371 DA\350\007\227@]\370\t\032\2522\005\\\341\245x&`\0373\313\253\367\237p\311\010\013\272w\260\271\001[\345\345\374\000\255DhY\"IC\345\300\312hV\330X\260#P\000\233A\222\3323\261\207S\020#\036\364\305\331\017\214w\025\262\262P\013\332\003\036\327?\313\353Y\221\274&\013\004T\356\344\233\267\201Y\314\033\\N\354\250\311<S$\231#\327\340\255\202\224,\345iQ\216\353\361z\326\275\251@\260B+\013\237l\030s\212\213\005\216\324\000\373\227\340\232^\317zA\341\205\216j\210\313\3557\201\344NUr\250!\272\360\t2\344\262\276""\217i\372P^\352\270\"\340\223\332d\031\326\013\234\007\231\214\313\371Q\002\007\315\025j\320'GeJS\3454\230\215.\000\323\277\327\0178\315{\322\353\313\251\222\232\220\247\016>\220\020fPWk\234\362Djdp\215\332\373\33274ri\363a\003\334\210-\034(s\317\001\336H\320\303\230\231m\325\020\023\"U\213f!VK\311q\243\3045D\206\025\336\3764\1775\275\250/;UM+\255~\271\010j\216\241\"\375'\034\273HB$\032\013\241\332\232\007\240h8\rB\210\3665\361\320\204\240\210\307\232\007\250\357\224\031\224\273o\235\200\013n\353\304\345H\273\312\253\t\361\206\255R\346A\344\240D\270\321\007\000\245\020\005%\340\027\000\001u\314\022P\354\265x\322/\255\3406v\305\021\265u\325\2574~\327\376\221\206\241\340\026\214\376\037M\316#\303\t\246\265S^\200\177\316\231\265\375\237\261\222{\273Y\316\215.\242Y\000\271i\373\"\352\321\265\355\373\206?\240\007\223\252\366%P x\353C\031\263P\204\247\260[\377\035\350]\256.\370\225\0268y\021\007\\\325\245\232\033\266&\372\374\215\216\245\347\t\300\223Nj/c\266gp\257\304}\r\001\247\022\241\033\237<\246j\311\347_\342\016\264\275c\316\314\335i\\\347\216\234&.\277]3\315\201\203\333-\300\207Av\317_Y\353H\257\365\312\305\376\0271\236w\344\353\361_E\221\036!\346\025\214)}\3711k*\374\267\316\210\307f\026\2572y\\\001,\220\357:QH;Ae\321\217\021\374\002}$s\373\204\035\211\223`5\250E,\363\257=s\354\016\310z\354\007\203\027\320\004rD\021\\\210\254\367\225\336e\334G\267\001\201_E\277\345\020\351J\020\263ca\373h09\013_\263Q\377e^+\207\2651g\245\276\344\n\277\312}\334\263\364h\221-\260j\201K\322X\335G^^\234\210\370e\205\271\217\1778\235*s\312\202n\242v\201DB\212\246\376\357G\0233\331\311\347\315V[\316i\304\256\207L\252\261\215Jt\243;a\377\024\350^a:,\301\t\274P6h>\243\316\\\004\242k\001\340\236f\206\025Wp\215\020\002)f\354\224C\261P\277\211I\373\232\364\311\225PT&S\255\233\247\377k\\\243\360$#\245(\341\326\020\364j\242\016x\024D\336d\033\220\206Q\221S\016\261\365\216\\!\360C\313X\216r\351\317\000\274\267\372\357\376\367\257\346\341^\235\370\366\221~\313G\177\212l\221\027\014}\230\023\332""\344\\\327\220C\260\027\273 S\327\274\002\004\024\240\337\035 \245M4\206\t\nZ\315A\322-\363~\217]\2746\333\242\266l\233\272\374~3O\235\0169\233UK\026\322b\253\271\246\\\026\017\236\017o\371\337%]\2050\030s\013\223\004\242\335a33\252\277\230\203E\265\251E\013n\254\343\233\213\336X\214p\3616\325=9asa\260\260\0237\346Z\023\035{\370\037\234z\215\270Ft\366\020\216\316,\304Y\301`N|\215b`V\376m\353\257\010@\036\240\017\371=\214J\207\3127C3h\037h@%\225 *k\221\304L\202\032\214^\031\371\231X\246\nc\036\205Z\201\214\352\334%\2610\236\272Q8\3015\2109}\243\243\007E\200\007\364\342g\342\030\341\367U\375a\360\356L\271\242J\334\376\"\232?\245\025;\315 p\210\263\031\035 \326\240\037%kE\202\340c3\212\261\366&Zv\216L?E\004\252Z\022m7\234\250\023y\330D\216\261T\335\321j\230\334\254\333\026_\324\231\014\332u\n_\205\260\252=P\3473R\250\233\264\330\315k\0140(\344\202|\226\341\032\345\355W\235\235v\365\374\"\207;\204\t\377z\277\371Y\tm2X\033\201\211e%\320\346\376\232\001l\226\367\034e<hb9*\255EU\260\334J\253\240H\2313\224\324\356\316\241\026X\302x\202\\m\267 [\340U\374\032\035.+k\242\353O\036\364\\\314\024*\206\017\n\267i\304j\n\0245-fJ\"r}\233\034.\220\250\034\226\316\221\026\211\004\330M)F,\315T\222r&,;\202\204\271\377\223f\241c\267\014\030\205z\246\300\255#\037\362\376/\0315\026\030I\323 \356\355h\312gv\0065\031\207\3547\324K\301\335\314\236WMZ\370\362\024\341\227Qy\002\215$\242:Y=\305\343=\213\347\215'\252\314\005\030s\027\020\304R\\fJ\272J--\221\004\2574\361N\322\\\t:\247\357\244Y\302\\b$\233Zh\211\313$h[\010\372TT\304\211V\037\211\036\271\004\273\250\310~\250\034b\223p\276,.\206\360\322p\001j\312\257\003\203Xo\263\234\t\250#\374)r\222\222\271\323,\277\247F\254\234\340\300\320z\215K\004\204\340\313\017\310&\374g4]\274\025\"G8~U\203\357\023\026\3460\254\317\177,Qs\322\t\315\314\214\303\247\230\257B\033\253\t\232!\2444\271T@]\226\352\332\005\205\010\263\247\202\216\301\355v\331\005\203\316\206\316\331\303\004P\034G \2074\220r\313Cw\020\355Rv4\310bW8u\031\000v2g\230z\363i.X\244\375QG""\016\215\267\361\023W\340\231\246\n\315Xp\302\243t\224\352\207\325\200>\232#\277%j=\t\002\362s\253\020\325\273j\346\361\301\331\260\355\340\026\233-r\313\363l\2123\254\262\375\022\304\230\361\021\260\267K\353\300\331\206\3740\367\2071\243\3037\212\202Z7t\330\235\357\343\032\357\034\0050q\013\2459'\211\375\233$K6d\264\1775\3368x\236Q)\221\255L\371\361\226\372\346 \\\244\021\213\207\026\243y!\345\006e\324N>\025\020l\331\210b\210$g\321Q\276\226\256F\231\211\204D\342\232\343d\312C\276$i\234\301^\315.\363e;HR\240\016\337\216\272(\211G5\034\324\nu\326\027iRHy\312\261\365 \212\313\213:\346\t\267\344\305\373\362\346\226K;\2707\023\343|\251\370p\\\307\250P\016\317D\235\364]\032\275-\3122\370yJ\364\371\rz7\336\240\372\233#\371\374Kaqd\263A\357\345O\251\351<\036\000Ixl}\313;V\273\317\356\355]f[K\315\332K\362h\207 \036\247\360\3208$>W\034\177JC$\220\035o\0301\360\366\235\221\2043\332\010n\022\215\366\371\217\361\222\277AAAOL\220\2053/\034\024\373iJQ\327^V\024\323\n~\242\222\3103\230\202\305\315\251\024\035vT\001hPt\232?\230\265\345\017D\264\242\\\223h\362rR\361\337\227\324\3614\363\235\2075\304*\013\374i\272\023!\252\376p\212A\021\356\013\331\3314\276\373o\373\\\307h\217\355\256\010\242\326\026?\316)\367\n\217\213\272\027y+\346f\372^\225IHQ\322\306\300\036\014\002\273\237\346Q\366\206\234\366\020\010\336\364\316$^-\016\252\274\234\241 \257\310\377\312\361\215CY\177i\"\010\307\230\247\3414\324c\372\345)\nT\247\344\250\260\000\261\323\314 \365\240\314\300a4G$\"\343\362\332E\351\347\212@R\006\237\223\273\303\266\307\017\350\2615\350\"\220\374\337\3147\234\266\253lL\277\241{\330\230P\346\230V\033te\t7e\206\252\303]\211\252\234T*\326\245f\026\262\222+\037X\014\251\327\370}V\002\233n\370\245\000\002\275vQ<\264D\377\224\034\353L\244W[\363\220@\035\301\310\360\310\354$\300sl\030:f\252U\n+Bkw\205\370\301\021A\313\375o\311|\010^\253\301\025=\340\013\013t\006us\031q\265\331\035\342\005U5=\244\260A\344ZYi\364\233\224@\216\257\346\256c\226\356\021\243\211s\035Af\226\333\207\035\023r\322""\262\036$c\252\340\030\031\0259\264\206\363D9i\036\250\2554\371\323g\302\2373y\353\2050V\3559\267\3648\250\211\233\261{R\231\331e\001D\332\365j0b5M\215\213E\374\301\372\3740\3046<\021\007F9R\265\251\007H\373V\261\244\313\325\366\332.\262\013\241?4\307\270\335\311\355h\325\021\305Ox\177\304q\371t\361'\255y\027\032\325\026\375\033\372\353\340M\241\030k\266\224\336dc\357_sa\037\315\367\236\246s\003\254\351,\261\"0\344]\033\000*\377bTck\237j\000)\301\331\243\355\237B\370\210s8{\242qaS\314O\321\215\333\234\006<\006\255?\331\323B\354\303\014\031\371\303\260\236\350\030;\313\201\265\347\\\350\273\341G\244\303\202\355\211\222\020\0106\010\213\007\234#\257\321{7\241\320NI\312M!\017eK\001\212z=7\022i\307Y\224\005qb8q\307^d\363\006\237\205\2603\264f{\330\364\311E!-G\016\234\211\347\327\305\321\312I\337z\031z\371z\256\255vALN\035\027\237\300O\303\014\251G\n\276\265\017\\\256\304\311U\311\212\327\332\256kt$\371\354W\333b\2404\020\267Qv~\016\024o\0173%\3470A\364\304B\276w^u\200$\265\030\375\343\331*?\222\314R\"A\032Q\351\202\001+Y%\270\331\250\337\3267\303\000\365\224S\344\275\177\034F\273\301\341\212\003zmQiB=\023\022\240B#\224\244\033";
    PyObject *data = __Pyx_DecompressString(cstring, 6692, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (6605 bytes) */
const char* const cstring = "BZh91AY&SY\274U\370\314\000\006\247\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\300@@@@@@@@@@@@\000@\000`\033\037{\325\357\016zS\246\312;\330\265\335;\333n3\275\356{\314I\346\031\334+\314\363G\223O^j\266\331\\\215\260\0324\333\006\256\307\013\233\321\353\274\025\336\336\r\\\241\000}\013\356\005\000J\021\020#\311\251\243S`\236\2424\332&\320\310\n\236\332\2312cEO\311\210\214\246LjoM\024i\246\322~\251\275Q\247\211\246Si6G\2517\252\tB\000\021\032\020\021\225\037\222\203m\022\017(~Jh\0324\320\r\r\250\r\000\365\000\036\240\321\232\203\321\0004z\201\246@\221\004\024\364i5=C\365!\340\243z\243\324d=OSe\033SCa\247\244\221\352d\00044\364\236\240\321\241\352\000\323G\244\364\232\t5\022\010\214\222z\002\236\211\344\312i\262\2322yOMM2z\2321\000\000\r4i\240\000\365\r4\032\006#L\322z\215\002)\244\232h\3014\311\200@\310\323\023\007\250\206\t\240\031\032\014\2150\000\000&5\030\231\000\000\000\t\022L\200\232\000\021\2440$\331\030\204\302!=&'\2652 \332@h\000\006\206\203 \321\240h\320\r:\301\201\370\3206\204\216\306 #>\021~\336\350\253\207\034\252eL\332\312\036\016\254U\270/\233\314\262\223\t\327N\235\246\313S\334\357\251\247\035\007\267\211\351\260\363\331\371\376\267hz{>\262z\003\324\"\273\276\314\330\365\316o6\310z\220\354a\362\216\371\001\207\224G\327t!\303\346T\330\223\323\374\3241\2139\234\252\230I=\257Z\277\257\265\335\377\235\333&\200\177\270e<m^\352\210\361\275\\\266\"\032\005\020\222I&D\0143\252|;\305{\242#\005)*=\304\036R/\366?\007\374\374\236\037O\366\370\270\177\227\213w\261\275{Z\326\235\255k[\030\376\276\277\207\333\352\365O\343\343\366z\346\327+\006!b\261Z(\242\210\241\024QDG\373\t\244\035*#*\030=>s\323\237\251\243F\216'ZX\377N\214U\226RP\260\216s\022\021I$\221I$\222I%\022JT\262\306\373\244\216\"\376\276?\343\235\372\307\377\252\225J\306A\220f\271\222\031$\222B)$\2229$\241\201\306\202%?^\255\277\307\271\237r\276\306,y\362\222\330\311\2168\343\2168\342\212(\250\327\263cS&_\177\353\253c\342J\245K5uc\2168\242\212(\242\217\021\013\207^\n\212\"""\250\300b\242\221Ub*\250\240\254U\021\004b\365\341M4y~\363\311\352\366{\336\177\2708u\327]u\327_\007j\023BE\335]\277\"\315\366<\037hKG\212\211%a\347<6\254\233\020\322\033\000i\024\005\024U\220\026H\242\220R*\"\222#5b\240\241\260\0179\r\201\265\003o\001\213\223I\250\3611\210\341\375e4\223\314+\013$T\232\005\205v7f\030_}\374\353\237\365\220Z\254E| ,\005\212nh\363C|\316\006\364R\nH\n\021\022E\200\260\213\010\260]\"\241\246f\200\024\207\3351\304\262ec\277\263<\361C%/\250\"\032\004\2046\206\2257\207\272\010\262s\207\311\244\344)g\010-\255\025Y\323WzU\303\003\213\252\2237\tmNO\027\"\034\207~\370\242\250\311=\ty\"\227\003TH\2142J\026\314r_\217\330\026@\271+\330$llii\305\340\214\211\264\330a\200\214\311\214\020\037\366\320\252&\262\346w\222\t\204Ru\320\266\334\334}D\r8\036\206\353\330\331t\330V\177pM\210h,\351f\025P\301vFUf\021\231\220\271mWIa1\275-m66\r\206A\334Pw\304a&lv\341\206\237\333E\3330\010\323\205U\024U\2726\021\327\276\255\263\222}\2044B\327\022\004\000*nc\034o\014\030\311>\365\213\004\312\023\027\014S>\004\334\377\255\255,\210X]VBK\225\360\330\317O\001T\261\340\221\232\332\242\262\361\343\322I\241\274Bg]D\325\233\314HU\327\002\262\250\345V\026\3057a\254\344=[\312\277\025\306\375\225\357b\003\345x\354\374\270\0079\005Y\0049\341\351\036\256a\362\370WV\030\004X\022Yu\177\350\233l\306\235h\355\233\200\3758\036\034\347\3251\220\003\027\367\226X\335\037*N\204\344\276\233\267R0?\352\246\250<5ZH=\365q\344W#\232\361\030]+\266;\360\2547-cGV$\037,\r\257\347\253\325\326\326\303y!w\372.6*<{\ryd\354E\321c1\357Q\331\252I\330gM\363\206\302\224|\032PJI\356\336-Y\214hr\254A\270\234\353e\324\334\207\251\222\177\036\340B\247\224\3432\332\002\373\332 \241#%\253X\243u\362z\312\341\177\306>:\035\213\"\\\014\302\206\265\014\264>\311\251t3\r@\322\273{\265\257\032\323\225\326\310\210\231\031\027\315\006(E\222\003\024\304\240\210:!\010S\234\312\351S\205\355\333\342\346\217\024J\343\375\331\036g\265\037\360\352\032\234\001\311\253\2035k:f\233\003\314\245\023\227\340p\007\006\375\367\343""\226X\340\310\277\354!\310\316\352{\335\226I\226T\215\223{\177Fd\314\271\265\336^\270\032~\034\365\031\003R\275]\236\276\3765\305\316\363\263\223\252\362\363@\363\177\005\205\324\235>\221\367\265\235\366\367jN\321+Q\313\201\341\372[\002\375\334S\240u0\300/\252\306\\:\204\267\3333\022\373\n[(f\211J-d\276\356_\251E\224\350\206\266u\034xi\236\270M\034bG-}\023\tkmx\277\370\013\363q\247V\245L2\006\203\016\350\331\177\021\267eh\005\002\007Q\003d6\014\202\034P\215\235\374\347\r\230\214\375\373\3138\357\356\340\272\375\206MR\255\367\242\276NP?#*\314\3775G\250\231C\322KE\333S\320\236C8t\345Y\315\245\0040e\301\215(J\253\274\n\211\020\034F\301Z\314\242\263\365\314\374n\201\247\202U\002\010\224*\233L\266vs\256I\376?\246\354\010\230\003\010_\247V\371\313\203\260\265B\245R\250h\236\267\r\374{\357\330\231\026K\025\252p\245\267.\351\t\337\314&\204\322}\304\317Y\024\217\016\343\346\277\327%d\324\017,k\261\323U\357x;\275\033\020\265\265\3548\266\234=RBI\304\224;h$\374;\322&\241\2438HH\363f[A   \303\203\016!\321\246\034\233>\013\271.\271\352\350;a\366\010O\267\347\371\220Xy\374\374\236T{\234\244\350'\271\023\033\246\271f\313c\321\353sW\305U\306E1\216\3009B~\277W\242\262\221J\311\310\234\213(\340rl\232j\307\375\245)a$t:\220\201\024\252\000\025\225J\204\270?\267\203\326\1770o\021\345\366>:\363S\016X~_k\311\230\026V\003L[\236Z\347\342vd\316\022,\025.\253\312\366w\237\340|G\325\333>\360\212\231F\013(\302P\357\230Q\216\300\036\351La,\001\\%\227\0251\261b\245I\272\372\n\210\371\035\225\204\201Nc\224\314\352}N\030\205\2331\214Zt\322\236\021\247\370\354Q!\311\317\216CG\246\237[\376 DS\272\207\351\351:T\362\n\253\0241n\266)\0011\353v\350O\306\337\257\242\307\231bh\030E\261\331\2163\007\256\325S\261g\304\360\311\216\260\222\226^\223\314n\352\217\243\225\022\346\\9\221\346\347\362\237o1\374z\203\254\303\000\300\014\025\352\352l\2637\237\\\321\331\330\005r\367\371=~\274\271U4\320\016\203F\304\210\030\303\007[\022zOI\345\212\035\033\3246\227;\026\226D@S\243_0\314\030\306\235\004\302mb\016\252\206E""\232\343bT\250\235L\036\252\373\363yI\231\035\010c! *=(K\267\356\3069\264Ij*\335;\026\037\202\251\005)\\\2270\025\006\264\225id\307\226\027\333K\255\215>\375\350)\327\243V\001\315\317O\214\216\226\010-\210\323#\365\347CF\217\257\253#\364\031\253\337!h&\245\326\306(\2452g\257\260%\327\345\213.\027\341\n\277GN\263kfK\214\216\257\251\270\010m\244E;&\236_\303\246S\276\301\266\274kq\372\035\\\255\200j\305\312\347]&\266Y\020e\251\002\006\342&\035V+V*\225j\324\265pS\037R\252R\341B:g\336\204\3010rx\302l\223\360f\253\337\202\303v\263\311\375\311\3147O\233\311a\322`7\300\206\037<H\354\316\352Nj\005\304\313[:j\006\310\006)\200E\3039\2113\002(\213\227\"L\326\241\273\317<\355[g\232\301!lp\025\2512\036C\304\234.\327\241\024\202\306\020\321\331\367=\375\273\367\300s\325\037\231\257\353\3760\364\352\331\263\265\036j\214z\343s+\010\2454\245=\211\373\272z/\215\023\215\274\353\235.P\326\271\2277\237B4\374\0325\217\274\233RR\366\260\333\034\334\322\322\217=\224\025{\347\206\2500:\257\3333\344\203\242\010\363\3567\033M\n\377\006D|\031\371vW8K\337\324a\3013\003\313\321^\336\365\314SH[2\304_\333\307:\224R8\261(\027v\232<P\352_\225\357\322\235\365>\223\036\262\023FY\2113\003\000\270kK%\233\0109g\2602\3167\364\346b/%\210H\207\324Z\2133'A\013\"F9\313JvqNE\322\2227V\021\260$}\305\373<\362\326\272\270pv\366\241\r\325\377\"\363\0203\344pG\226}\362\332\001o\303u\347\241\344%\0313\360\351\211\321+\350O\261\257\312\332\307D\014\226j\022~\275j\2207\013D\235\273\210\237sC\016\360\326\230x\264\0100\227\232\245\367\236g\326S\325\271p\237\303=A\341*\205\221\347o\241\017\241\363\365\347\235\211\276rg%\214\201Z\242 \"\035\305E\002\n\364\221g\021\242Q+\322\003\003r\244\004*\035\334\233)\022\232\342\302\326\204\226R\037\252\022\177;\r\346\331\02104U\253\341\333\"\364D\243;'\006\t\006x\023\351\005nJ\227\231\007\3108\266L\006\263\241\365f\200\301\017.\023\266\255\003\274\271\221\2636\302\364EU\335F\313\245\273\345\274XW'\217S\032\2555Ns=\267\223\304\3431\344\343r\312\252g\030\315\007 \320\274\231ho\252\223""\034\242\242\021Q\224\242\t7\301\230\223\262`\235T`\252\004!Be\014)[\263\030\224\215k\210\212\366U|I\303\0149\354\303\374S\303\305\275\324\211o\341\327\346}\373\273\263q/\373\267L\2036\275\244\332R\333-\204\225\343\257\334\001X\305h\304||I\177\245m\001=\307\342\315\223)\t\355\374\271\006-T\334Ef(\255 \016D\020M\267\304o\266`\351'\261\001\247\245\264\023\346H\220+\326\306F\347$.\270\260S\027r\006\001zyym\r\270\203 \220#\344h\017\263a~\363\031s\253\376/\034\202\232~`AD\332\362OwEO\226K\210\0023hOT\231c5\r%\2641D\364\232\tI\326\204\315\216E\322B\274Az\272YO\017\003v\350]\023a;Gn\364-\371kB\355\351\263\007N\007N\036\303\370\225\222\025\t\216dQ\234\365y1\3209\303\340Y\220V\266\275\305\356b\010\222\250\272]\202Z\300Te\267P\330\021ECCa\025\240:|]\366\277\034\345\203G5f,\204\223<\023\205O\317z>\247W?\264\257\005\204$\243:\024Z{\362\200Z\301\354\210P\230\210f6\210\200<<\307\310\345\302\033w\241\277gW`\031\336.T@D6#\027\201\273\337\210\351h]\360\312\327d\315K\027\207\252\2518\270\331\353t\260ZF\202\3666\013+!\246\303\006\226l\230\007@\272N\205\021\325\343\270\266\327u\361\016L#\031\325\275\020fAbX9\013\260\205R\021<*aD\222Hvq\000\007\272y\002T\244\234P,\203\027\332\315Z\366]\2567\274%\313\007\354\377\361\226\374~\253\020\330\335\031\n\003\265\003\353\257\211B\374\273\000%\244\332\354\2107_s\242D\2656\332\tP@\224\223%\221\266H\205\3551Yf\r\231F\3428\216\331\332\343\342Je\330\355/\311\3479\216\303\033\345\360\016BB\264[\212\226B\3767\230\216\031\310\345'\200Lk{\243\013\224\034i\"\2760\200\212L\257Z\001\030c\373\325\323\030\020\037G\321\317H4$\026j\202\001E\220\321a>\003\206\275v\331\206\264C\004\2630\363\246\363P\352\323\312\2479*L\264\221\363U(\304\020\235Q\034\265\232\025S\220\261\027\263r\304\264\036A\226\227L\241$Q*\246_9\2742\212\337\225)c\020\333\024B \210q\001\021\235\300g\321\256\365\350\203\222\332\311k\320*\016D\300I\220\022u\315D\253\014jh\"\024TC\277(\371\366\020/I^\272X\3016\263\245\200\2622e(\323AQ~nTr\333s@\330Y.\270\326a\226\231$\276\315\360\226\\g\227\230c\031""\224xN\273\226Q\264\322S\321\237@\212\211\246\253,`Ov\022A\230s/\201+\225\207-\242\315U\244\021\021)\210\3145\265#\035\346{m\246\254\231\273\022%\2335\303J\022\324\020gy\271\210 \235J\311\010\215DFA\026\331\025\032g\21061\361\354\210(H+\tAz\303s\0351\014\261\307\273\347\224\234U\tlQT\036{\274\322c\302\251\271\220\343\317G4\027\202\031n8v\2063\206\223^\265\252T\224\345\222\"\327S%\3612\240\307\240\350\346\357~\254\207n\\\310K\215\231O\342\314\222\230\201\212q\307\"j[3\311I\255 w\021J\265\301j\027\316\362\243\321\333\247\362\243\"\343a\032\0042\026\025I \t\014G#\307\217=\217-\372!)D7\0335\340A\374\334\006\300\305\3622x\201<\262\271\030\252i\336\313\321\230d*\"\250\242\252\033\202\241L\006qo\004\220\341N\242\037\034\310\312 fO\2022Q\025$H\033\004q\263:\336f9}\231\375\017\321\331\242\346\332g\204\355\025R\371q)E\0170\232\035l\200\365\326\001\303D!m\r y\232\t\022\033\340Vm\345\336\212O\n\022\252\n\300\302\242mey\375,\303\2075*\341\205\241\333\035\033\343\334\327?\246\003\366\254U4fu[\021\\\343.\217\035\003-\226\375\016,\322Ih\244\2710/le\327\344\230\267m\206\037<\265z\021}|\001U*\023\200\306\233\350\212.\256\243\263\251z\270\036r\001\0274|>\223zH\3246\314\354\340\370\363\020HC\255v,r\313\267\013\364wFIC\312\020y$\205\322{\275\346\236P\250\002\327\344\025a\277\005 i9\325\225BW\022R!\312\243|\303\002\263\236\210\004\340s\003\347\310\272\220,\205\374\367|E\305\026\017\362\030\222\316\321\363!d\370\337\014\216y\032\002\275Z\004\213\335s\026\031\230#\221\362l\272\307\254Z\232\350`\340 G\274\325\331\231\201[\001vn\3174U{W\n\337\265\354\354\222+p\361u\205j\002l2i\235B\307\262\222\000\345\230*[\226\260\352\365_\025\353e\341\354\332\354\307E\211s,UdR\223{\304\313Ts\312T,Jz\324\307\211\225\0349 JsB\303m\235\267\321\324\340\274\204\022p\010\034`\202\246\222`^\213p\277\031\331\200EF\026\\\266cA`\303\002\242I\321p*#aP|9\2575\310\022\327\021:\345\216\212\3337\345\201\343\007\004\024\264*O\035\025`,c0]\022\330.\013\253\345\035\301\345<\253\272\234^\336m9`\234\236\377G\342\330mb7!F\302""\n\r\313\251\013\347\256\207y#\277\263\265s\330~m\374\205\357!\354r)\243\006@\322\204\306\361\001N/\242!\206\006\224\216\332\000\r\230\334\341\260>\261\325\342\221\253\345\363\025\325\200\357n\364-2\021\236\255\200\275\341\364\352\211\r\n\277%\313\3503\002\363\210\001\326m8\307 9\2161\026>!\255\346\236]\333\212\233\016\374\026\206\032\364\241PGp\307\027Y\004F\362\264i\213s`Pa\020\233%\020\262\271Q\324\255\226\242FzK\"\t\025@@\021\004\022\341\204\3042*\314\300}\257\352\2755\201\243\313\354\354\354\r\350w:\204\352C\313\221(\220\370\345g?\307::\224P\255\0342:,\350\301\304\342\265\211T\245\251\202\240B\"\303\270q\t\220\214*\2429@j \201\315\005\230\246\205\t\304@\206\323q\021\013\233w\005\"\245\275\313\200\211\356~\n\343g\002\2247\024\371\230\307\200\207;/\341gs\306P\237,O\t\313\2429\255\252\313\"\007\020\341M\225\026O5\372/\275\"\305\222\370\013}\346\222U\210ii\242;\345\320\016n\361\265\235\0308\346u\000\362X,\r\3045\031\260\206\303\006Q\014\265\023\264\240\201\221\2665\025\004\031*\200*\232\204\320\341\201D\351\364NQ\316\360\037\204\371\233\273\345vP\323B+\301\255\251\3332\226\335\225!8\022Nt&\014Z\231f\342\357\233\316\274\220\312\230l\271%\347\201UJ\357\035I\3252T\327\"SI\001\352\034\202\220\3477}\200\"\006\245\246\272\337\037'Z\373\306nw\035\354\221\n\206$\311W\271M^\\\334nR/\201>\207\220UE\017\225\274\344\252\214\3719D\"\315UU\177y\370\2064\216\304\n\257\263\336\034o\\\356\331\215\313l\251`\020\354\320R7\255\336pN\033$\251R\212\r\207\227\231\304\236\002\3018\211\243;\221E9\3444\376_c\311\310aNu7\3231\021\243\245\326\014\320\264\226\263\263\212\2067j\276\t6\245s\303\232-\364,\271\321g\"\364\226\245\373\3529;3vT%\347\214Z-\254LN\227K\031\230\212d\030N\370\274\211\241s\033R\244L\346\203\n\26394\027@\300\340pT\030\032\211X\327\245Z\354\257\207\266A\364e\200\314+[\242P\206\206\002\013D\351\010<\035\374\365M\212 \000&\034\350\3515\316\327\0065\"\304\210\316\366=J\035\305\026\367\356rL\241Y\224\301&\000d\022y\032\331\214\211.ySD\005Urj\215\321\334\242\020'R\324\314\375Q`""\345\243D<\265*\333\020\313\314\315\022'\237\030Dd\2113-U!I\030H\314\333\021\030\t\274\334\200\271\000\344\364\256\0228\036\263G\374\3529\303\023eL\030\014\351T\025A6\212ic@5\263\254\241\243\311\311\311\262\243~\371\022\320g\300\254A\306g\017\246\233\020\r\2444\n\322\302R\361\243\256\306be<\\\026\363\207\014\331\317s\357\314n\031\323\223,\203Ls\006n5\020\201\261T\021\300N\264\245\324\251\325\242\006\211\320l\372\364\356\257k4+\227*!\220\354\303\320\025=\227\037s\255\242hh\032>uU\031\364\033<\332Y\t\201\343\220{\004\306\304\243\212\022\236p1/W\356\014tSs\323.\210\\\0356ii\206\211p\034\022\032\000p\203\262Tyn\336Kj\244\"\202\200\370\025#c;Z\320_\270B2\255Z\263j\331\\\325\311]Z\251Q(\025<\224:k\344\025\n,\233\220\217\035\325[\213\305\362\344\372)\227UK/\365\325mD\275\277\253\364\373\276\337\372\316\275\017K\027\212\306k\207\233+\035\311\352\010\262+\022,Tb$\275,T\004X\210\242\373\034\237\351\nC\321\365\022!\370\322\206I\324J\215t.\334\0338\353\3652<\236+>\312N\305\316\335\024y\027\\\313\353w\003\355\014\354-B\263\032\253\261d\225\330\373\236\217\257\347& \221VZA\357\353\271\212.(\312\210d\345?\"W\325>u\206\023\267U\323\355fY\354\350\321\341]\\\363\337mS=D\346\363C\231\004\000\302\374\223.\212\2069\322\034\375\366rf@\243\324\363\270cx\366\207XO)\207\277a\237\244Q\3439\271\016;\026Y0\326Ma1EJ\272\353\333=#\17764\017\024.o\265\226\362\260\312\020{Vk\210gA\356^o\357\251\344\036\203~W~\001\304E\243/\002\020\010\201\337\201\363\272\236\000\340\001\324\373\036/\315\023a\031\247\212\010Y\002\021\366\177\243\017;\332\005\004\010b:\256\275\277\304:\363\022\207\237\0021-\001\317\265\364\263\236\261\263\257\263\263\262\371\310z\340\006\344\036\320\216\033qw\021\343N\230\323\266}>\323\204\336Q\307{tO\365\355\261.\303\013\260?\367\2750x\215\347\224\215\035\364!\324\313qkn\367ew=\356\317\020\235\224<D\\6\300F\036,\214l\024?\216\314\302<}\261\333\034a\010\256\345;ASQ2\334p\354\360\345\370\272]\240}U\343\013\265\340\034B6,;* \330\235$9\251v\331\333\0334\361\016\332\356\004\027\247\263""\354\270\020\016\032<na\253\321\343\375Al\331\307\335\360\314WJ)\360\275\212<\023\332\022t\355\376*>7\003\233\245\375\363\340o\014\324Y\214w\270\256\006\376\360\301\335\345n2\036\027|,\323\r\376-\375\353\275\336\357u\330\034#\270\270\021\246\315\204\230\273\377\236\367\262\363;w\272\364\273\204\363O\333\265\275\270\033\303\240\375NG{\257\035\236O\033'\341G\177\324\2637\367\302\367\357\334\345\374\023\364\335\327\230o'\003\270\024\205\3443\237\266\236M\264\340Q\224\335m\367~\2201\311\017\003\357r\357\352\371\037\300\256\215\026\007o\277\324in\252D\273\256\367\336z\274V\362\353\337\355\355\264\337[\227h\201\360\336]\273\314\023\226\r\273\333;k\343f_\033h\355\214\257\367\006\277#~jl\360n3vz>qX\355l*v\325\373L\311\363\256\246\271\327\327\326m\215f\026\005\201\313\367\374\332\272\353\315y\265\274H\361\357\273\306\177\021W\262\327^|\256v\277i~NT\371\025>\254$\027\204\321\024\323;Nu\326m7\351\\\243\241\241/\306\220\275\331\244\251\"\333\362\273\303\007\233\300\271\254\331\371\326\340W0\254\334v\226\263w\265\033\225=\033iK\216\323dr\345e\332nP{\034\236/'\221\270ps\276\271\216\362\267\233\203k\206\336{\256\301q\200\304=\221\321&\271\\\032\000H\271\034\020\303\370\006=\263H_2\027\274\351\254g\213\001o\010*#\264\222\r\031\327*\352\217\215\305r\252\327\271\261\334_\245\331\330\225\325\253\025\253Q**+w\365u7\003\367-\377\027\323\310\247\n\213\375q>\276~-O\035\035\024\3734\254xC\252\243\213w\355\035NR^\030`\352\254\2557\373{\347\275\377BPPQ}\036\210\031\030;f\337\360\267\340\344\322\312\017\207\276\237Rj\231E\017\264\277\335\372\r\352w\222\212K\261\366\203Q\347\275\001\344)xRT\315H\273\031\313\200s\340d_\366y\203\233/#\304S\233k\210\2152<kOmJE<?\020\252\203\034\355\240\022\"\310\357\035\311\303\256\344\n|\026\347I1<\260V\"\367(U\372\366\373\314\r`\210\221\372k]F\032\250W\301\345s\371\334m7\371\313\nR7s\272\031\312\322iJ\023\257m\324-:\223#Q\362\254j\336\227\2320\317Z\251c\030\246\201\014ii\016L\004\260\"\225E\272w\315\354^E\356\320\252\242$\335\032\0222\017v\256\031\025X%\254""\020\322\037\003\205T\250\245\024 c\234\020\312 \032p\243\320\301JpO\347\353\035\257\251\235\311\300\321\350Nzu\2464\340\250\205\245_\362z\334\027y\254\2615uDX\000\212\027\007s\t[X\031\213\004\351\023\212\"\321e\221C<\001\2064\004\313\254\342\0308!\302\233\261/\365o\223\275\2665\245\207\313\000\254\326\346k\005IW\250\025\0264\314\243\ng\020G\\\235Y\271\247\255\207\020\246T\202\262\013\350y\356q*D\322t]\220\254\210\315#K\244\227\3138\ty\372\325\314\375<\2048}/\336\033\372\005z&FV\3471b\371B6\2272'V6\362\346f4f4\245n\3438\2237\020\253\n\003\214\236\304\024\250\030\026\342\360\212\240\236b \"\023\004\370\202\247\205\365G\305\313&}\312\335?\223\203\364t\302\373\261\021\340J\036\036a\036lLH\232\0171Q\017Ra\345\340\273\303\312y\251\231c\020\250=D\017\327sR^b\27453Is\367\266\371'W\"\004wW?{\223\310\375\337#\240\363y\357\255'\346-O\255\371\230\203\321\257\202\343\240p\016\356\247:\351\263'$\037\377\213\271\"\234(H^*\374f\000";
    PyObject *data = __Pyx_DecompressString(cstring, 6605, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (6762 bytes) */
const char* const cstring = "x\332\235Y\311_\023\331\026\016\020\006\273Q\210\202\014\242VpDm\354\264\250O\273\333~\021\"\242\220\220\001\234-\213\244\002\325\204\312P\025\006m\273{\3112\313Z\3262\313,\263\3142\313Zf\311\237\340\237\360\276soe\016\332\375\374!\347\326\035\317=\303w\316\271x\205\035Y\323\244MY\330\222\324XB\316\010\031I\321\344\230 \251\202\274\037\225S\272\222T\037\nW4o\303\267\220\214f3\031L\332\333\222\321\275\243\350\272\242n\n\201\215\337\345\250\276\"\251\330.3\273\244\352r&.Ee\315\033\213an<\231\3016\263B8\271#\013\251L2%gtE\326\204=%\221\020\324\244.l\310\202\242F\023Y\232\254\250\202\276%\013\232\262\251J\211Y\234\255Tw\303|}\013\203\212&\250\022v\002\225\022\031Y\212\035\200\277T2\243cuR\345\0236\262\030\324\205\224\204\025\323\325M\260\241 g2\340&\031\345\327x(<N$\243\333ti]\227wR\272\240'\005MV\361-d\344T\342@\210g\222;5\001\351[\3303#Gee\227\226\324\004\310\030\213'\244Ma\205\367<A{\326\037\020C\276\325\345W\242\357\345\252o>\342[ a\316K\211\204\264\221\220\337\274\261\247\276\273U]$\374!l$\223\t\020\177R\225\337\265\315\264\007n\t\276\2326\354\251\267\376\337\025\366g}!\344\224\231\365'c\377\340\260d6\021c\332\213+j\254AK\230I\322\277\316\364@:\302\347&\2515\206\356\037\342\222\246\317\264\356\331\314n\365?>\353\214\205\344\204,i\262\037\212\0171\305|\213\277\016;\244\263\262\246\377\233\035t\231\253|\376@\337\3020.\023\223\023\312\206\234\221t\031\033hzF\211\352\334.Ta\325\267\372\303\334\177\346\340>1\330\010\371\203&h\331\215hB\3224\030{2\0169(\t\235\354\373 %\303\035\226\342\302A2+\2502l\tf\227\302\274\306\005:y\230&\353\314\035\256I*D-\021\227\"\226\303\347\256\t1\005\246\250\303\024i\365\023)\241\311\263a9\263\253D\345\232\003\342F`\322\276\327\354\364-\341\267\351\207\302\364\364\355\331\357$!\n\311lH\321ma'\2531\027\214\332\242\262\375l\217X\312@Z\330K\223\332\300\242\363*\t\216\253n\342\253\266\264}\245\276\225\221\367\232P\206lF\333\312\352\261\344\236*}JJ\2374\374\354~\376\374\231\021)\026\023v$=\272\005\2612\025\nqII\310\261Y\336\373\3534&\210\220\216<]""uy\272\243\020\255\031(\270\214'\263j,\332l\262R#\266L\327\0077!\363\035)\272\245\250\262\2504,\"\016\005bQ\320\0103t\262g\221\354y\266\336\022S\031e\027\3261\013\2362\270w\207\221\254\256$\352\335\321\244\252\351\222\2527\314d\020\325\360m\313\257\336\001\010\335?\020\223\014s\353\275\004[\"\003\255\306>f\017\r\035\004\253z6\323\320\265+%\224\230\244\323\221\212F\232\234\306%a\177t\345-i\267\206\330\007\3024!\344\201\220P\240\002f\316pn~ML\337\204!\252\262J\033lF!B\026\027\310\0274\273\335\004\374d*\024?h\277\272\022\310\2410S\341\207k\331\224\215\352\007\262\276\211\216\254\252\354\013zFR5\352\347\273d\325m\225T\302\220^K\311Q%\256\310\031>\233\217\330,\326\027>lT{\275Y5hIh\365\242\1772G@T\251\317c\361\211\356P\303\323F`\345.\351\213\314\372\022\362\216\254B:L\0075G!|`A\023\016\264\225\2141\027Cdf\262\215\221\364\337x\325\203w\254\201my\003{\276S\223u\026\264\006_\250;T2\2639\033\317\000pdm[O\246f\027\036g\265\333\350\274\335\320y\233:;M\234\355\330\t\td\222$x\235\330\3538\245);\3508cU>n\240f4\r\346S\2273\031\252z\315\266S[Z\323\031y'I\237_\203\214i\344#W\264inC5\247\020\246\251\257\0358\310\265\344\314\257\327:\261x\355V\215\235\343&\220\032~\275\326Q\316\327n\355\310;\033\2647\305\245\300\236*g\346\201\223\360\366kZ&z\273\346\245\267m\333\020\3211\233:\240\220P\265\026rCe'\305M\211E\010D\006\316?d\266\253\304\310\\\031d\010\0342\004\026ah\213\232g7;<\345T\202\024\205\0215\317\202_\322PRM0\006\246I,\323U\261W]\243\306J=\227S\324-9\2430\020`G_\327!\005dV\322&\315\233iSB\273Z\3662I,\256w\220sT\331\232\245\354\017\327\302y\323\336'\342\222\337\027\001Y\363/\275D\366\271B\352\206\267<F\356`g\031\220z\363\327\254\010\330\214e\243\262\030eq^\024\333\306\201a@i\375\370\031\024\202\230i\211\231lBn\035%\007\356\324G\341W\344\362\023\355\350\3306mK\306\234\332d\202\206\316S\354m22\004\244\266N\211\311q)\233\320E\340\262X\017m\307\235\331<\233\2746fG\033\355[K\224\032\032|k&\3450\337\234S\363\371\343fR\005\"\326\034\220\324 \307\2761\207\303C\333,\244\004\000\341\217m\322UT""\254\336R6\267\304\204\274+'\304hB\201\321\266\317\252n\317\013\027\312G\224\370A\207iU\361\360\222E$lh\235\265#m\313\3370\013H\206\334S\264A\240u\230\337\361+\026\311\362\204c\230d\211D\203\225\260\271-\223\230\275\333\220\324\231E$\023\310mT\\\265e\200_\274\245\223L\2551\255i\031\256\313\255e@\225\367u0\234Q\244V\007\313\360\202A\244P\3346\304\245\363U\376\355\300\321i=\t\250\245+\253\326\257\265J\367\3401\017C\021xl\265\010!\304\367Qv\347\013\205\002!_\304\216\377\021\300!\353\246\271\276}E\017\353\360\365'\336\245e\337\302\242\254\343\307\233H\340\367\n\327\311R\214\265\231_\362c\264\247\374\n\264~\311\037\361\205\374\336e\221\235\261\344_\367./-\210\341\245E\2777\262\026\362\265\324\346\365\317\020w\213z8_\342Y\211\227\247O\214?q9\260\270\350\013\255\370\"O\003\013\342\274wy\331n\342.k!\277-\217\206\032\330n\022_\242\335\006%\303\366\007\374>\177 \"\206\327VW\003!\024\307m\3252\005D\332\24350R\022E\345\314j(\260\352\013E^a\231wA\014\370\227_\255\022\244\330\031\303A\203\026\304\306\266\270z\260\217\377\013\250\334D?\254'$\307\233j\313\3462\223K\205E\221\246\372\261\271\224\014\373\302\341\245\200?\374t-\"\206\026^\204\230\264\227\303\201\371\347b8\002\366V\302\260\030>\263%m\014\313z\344\325\252O\234\177\352\233\177\276\344_\\\363?\367\007^\370E\246\305'\336y_\265\203\013\272\372\025x\374\0142\252~U%\261.\301\017\220\003l \031\224\220\217\261\010\316B\023r\204z\204\342^\337\022\262Z>g\177I$\021t\264G\263\255\353:x\276\224J\021dH58\242\002\026\330F\311\013\271\217\310K\014\336\311\375\233\341^\265\377@\215*ITB\231$j#\025`\277A\2172\"\363)\026\3309\004m$c\007\364@B\333\332I\275\330\320\256\236F\224\302$\013\232\265\300yL\270\355\020^\305\343\373\232b,|1\021c'\362\026\335\210\2652\262\032\205\025e\020)\010@Q\260C\0332\355\025M$59\232L$\250nG\3417+mDm\220\254\325\201h\3500\313\204\262\321V\001\322mc\270\337f5>~=\254\177c\270\256b\036\014:\257\352\030\375\377\311\234\372\366\212\006\211i4=\232\244\344\020i\324\277ZO\223\240\214\306l\240\246\234\343\363\216\216\211""\306W2\213\257\0145\263R\315;\333\231\370\332J\355\377^\371\225\353\243\222\200\303\360W!1F\210\306\211]\310\307\3521X\2547Q\177tL\233:vv\274z\223\006:gWp\001\300\264(R\035\220\251\022\333\264e5\273\303\236\320\344L\206\275u\260_\366\305c\374\203\315c\357 2\025\013\362~\024g\304\223\265\027#l\2118)\332YTC.%\306cqTzj\262\226\320\321\273\254\026W\305Z\365\200\342\001\200&\322\236\364\272[\005-jo\313\007\232(\306\263j\224\377\326\0017\032n\216\237\345\344&\252\327\257\331b\313\330\001\301\033\302\004u7BV\263 \217\021kgCk\352e\273\267\346M\"\315\341\245\212\270e\233R\325\300k\002hOgY\226\2530q\305\266\2220*\205\345\004\307$\277\307t\037\0373\024\225\271\246\322\366\240\302\303\3031\311s\375-\203\274\273\301\303;g\321\365\336Vd\253mg\217\303~\224\244\010X\252\205\234v\210RtyGK@\347\364\234I\357R\251F\010E\033\270.v\312\324\251\213,\220\335\277!\276\326\233\332\216\264\257\245\022\212\316K\177\333\374\252\030O\341\306\336\261)\334T\367\327x/\314t'\031\243\215\305\035mSer\344\322\264I\222R\246\306\000_\357\325Ty\023\"!#\241'5\270\214\330\336\203\256=\376\213\371!5\232\370\241\016\256\256\206\034\\\205\323\323\177-)i\251\372\3531Z\232\314~U\275\000\037do\314c\331/\256H-\225L\341\207\334\210\353\265\3715\265\351\r\265\265\006\"\307\240\377\354\242\254A/\217r\2065\231\263\244\032\037\223\032\\&\205\2140*\245\024\210\216\267)\330k\331\035\376e\033\006k\333\236EM\226\026\260VVM)\321mH\270\271&\340\203\273\354Y\214vNg!\037\246 zD\341\275\366\273\203\330\366\002Q\353\220\367\251Y/e\032\333\235\355\274Z\374\001s\232\312\300\346\321\006\303h\353i\334\267m\203\316\305\223\r\373uWn\353`\034km\335\032\261N\303q\2304=\373\300\275\366\253}h\362>\014\262+6g*\215\267nos\213l,\343\032\333\235e\307umk\274\206\227\334\3403{\033\310`\023q\252\376X\211\314#U\307j\271\376\026o\263a?\304\263\227$\333M;g\004Z\033\304\243\207\345\303\000\"4\253\031C\375IJ\354\360<U\375cJ\035\362E\200\031\222+Pl\305\377~\3010H\303\277],\206\357\221\244\3316\364K\211\3328\243\343\212\220\210\264\243e\365hJ\024iXd""\361YO\362\367\372Zz\313\3770\225\255\326\302@\022\310\233\335\226@\305\006\026-\233\212\341\214,l\270\3126\332H\277$]\022y\253\236\265\260\357\026S\323v\355\277X\310uA1\333\252\377!\203\311\215\013oO\312\250`j/\2430G\334\337I\314\262\214b\266\241\366^\265kC\341\206\203\376\255z\347\237\373\026\304\307\201\300\262\370\004e\234\257\251'\022Z\253u\254\241L\273\363\223\370\332\027\n\260.\273\303AQ\271.z\275\351\210\353\365\346-z\311\026ld\331F\204\301\315S\344j3\016GK\326\340hB\317\026\206\331?l\345\3102\205\263\207W\335\361x\231\352\3175\177\265\236\346\345\265\243\366\006\341XA\325\352]\364\211\274\000E1\337\334\303\213XGC5\357h(\347\035T\300;\332\212vG\307\322\317q\\\355\347h*~\333\267\023\327\275\313k\276N\327\265\377\301\002\263\321\252\014\261\275\370\240V5\211\017\352*\010W[\244n\276M\355\301\305\361\324\347]\360\205\304\005_8\262\344\367FP\310W\273\330\023\212\350\367\256\370\252=\265\272\274\332\261\342[y\354\013U\277V\275\221\247\3256\277I\330\027Z\202\024\355\276\260\317\277P\237]{\224\251v\320\243\265\370d!\354X^\212D\226}\"f/y\3755\265<Y\366.6}\210L\tMZkx\233iR\327j(\020\t\314\303~\327}!z\253\350`\243\216\032?0r\237O\\l\355\010\264v\204[;\326\032T\225U\323\331\244.\223a\n\327\277\246\247\373;\265\227!\376\027\215\0333\016\221\227\376\032\007Q\313y\316:w3\357\3712\3458\3416\273LWe\340\373\303\271\303\217\206\313\270i\006+\203\247s3\206\307\360\036\241\367n\256?\247\033\236\312\340p\356\224!\031\373f\272r\362l.n\314\033\272\371\250\340*\270i\366\r\303[\031~i\275\224,i\303\332\330\266\266\023_\372\034'&\214\023\246\313\274\231_/\314\025\322\225\201\301C\277\3416\356\342\270\211\374L\301\203\016kp\332t\233\367\362\256\303\256\312\230\247p\256\370\254$UN\236\252\014\236\254\014\016\035\352\271\373\206\2732|&7\227KWF.\233\336\312\310\005c;\357\312\243\323u\204S\335\271\273F\2271a\316\344=G\203C\326\220\033\367\030\236\304\031\367\255\351\271\202\267\260f=\\.{\313A\313y\336:\377S\301M<\r\342\232i\034pD\247\2377\202\240\207OsOp\020\032OrW\215.\352y\236\323\255sw""\n\367\213n\342ex,\2276\372\014\251rf\204\332\373\006\330yZ>a\005C\264\343Ik\360\262\371$\357\346;-\200\243\021#H\342:\001i\272\3319\227\350\216\226s&\357\3722Pg\201\t`6/\035\r\2347\326\254\351\237\nW\254\373\340\367\313\010\366\004+8\372L\316S\031\236\"\331N\222$FsA\306K\3753\027\303\t\203's]\225\213Be\362\\EpW&&+\243g+#\243\225\361s\306\234\261gJ\225\251\253\3466S\324\324\371\243qH\320\232\371\265\030\254L\t\346`\336\233\017\342\n\023\227L\014^\262.\335-\004i\013\366c\216\345\273\362#\371\267\305\221b\260(U\004b\276\3171:e\374\232\357\252\214OC\255\301\274d\r\010\226p\327\272\373\254\314\005u\301\272p\247\340),\026\357\226\272*\303\023\220\304\232y\025\363G&\214Q\030\017\344v+\357=\302\275~51>\016Y\235E'is$\347\315\2754\202\337\330\320\232\000\033\371+\371,\264\033\254|m\037\307%\363\327B\327\227S\216\336\301\303{9\330\367\t\322\325w\326\200\333r\337\263\356=/{\270\211\335a\246\234>\242\265C\207\331\234\337\274d\276)`\323\221\\\300\274\233\357\245[\342\303\032\201\267\344}\005\327\021\304\376\336\274\003\211\216\025\235E_i\252\374\302\212\254\035q\2633o@\242k\205+\205\317\245\371R\272\334[\016\262\201\312\3109\343\241\0314\345\374\203\302R1H\332\272o\335_,\245\231\246\306\340^\367\241\200\252L+\343\023d\350\222\261g]\375O\261\253\350\262\006\246\255\351\373\3146\210\3474\331\300.Ll\344~!]tZ\277\274\260^\300\365^\035\271Fs/\014\2379b\206\363\247\n\321\342\271\222\267\363\3147\326\233\017\326\007\346\252\235w\266.xK\256\322\254\265\032\204\211W\276\261\355\251\222T\322\312W\312i\232\356\0347\006M\357\227A\307\211!\353\024\271\343\340\311\277\273*N(\035 \340\371\333[9s\035\326p\342\273\312\3009@\312\3008y\033\034\233L~\360\320C\n%},\232\236\243\201a\210\211p`87`8\r\306\237\006\367\354\201Qk\346ef\321\227\n\353\305\237\212A\362\251\037\362^\302\241\3139\305H\233N\323_p\303y/\027\267J\022sz\353\373\363\344\223gsRn\317\272\360c\241\2530j\335{Z\356*\273\030\024\234\250\014\216Yc3\371\361\302h!\016\245\2162\030\3722I\216\3704\347%&N\032\021\363B>]\350-\274(B\000\260\322""\007EWe\344\242u\361\227\242\367o\357\021A\203\213\260kd\224N\034\266\2060D\246\373\2648_\374\253\034%I\016\270rgs\032\014\345\027\200(\240\365\347\\\324\232\370\261\320Sx\004q_\201\024\231\315\017\300\021\241wv\371\323\204\002\220\304\321\300\351\032\036\2347\336@\206 a\262\375)\262^\002\204\253\3645J\266\017\240\202\353\215\003z\335\220\370\004\230`\022\037:\334\303\365\201k\367\n\333%\027F\256\001#\031\257\207\351#\006\377\373\200\271\256\006\360\037\313\355\031\277\003\005Xt\270s(\035\376\001\347\357\311{jS,'\300\351\313w\014\003\005\234\317va\320\006\367yb\314\230\036\002\306:lZ\302\243\242RJ7\332\201\275b\330\032\276f\246\311\335\230B&\215k\226\333CJ\202\243~\231\356\000\210\014\013\031\014\002\020\001\201P\001\204\177\372\014\277\211F\223\207\020\317F\214\267\300\255A\332 `\3341Tf\210s\205\203R\177\211\237\n>\362g\362\317\013{E\356\346\227M\037\003:,\360\345\\97\337\357/#\206(s\237\202\035\001\314\272\3419\364V\316M\221\253\3427\274\330u\232\007\252=\010\277\026\245\000\302\303gs\333\226\033\270ZP\212i\2020\016\007\326\271\037\340\352r\341A\361Ii\246\354\2512_\031\032&\023:\361\035\235z/7\222\013\033'\315H~\024\240\300L0hD\231X\nR\205\374#7ftA\226\3430\030x\"\226}\231\345\321\345Of\033\\K0\313Z\224\202N\t\363\000\232\346d\376^\341b\t\313\217p\354\251!:\374<\205X7W\014\337\t\232\236\264&o\303\354a\201\023\306\230%\374X\350e\340\314}\343\233:\251\214\215\323f\3034y\036\350\272\204+\304L\246\233L\356\014<\013v\262`\215\263\023\300(\026\214\\\266./\000b\260\252\232\233\2200\036B\024\270\021y\361I\027\364r\223\337\220}St\376\336\364\320\327+S:\252^{\245\034,\307\254P\330\nG\270>\237\303\367.\303\004\026\340\376c\305\236\242\207y\033\024A\007\374f\\#\270\202EL#\002\274\316\353\005\2175\267PZ,\337)K\344\331\210\341\367\363\356\274\0355<\214q\343\224)\301\223\007\247\214\345|\2275\003 8\202\232\234\210!nb\007{]\301N{\320\026\214{\017\321\362\366\177\311\004X\340\265~@\233%\007\220\272\271\236\367XN\246\037\362s\352\2352\026L\206\0010\253\373\306%2c\262(\n\026\036""\343\2519\217s\307\247\000\313pr\026-\310\330\252\361\220PTeSF\306\215^\002\004\343\017D/om\"\364\363\321tY\323\201r\272\266\250\241\253m\203\312\370E\343#``\352|e\352\n\362\303\251\207E7E\344\322D\371\246\265\266Ny\301E\266\363\021\003\n\225a\022\347\375?\360:\362\254\334<\000@\003\263\254\271\313\301\213\232\237 n\204\3111(\347\n\260\233\261\377\020\303=\210\276\004=\340\340$b\347\026|`t\022\202\210\230\254\317i\2540\211\020Z4\234i+g\322\270l]\230cI\002s\313?\261\203D\322K\323U\322f/\216Dc\227\356\202;\241\253\376\353\010\327\030f\246d\356\002\216x\210n\\7\315\262%\363a\236'K\310H*\002\345\261w\314\004\302\316\035\250[\270\004\344\203\370 \030\204\021\030\337\2441b\235\277[\210\024]\305K\310\275\352\366f\363K\341>k\262@\343\264(G\312\207\013\344\233p\314\241I\343:\016\204\177>{\316]\224\273\306\005\322+\335\375An\021I\265\223V\327\235\225\301*2w\302#@\326S\303K\251\356\351\3345\003\207\216\223+\301\213X@\344\016\314[\344Y\310\200y\236\374\000\312!\214\314\365!l\0340cl\005\201j\246\232{`x9\267\315lN~\213\315\177\302\220\373\377d\207\243\3162\266f\240\347\251\241\021\270:\233\013V:\206\274)$\037\017Y\026\306C\2365$\230'I\031\rsXB\317\300\200\307}\004\001\000\004\032t\177\362\260Z~3\010\320\243\030\364\036`K\340\222\353E\350\240\\\017F\371\023C4d\206\036^e\365\344<-\210M\001\210\204\36139P\023\2666\326\003\023\206\213\302\007\022\271\337\212i;\244zx\346P\017\205\366\276\310\237oX7B\000\305\272\323|\312\337F\212\037.}\317\220\216\020\261>b\257|\304<m\340\324\241B\032\030\265F\257ZW\375e$\377\244\346\252\t\217q\355\364\344\036\231g\231\343\300\273\227\214\327\204{\344@\334\343\311\211(\375\007\332\335\266n/\224\374`\305f\270\226\372QZ\350\264\246\310{\303\305>\312\027*\204\212\271\373\326\344-;\275N\027\273\2326 \210\274j\366\343\254\337\213]\374\002[\271M\343%R\326~\030Z\017\342\354|Q+5\010\002V7\214*\250\030\265\274H\207\337ZoEK\374\300=\365\214\215\252\314I/\031\301\346E.n\215w\016\343\260\3479\202\234&\331\"t\225\302\345.\256\277g\271(S\276'?\237\337%\347\267\036>""\347R\036BF\301\302J\365\007\013\\#\220\300\226\021\205\370\264\374\245\374K\334\036\366!\324\201p\222\022\252\3128\245\325\343@a\353j\200%\335G\014\256i\241\253\251n\030%\321\225\273l\274O7_\003\376g\375\210\334\252<_&\224:q\326\032\275b]\241<E:\262\345\027EM\245\001\234_r\363\037G\352}\227=\025P\n\304\270f\270\302\001\226\324\373]\376r>V\270\214\035\2526q\226\322\361\312\010E\351\0217E\027:\221r\316\223#\254tw\361\254\376:\0233\333\207J!\224\363\315\227\235 \351\234F\262M\233\261\004\212\222\315\021\272\310\350\331/7\034.\267%\300\\h\002\020\035\223O\217\2023\226\027w\334\023\025 \230\034\256\337\010\323\356\"\205\270c\306(\3066\036\375\270\344.\315\225\322\024\237\020xQ%\262\224\337S8[\370\204\214\235\n8$\227\256qk\354&\0350aL\331e\336|\001k\204\006\266\"\360\241\313y\252FN\271P\321\364`3\n\220\004\023T\277\332-\362h\327\351/\247\035'\317[ST\215S7\352\033\310\013.s\313\272\345+\275\247|\346l\323C\306?\001\n\370\026\322\365[\371\247`h@\340i\325`KJ\324_d\351\300\\.\213\014\303k\006y\322\311]\030\312~N\257\t\346A\341\373\242\347\310\236\306\242\n\220\232\366\npw \325\377\334\360L3a\234\243\"\000\0108Q\234.z\021\375X\235=\017y\316\001b.\223\313\026\317\300?\323\366\364\311j\242E\315{\254\334?(v#\341\360PuO\357+\214\365%\366\372A)C\037\324v\2750S\274S\224(\277M[N8\342C\353!\334\343\313x\243\240\250\314#G \373\345-\252y\021\241\177t\234\230\260\306=()o\026\203\326\000<\201/\257\201\033{\034\250\027\336\224\376<*\273\312\356\257\325\334\325I\227\312k<\013e|\375V\374\263\034\354\000hNT\221]\320t\357\251\303H\356\"\342d\2400Go\004z\371\236\025\\\263\326v\255\335\217_\034\216O]K\335 K\335+DV\272\337\022y\333\375\201\310\207\356\217D>v\377I\344\317\356\027= /z\336\020y\323\363;\221\337{T\"j\317\274\023d\336\271Hd\321\371\202\310\013\347\033\"o\2342\021\331\251\020Q\234i\"ig\226H\326\371\027\221\277\234\363\275\264\274w\235\310z\357k\"\257{5\"Z\357\036\221\275\336\375\336\212s\360p1\347A!x\013\311\227\263\377\357\335\303\0279\037{\035\343i.U\t\003\344X\217\362c(\254\303\020""\202\277|\315\n\256[\353\257\254W\357\254w\033\326\206b)\252\245\246\255t\026\273\356v\255\323\325\326\273\337\021y\327\275Ad\243[&\"w+D\224\356]\"\273\335\237\211|\356~L\367}\334\343#\342\353Y\"\262\324cK\346=\221\367=Q\"\321\2368\221xUN\266\200\236\021y\346\014\020\t8CDB\316u\"\353N\225\210Z\225\314G\"\037\235\237\211|vzI\010\336\336\000\221@UNo\210\274\351}O\344}\357\006\221\215\3364\2214\304\005\262\337\373\231\310\347\336\377\366\201\374\267o\201\310B\337\n\221\225\276\010\221H\337+\"\257\372\336\022y\333\367\201\310\207\276M\"\233}*\021\265O#\242\365\355\022\331\355\373H\344c\337|?\335\250\377\031\221g\375\001\"\201\376\020\221P\377:\221\365\376-\"[\375I\"\311~\235\210\336\277Gd\257\377\023\221O\375\341\001\220\360\300k\"\257\007D\"\342\300\006\221\215\2018\221\370\200FD\033\370H\344\343\300\247\001R=b\370\2205t\233\312\252\302b\361\347\322f\031\300\321\324#Y\316\037\020\364\202<\276\376\314Bg\320N\357k_\274\010N\346\203\3343\251\220\235\312\207\362\014:\200\t\013l\030( \230\275\024\315\3268\010L\376\213\007U\004\257\223pT\000\212\233\277\325~\233\023\006\301+\206\313\230\315w\265\276\345\016\377\353\243g\254\231GE\265\354m\302\210\340\337]G\316\213\364\200\362#\340\367\347\3226='9\317 \327\032g@\013\t\377\301^\313\007~,tY\236\307\354\361\256\342DbE/\353\343\224\003\3407\177]`\265\367\030\205\034\027\217\2464~\316\270\307\"\355\021\017{\370EQz\024\031\334\013\223U\265\275\234\337OTnR\340\345\245$\005-\336B\037=A\375\017\322?F\031";
    PyObject *data = __Pyx_DecompressString(cstring, 6762, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (15108 bytes) */
const char* const bytes = "A message handler raised an exception: %sAn exception ocurred when emitting ObjectManager.InterfacesAdded for %s. Some properties will not be included in the signal.An interface with this name is already exported on this bus at path \"An internal error occurred: Blocked attempt to send a reply from handler that received a message with flag MessageFlag.NO_REPLY_EXPECTED: %sCallable[[Message], Message | bool | None]Callable[[Message | None, Exception | None], None]Callable[[Message | None, Exception | None], None] | NoneCallable[[intr.Node | None, Exception | None], None]Could not find interface on bus (this is a bug in dbus-fast)Exception | NoneMessage | NoneNoneNone | Callable[[ReleaseNameReply | None, Exception | None], None]None | Callable[[RequestNameReply | None, Exception | None], None]Note that Cython is deliberately stricter than PEP-484 and rejects subclasses of builtin types. If you need to pass subclasses then set the 'annotation_typing' directive to False.ServiceInterface | str | None.\", ?\": \"\"/.\na callback must be callable with two parametersa message handler must be callable with a single parametera message handler threw an exception on shutdowna{oa{sa{sv}}}a{sv}add match request failed. match=\"add_note\" at path: \"\" could not be foundcould not find an interface \"could not get machine_idcould not shut down socketdbus_fast.dbus_fast._private.addressdbus_fast._private.utildbus_fast.constantsdbus_fast.errorsdbus_fast.messagedbus_fast.proxy_objectdbus_fast.send_replydbus_fast.servicedbus_fast.signaturedbus_fast.validatorsdisable\" does not have property \"empty list of bus addresses givenenablegcgetting and setting properties with an empty interface string is not supported yetgot unix transport with unknown path specifiergot unknown address transport: interface \"interface must be a ServiceInterfaceinterface must be a ServiceInterface or interface name not intr.Nodeintr.Node | str | ET.Elementinvalid message type for method callisenabledlist[Any]li""st[int]list[str]no interfaces at path: \"oa{sa{sv}}org.freedesktop.DBus/org/freedesktop/DBusorg.freedesktop.DBus.org.freedesktop.DBus.Introspectableorg.freedesktop.DBus.ObjectManagerorg.freedesktop.DBus.Peerorg.freedesktop.DBus.Propertiesproperties interface doesn't have method \"remove match request failed. match=\"\"%s.%s\" with signature \"%s\" could not be foundsender='org.freedesktop.DBus',interface='org.freedesktop.DBus',path='/org/freedesktop/DBus',member='NameOwnerChanged'src/dbus_fast/message_bus.pythe message bus implementation did not provide a proxy object classthe property does not have read accessthe property is readonlythe \"send\" method must be implemented in the inheriting class(tree fragment) with signature \"\" with signature \"wrong signature for property. expected \"AF_INETAF_UNIXAddMatchAnyBaseMessageBusBaseMessageBus.__reduce_cython__BaseMessageBus.__setstate_cython__BaseMessageBus._add_match_ruleBaseMessageBus._callBaseMessageBus._callback_method_handlerBaseMessageBus._check_callback_typeBaseMessageBus._check_method_returnBaseMessageBus._default_get_machine_id_handlerBaseMessageBus._default_get_managed_objects_handlerBaseMessageBus._default_introspect_handlerBaseMessageBus._default_ping_handlerBaseMessageBus._default_properties_handlerBaseMessageBus._emit_interface_addedBaseMessageBus._emit_interface_removedBaseMessageBus._finalizeBaseMessageBus._init_high_level_clientBaseMessageBus._interface_signal_notifyBaseMessageBus._introspect_export_pathBaseMessageBus._make_method_handlerBaseMessageBus._process_messageBaseMessageBus._remove_match_ruleBaseMessageBus._reply_notifyBaseMessageBus._send_machine_id_replyBaseMessageBus.add_message_handlerBaseMessageBus.disconnectBaseMessageBus.exportBaseMessageBus.get_proxy_objectBaseMessageBus.introspectBaseMessageBus.next_serialBaseMessageBus.release_nameBaseMessageBus.remove_message_handlerBaseMessageBus.request_nameBaseMessageBus.sendBaseMessageBus.unexportBaseProxyObjectBusTypeCallableDBusErrorERRORETEl""ementTreeErrorTypeExitStackFAILEDGetGetAllGetMachineIdGetManagedObjectsHandlerTypeINTERNAL_ERRORINVALID_SIGNATUREInterfacesAddedInterfacesRemovedIntrospectInvalidAddressError_LOGGERMETHOD_CALLMETHOD_RETURNMessageMessageFlagMessageType_Message_MethodNONENOT_SUPPORTEDNO_REPLY_EXPECTEDNameFlagNameOwnerChangedNodeNonePROPERTY_READ_ONLYPing_PropertyProxyObject_ProxyObject__Pyx_PyDict_NextRefReleaseNameReleaseNameReplyRemoveMatchRequestNameRequestNameReplySESSIONSHUT_RDWRSIGNALSOCK_STREAMSendReplyServiceInterfaceSetTYPE_CHECKINGUNKNOWN_INTERFACEUNKNOWN_METHODUNKNOWN_OBJECTUNKNOWN_PROPERTYVariantabstractaccess_add_busadd_match_notify_add_match_rule_add_match_rule.<locals>.add_match_notifyadd_message_handlerappend_as_messageassert_bus_name_validassert_object_path_validasyncio.coroutines_block_unexpected_replybodyboolbus_address_bus_addressbus_namebus_type_callcallback_callback_method_handlercheck_callback_type_check_callback_type_check_method_returnchild_namechild_pathchildrenclearcline_in_tracebackclosecollections.abcconnectconstantscontextlibdbus_fast.message_busdebugdefault_default_get_machine_id_handler_default_get_machine_id_handler.<locals>.reply_handler_default_get_managed_objects_handler_default_get_managed_objects_handler.<locals>.is_result_complete_default_get_managed_objects_handler.<locals>.get_all_properties_callback_default_introspect_handler_default_ping_handler_default_properties_handler_default_properties_handler.<locals>.get_property_callback_default_properties_handler.<locals>.set_property_callback_default_properties_handler.<locals>.get_all_properties_callbackdestination__dict___dictdisableddisconnect_disconnectede_emit_interface_added_emit_interface_added.<locals>.get_properties_callback_emit_interface_removedencode__enter__enter_contextenumerateerrerrorerror_handlederror_texterrorsetreeexc_infoexception__exit__exportexport_path_fdfileno_finalizeflagsfn_signatureformat_exc_from_messagefromkeys__func__functoolsgetgetLoggerget_all_properties_callback_get_""all_property_valuesget_bus_address_get_propertiesget_properties_callbackget_property_callback_get_property_valueget_proxy_object__getstate__hhandlerhandler_signature_high_level_client_initializedhostiifaces_init_high_level_client_init_high_level_client.<locals>.add_match_notifyinspectinterfaceinterface_name_interface_signal_notifyinterfacesintrintrospect_introspect_export_pathintrospect.<locals>.reply_notifyintrospectionio_is_coroutineis_result_completeitemslogginglstrip_machine_id__main___make_method_handlermakefilematchmatch_rule_match_rulesmaxsplitmembermessagemessage_typemethod_method_return_handlersmethods__module__msgnname__name___name_owner_match_rule_name_ownersnegotiate_unix_fd_negotiate_unix_fd__new__new_errornew_method_returnnew_signalnext_serialnodenodesoaspparametersparseparse_addresspartialpath_path_exportspoppop_allport_private.address_private.util_process_messagepropprop_nameprop_setterprop_valuepropertiesproxy_object__pyx_capi____pyx_checksum__pyx_result__pyx_state__pyx_type__pyx_unpickle_BaseMessageBus__pyx_vtable____qualname__readable__reduce____reduce_cython____reduce_ex__release_namerelease_name.<locals>.reply_notify_remove_busremove_match_notify_remove_match_rule_remove_match_rule.<locals>.remove_match_notifyremove_message_handlerremoved_interfaceremoved_interface_namesremoved_interfacesreplace_fds_with_idxreplace_idx_with_fdsreplyreply_handler_reply_notifyreply_notifyreply_serialrequest_namerequest_name.<locals>.reply_notifyresultresult_signaturereturnrwbsselfsendsend_error_send_machine_id_replysend_reply_serialservice__set_name__set_property_callback_set_property_valuesetblockingsetdefault__setstate____setstate_cython__shutdownsignature__slots___socksocketsplitssssvstartswithstatestaticmethodstr_streamsutcp__test__texttostringtracebacktypinguunexportunique_nameunixunix_fdsupdateuse_setstateuser_data_user_disconnect_user_message_handlersvvalidate_property_namesvalidatorsvaluevalueswarningwritablexml.etree.ElementTreePyObject *\000\000\000\000""\000PACKED_BOOL_FALSE\000PACKED_BOOL_TRUE\000PACKED_UINT32_ZERO\000PACK_UINT32\000get_signature_treePyObject *(PyObject *, int __pyx_skip_dispatch)\000\000get_bus_address\000parse_addressPyObject *\000\000\000\000\000\000\000\000\000\000int\000unsigned int\000BLOCK_UNEXPECTED_REPLY\000DBusError\000MESSAGE_TYPE_CALL\000MESSAGE_TYPE_SIGNAL\000MessageFlag\000MessageType\000NONE\000NO_REPLY_EXPECTED\000assert_bus_name_valid\000assert_object_path_valid\000TYPE_CHECKING\000NO_REPLY_EXPECTED_VALUEPyObject *\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000struct __pyx_obj_9dbus_fast_9signature_SignatureTree *\000\000\000\000ErrorType\000HEADER_DESTINATION\000HEADER_ERROR_NAME\000HEADER_INTERFACE\000HEADER_MEMBER\000HEADER_PATH\000HEADER_REPLY_SERIAL\000HEADER_SENDER\000HEADER_SIGNATURE\000HEADER_UNIX_FDS\000LITTLE_ENDIAN\000MESSAGE_FLAG\000MESSAGE_FLAG_NONE\000MESSAGE_TYPE_METHOD_CALL\000MessageType\000PROTOCOL_VERSION\000get_signature_tree\000SIGNATURE_TREE_G\000SIGNATURE_TREE_O\000SIGNATURE_TREE_S\000SIGNATURE_TREE_UPyObject *\000unquote\000int (struct __pyx_obj_9dbus_fast_7message_Message *)\000_expects_reply\320\004\033\320\033+\2501\360\034\000\t!\240\001\240\021\330\010\013\2104\210z\230\021\230+\240Q\330\014\022\220)\2301\230A\340\010\013\2105\220\007\220t\2301\330\014\020\220\016\230a\230x\240q\330\r\026\220f\230C\230t\240>\260\021\260!\330\014\022\220*\230A\330\020X\320Xa\320ab\320bk\320kl\360\006\000\t\031\230\t\240\021\240+\250V\2604\260q\330\010\014\210N\230!\2305\240\001\240\031\250)\2601\330\010\014\320\014\"\240!\2406\250\021\210\001\330\0271\260\033\270J\300a\330\r\016\330\014\r\330\014\017\210t\2207\230!\330\020\023\2204\220q\330\024$\240A\330\024\036\230k\250\021\250!\330\020\021\340\014\022\220!\2205\230\001\230\031\240)\2501\340\014\017\320\017!\240\021\330\020\032\230!\2307\320\"4\260A\260U\320:L\310A\310Q\320\004\035\320\0352\260!\360\006\000\t\014\2104\210q\330\014\r\340\010\014\320\014\035\230Q\340\010\014\210H\220F\230!\330\010""\014\210F\220&\230\001\340\010\014\210K\220t\320\0333\2607\270!\330\014\r\330\020\027\220q\230\006\230a\330\023\024\330\020\027\220x\230q\330\024H\310\t\320QR\360\006\000\t\r\320\014$\240F\250!\340\010\014\210H\220D\230\001\230\024\230Q\330\014\020\220\t\230\021\230!\340\010\014\320\014#\2406\250\021\320\004)\250\021\360\010\000\t\014\2104\210q\330\014\r\330\010\014\320\014.\250a\340\010\035\230U\320\"2\260%\3207L\310A\360\024\000\t\r\210F\220!\330\014\023\2201\330\020\034\230A\330\020\032\230!\330\020\025\220Q\330\020\027\220q\330\020\032\230!\330\020\025\220Q\220d\230!\340\014\r\220\001\330\037 \330\032\033\330 !\330\031\032\330\025\026\330\024\025\330\030\033\2304\230w\240a\330\034&\240k\260\021\260!\330\034\035\340\030\036\230k\320)=\270Q\330\034 \240\014\250A\250Q\360\006\000\031#\240!\330\034#\320#5\260Q\330 !\330 !\330 !\240\027\250\001\250\024\250\\\270\024\270Q\270a\330 )\250\021\360\006\000\025\034\230=\250\001\330\030\"\240+\250Q\250a\320\010 \320 5\3205J\310!\330\014\r\330\020\036\320\0363\2601\260G\2705\300\001\330\020\031\230\024\230U\240&\250\001\330\024\031\230\025\230a\230q\330\024,\250A\340\014\023\220=\240\001\330\020\030\230\001\230\026\230q\330\020\021\340\014\024\220A\220X\230Q\320\010 \320 5\3205J\310!\330\014\r\330\020\036\320\0363\2601\260G\2705\300\001\330\020\031\320\031)\250\021\250%\250u\260A\260Q\330\014\023\220=\240\001\330\020\030\230\001\230\026\230q\330\020\021\340\014\024\220A\220X\230Q\320\000#\240=\260\001\360\016\000\005\014\2106\220\021\330\010\t\360\006\000\t\n\320\010!\320!6\3206K\3101\330\014\017\210t\2203\220f\230C\230q\340\020\021\340\014\017\210u\220N\240#\240[\260\001\330\020\024\220O\2405\250\005\250Q\250a\330\020\024\320\024+\2501\250E\260\021\340\020\025\220^\2403\240k\260\027\270\004\270E\300\034\310W\320TU\340\020\032\230!\2307\240*\250A\250U\260%\260}\300C\300q\310\005\310Q\340\020\032\230!\330\024\033\230:\240Q\240e\2509\260I\270Q\220\001\330\0377\3207G\300q\330\025\026\330\024\027\220t\2307\240!\330\030\"\240+""\250Q\250a\330\030\031\330\024\036\230a\230w\320&8\270\001\270\021\320\010\"\320\"7\3207L\310A\330\014\017\210q\330\020\027\220v\230Q\330\0247\260q\270\004\320<W\320WX\320XY\340\021\025\220W\230E\240\024\240S\250\016\260c\270\033\300A\330\020\027\220v\230Q\330\0247\260q\270\004\320<W\320WX\320X[\320[`\320`a\320ab\320\010\"\320\"7\3207L\310A\330\014\017\210q\330\020\027\220v\230Q\320\036A\300\021\300.\320PQ\320QR\330\021\025\220W\230E\240\024\240S\250\016\260c\270\033\300A\330\020\027\220v\230Q\330\0247\260q\270\016\300a\300s\310%\310q\320PQ\320\004\030\230\014\240A\360\014\000\t\017\320\016!\240\021\330\014\r\200\001\330\004,\250A\250V\2601\200A\330\023(\250\001\330\t\n\330\010\033\2301\330\010\030\230\001\340\010$\240A\360\024\000\t\014\2101\330\014\023\2203\220f\230G\2401\340\010\020\220\001\330\014\r\330\014\020\220\010\230\004\230A\330\014\017\210s\220&\230\003\2304\230s\240$\240k\260\021\260#\260V\2702\270Q\360\010\000\t-\250A\330\014\022\220$\220i\230q\240\004\240N\260!\2607\270$\270h\300a\360\006\000\t\014\320\013\035\230Q\330\014\026\220a\220w\320\0360\260\001\260\025\3206H\310\001\310\021\330\014\r\340\010\t\330\014\027\320\027)\250\030\260\025\260f\270E\300\025\300a\330\r\016\360\032\000\t\r\210H\220A\330\014\020\220\r\230T\240\036\250q\260\005\260W\270A\330\020 \320 9\270\021\330\024\037\320\037<\270A\200A\340\023\024\330\020\021\330\r\016\330\024\025\360\006\000\t\020\320\017\037\320\0373\2601\260H\270C\270\177\310c\320QR\330\010\021\220\026\220s\230!\230<\240q\330\010\013\210;\220c\320\0310\260\003\260>\300\021\300%\300s\310!\330\014\r\330\010#\320#8\270\001\330\014\r\330\014\022\220!\330\014\020\220\001\340\010\022\220!\330\014\023\2201\330\020\035\230[\250\001\330\020\035\230S\240\001\330\020\034\230C\230q\330\020\032\230&\240\001\330\020\025\220X\230Q\230a\330\020\031\230\030\240\021\240!\200A\330\0313\2601\330\t\n\330\010\017\210w\220a\220t\320\0336\260k\300\021\200A\330'4\260A\360\006\000\t\020\210q\340\010\013\2104\210x\220q\230\001\330\014\022""\220)\2301\230A\340\010\027\220w\230j\250\001\250\021\330\010\013\2103\210a\210|\230=\250\003\2501\330\014\022\220)\2301\230A\320\004\034\230A\360\n\000\t\r\320\014 \240\001\330\010\013\2104\210q\330\014\r\330\020\024\220F\230)\2401\240F\250!\330\023\024\330\020\027\220x\230q\320 >\270i\300q\200A\330\023(\250\001\330\t\n\330\010\013\2104\210q\330\014\020\320\020'\240q\250\005\250Q\330\014\r\340\010\032\230'\320!1\260\025\3206K\3101\360\"\000\t\r\210F\220!\330\014\023\2201\330\020\034\230A\330\020\025\220Q\330\020\032\230!\330\020\027\220q\340\014\r\200A\340\r\016\330\022\023\340\010\013\2104\210s\220!\330\014\017\210z\230\024\230\\\250\021\360\014\000\t\r\210O\2303\230n\250A\250V\2604\260y\300\007\300q\330\014\020\320\020(\250\001\250\023\250K\260w\270a\330\020\024\320\024$\240E\250\021\360\006\000\t\r\210E\220\021\220!\340\010\013\2104\210\177\230d\240)\2507\260!\330\014\024\220A\220V\2301\210A\330\033\034\330\030\031\330\033\034\330\025\026\330\021\022\330\020\023\2204\220w\230a\330\024\036\230k\250\021\250!\330\024\025\330\020\026\220k\320!5\260Q\260i\270q\300\001\330\020\032\230!\330\024\033\320\033-\250Q\250e\2609\270F\300)\3101\200A\340\r\016\330\022\023\330\017\020\330\r\016\330\t\n\340\010\013\2106\220\024\220S\230\r\240T\250\025\250a\330\014\020\220\r\230Q\230c\320!1\260\025\260a\330\010\020\220\001\220\027\230\001\200A\330\030#\320#7\260q\330\t\n\360.\000\t\014\2104\210~\230S\240\001\330\014\022\220)\2301\330\020\021\360\006\000\t\r\320\014$\240A\340\010\017\210t\220=\240\001\240\032\2506\260\037\300\001\200A\340\022\023\330\016\017\330\022\023\330\035$\240A\330!(\250\001\330\t\n\360.\000\t\014\2101\330\014\032\320\032/\250q\260\001\340\010\031\230\027\320 0\260\005\3205J\310!\360\032\000\t\r\210F\220!\330\014\023\2201\330\020\034\230A\330\020\025\220Q\330\020\032\230!\330\020\027\220q\340\014\r\200A\330\027\030\330\t\n\360\020\000\t\r\210C\210u\220I\230Q\230d\240!\330\014\017\210r\220\023\220A\330\020\024\220D\320\030/\250q\260\001\330\020\021\200A\330""\024$\320$D\300A\330\t\n\360\034\000\t!\240\001\240\021\340\010\013\210:\220S\230\001\330\014\035\230Q\330\r\021\220\021\220+\230S\240\001\330\014\035\230Q\330\r\027\220q\230\013\2401\330\014\035\230Y\240a\340\014\022\220)\2301\330\020M\310Q\310d\320RS\320ST\360\006\000\t\r\210K\220s\230$\230n\250D\260\001\260\027\270\003\2701\330\014\r\330\010-\250Q\340\010\013\210?\230'\240\021\330\014\020\320\020\"\240#\240Z\250t\2601\3204D\300G\3103\310a\330\020\021\330\014#\2407\250!\2501\330\014\017\210t\2201\330\020\024\220D\230\016\240a\240q\330\014\034\230L\250\001\320)<\270A\340\014\020\220\004\220N\240!\2401\330\014\020\320\020%\240Z\250w\260a\330\020'\240w\250a\320/@\300\001\330\020 \240\014\250A\320-@\300\001\340\010\014\320\014$\240A\240V\2501\320\004$\240A\340\010\022\220!\330\010\014\320\014\034\230D\240\001\330\014\r\330\020\023\2207\230#\230\\\250\021\250!\330\024\027\220t\2301\230H\240C\240q\330\030\034\230E\240\021\240!\330\024\036\230a\330\024\025\330\014\023\220=\240\001\330\020\023\2203\220n\240C\240q\330\024\030\230\005\230Q\230a\230|\2501\250A\330\024\036\230a\330\024\025\330\020\027\220z\240\021\320\"O\310q\330\014\023\220=\240\001\330\020\027\220z\240\021\320\"O\310q\330\020\023\2203\220n\240C\240q\330\024\030\230\005\230Q\330\030\037\230z\250\021\330\034\035\330\034%\240Q\330\034:\270!\2705\300\001\300\031\310+\320UV\360\006\000\025\037\230a\330\024\025\340\010\013\2103\210n\230C\230q\330\014\r\330\020\023\2208\2303\230a\330\020\024\220C\220x\230s\240!\330\020\024\220C\220v\230S\240\001\330\020\024\220C\220{\240#\240Q\340\020\027\220s\230%\230q\240\001\330\020\023\220:\230S\240\003\2405\250\001\250\021\330\024\030\230\r\240Q\240h\250a\330\025\032\230#\230T\240\021\330\024\030\230\004\230M\250\021\250!\330\014\r\340\010\013\2103\210n\230C\230q\330\014\017\210t\2201\330\020\032\230$\320\0364\260A\260Q\330\020\023\2204\220~\240Q\240a\330\024\027\220q\330\030\037\230q\240\005\240Q\340\030\037\230v\240Q\330\034\035\330\034\037\230q\330\034\037\230q\330\034""\037\230q\340\024\025\340\020\035\230Y\240a\240v\250Q\330\025\026\330\024\027\220q\330\030\037\230q\240\005\240Q\340\030\"\240!\330\034#\240:\250Q\330 !\330 )\250\021\330 \"\240!\2403\240l\260!\2603\260a\330 #\2401\240C\240q\360\006\000\r\016\360\006\000\t\032\230\024\320\0355\260T\270\021\270#\270Q\330\010\013\210?\230'\240\021\330\014\017\210t\2201\330\020\036\230a\230u\240A\330\014\020\220\004\320\024,\250A\250S\260\001\200A\340\016\017\330\017\032\230(\240!\330\022\023\330JK\330\035$\240A\330\t\n\360\034\000\t\036\230Q\230a\340\010\013\2109\220G\2305\240\004\240A\330\014\032\320\032/\250q\260\001\340\010\013\2104\210q\220\007\220w\230a\330\014\024\220H\230A\230Q\340\010\022\220'\230\021\330\014\030\230\001\330\014\021\220\021\330\014\026\220a\330\014\023\2201\330\014\026\220a\330\014\021\220\021\220&\230\001\360\006\000\t\014\2109\220C\220q\330\014\020\220\006\220a\220y\240\001\330\014\r\340\010\031\230\027\320 0\260\005\3205J\310!\360\024\000\t\r\210F\220!\2209\230A\200A\340\016\017\330\022\023\330JK\330\035$\240A\330\t\n\360\032\000\t\036\230Q\230a\340\010\013\2109\220G\2305\240\004\240A\330\014\032\320\032/\250q\260\001\340\010\022\220'\230\021\330\014\030\230\001\330\014\021\220\021\330\014\026\220a\330\014\023\2201\330\014\026\220a\330\014\021\220\021\220!\360\006\000\t\014\2109\220C\220q\330\014\020\220\006\220a\220y\240\001\330\014\r\340\010\031\230\027\320 0\260\005\3205J\310!\360\024\000\t\r\210F\220!\2209\230A\200A\360\020\000\t\r\210L\230\001\330\010\017\210t\2201\200A\330\027\030\330\t\n\360\032\000\t\026\220Q\330\010\013\2104\210x\220q\230\001\330\014\022\220)\2301\230A\340\010\034\230G\240:\250Q\250a\330\010\013\2103\210a\320\017 \240\r\250S\260\001\330\014\022\220)\2301\230A\340\010\014\320\014#\2407\250!\2501\200A\340\023\024\330\030\031\330\020\021\330\023\024\330\016\017\330\022\036\230a\330\t\n\330\010\033\2301\330\010\014\210C\210z\230\024\230^\2506\260\021\330\014\020\220\005\220V\2307\240!\330\020\023\2202\220S\230\001\330\024\033\2301\340""\010\013\2105\220\003\2201\330\014\022\220)\2301\330\020\021\360\006\000\t\r\210E\220\021\330\014\023\220;\230a\330\020\025\220Q\330\020\032\230!\330\020\027\220q\330\020\032\230!\330\020\025\220Q\330\020\031\230\021\200A\340\r\"\320\"?\270q\330\t\n\330\010\013\2101\330\014\022\220!\330\010\013\2104\210s\220!\330\014\022\220)\2301\330\020\031\320\031*\320*R\320RS\340\010\013\2103\210n\230C\230{\250/\270\024\270S\300\013\3103\310a\330\014\r\330\010\013\2103\210n\230C\230{\250!\330\014\022\220)\230>\250\021\250!\330\010\016\210i\220q\330\014\025\320\025&\320&N\310a\320\010$\240A\330\014\017\210t\2201\330\020\027\220q\330\014\020\220\003\220>\240\026\240v\250Q\330\020\024\220I\230Z\240w\250a\330\024\027\220v\230S\240\001\330\030\037\230q\340\014\023\2201\320\004/\320/D\300N\320RS\330\010\013\2101\330\014\023\2203\220f\230G\2401\330\010\030\230\004\320\0344\260A\260S\270\006\270i\300q\330\010\022\220!\2207\320\032,\250A\250U\260%\260q\270\001\320\004/\320/D\300N\320RS\330\010\023\2207\230&\240\007\240w\250j\270\001\330\010\013\2103\210h\220g\230X\240S\250\007\250q\260\003\2609\270C\270s\300!\330\014\022\220)\2301\330\020\031\230\021\330\020=\270Q\270c\320A[\320[\\\320\\_\320_`\360\006\000\t\032\230\023\230E\240\021\240!\330\010\013\210?\230#\230Q\330\014\022\220)\2301\330\020\031\230\021\330\020\021\360\006\000\t\014\2103\210f\220G\2304\230q\330\014\022\220)\2301\330\020\031\320\031*\320*D\300A\300S\310\001\360\006\000\t\r\210J\220c\230\024\230^\2501\250C\250v\260T\270\021\320:K\3103\310a\330\014\017\210\177\230a\330\020\021\330\020\021\330\020\021\330\020\021\360\006\000\021\024\2203\220h\230c\240\026\240s\250#\250X\260S\270\001\330\024 \240\003\2405\250\001\250\021\330\024\032\230)\2401\330\030!\240\021\330\030%\240Q\320&O\310q\320PQ\340\020\023\2203\220h\230c\240\021\330\024\036\230a\230w\320&8\270\001\270\025\270i\300q\310\001\330\024\025\330\020\027\220q\330\014\022\220)\2301\330\020\031\230\021\330\020/\250q\3200K\3101\310C\310q\360\006\000\t\026\320\025%\320%5""\260Q\260a\340\010\013\2103\210h\220c\230\026\230s\240#\240X\250S\260\001\330\014\030\230\003\2305\240\001\240\021\330\014\024\220A\330\020\021\330\020\024\220H\230A\330\020\023\2204\220v\230S\240\n\250$\250d\260$\260a\340\014\017\210t\2201\330\020\026\220i\230q\330\024\035\230Q\330\024!\240\021\320\"K\3101\310A\360\006\000\r\024\2205\230\001\230\021\330\014\017\210s\220(\230#\230Q\330\020\023\2204\220t\2307\240)\2501\330\024\032\230)\2401\330\030!\240\021\330\030\031\360\006\000\021\022\330\024\037\230q\330\024\032\230!\330\024 \240\001\330\024\031\230\021\330\025\026\360*\000\021!\320 4\260A\330\024\037\230v\240Q\360\006\000\022\025\220H\230C\230q\330\020\023\2204\220t\2307\240)\2501\330\024\032\230)\2401\330\030!\320!6\260a\340\020\030\230\003\2305\240\001\240\021\330\020\023\2205\230\013\2403\240d\250!\330\024\032\230)\2401\330\030!\240\021\330\030B\300!\3004\300q\340\020\027\220t\2301\340\020\021\330\024\037\320\0371\260\026\260{\300%\300q\330\025\026\360\014\000\021\030\320\027+\2501\330\024\031\230\034\240Q\240e\2509\260C\260q\340\020 \320 4\260A\330\024\037\230v\240T\250\021\250$\250a\360\006\000\016\021\220\010\230\003\2301\340\014\r\330\020\033\2301\330\020\030\230\001\330\020\033\2301\330\020\025\220Q\330\021\022\360\022\000\r\035\320\0345\260Q\330\020\033\2301\360\010\000\r\024\2201\320\004,\320,E\300^\320ST\360\026\000\t\014\2104\210q\330\014\r\340\010\014\210E\220\021\330\014\023\220;\230a\330\020\025\220Q\330\020\032\230!\330\020\027\220q\330\020\032\230!\330\020\025\220Q\220f\230A\320\004,\250H\260A\330\010 \240\001\240\021\340\010\014\210K\220s\230$\230n\250D\260\001\260\027\270\007\270q\330\014\023\2204\220u\230H\240A\240Q\330\014\020\220\r\230Z\240w\250a\330\020\024\220K\230w\240a\240y\260\013\2701\340\014\023\2204\220u\230A\230Q\340\010\026\220a\340\010\014\210O\2304\230q\330\014\017\210t\220;\230k\250\021\250!\330\020\021\340\014\031\230\033\240F\250!\2506\260\031\270\"\270A\270Q\330\014\017\210u\220C\220t\2304\230{\250$\250j\270\001\270\023""\270C\270q\330\020\021\340\014\031\230\032\2407\250!\2501\330\014\031\230\032\2406\250\021\250%\250y\270\002\270!\2701\340\014\024\220D\230\001\230\021\340\010\014\210I\220Q\220d\230%\230q\240\006\240d\250(\260)\2703\270a\340\010\017\210q\320\004*\320*:\320:O\310q\360\030\000\t\014\2104\210q\330\014\r\340\010\t\330\014\027\220q\330\014\024\220A\330\014\027\220q\330\014\017\210q\330\r\016\3600\000\t\031\320\0301\260\021\260+\270Q\320\010%\320%:\320:O\310q\330\014\017\210t\2201\330\020\021\340\014\017\210q\330\020\027\220v\230Q\330\024:\270!\270>\310\021\310!\340\021\025\220W\230E\240\024\240S\250\016\260c\270\033\300A\330\020\027\220v\230Q\330\024:\270!\270>\310\021\310#\310U\320RS\320ST\320\004*\320*?\270~\310Q\330\010\022\220!\2207\320\032,\250A\250U\260%\260q\270\004\270A\200\001\360\010\000\005\016\210T\220\037\240\004\240O\2604\3207G\300t\3106\320QU\320Uv\320vz\360\000\000{\001I\002\360\000\000I\002M\002\360\000\000M\002\\\002\360\000\000\\\002`\002\360\000\000`\002z\002\360\000\000z\002~\002\360\000\000~\002W\003\360\000\000W\003[\003\360\000\000[\003j\003\360\000\000j\003n\003\360\000\000n\003C\004\360\000\000C\004G\004\360\000\000G\004W\004\360\000\000W\004[\004\360\000\000[\004e\004\360\000\000e\004i\004\360\000\000i\004q\004\360\000\000q\004u\004\360\000\000u\004\177\004\360\000\000\177\004C\005\360\000\000C\005V\005\360\000\000V\005Z\005\360\000\000Z\005s\005\360\000\000s\005w\005\360\000\000w\005x\005\330\004\014\210G\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220t\230>\250\027\260\005\260S\270\004\270N\310'\320QV\320VY\320Y]\320]b\320bi\320in\320nq\320qu\360\000\000v\001V\002\360\000\000V\002]\002\360\000\000]\002b\002\360\000\000b\002e\002\360\000\000e\002i\002\360\000\000i\002v\002\360\000\000v\002}\002\360\000\000}\002B\003\360\000\000B\003E\003\360\000\000E\003I\003\360\000\000I\003W\003\360\000\000W\003^\003\360\000\000^\003c\003\360\000\000c\003f\003\360\000\000f\003j\003\360\000\000j""\003C\004\360\000\000C\004J\004\360\000\000J\004O\004\360\000\000O\004R\004\360\000\000R\004V\004\360\000\000V\004n\004\360\000\000n\004u\004\360\000\000u\004z\004\360\000\000z\004}\004\360\000\000}\004A\005\360\000\000A\005O\005\360\000\000O\005V\005\360\000\000V\005[\005\360\000\000[\005^\005\360\000\000^\005b\005\360\000\000b\005q\005\360\000\000q\005x\005\360\000\000x\005}\005\360\000\000}\005@\006\360\000\000@\006D\006\360\000\000D\006M\006\360\000\000M\006T\006\360\000\000T\006Y\006\360\000\000Y\006\\\006\360\000\000\\\006`\006\360\000\000`\006g\006\360\000\000g\006n\006\360\000\000n\006s\006\360\000\000s\006v\006\360\000\000v\006z\006\360\000\000z\006C\007\360\000\000C\007J\007\360\000\000J\007O\007\360\000\000O\007R\007\360\000\000R\007V\007\360\000\000V\007h\007\360\000\000h\007o\007\360\000\000o\007t\007\360\000\000t\007w\007\360\000\000w\007{\007\360\000\000{\007S\010\360\000\000S\010Z\010\360\000\000Z\010_\010\360\000\000_\010b\010\360\000\000b\010f\010\360\000\000f\010s\010\360\000\000s\010z\010\360\000\000z\010{\010\330\004\007\200q\330\010\017\320\017/\250t\2601\260G\270;\300g\310Q\340\010\017\320\017/\250t\2601\260G\270;\300a\320\004-\250X\260Q\360\006\000\t\014\210;\220c\230\024\230Q\330\014\r\340\010\013\210;\220c\230\024\230Q\330\014\020\220\r\230Q\230o\250Q\330\014\017\210t\220=\240\001\240\034\250R\250q\330\020\021\340\010\014\210D\220\r\230Q\230a\340\010 \240\005\320%5\260U\320:O\310q\360\032\000\t\r\210F\220!\330\014\023\2201\330\020\034\230A\330\020\032\230!\330\020\025\220Q\330\020\027\220q\330\020\032\230!\330\020\025\220Q\220a\340\014\r\320\004*\250(\260!\360\010\000\t\014\210;\220c\230\024\230Q\330\014\r\340\010\013\210;\220c\230\024\230Q\330\014\020\220\r\230Q\230o\250Q\330\014\r\340\010\014\210M\230\021\230.\250\001\340\010\035\230U\320\"2\260%\3207L\310A\360\020\000\t\r\210F\220!\330\014\023\2201\330\020\034\230A\330\020\032\230!\330\020\025\220Q\330\020\027\220q\330\020\032\230!\330\020\025\220Q\220a\340\014\r\320\004)\320)>\270n\310A""\330\010\022\220!\2207\320\032,\250A\250Q\200\001\340\004\037\230q\320 0\260\013\270;\300k\320QR\330\004\023\220>\240\030\250\021\250!\330\004\007\200|\2207\230!\330\0100\260\001\3201B\300.\320PQ\330\004\013\2101\210\001\330\027\030\330\024\025\330\027\030\330\017\020\330\r\016\330\014\017\210r\220\027\230\001\330\020\021\330\024\032\230!\330\027\030\330\024\033\2306\240\021\330\030\031\340\030!\240\021\330\030!\240\021\360\006\000\r\025\220I\230W\240A\340\014\020\220\005\220Q\330\020\027\220{\240!\330\024\031\230\021\330\024\036\230a\330\024\033\2301\330\024\036\230a\330\024\031\230\021\230&\240\001";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 446; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 88) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 446; i < 501; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 501; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 446;
      for (Py_ssize_t i=0; i<55; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab + 0;
    int8_t const cint_constants_1[] = {0,1};
    int32_t const cint_constants_4[] = {164667464L};
    for (int i = 0; i < 3; i++) {
      numbertab[i] = PyLong_FromLong((i < 2 ? cint_constants_1[i - 0] : cint_constants_4[i - 2]));
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_number_tab;
    for (Py_ssize_t i=0; i<3; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 3;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 5;
    unsigned int flags : 10;
    unsigned int first_line : 11;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 294};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_reply, __pyx_mstate->__pyx_n_u_err, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_e};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_reply_notify_2, __pyx_mstate->__pyx_kp_b_iso88591_55J_31G5_U_aq_A_q_AXQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 332};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_interface, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_user_data, __pyx_mstate->__pyx_n_u_e, __pyx_mstate->__pyx_n_u_body};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_get_properties_callback, __pyx_mstate->__pyx_kp_b_iso88591_r_6_IWA_Q_a_1_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 429};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_reply, __pyx_mstate->__pyx_n_u_err, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_e};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_reply_notify_2, __pyx_mstate->__pyx_kp_b_iso88591_55J_31G5_uAQ_q_AXQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 478};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_reply, __pyx_mstate->__pyx_n_u_err, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_e};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_reply_notify_2, __pyx_mstate->__pyx_kp_b_iso88591_55J_31G5_uAQ_q_AXQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1004};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_reply, __pyx_mstate->__pyx_n_u_err};
    __pyx_mstate_global->__pyx_codeobj_tab[4] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_reply_handler, __pyx_mstate->__pyx_kp_b_iso88591_66K1_t3fCq_uN_O5_Qa_1E_3k_E_WTU, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[4])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {0, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1037};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_n, __pyx_mstate->__pyx_n_u_interfaces, __pyx_mstate->__pyx_n_u_value};
    __pyx_mstate_global->__pyx_codeobj_tab[5] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_is_result_complete, __pyx_mstate->__pyx_kp_b_iso88591_A_t1_q_vQ_IZwa_vS_q_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[5])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1065};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_interface, __pyx_mstate->__pyx_n_u_values, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_err};
    __pyx_mstate_global->__pyx_codeobj_tab[6] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_get_all_properties_callback, __pyx_mstate->__pyx_kp_b_iso88591_1_Ja_t7_4q_A_k_5_1_7_4AU_LAQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[6])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1152};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_interface, __pyx_mstate->__pyx_n_u_prop, __pyx_mstate->__pyx_n_u_prop_value, __pyx_mstate->__pyx_n_u_err, __pyx_mstate->__pyx_n_u_body, __pyx_mstate->__pyx_n_u_unix_fds, __pyx_mstate->__pyx_n_u_e};
    __pyx_mstate_global->__pyx_codeobj_tab[7] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_get_property_callback, __pyx_mstate->__pyx_kp_b_iso88591_4wa_k_k_Q_AQ_5Q_Qa_Qa, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[7])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1195};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_interface, __pyx_mstate->__pyx_n_u_prop, __pyx_mstate->__pyx_n_u_err};
    __pyx_mstate_global->__pyx_codeobj_tab[8] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_set_property_callback, __pyx_mstate->__pyx_kp_b_iso88591_77Gq_t7_Qa_aw_8, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[8])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1212};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_interface, __pyx_mstate->__pyx_n_u_values, __pyx_mstate->__pyx_n_u_user_data, __pyx_mstate->__pyx_n_u_err, __pyx_mstate->__pyx_n_u_body, __pyx_mstate->__pyx_n_u_unix_fds};
    __pyx_mstate_global->__pyx_codeobj_tab[9] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_get_all_properties_callback, __pyx_mstate->__pyx_kp_b_iso88591_A_4wa_k_k_5Qiq_Qe9F_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[9])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1241};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_err};
    __pyx_mstate_global->__pyx_codeobj_tab[10] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_add_match_notify, __pyx_mstate->__pyx_kp_b_iso88591_77LA_q_vQ_7q_WWXXY_WE_S_c_A_vQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[10])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1276};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_err};
    __pyx_mstate_global->__pyx_codeobj_tab[11] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_add_match_notify, __pyx_mstate->__pyx_kp_b_iso88591_77LA_q_vQ_A_PQQR_WE_S_c_A_vQ_7q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[11])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1309};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_err};
    __pyx_mstate_global->__pyx_codeobj_tab[12] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_remove_match_notify, __pyx_mstate->__pyx_kp_b_iso88591_Oq_t1_q_vQ_WE_S_c_A_vQ_URSST, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[12])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 58};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_reply};
    __pyx_mstate_global->__pyx_codeobj_tab[13] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_block_unexpected_reply, __pyx_mstate->__pyx_kp_b_iso88591_6, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[13])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 184};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_path, __pyx_mstate->__pyx_n_u_interface};
    __pyx_mstate_global->__pyx_codeobj_tab[14] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_export, __pyx_mstate->__pyx_kp_b_iso88591_1_4z_Q_1A_5_t1_axq_fCt_A_XXaabb, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[14])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 213};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_path, __pyx_mstate->__pyx_n_u_interface, __pyx_mstate->__pyx_n_u_interface_name, __pyx_mstate->__pyx_n_u_removed_interface_names, __pyx_mstate->__pyx_n_u_removed_interface, __pyx_mstate->__pyx_n_u_interfaces};
    __pyx_mstate_global->__pyx_codeobj_tab[15] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_unexport, __pyx_mstate->__pyx_kp_b_iso88591_A_DA_S_Q_S_Q_q_1_Ya_1_MQdRSST_Ks, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[15])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {6, 0, 0, 8, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 261};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_bus_name, __pyx_mstate->__pyx_n_u_path, __pyx_mstate->__pyx_n_u_callback, __pyx_mstate->__pyx_n_u_check_callback_type, __pyx_mstate->__pyx_n_u_validate_property_names, __pyx_mstate->__pyx_n_u_reply_notify_2, __pyx_mstate->__pyx_n_u_reply_notify_2};
    __pyx_mstate_global->__pyx_codeobj_tab[16] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_introspect, __pyx_mstate->__pyx_kp_b_iso88591_A_A_1_q_0_5J_F_1_A_Q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[16])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 317};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_path, __pyx_mstate->__pyx_n_u_interface, __pyx_mstate->__pyx_n_u_get_properties_callback, __pyx_mstate->__pyx_n_u_get_properties_callback};
    __pyx_mstate_global->__pyx_codeobj_tab[17] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_emit_interface_added, __pyx_mstate->__pyx_kp_b_iso88591_Oq_4q_q_A_q_q_0_1_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[17])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 363};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_path, __pyx_mstate->__pyx_n_u_removed_interfaces};
    __pyx_mstate_global->__pyx_codeobj_tab[18] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_emit_interface_removed, __pyx_mstate->__pyx_kp_b_iso88591_E_ST_4q_E_a_Q_q_QfA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[18])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {5, 0, 0, 8, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 387};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_flags, __pyx_mstate->__pyx_n_u_callback, __pyx_mstate->__pyx_n_u_check_callback_type, __pyx_mstate->__pyx_n_u_message, __pyx_mstate->__pyx_n_u_reply_notify_2, __pyx_mstate->__pyx_n_u_reply_notify_2};
    __pyx_mstate_global->__pyx_codeobj_tab[19] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_request_name, __pyx_mstate->__pyx_kp_b_iso88591_A_JK_A_Qa_9G5_A_q_4q_wa_HAQ_a_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[19])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 441};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_callback, __pyx_mstate->__pyx_n_u_check_callback_type, __pyx_mstate->__pyx_n_u_message, __pyx_mstate->__pyx_n_u_reply_notify_2, __pyx_mstate->__pyx_n_u_reply_notify_2};
    __pyx_mstate_global->__pyx_codeobj_tab[20] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_release_name, __pyx_mstate->__pyx_kp_b_iso88591_A_JK_A_Qa_9G5_A_q_a_1_a_9Cq_ay_0, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[20])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 490};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_bus_name, __pyx_mstate->__pyx_n_u_path, __pyx_mstate->__pyx_n_u_introspection};
    __pyx_mstate_global->__pyx_codeobj_tab[21] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_get_proxy_object, __pyx_mstate->__pyx_kp_b_iso88591_A_7q_4_S_1_A_t_6, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[21])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 524};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[22] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_disconnect, __pyx_mstate->__pyx_kp_b_iso88591_A_4q_F_1F_xq_iq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[22])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 536};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[23] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_next_serial, __pyx_mstate->__pyx_kp_b_iso88591_A_L_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[23])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 547};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_handler, __pyx_mstate->__pyx_n_u_error_text, __pyx_mstate->__pyx_n_u_handler_signature};
    __pyx_mstate_global->__pyx_codeobj_tab[24] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_add_message_handler, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_4xq_1A_G_Qa_3a_S_1A_7_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[24])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 572};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_handler, __pyx_mstate->__pyx_n_u_i, __pyx_mstate->__pyx_n_u_h};
    __pyx_mstate_global->__pyx_codeobj_tab[25] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_remove_message_handler, __pyx_mstate->__pyx_kp_b_iso88591_A_CuIQd_r_A_D_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[25])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 587};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_msg};
    __pyx_mstate_global->__pyx_codeobj_tab[26] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_send, __pyx_mstate->__pyx_kp_b_iso88591_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[26])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 597};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_err, __pyx_mstate->__pyx_n_u_handler, __pyx_mstate->__pyx_n_u_path};
    __pyx_mstate_global->__pyx_codeobj_tab[27] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_finalize, __pyx_mstate->__pyx_kp_b_iso88591_2_4q_Q_HF_F_Kt_37_q_a_xq_H_QR_F, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[27])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {7, 0, 0, 11, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 623};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_interface, __pyx_mstate->__pyx_n_u_interface_name, __pyx_mstate->__pyx_n_u_member, __pyx_mstate->__pyx_n_u_signature, __pyx_mstate->__pyx_n_u_body, __pyx_mstate->__pyx_n_u_unix_fds, __pyx_mstate->__pyx_n_u_path, __pyx_mstate->__pyx_n_u_p, __pyx_mstate->__pyx_n_u_ifaces, __pyx_mstate->__pyx_n_u_i};
    __pyx_mstate_global->__pyx_codeobj_tab[28] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_interface_signal_notify, __pyx_mstate->__pyx_kp_b_iso88591_A_a_1_Cz_6_V7_2S_1_5_1_1_E_a_Q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[28])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 10, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 654};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_path, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_interface, __pyx_mstate->__pyx_n_u_children, __pyx_mstate->__pyx_n_u_export_path, __pyx_mstate->__pyx_n_u_child_path, __pyx_mstate->__pyx_n_u_child_name, __pyx_mstate->__pyx_n_u_interfaces, __pyx_mstate->__pyx_n_u_name};
    __pyx_mstate_global->__pyx_codeobj_tab[29] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_introspect_export_path, __pyx_mstate->__pyx_kp_b_iso88591_HA_Ks_nD_q_4uHAQ_Zwa_Kway_1_4uA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[29])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {5, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 749};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_callback, __pyx_mstate->__pyx_n_u_reply, __pyx_mstate->__pyx_n_u_err};
    __pyx_mstate_global->__pyx_codeobj_tab[30] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_reply_notify, __pyx_mstate->__pyx_kp_b_iso88591_A_6_S_T_a_Qc_1_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[30])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 761};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_callback};
    __pyx_mstate_global->__pyx_codeobj_tab[31] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_call, __pyx_mstate->__pyx_kp_b_iso88591_A_4s_z_O3nAV4y_q_Kwa_E_E_4_d_7_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[31])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 783};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_callback, __pyx_mstate->__pyx_n_u_text, __pyx_mstate->__pyx_n_u_fn_signature};
    __pyx_mstate_global->__pyx_codeobj_tab[32] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_check_callback_type_2, __pyx_mstate->__pyx_kp_b_iso88591_A_4A_q_4xq_1A_wj_3a_1_1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[32])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 796};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_err, __pyx_mstate->__pyx_n_u_signature};
    __pyx_mstate_global->__pyx_codeobj_tab[33] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_check_method_return, __pyx_mstate->__pyx_kp_b_iso88591_A_q_1_4s_1_RRS_3nC_S_3a_3nC_iq_N, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[33])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 814};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_msg};
    __pyx_mstate_global->__pyx_codeobj_tab[34] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_process_message, __pyx_mstate->__pyx_kp_b_iso88591_A_D_7_t1HCq_E_a_3nCq_Qa_1A_a_z, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[34])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {5, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 894};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_interface, __pyx_mstate->__pyx_n_u_method, __pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_send_reply};
    __pyx_mstate_global->__pyx_codeobj_tab[35] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_callback_method_handler, __pyx_mstate->__pyx_kp_b_iso88591_A_31HC_cQR_s_q_c_0_s_8_1_S_Cq_XQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[35])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 922};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_interface, __pyx_mstate->__pyx_n_u_method};
    __pyx_mstate_global->__pyx_codeobj_tab[36] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_make_method_handler, __pyx_mstate->__pyx_kp_b_iso88591_A_31_wat_6k, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[36])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 985};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_send_reply, __pyx_mstate->__pyx_n_u_introspection};
    __pyx_mstate_global->__pyx_codeobj_tab[37] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_default_introspect_handler, __pyx_mstate->__pyx_kp_b_iso88591_DNRS_1_3fG1_4AS_iq_7_AU_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[37])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 991};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_send_reply};
    __pyx_mstate_global->__pyx_codeobj_tab[38] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_default_ping_handler, __pyx_mstate->__pyx_kp_b_iso88591_nA_7_AQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[38])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 994};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_send_reply};
    __pyx_mstate_global->__pyx_codeobj_tab[39] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_send_machine_id_reply, __pyx_mstate->__pyx_kp_b_iso88591_Q_7_AU_q_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[39])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 997};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_send_reply, __pyx_mstate->__pyx_n_u_reply_handler, __pyx_mstate->__pyx_n_u_reply_handler};
    __pyx_mstate_global->__pyx_codeobj_tab[40] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_default_get_machine_id_handler, __pyx_mstate->__pyx_kp_b_iso88591_A_4q_q_Q_1_6K1_F_1_A_Q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[40])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 15, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1031};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_send_reply, __pyx_mstate->__pyx_n_u_result_signature, __pyx_mstate->__pyx_n_u_error_handled, __pyx_mstate->__pyx_n_u_is_result_complete, __pyx_mstate->__pyx_n_u_is_result_complete, __pyx_mstate->__pyx_n_u_nodes, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_get_all_properties_callback, __pyx_mstate->__pyx_n_u_get_all_properties_callback, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_interface, __pyx_mstate->__pyx_n_u_node, __pyx_mstate->__pyx_n_u_node};
    __pyx_mstate_global->__pyx_codeobj_tab[41] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_default_get_managed_objects_han, __pyx_mstate->__pyx_kp_b_iso88591_A_1_A_1_3fG1_A_s_4s_k_V2Q_A_iq_N, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[41])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 19, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1086};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_msg, __pyx_mstate->__pyx_n_u_send_reply, __pyx_mstate->__pyx_n_u_methods, __pyx_mstate->__pyx_n_u_interface_name, __pyx_mstate->__pyx_n_u_prop_name, __pyx_mstate->__pyx_n_u_properties, __pyx_mstate->__pyx_n_u_match, __pyx_mstate->__pyx_n_u_prop, __pyx_mstate->__pyx_n_u_get_property_callback, __pyx_mstate->__pyx_n_u_get_property_callback, __pyx_mstate->__pyx_n_u_value, __pyx_mstate->__pyx_n_u_set_property_callback, __pyx_mstate->__pyx_n_u_set_property_callback, __pyx_mstate->__pyx_n_u_body, __pyx_mstate->__pyx_n_u_get_all_properties_callback, __pyx_mstate->__pyx_n_u_get_all_properties_callback, __pyx_mstate->__pyx_n_u_interface, __pyx_mstate->__pyx_n_u_prop};
    __pyx_mstate_global->__pyx_codeobj_tab[42] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_default_properties_handler, __pyx_mstate->__pyx_kp_b_iso88591_DNRS_7_wj_3hgXS_q_9Cs_1_QcA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[42])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1233};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_add_match_notify, __pyx_mstate->__pyx_n_u_add_match_notify};
    __pyx_mstate_global->__pyx_codeobj_tab[43] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_init_high_level_client, __pyx_mstate->__pyx_kp_b_iso88591_4q_a_U_2_7LA_F_1_A_Q_q_Qd, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[43])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1263};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_match_rule, __pyx_mstate->__pyx_n_u_add_match_notify, __pyx_mstate->__pyx_n_u_add_match_notify};
    __pyx_mstate_global->__pyx_codeobj_tab[44] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_add_match_rule, __pyx_mstate->__pyx_kp_b_iso88591_c_Q_c_Q_QoQ_M_U_2_7LA_F_1_A_Q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[44])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1296};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_match_rule, __pyx_mstate->__pyx_n_u_remove_match_notify, __pyx_mstate->__pyx_n_u_remove_match_notify};
    __pyx_mstate_global->__pyx_codeobj_tab[45] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_dbus_fast_message_bus_py, __pyx_mstate->__pyx_n_u_remove_match_rule, __pyx_mstate->__pyx_kp_b_iso88591_XQ_c_Q_c_Q_QoQ_t_Rq_D_Qa_5U_Oq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[45])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_2, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[46] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_T_O47Gt6QUUvvz_I_I_M_M_z_z_W_W, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[46])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[47] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_AV1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[47])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[48] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_BaseMessageBus, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_7_0_1B_PQ_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[48])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* AssertionsEnabled.init */
  if (likely(__Pyx_init_assertions_enabled() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* TupleAndListFromArray (used by fastcall) */
#if !CYTHON_COMPILING_IN_CPYTHON && CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    Py_ssize_t i;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    for (i = 0; i < n; i++) {
        if (unlikely(__Pyx_PyTuple_SET_ITEM(res, i, src[i]) < (0))) {
            Py_DECREF(res);
            return NULL;
        }
        Py_INCREF(src[i]);
    }
    return res;
}
#elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL ||\
        !(CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS)
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length, length2;
        int kind;
        void *data1, *data2;
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        #endif
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length < 0)) return -1;
        #endif
        length2 = __Pyx_PyUnicode_GET_LENGTH(s2);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length2 < 0)) return -1;
        #endif
        if (length != length2) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    return (equals == Py_EQ);
return_ne:
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = __Pyx_PyTuple_GET_SIZE(kwnames);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(n == -1)) return NULL;
    #endif
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        if (s == namei) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        int eq = __Pyx_PyUnicode_Equals(s, namei, Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs;
    PyObject *dict;
#if !CYTHON_ASSUME_SAFE_SIZE
    nkwargs = PyTuple_Size(kwnames);
    if (unlikely(nkwargs < 0)) return NULL;
#else
    nkwargs = PyTuple_GET_SIZE(kwnames);
#endif
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
#if !CYTHON_ASSUME_SAFE_MACROS
        PyObject *key = PyTuple_GetItem(kwnames, i);
        if (!key) goto bad;
#else
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
#endif
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall (used by PyObjectCallOneArg) */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) != (0)) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
#if CYTHON_VECTORCALL && !CYTHON_COMPILING_IN_LIMITED_API
  #if PY_VERSION_HEX < 0x03090000
    #define __Pyx_PyVectorcall_Function(callable) _PyVectorcall_Function(callable)
  #elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE vectorcallfunc __Pyx_PyVectorcall_Function(PyObject *callable) {
    PyTypeObject *tp = Py_TYPE(callable);
    #if defined(__Pyx_CyFunction_USED)
    if (__Pyx_CyFunction_CheckExact(callable)) {
        return __Pyx_CyFunction_func_vectorcall(callable);
    }
    #endif
    if (!PyType_HasFeature(tp, Py_TPFLAGS_HAVE_VECTORCALL)) {
        return NULL;
    }
    assert(PyCallable_Check(callable));
    Py_ssize_t offset = tp->tp_vectorcall_offset;
    assert(offset > 0);
    vectorcallfunc ptr;
    memcpy(&ptr, (char *) callable + offset, sizeof(ptr));
    return ptr;
}
  #else
    #define __Pyx_PyVectorcall_Function(callable) PyVectorcall_Function(callable)
  #endif
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject *const *args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
          #if CYTHON_COMPILING_IN_LIMITED_API
            return PyObject_Vectorcall(func, args, _nargs, NULL);
          #else
            vectorcallfunc f = __Pyx_PyVectorcall_Function(func);
            if (f) {
                return f(func, args, _nargs, NULL);
            }
          #endif
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_mstate_global->__pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod0) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
#elif CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject **args, Py_ssize_t nargs, PyObject *kwnames) {
        return _PyObject_Vectorcall
            (method, args ? args+1 : NULL, nargs ? nargs-1 : 0, kwnames);
}
#else
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *const *args, Py_ssize_t nargs, PyObject *kwnames) {
    return
#if PY_VERSION_HEX < 0x03090000
    _PyObject_Vectorcall
#else
    PyObject_Vectorcall
#endif
        (method, args ? args+1 : NULL, nargs ? (size_t) nargs-1 : 0, kwnames);
}
#endif
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
     METH_VARARGS | METH_KEYWORDS,
#else
     METH_FASTCALL | METH_KEYWORDS,
#endif
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method, *result=NULL;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    result = method;
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            result = unbound_method;
        }
    }
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    if (unlikely(target->method)) {
        Py_DECREF(result);
    } else
#endif
    target->method = result;
    return 0;
}

/* CallUnboundCMethod0 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        if (likely(cfunc->flag == METH_NOARGS))
            return __Pyx_CallCFunction(cfunc, self, NULL);
        if (likely(cfunc->flag == METH_FASTCALL))
            return __Pyx_CallCFunctionFast(cfunc, self, NULL, 0);
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, NULL, 0, NULL);
        if (likely(cfunc->flag == (METH_VARARGS | METH_KEYWORDS)))
            return __Pyx_CallCFunctionWithKeywords(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple, NULL);
        if (cfunc->flag == METH_VARARGS)
            return __Pyx_CallCFunction(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple);
        return __Pyx__CallUnboundCMethod0(cfunc, self);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod0(&tmp_cfunc, self);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod0(cfunc, self);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *result;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
    result = __Pyx_PyObject_CallOneArg(cfunc->method, self);
    return result;
}

/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, args, 2);
        }
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, 2, NULL);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod2(&tmp_cfunc, self, arg1, arg2);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *result = NULL;
        PyObject *args = PyTuple_New(2);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
        return result;
    }
#endif
    {
        PyObject *args[4] = {NULL, self, arg1, arg2};
        return __Pyx_PyObject_FastCall(cfunc->method, args+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
    }
}

/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyDictVersioning (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        if (!PyErr_Occurred())
            PyErr_SetNone(PyExc_NameError);
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
    PyErr_Clear();
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    if (unlikely(__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, name, &result) == -1)) PyErr_Clear();
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return result;
    }
#else
    result = _PyDict_GetItem_KnownHash(__pyx_mstate_global->__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* ArgTypeTestFunc (used by ArgTypeTest) */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    PyObject *extra_info = __pyx_mstate_global->__pyx_empty_unicode;
    int from_annotation_subclass = 0;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (!exact) {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    } else if (exact == 2) {
        if (__Pyx_TypeCheck(obj, type)) {
            from_annotation_subclass = 1;
            extra_info = __pyx_mstate_global->__pyx_kp_u_Note_that_Cython_is_deliberately;
        }
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")"
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        "%s%U"
#endif
        , name, type_name, obj_type_name
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        , (from_annotation_subclass ? ". " : ""), extra_info
#endif
        );
#if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    if (exact == 2 && from_annotation_subclass) {
        PyObject *res;
        PyObject *vargs[2];
        vargs[0] = PyErr_GetRaisedException();
        vargs[1] = extra_info;
        res = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_kp_u_add_note, vargs, 2, NULL);
        Py_XDECREF(res);
        PyErr_SetRaisedException(vargs[0]);
    }
#endif
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* RaiseException */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
#elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}

/* DictGetItem */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    if (unlikely(__Pyx_PyDict_GetItemRef(d, key, &value) == 0)) { // no value, no error
        if (unlikely(PyTuple_Check(key))) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args)) {
                PyErr_SetObject(PyExc_KeyError, args);
                Py_DECREF(args);
            }
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
    }
    return value;
}
#endif

/* PyUnicode_Unicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj) {
    if (unlikely(obj == Py_None))
        obj = __pyx_mstate_global->__pyx_kp_u_None;
    return __Pyx_NewRef(obj);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    if (max_char > 1114111) max_char = 1114111;
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - result_ulength < 0))
        goto overflow;
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = values[i];
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (__Pyx_PyUnicode_READY(uval) == (-1))
            goto bad;
        #endif
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(ulength < 0)) goto bad;
        #endif
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    Py_ssize_t i;
    PyObject *result = NULL;
    PyObject *value_tuple = PyTuple_New(value_count);
    if (unlikely(!value_tuple)) return NULL;
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    for (i=0; i<value_count; i++) {
        if (__Pyx_PyTuple_SET_ITEM(value_tuple, i, values[i]) != (0)) goto bad;
        Py_INCREF(values[i]);
    }
    result = PyUnicode_Join(__pyx_mstate_global->__pyx_empty_unicode, value_tuple);
bad:
    Py_DECREF(value_tuple);
    return result;
#endif
}

/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* PyObjectCall2Args (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    int was_initialized =  __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return __Pyx_CallCFunction(cfunc, self, arg);
        } else if (flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, &arg, 1);
        } else if (flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, &arg, 1, NULL);
        }
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod1(&tmp_cfunc, self, arg);
    }
#endif
    PyObject* result = __Pyx__CallUnboundCMethod1(cfunc, self, arg);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *args = PyTuple_New(1);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
    } else
#endif
    {
        result = __Pyx_PyObject_Call2Args(cfunc->method, self, arg);
    }
    return result;
}

/* dict_getitem_default */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
    if ((1));
#else
    if (PyBytes_CheckExact(key) || PyUnicode_CheckExact(key) || PyLong_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    }
#endif
    else {
        if (default_value == Py_None)
            value = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_get, d, key);
        else
            value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_get, d, key, default_value);
    }
    return value;
}

/* IterFinish (used by dict_iter) */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* PyObjectCallNoArg (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(tp);
    PyErr_Format(PyExc_AttributeError,
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}
#endif

/* PyObjectCallMethod0 (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* RaiseNeedMoreValuesToUnpack (used by UnpackTuple2) */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseTooManyValuesToUnpack (used by UnpackItemEndCheck) */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* UnpackItemEndCheck (used by UnpackTuple2) */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* RaiseNoneIterError (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else {
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(t);
 #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely(size < 0)) return;
 #endif
      if (size < index) {
        __Pyx_RaiseNeedMoreValuesError(size);
      } else {
        __Pyx_RaiseTooManyValuesError(index);
      }
    }
}

/* UnpackTuple2 (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
        PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple) {
    if (likely(is_tuple || PyTuple_Check(tuple))) {
        Py_ssize_t size;
        if (has_known_size) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        size = __Pyx_PyTuple_GET_SIZE(tuple);
        if (likely(size == 2)) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        if (size >= 0) {
            __Pyx_UnpackTupleError(tuple, 2);
        }
        return -1;
    } else {
        return __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple);
    }
}
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
    value1 = __Pyx_PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = __Pyx_PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
#if CYTHON_COMPILING_IN_PYPY
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#else
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
#if !CYTHON_AVOID_BORROWED_REFS
static CYTHON_INLINE int __Pyx_dict_iter_next_source_is_dict(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem) {
    PyObject *key, *value;
    if (unlikely(orig_length != PyDict_Size(iter_obj))) {
        PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
        return -1;
    }
    if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
        return 0;
    }
    if (pitem) {
        PyObject* tuple = PyTuple_New(2);
        if (unlikely(!tuple)) {
            return -1;
        }
        Py_INCREF(key);
        Py_INCREF(value);
        #if CYTHON_ASSUME_SAFE_MACROS
        PyTuple_SET_ITEM(tuple, 0, key);
        PyTuple_SET_ITEM(tuple, 1, value);
        #else
        if (unlikely(PyTuple_SetItem(tuple, 0, key) < 0)) {
            Py_DECREF(value);
            Py_DECREF(tuple);
            return -1;
        }
        if (unlikely(PyTuple_SetItem(tuple, 1, value) < 0)) {
            Py_DECREF(tuple);
            return -1;
        }
        #endif
        *pitem = tuple;
    } else {
        if (pkey) {
            Py_INCREF(key);
            *pkey = key;
        }
        if (pvalue) {
            Py_INCREF(value);
            *pvalue = value;
        }
    }
    return 1;
}
#endif
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_AVOID_BORROWED_REFS
    if (source_is_dict) {
        int result;
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_BEGIN_CRITICAL_SECTION(iter_obj);
#endif
        result = __Pyx_dict_iter_next_source_is_dict(iter_obj, orig_length, ppos, pkey, pvalue, pitem);
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_END_CRITICAL_SECTION();
#endif
        return result;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t tuple_size = __Pyx_PyTuple_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(tuple_size < 0)) return -1;
        #endif
        if (unlikely(pos >= tuple_size)) return 0;
        *ppos = pos + 1;
        #if CYTHON_ASSUME_SAFE_MACROS
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        #else
        next_item = PyTuple_GetItem(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
        #endif
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t list_size = __Pyx_PyList_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(list_size < 0)) return -1;
        #endif
        if (unlikely(pos >= list_size)) return 0;
        *ppos = pos + 1;
        next_item = __Pyx_PyList_GetItemRef(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS)) {
        return __Pyx_PyList_GetItemRefFast(o, wrapped_i, unsafe_shared);
    } else
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyList_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyTuple_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)) {
            return __Pyx_PyList_GetItemRefFast(o, n, unsafe_shared);
        } else if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            return __Pyx_NewRef(PyList_GET_ITEM(o, n));
        }
    } else
    #if !CYTHON_AVOID_BORROWED_REFS
    if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            return __Pyx_NewRef(PyTuple_GET_ITEM(o, n));
        }
    } else
    #endif
#endif
#if CYTHON_USE_TYPE_SLOTS && !CYTHON_COMPILING_IN_PYPY
    {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (!is_list && mm && mm->mp_subscript) {
            PyObject *r, *key = PyLong_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (is_list || likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    (void)wraparound;
    (void)boundscheck;
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
}

/* PyObjectVectorCallKwBuilder (used by PyObjectVectorCallMethodKwBuilder) */
#if CYTHON_VECTORCALL
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_PyObject_FastCallDict;
    if (__Pyx_PyTuple_SET_ITEM(builder, n, key) != (0)) return -1;
    Py_INCREF(key);
    args[n] = value;
    return 0;
}
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_VectorcallBuilder_AddArgStr;
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n);
}
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    PyObject *pyKey = PyUnicode_FromString(key);
    if (!pyKey) return -1;
    return __Pyx_VectorcallBuilder_AddArg(pyKey, value, builder, args, n);
}
#else // CYTHON_VECTORCALL
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, CYTHON_UNUSED PyObject **args, CYTHON_UNUSED int n) {
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return PyDict_SetItem(builder, key, value);
}
#endif

/* PyObjectVectorCallMethodKwBuilder */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames) {
    PyObject *result;
    PyObject *obj = PyObject_GetAttr(args[0], name);
    if (unlikely(!obj))
        return NULL;
    result = __Pyx_Object_Vectorcall_CallFromBuilder(obj, args+1, nargsf-1, kwnames);
    Py_DECREF(obj);
    return result;
}
#endif

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C0000
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#elif __PYX_LIMITED_VERSION_HEX > 0x030C0000
    local_value = PyErr_GetRaisedException();
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
#if __PYX_LIMITED_VERSION_HEX > 0x030C0000
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
#else
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
#endif // __PYX_LIMITED_VERSION_HEX > 0x030C0000
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#elif __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    PyErr_SetHandledException(local_value);
    Py_XDECREF(local_value);
    Py_XDECREF(local_type);
    Py_XDECREF(local_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
#if __PYX_LIMITED_VERSION_HEX <= 0x030C0000
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
#endif
}

/* RaiseClosureNameError */
static void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static Py_ssize_t __Pyx_GetTypeDictOffset(void) {
    PyObject *tp_dictoffset_o;
    Py_ssize_t tp_dictoffset;
    tp_dictoffset_o = PyObject_GetAttrString((PyObject*)(&PyType_Type), "__dictoffset__");
    if (unlikely(!tp_dictoffset_o)) return -1;
    tp_dictoffset = PyLong_AsSsize_t(tp_dictoffset_o);
    Py_DECREF(tp_dictoffset_o);
    if (unlikely(tp_dictoffset == 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' doesn't have a dictoffset");
        return -1;
    } else if (unlikely(tp_dictoffset < 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' has an unexpected negative dictoffset. "
            "Please report this as Cython bug");
        return -1;
    }
    return tp_dictoffset;
}
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp) {
    static Py_ssize_t tp_dictoffset = 0;
    if (unlikely(tp_dictoffset == 0)) {
        tp_dictoffset = __Pyx_GetTypeDictOffset();
        if (unlikely(tp_dictoffset == -1 && PyErr_Occurred())) {
            tp_dictoffset = 0; // try again next time?
            return NULL;
        }
    }
    return *(PyObject**)((char*)tp + tp_dictoffset);
}
#endif

/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType (used by FetchCommonType) */
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if __PYX_LIMITED_VERSION_HEX > 0x030900B1
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#else
    const PyType_Slot *slot = spec->slots;
    int changed = 0;
#if !CYTHON_COMPILING_IN_LIMITED_API
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
#if !CYTHON_COMPILING_IN_CPYTHON
        const
#endif  // !CYTHON_COMPILING_IN_CPYTHON)
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_vectorcall_offset = memb->offset;
                    changed = 1;
                }
#endif  // CYTHON_METH_FASTCALL
#if !CYTHON_COMPILING_IN_PYPY
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                    Py_DECREF(descr);
                    if (unlikely(set_item_result < 0)) {
                        return -1;
                    }
                    changed = 1;
                }
#endif  // !CYTHON_COMPILING_IN_PYPY
            }
            memb++;
        }
    }
#endif  // !CYTHON_COMPILING_IN_LIMITED_API
#if !CYTHON_COMPILING_IN_PYPY
    slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_getset)
        slot++;
    if (slot && slot->slot == Py_tp_getset) {
        PyGetSetDef *getset = (PyGetSetDef*) slot->pfunc;
        while (getset && getset->name) {
            if (getset->name[0] == '_' && getset->name[1] == '_' && strcmp(getset->name, "__module__") == 0) {
                PyObject *descr = PyDescr_NewGetSet(type, getset);
                if (unlikely(!descr))
                    return -1;
                #if CYTHON_COMPILING_IN_LIMITED_API
                PyObject *pyname = PyUnicode_FromString(getset->name);
                if (unlikely(!pyname)) {
                    Py_DECREF(descr);
                    return -1;
                }
                int set_item_result = __Pyx_SetItemOnTypeDict(type, pyname, descr);
                Py_DECREF(pyname);
                #else
                CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
                int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                #endif
                Py_DECREF(descr);
                if (unlikely(set_item_result < 0)) {
                    return -1;
                }
                changed = 1;
            }
            ++getset;
        }
    }
#else
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#endif  // !CYTHON_COMPILING_IN_PYPY
    if (changed)
        PyType_Modified(type);
#endif  // PY_VERSION_HEX > 0x030900B1
    return 0;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  static PyObject *__Pyx_PyImport_AddModuleObjectRef(PyObject *name) {
      PyObject *module_dict = PyImport_GetModuleDict();
      PyObject *m;
      if (PyMapping_GetOptionalItem(module_dict, name, &m) < 0) {
          return NULL;
      }
      if (m != NULL && PyModule_Check(m)) {
          return m;
      }
      Py_XDECREF(m);
      m = PyModule_NewObject(name);
      if (m == NULL)
          return NULL;
      if (PyDict_CheckExact(module_dict)) {
          PyObject *new_m;
          (void)PyDict_SetDefaultRef(module_dict, name, m, &new_m);
          Py_DECREF(m);
          return new_m;
      } else {
           if (PyObject_SetItem(module_dict, name, m) != 0) {
                Py_DECREF(m);
                return NULL;
            }
            return m;
      }
  }
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *py_name = PyUnicode_FromString(name);
      if (!py_name) return NULL;
      PyObject *module = __Pyx_PyImport_AddModuleObjectRef(py_name);
      Py_DECREF(py_name);
      return module;
  }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif

/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject* __Pyx_PyType_FromMetaclass(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *result = __Pyx_PyType_FromModuleAndSpec(module, spec, bases);
    if (result && metaclass) {
        PyObject *old_tp = (PyObject*)Py_TYPE(result);
    Py_INCREF((PyObject*)metaclass);
#if __PYX_LIMITED_VERSION_HEX >= 0x03090000
        Py_SET_TYPE(result, metaclass);
#else
        result->ob_type = metaclass;
#endif
        Py_DECREF(old_tp);
    }
    return result;
}
#else
#define __Pyx_PyType_FromMetaclass(me, mo, s, b) PyType_FromMetaclass(me, mo, s, b)
#endif
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t expected_basicsize) {
    Py_ssize_t basicsize;
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (expected_basicsize == 0) {
        return 0; // size is inherited, nothing useful to check
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
    if (unlikely(!py_basicsize)) return -1;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = NULL;
    if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) return -1;
#else
    basicsize = ((PyTypeObject*) cached_type)->tp_basicsize;
#endif
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module = NULL, *cached_type = NULL, *abi_module_dict, *new_cached_type, *py_object_name;
    int get_item_ref_result;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    py_object_name = PyUnicode_FromString(object_name);
    if (!py_object_name) return NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) goto done;
    abi_module_dict = PyModule_GetDict(abi_module);
    if (!abi_module_dict) goto done;
    get_item_ref_result = __Pyx_PyDict_GetItemRef(abi_module_dict, py_object_name, &cached_type);
    if (get_item_ref_result == 1) {
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else if (unlikely(get_item_ref_result == -1)) {
        goto bad;
    }
    cached_type = __Pyx_PyType_FromMetaclass(
        metaclass,
        CYTHON_USE_MODULE_STATE ? module : abi_module,
        spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    new_cached_type = __Pyx_PyDict_SetDefault(abi_module_dict, py_object_name, cached_type);
    if (unlikely(new_cached_type != cached_type)) {
        if (unlikely(!new_cached_type)) goto bad;
        Py_DECREF(cached_type);
        cached_type = new_cached_type;
        if (__Pyx_VerifyCachedType(
                cached_type,
                object_name,
                spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else {
        Py_DECREF(new_cached_type);
    }
done:
    Py_XDECREF(abi_module);
    Py_DECREF(py_object_name);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CommonTypesMetaclass (used by CythonFunctionShared) */
static PyObject* __pyx_CommonTypesMetaclass_get_module(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED void* context) {
    return PyUnicode_FromString(__PYX_ABI_MODULE_NAME);
}
#if __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject* __pyx_CommonTypesMetaclass_call(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *args, CYTHON_UNUSED PyObject *kwds) {
    PyErr_SetString(PyExc_TypeError, "Cannot instantiate Cython internal types");
    return NULL;
}
static int __pyx_CommonTypesMetaclass_setattr(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *attr, CYTHON_UNUSED PyObject *value) {
    PyErr_SetString(PyExc_TypeError, "Cython internal types are immutable");
    return -1;
}
#endif
static PyGetSetDef __pyx_CommonTypesMetaclass_getset[] = {
    {"__module__", __pyx_CommonTypesMetaclass_get_module, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_CommonTypesMetaclass_slots[] = {
    {Py_tp_getset, (void *)__pyx_CommonTypesMetaclass_getset},
    #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {Py_tp_call, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_new, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_setattro, (void*)__pyx_CommonTypesMetaclass_setattr},
    #endif
    {0, 0}
};
static PyType_Spec __pyx_CommonTypesMetaclass_spec = {
    __PYX_TYPE_MODULE_PREFIX "_common_types_metatype",
    0,
    0,
    Py_TPFLAGS_IMMUTABLETYPE |
    Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT,
    __pyx_CommonTypesMetaclass_slots
};
static int __pyx_CommonTypesMetaclass_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    PyObject *bases = PyTuple_Pack(1, &PyType_Type);
    if (unlikely(!bases)) {
        return -1;
    }
    mstate->__pyx_CommonTypesMetaclassType = __Pyx_FetchCommonTypeFromSpec(NULL, module, &__pyx_CommonTypesMetaclass_spec, bases);
    Py_DECREF(bases);
    if (unlikely(mstate->__pyx_CommonTypesMetaclassType == NULL)) {
        return -1;
    }
    return 0;
}

/* CallTypeTraverse (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i;
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos;
    #else
    Py_ssize_t pos;
    #endif
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    #if !CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t nkw = PyDict_Size(kw);
    if (unlikely(nkw == -1)) return NULL;
    #else
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    #endif
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = 0;
    i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (__Pyx_PyDict_NextRef(kw, &pos, &key, &value)) {
        keys_are_strings &=
        #if CYTHON_COMPILING_IN_LIMITED_API
            PyType_GetFlags(Py_TYPE(key));
        #else
            Py_TYPE(key)->tp_flags;
        #endif
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(PyTuple_SetItem(kwnames, i, key) < 0)) goto cleanup;
        #else
        PyTuple_SET_ITEM(kwnames, i, key);
        #endif
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(pos);
    #endif
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    Py_ssize_t kw_size =
        likely(kw == NULL) ?
        0 :
#if !CYTHON_ASSUME_SAFE_SIZE
        PyDict_Size(kw);
#else
        PyDict_GET_SIZE(kw);
#endif
    if (kw_size == 0) {
        return vc(func, args, nargs, NULL);
    }
#if !CYTHON_ASSUME_SAFE_SIZE
    else if (unlikely(kw_size == -1)) {
        return NULL;
    }
#endif
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* RejectKeywords */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds) {
    PyObject *key = NULL;
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds))) {
        key = __Pyx_PySequence_ITEM(kwds, 0);
    } else {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *pos = NULL;
#else
        Py_ssize_t pos = 0;
#endif
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
        if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return;
#endif
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL);
#if CYTHON_AVOID_BORROWED_REFS
        Py_XDECREF(pos);
#endif
    }
    if (likely(key)) {
        PyErr_Format(PyExc_TypeError,
            "%s() got an unexpected keyword argument '%U'",
            function_name, key);
        Py_DECREF(key);
    }
}

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return __Pyx_NewRef(op2);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    calculate_long:
        {
            long x;
            x = a + b;
            return PyLong_FromLong(x);
        }
    calculate_long_long:
        {
            PY_LONG_LONG llx;
            llx = lla + llb;
            return PyLong_FromLongLong(llx);
        }
    
}
#endif
static PyObject* __Pyx_Float___Pyx_PyLong_AddObjC(PyObject *float_val, long intval, int zerodivision_check) {
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    double a = __Pyx_PyFloat_AS_DOUBLE(float_val);
        double result;
        
        result = ((double)a) + (double)b;
        return PyFloat_FromDouble(result);
}
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        return __Pyx_Float___Pyx_PyLong_AddObjC(op1, intval, zerodivision_check);
    }
    return __Pyx_Fallback___Pyx_PyLong_AddObjC(op1, op2, inplace);
}
#endif

/* PyObjectCallMethod1 (used by append) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* append */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_mstate_global->__pyx_n_u_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* set_iter */
static CYTHON_INLINE PyObject* __Pyx_set_iterator(PyObject* iterable, int is_set,
                                                  Py_ssize_t* p_orig_length, int* p_source_is_set) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    is_set = is_set || likely(PySet_CheckExact(iterable) || PyFrozenSet_CheckExact(iterable));
    *p_source_is_set = is_set;
    if (likely(is_set)) {
        *p_orig_length = PySet_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
    }
#else
    CYTHON_UNUSED_VAR(is_set);
    *p_source_is_set = 0;
#endif
    *p_orig_length = 0;
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_set_iter_next(
        PyObject* iter_obj, Py_ssize_t orig_length,
        Py_ssize_t* ppos, PyObject **value,
        int source_is_set) {
    if (!CYTHON_COMPILING_IN_CPYTHON || PY_VERSION_HEX >= 0x030d0000 || unlikely(!source_is_set)) {
        *value = PyIter_Next(iter_obj);
        if (unlikely(!*value)) {
            return __Pyx_IterFinish();
        }
        CYTHON_UNUSED_VAR(orig_length);
        CYTHON_UNUSED_VAR(ppos);
        return 1;
    }
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    if (unlikely(PySet_GET_SIZE(iter_obj) != orig_length)) {
        PyErr_SetString(
            PyExc_RuntimeError,
            "set changed size during iteration");
        return -1;
    }
    {
        Py_hash_t hash;
        int ret = _PySet_NextEntry(iter_obj, ppos, value, &hash);
        assert (ret != -1);
        if (likely(ret)) {
            Py_INCREF(*value);
            return 1;
        }
    }
#endif
    return 0;
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* RaiseUnboundLocalError */
static void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_SubtractObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return PyLong_FromLong(-intval);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    calculate_long:
        {
            long x;
            x = a - b;
            return PyLong_FromLong(x);
        }
    calculate_long_long:
        {
            PY_LONG_LONG llx;
            llx = lla - llb;
            return PyLong_FromLongLong(llx);
        }
    
}
#endif
static PyObject* __Pyx_Float___Pyx_PyLong_SubtractObjC(PyObject *float_val, long intval, int zerodivision_check) {
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    double a = __Pyx_PyFloat_AS_DOUBLE(float_val);
        double result;
        
        result = ((double)a) - (double)b;
        return PyFloat_FromDouble(result);
}
static CYTHON_INLINE PyObject* __Pyx_PyLong_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_SubtractObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        return __Pyx_Float___Pyx_PyLong_SubtractObjC(op1, intval, zerodivision_check);
    }
    return __Pyx_Fallback___Pyx_PyLong_SubtractObjC(op1, op2, inplace);
}
#endif

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* VoidPtrExport */
static int __Pyx_ExportVoidPtr(PyObject *api_dict, const char *name, void *p, const char *sig) {
    PyObject *cobj;
    cobj = PyCapsule_New(p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(api_dict, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(cobj);
    return -1;
}

/* GetApiDict */
static PyObject *__Pyx_ApiExport_GetApiDict(void) {
    PyObject *d;
    if (__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_capi, &d) == -1)
        return NULL;
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_pyx_capi, d) < 0)
            goto bad;
    }
    return d;
bad:
    Py_XDECREF(d);
    return NULL;
}

/* FunctionExport */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig) {
    PyObject *cobj;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    tmp.fp = f;
    cobj = PyCapsule_New(tmp.p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(api_dict, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(cobj);
    return -1;
}

/* ValidateBasesTuple (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_SIZE
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (unlikely(n < 0)) return -1;
#endif
    for (i = 1; i < n; i++)
    {
        PyTypeObject *b;
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !CYTHON_USE_TYPE_SLOTS
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i=0;
    Py_ssize_t size;
    void** base_vtables;
    __Pyx_TypeName tp_base_name = NULL;
    __Pyx_TypeName base_name = NULL;
    void* unknown = (void*)-1;
    PyObject* bases = __Pyx_PyType_GetSlot(type, tp_bases, PyObject*);
    int base_depth = 0;
    {
        PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        while (base) {
            base_depth += 1;
            base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
        }
    }
    base_vtables = (void**) PyMem_Malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
#if CYTHON_COMPILING_IN_LIMITED_API
    size = PyTuple_Size(bases);
    if (size < 0) goto other_failure;
#else
    size = PyTuple_GET_SIZE(bases);
#endif
    for (i = 1; i < size; i++) {
        PyObject *basei;
        void* base_vtable;
#if CYTHON_AVOID_BORROWED_REFS
        basei = PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#else
        basei = PyTuple_GET_ITEM(bases, i);
#endif
        base_vtable = __Pyx_GetVtable((PyTypeObject*)basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
            }
        }
    }
    PyErr_Clear();
    PyMem_Free(base_vtables);
    return 0;
bad:
    {
        PyTypeObject* basei = NULL;
        PyTypeObject* tp_base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        tp_base_name = __Pyx_PyType_GetFullyQualifiedName(tp_base);
#if CYTHON_AVOID_BORROWED_REFS
        basei = (PyTypeObject*)PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = (PyTypeObject*)PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#else
        basei = (PyTypeObject*)PyTuple_GET_ITEM(bases, i);
#endif
        base_name = __Pyx_PyType_GetFullyQualifiedName(basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
    }
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
really_bad: // bad has failed!
#endif
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
other_failure:
#endif
    PyMem_Free(base_vtables);
    return -1;
}

/* DelItemOnTypeDict (used by SetupReduce) */
static int __Pyx__DelItemOnTypeDict(PyTypeObject *tp, PyObject *k) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_DelItem(tp_dict, k);
    if (likely(!result)) PyType_Modified(tp);
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_mstate_global->__pyx_n_u_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_mstate_global->__pyx_n_u_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_mstate_global->__pyx_n_u_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_reduce_cython);
            if (likely(reduce_cython)) {
                ret = __Pyx_SetItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = __Pyx_DelItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_mstate_global->__pyx_n_u_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = __Pyx_SetItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = __Pyx_DelItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetFullyQualifiedName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType_3_2_4
#define __PYX_HAVE_RT_ImportType_3_2_4
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size)
{
    PyObject *result = 0;
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API)
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !( defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API) )
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    if (size == 0) {
        return (PyTypeObject *)result;
    }
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_2_4 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_2_4 && (size_t)basicsize > size) {
        if (PyErr_WarnFormat(NULL, 0,
                "%.200s.%.200s size changed, may indicate binary incompatibility. "
                "Expected %zd from C header, got %zd from PyObject",
                module_name, class_name, size, basicsize) < 0) {
            goto bad;
        }
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* PxdImportShared (used by VoidPtrImport) */
#ifndef __PYX_HAVE_RT_ImportFromPxd_3_2_4
#define __PYX_HAVE_RT_ImportFromPxd_3_2_4
static int __Pyx_ImportFromPxd_3_2_4(PyObject *module, const char *name, void **p, const char *sig, const char *what) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    d = PyObject_GetAttrString(module, "__pyx_capi__");
    if (!d)
        goto bad;
#if (defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030d0000) || (!defined(Py_LIMITED_API) && PY_VERSION_HEX >= 0x030d0000)
    PyDict_GetItemStringRef(d, name, &cobj);
#else
    cobj = PyDict_GetItemString(d, name);
    Py_XINCREF(cobj);
#endif
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C %.8s %.200s",
                PyModule_GetName(module), what, name);
        goto bad;
    }
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C %.8s %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             what, PyModule_GetName(module), name, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    *p = PyCapsule_GetPointer(cobj, sig);
    if (!(*p))
        goto bad;
    Py_DECREF(d);
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(d);
    Py_XDECREF(cobj);
    return -1;
}
#endif

/* VoidPtrImport */
#ifndef __PYX_HAVE_RT_ImportVoidPtr_3_2_4
#define __PYX_HAVE_RT_ImportVoidPtr_3_2_4
static int __Pyx_ImportVoidPtr_3_2_4(PyObject *module, const char *name, void **p, const char *sig) {
    return __Pyx_ImportFromPxd_3_2_4(module, name, p, sig, "variable");
}
#endif

/* FunctionImport */
#ifndef __PYX_HAVE_RT_ImportFunction_3_2_4
#define __PYX_HAVE_RT_ImportFunction_3_2_4
static int __Pyx_ImportFunction_3_2_4(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    int result = __Pyx_ImportFromPxd_3_2_4(module, funcname, &tmp.p, sig, "function");
    if (result == 0) {
        *f = tmp.fp;
    }
    return result;
}
#endif

/* HasAttr (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* ImportImpl (used by Import) */
static int __Pyx__Import_GetModule(PyObject *qualname, PyObject **module) {
    PyObject *imported_module = PyImport_GetModule(qualname);
    if (unlikely(!imported_module)) {
        *module = NULL;
        if (PyErr_Occurred()) {
            return -1;
        }
        return 0;
    }
    *module = imported_module;
    return 1;
}
static int __Pyx__Import_Lookup(PyObject *qualname, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject **module) {
    PyObject *imported_module;
    PyObject *top_level_package_name;
    Py_ssize_t i;
    int status, module_found;
    Py_ssize_t dot_index;
    module_found = __Pyx__Import_GetModule(qualname, &imported_module);
    if (unlikely(!module_found || module_found == -1)) {
        *module = NULL;
        return module_found;
    }
    if (imported_names) {
        for (i = 0; i < len_imported_names; i++) {
            PyObject *imported_name = imported_names[i];
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
            int has_imported_attribute = PyObject_HasAttr(imported_module, imported_name);
#else
            int has_imported_attribute = PyObject_HasAttrWithError(imported_module, imported_name);
            if (unlikely(has_imported_attribute == -1)) goto error;
#endif
            if (!has_imported_attribute) {
                goto not_found;
            }
        }
        *module = imported_module;
        return 1;
    }
    dot_index = PyUnicode_FindChar(qualname, '.', 0, PY_SSIZE_T_MAX, 1);
    if (dot_index == -1) {
        *module = imported_module;
        return 1;
    }
    if (unlikely(dot_index == -2)) goto error;
    top_level_package_name = PyUnicode_Substring(qualname, 0, dot_index);
    if (unlikely(!top_level_package_name)) goto error;
    Py_DECREF(imported_module);
    status = __Pyx__Import_GetModule(top_level_package_name, module);
    Py_DECREF(top_level_package_name);
    return status;
error:
    Py_DECREF(imported_module);
    *module = NULL;
    return -1;
not_found:
    Py_DECREF(imported_module);
    *module = NULL;
    return 0;
}
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *from_list = 0;
    int module_found;
    if (!qualname) {
        qualname = name;
    }
    module_found = __Pyx__Import_Lookup(qualname, imported_names, len_imported_names, &module);
    if (likely(module_found == 1)) {
        return module;
    } else if (unlikely(module_found == -1)) {
        return NULL;
    }
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    if (imported_names) {
#if CYTHON_COMPILING_IN_CPYTHON
        from_list = __Pyx_PyList_FromArray(imported_names, len_imported_names);
        if (unlikely(!from_list))
            goto bad;
#else
        from_list = PyList_New(len_imported_names);
        if (unlikely(!from_list)) goto bad;
        for (Py_ssize_t i=0; i<len_imported_names; ++i) {
            if (PyList_SetItem(from_list, i, __Pyx_NewRef(imported_names[i])) < 0) goto bad;
        }
#endif
    }
    if (level == -1) {
        const char* package_sep = strchr(__Pyx_MODULE_NAME, '.');
        if (package_sep != (0)) {
            module = PyImport_ImportModuleLevelObject(
                name, moddict, empty_dict, from_list, 1);
            if (unlikely(!module)) {
                if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                    goto bad;
                PyErr_Clear();
            }
        }
        level = 0;
    }
    if (!module) {
        module = PyImport_ImportModuleLevelObject(
            name, moddict, empty_dict, from_list, level);
    }
bad:
    Py_XDECREF(from_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__10);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* GetNameInClass */
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    PyObject *dict;
    assert(PyType_Check(nmspace));
#if CYTHON_USE_TYPE_SLOTS
    dict = ((PyTypeObject*)nmspace)->tp_dict;
    Py_XINCREF(dict);
#else
    dict = PyObject_GetAttr(nmspace, __pyx_mstate_global->__pyx_n_u_dict);
#endif
    if (likely(dict)) {
        result = PyObject_GetItem(dict, name);
        Py_DECREF(dict);
        if (result) {
            return result;
        }
    }
    PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static __Pyx_CachedCodeObjectType *__pyx__find_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line) {
    __Pyx_CachedCodeObjectType* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!code_cache->entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if (unlikely(pos >= code_cache->count) || unlikely(code_cache->entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = code_cache->entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__find_code_object;
    return NULL; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just miss.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type old_count = __pyx_atomic_incr_acq_rel(&code_cache->accessor_count);
    if (old_count < 0) {
        __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
        return NULL;
    }
#endif
    __Pyx_CachedCodeObjectType *result = __pyx__find_code_object(code_cache, code_line);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
#endif
    return result;
#endif
}
static void __pyx__insert_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line, __Pyx_CachedCodeObjectType* code_object)
{
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = code_cache->entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            code_cache->entries = entries;
            code_cache->max_count = 64;
            code_cache->count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if ((pos < code_cache->count) && unlikely(code_cache->entries[pos].code_line == code_line)) {
        __Pyx_CachedCodeObjectType* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_INCREF(code_object);
        Py_DECREF(tmp);
        return;
    }
    if (code_cache->count == code_cache->max_count) {
        int new_max = code_cache->max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            code_cache->entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        code_cache->entries = entries;
        code_cache->max_count = new_max;
    }
    for (i=code_cache->count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    code_cache->count++;
    Py_INCREF(code_object);
}
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__insert_code_object;
    return; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just fail.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type expected = 0;
    if (!__pyx_atomic_int_cmp_exchange(&code_cache->accessor_count, &expected, INT_MIN)) {
        return;
    }
#endif
    __pyx__insert_code_object(code_cache, code_line, code_object);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_sub(&code_cache->accessor_count, INT_MIN);
#endif
#endif
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result = PyObject_Call(replace, __pyx_mstate_global->__pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!code_object) {
        code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
        if (unlikely(!code_object)) goto bad;
        py_py_line = PyLong_FromLong(py_line);
        if (unlikely(!py_py_line)) goto bad;
        if (c_line) {
            py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        } else {
            py_funcname = PyUnicode_FromString(funcname);
        }
        if (unlikely(!py_funcname)) goto bad;
        dict = PyDict_New();
        if (unlikely(!dict)) goto bad;
        {
            PyObject *old_code_object = code_object;
            code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
            Py_DECREF(old_code_object);
        }
        if (unlikely(!code_object)) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, code_object);
    } else {
        dict = PyDict_New();
    }
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    if (c_line) {
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
    }
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_mstate_global->__pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CheckUnpickleChecksum */
static void __Pyx_RaiseUnpickleChecksumError(long checksum, long checksum1, long checksum2, long checksum3, const char *members) {
    PyObject *pickle_module = PyImport_ImportModule("pickle");
    if (unlikely(!pickle_module)) return;
    PyObject *pickle_error = PyObject_GetAttrString(pickle_module, "PickleError");
    Py_DECREF(pickle_module);
    if (unlikely(!pickle_error)) return;
    if (checksum2 == checksum1) {
        PyErr_Format(pickle_error, "Incompatible checksums (0x%x vs (0x%x) = (%s))",
            checksum, checksum1, members);
    } else if (checksum3 == checksum2) {
        PyErr_Format(pickle_error, "Incompatible checksums (0x%x vs (0x%x, 0x%x) = (%s))",
            checksum, checksum1, checksum2, members);
    } else {
        PyErr_Format(pickle_error, "Incompatible checksums (0x%x vs (0x%x, 0x%x, 0x%x) = (%s))",
            checksum, checksum1, checksum2, checksum3, members);
    }
    Py_DECREF(pickle_error);
}
static int __Pyx_CheckUnpickleChecksum(long checksum, long checksum1, long checksum2, long checksum3, const char *members) {
    int found = 0;
    found |= checksum1 == checksum;
    found |= checksum2 == checksum;
    found |= checksum3 == checksum;
    if (likely(found))
        return 0;
    __Pyx_RaiseUnpickleChecksumError(checksum, checksum1, checksum2, checksum3, members);
    return -1;
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE unsigned int __Pyx_PyLong_As_unsigned_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const unsigned int neg_one = (unsigned int) -1, const_zero = (unsigned int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        unsigned int val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (unsigned int) -1;
        val = __Pyx_PyLong_As_unsigned_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(unsigned int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(unsigned int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(unsigned int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(unsigned int) >= 2 * PyLong_SHIFT)) {
                            return (unsigned int) (((((unsigned int)digits[1]) << PyLong_SHIFT) | (unsigned int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(unsigned int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(unsigned int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(unsigned int) >= 3 * PyLong_SHIFT)) {
                            return (unsigned int) (((((((unsigned int)digits[2]) << PyLong_SHIFT) | (unsigned int)digits[1]) << PyLong_SHIFT) | (unsigned int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(unsigned int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(unsigned int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(unsigned int) >= 4 * PyLong_SHIFT)) {
                            return (unsigned int) (((((((((unsigned int)digits[3]) << PyLong_SHIFT) | (unsigned int)digits[2]) << PyLong_SHIFT) | (unsigned int)digits[1]) << PyLong_SHIFT) | (unsigned int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (unsigned int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(unsigned int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(unsigned int, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(unsigned int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(unsigned int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(unsigned int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(unsigned int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(unsigned int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(unsigned int) - 1 > 2 * PyLong_SHIFT)) {
                            return (unsigned int) (((unsigned int)-1)*(((((unsigned int)digits[1]) << PyLong_SHIFT) | (unsigned int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(unsigned int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(unsigned int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(unsigned int) - 1 > 2 * PyLong_SHIFT)) {
                            return (unsigned int) ((((((unsigned int)digits[1]) << PyLong_SHIFT) | (unsigned int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(unsigned int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(unsigned int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(unsigned int) - 1 > 3 * PyLong_SHIFT)) {
                            return (unsigned int) (((unsigned int)-1)*(((((((unsigned int)digits[2]) << PyLong_SHIFT) | (unsigned int)digits[1]) << PyLong_SHIFT) | (unsigned int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(unsigned int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(unsigned int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(unsigned int) - 1 > 3 * PyLong_SHIFT)) {
                            return (unsigned int) ((((((((unsigned int)digits[2]) << PyLong_SHIFT) | (unsigned int)digits[1]) << PyLong_SHIFT) | (unsigned int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(unsigned int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(unsigned int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(unsigned int) - 1 > 4 * PyLong_SHIFT)) {
                            return (unsigned int) (((unsigned int)-1)*(((((((((unsigned int)digits[3]) << PyLong_SHIFT) | (unsigned int)digits[2]) << PyLong_SHIFT) | (unsigned int)digits[1]) << PyLong_SHIFT) | (unsigned int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(unsigned int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(unsigned int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(unsigned int) - 1 > 4 * PyLong_SHIFT)) {
                            return (unsigned int) ((((((((((unsigned int)digits[3]) << PyLong_SHIFT) | (unsigned int)digits[2]) << PyLong_SHIFT) | (unsigned int)digits[1]) << PyLong_SHIFT) | (unsigned int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(unsigned int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(unsigned int, long, PyLong_AsLong(x))
        } else if ((sizeof(unsigned int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(unsigned int, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        unsigned int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (unsigned int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (unsigned int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (unsigned int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (unsigned int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(unsigned int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((unsigned int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(unsigned int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((unsigned int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((unsigned int) 1) << (sizeof(unsigned int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (unsigned int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to unsigned int");
    return (unsigned int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to unsigned int");
    return (unsigned int) -1;
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyLong_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_unsigned_int(unsigned int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const unsigned int neg_one = (unsigned int) -1, const_zero = (unsigned int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(unsigned int) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(unsigned int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(unsigned int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(unsigned int) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(unsigned int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(unsigned int),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(unsigned int));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* UpdateUnpickledDict */
static int __Pyx__UpdateUnpickledDict(PyObject *obj, PyObject *state, Py_ssize_t index) {
    PyObject *state_dict = __Pyx_PySequence_ITEM(state, index);
    if (unlikely(!state_dict)) {
        return -1;
    }
    int non_empty = PyObject_IsTrue(state_dict);
    if (non_empty == 0) {
        Py_DECREF(state_dict);
        return 0;
    } else if (unlikely(non_empty == -1)) {
        return -1;
    }
    PyObject *dict;
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    dict = PyObject_GetAttrString(obj, "__dict__");
    #else
    dict = PyObject_GenericGetDict(obj, NULL);
    #endif
    if (unlikely(!dict)) {
        Py_DECREF(state_dict);
        return -1;
    }
    int result;
    if (likely(PyDict_CheckExact(dict))) {
        result = PyDict_Update(dict, state_dict);
    } else {
        PyObject *obj_result = __Pyx_PyObject_CallMethod1(dict, __pyx_mstate_global->__pyx_n_u_update, state_dict);
        if (likely(obj_result)) {
            Py_DECREF(obj_result);
            result = 0;
        } else {
            result = -1;
        }
    }
    Py_DECREF(state_dict);
    Py_DECREF(dict);
    return result;
}
static int __Pyx_UpdateUnpickledDict(PyObject *obj, PyObject *state, Py_ssize_t index) {
    Py_ssize_t state_size = __Pyx_PyTuple_GET_SIZE(state);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(state_size == -1)) return -1;
    #endif
    if (state_size <= index) {
        return 0;
    }
    return __Pyx__UpdateUnpickledDict(obj, state, index);
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__12);
    }
    goto done;
}
#endif

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyLong_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#if CYTHON_COMPILING_IN_LIMITED_API
    static PyObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                       PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                       PyObject *fv, PyObject *cell, PyObject* fn,
                                       PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
#elif PY_VERSION_HEX >= 0x030B0000
  static PyCodeObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                         PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                         PyObject *fv, PyObject *cell, PyObject* fn,
                                         PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, __pyx_mstate_global->__pyx_empty_bytes);
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030c00A1
    if (likely(result))
        result->_co_firsttraceable = 0;
    #endif
    return result;
  }
#elif !CYTHON_COMPILING_IN_PYPY
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
) {
    PyObject *code_obj = NULL, *varnames_tuple_dedup = NULL, *code_bytes = NULL;
    Py_ssize_t var_count = (Py_ssize_t) descr.nlocals;
    PyObject *varnames_tuple = PyTuple_New(var_count);
    if (unlikely(!varnames_tuple)) return NULL;
    for (Py_ssize_t i=0; i < var_count; i++) {
        Py_INCREF(varnames[i]);
        if (__Pyx_PyTuple_SET_ITEM(varnames_tuple, i, varnames[i]) != (0)) goto done;
    }
    #if CYTHON_COMPILING_IN_LIMITED_API
    varnames_tuple_dedup = PyDict_GetItem(tuple_dedup_map, varnames_tuple);
    if (!varnames_tuple_dedup) {
        if (unlikely(PyDict_SetItem(tuple_dedup_map, varnames_tuple, varnames_tuple) < 0)) goto done;
        varnames_tuple_dedup = varnames_tuple;
    }
    #else
    varnames_tuple_dedup = PyDict_SetDefault(tuple_dedup_map, varnames_tuple, varnames_tuple);
    if (unlikely(!varnames_tuple_dedup)) goto done;
    #endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(varnames_tuple_dedup);
    #endif
    if (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table != NULL && !CYTHON_COMPILING_IN_GRAAL) {
        Py_ssize_t line_table_length = __Pyx_PyBytes_GET_SIZE(line_table);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(line_table_length == -1)) goto done;
        #endif
        Py_ssize_t code_len = (line_table_length * 2 + 4) & ~3LL;
        code_bytes = PyBytes_FromStringAndSize(NULL, code_len);
        if (unlikely(!code_bytes)) goto done;
        char* c_code_bytes = PyBytes_AsString(code_bytes);
        if (unlikely(!c_code_bytes)) goto done;
        memset(c_code_bytes, 0, (size_t) code_len);
    }
    code_obj = (PyObject*) __Pyx__PyCode_New(
        (int) descr.argcount,
        (int) descr.num_posonly_args,
        (int) descr.num_kwonly_args,
        (int) descr.nlocals,
        0,
        (int) descr.flags,
        code_bytes ? code_bytes : __pyx_mstate_global->__pyx_empty_bytes,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        varnames_tuple_dedup,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        filename,
        funcname,
        (int) descr.first_line,
        (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table) ? line_table : __pyx_mstate_global->__pyx_empty_bytes
    );
done:
    Py_XDECREF(code_bytes);
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(varnames_tuple_dedup);
    #endif
    Py_DECREF(varnames_tuple);
    return code_obj;
}

/* DecompressString */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo) {
    PyObject *module = NULL, *decompress, *compressed_bytes, *decompressed;
    const char* module_name = algo == 3 ? "compression.zstd" : algo == 2 ? "bz2" : "zlib";
    PyObject *methodname = PyUnicode_FromString("decompress");
    if (unlikely(!methodname)) return NULL;
    #if __PYX_LIMITED_VERSION_HEX >= 0x030e0000
    if (algo == 3) {
        PyObject *fromlist = Py_BuildValue("[O]", methodname);
        if (unlikely(!fromlist)) goto bad;
        module = PyImport_ImportModuleLevel("compression.zstd", NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
    } else
    #endif
        module = PyImport_ImportModule(module_name);
    if (unlikely(!module)) goto import_failed;
    decompress = PyObject_GetAttr(module, methodname);
    if (unlikely(!decompress)) goto import_failed;
    {
        #ifdef __cplusplus
            char *memview_bytes = const_cast<char*>(s);
        #else
            #if defined(__clang__)
              #pragma clang diagnostic push
              #pragma clang diagnostic ignored "-Wcast-qual"
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic push
              #pragma GCC diagnostic ignored "-Wcast-qual"
            #endif
            char *memview_bytes = (char*) s;
            #if defined(__clang__)
              #pragma clang diagnostic pop
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic pop
            #endif
        #endif
        #if CYTHON_COMPILING_IN_LIMITED_API && !defined(PyBUF_READ)
        int memview_flags = 0x100;
        #else
        int memview_flags = PyBUF_READ;
        #endif
        compressed_bytes = PyMemoryView_FromMemory(memview_bytes, length, memview_flags);
    }
    if (unlikely(!compressed_bytes)) {
        Py_DECREF(decompress);
        goto bad;
    }
    decompressed = PyObject_CallFunctionObjArgs(decompress, compressed_bytes, NULL);
    Py_DECREF(compressed_bytes);
    Py_DECREF(decompress);
    Py_DECREF(module);
    Py_DECREF(methodname);
    return decompressed;
import_failed:
    PyErr_Format(PyExc_ImportError,
        "Failed to import '%.20s.decompress' - cannot initialise module strings. "
        "String compression was configured with the C macro 'CYTHON_COMPRESS_STRINGS=%d'.",
        module_name, algo);
bad:
    Py_XDECREF(module);
    Py_DECREF(methodname);
    return NULL;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
#ifndef CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#if (CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX >= 0x030C0000)
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 1
#else
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 0
#endif
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE && !CYTHON_ATOMICS
#error "Module state with PEP489 requires atomics. Currently that's one of\
 C11, C++11, gcc atomic intrinsics or MSVC atomic intrinsics"
#endif
#if !CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#define __Pyx_ModuleStateLookup_Lock()
#define __Pyx_ModuleStateLookup_Unlock()
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
static PyMutex __Pyx_ModuleStateLookup_mutex = {0};
#define __Pyx_ModuleStateLookup_Lock() PyMutex_Lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() PyMutex_Unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(__cplusplus) && __cplusplus >= 201103L
#include <mutex>
static std::mutex __Pyx_ModuleStateLookup_mutex;
#define __Pyx_ModuleStateLookup_Lock() __Pyx_ModuleStateLookup_mutex.lock()
#define __Pyx_ModuleStateLookup_Unlock() __Pyx_ModuleStateLookup_mutex.unlock()
#elif defined(__STDC_VERSION__) && (__STDC_VERSION__ > 201112L) && !defined(__STDC_NO_THREADS__)
#include <threads.h>
static mtx_t __Pyx_ModuleStateLookup_mutex;
static once_flag __Pyx_ModuleStateLookup_mutex_once_flag = ONCE_FLAG_INIT;
static void __Pyx_ModuleStateLookup_initialize_mutex(void) {
    mtx_init(&__Pyx_ModuleStateLookup_mutex, mtx_plain);
}
#define __Pyx_ModuleStateLookup_Lock()\
  call_once(&__Pyx_ModuleStateLookup_mutex_once_flag, __Pyx_ModuleStateLookup_initialize_mutex);\
  mtx_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() mtx_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(HAVE_PTHREAD_H)
#include <pthread.h>
static pthread_mutex_t __Pyx_ModuleStateLookup_mutex = PTHREAD_MUTEX_INITIALIZER;
#define __Pyx_ModuleStateLookup_Lock() pthread_mutex_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() pthread_mutex_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(_WIN32)
#include <Windows.h>  // synchapi.h on its own doesn't work
static SRWLOCK __Pyx_ModuleStateLookup_mutex = SRWLOCK_INIT;
#define __Pyx_ModuleStateLookup_Lock() AcquireSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() ReleaseSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#else
#error "No suitable lock available for CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE.\
 Requires C standard >= C11, or C++ standard >= C++11,\
 or pthreads, or the Windows 32 API, or Python >= 3.13."
#endif
typedef struct {
    int64_t id;
    PyObject *module;
} __Pyx_InterpreterIdAndModule;
typedef struct {
    char interpreter_id_as_index;
    Py_ssize_t count;
    Py_ssize_t allocated;
    __Pyx_InterpreterIdAndModule table[1];
} __Pyx_ModuleStateLookupData;
#define __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE 32
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_int_type __Pyx_ModuleStateLookup_read_counter = 0;
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_ptr_type __Pyx_ModuleStateLookup_data = 0;
#else
static __Pyx_ModuleStateLookupData* __Pyx_ModuleStateLookup_data = NULL;
#endif
static __Pyx_InterpreterIdAndModule* __Pyx_State_FindModuleStateLookupTableLowerBound(
        __Pyx_InterpreterIdAndModule* table,
        Py_ssize_t count,
        int64_t interpreterId) {
    __Pyx_InterpreterIdAndModule* begin = table;
    __Pyx_InterpreterIdAndModule* end = begin + count;
    if (begin->id == interpreterId) {
        return begin;
    }
    while ((end - begin) > __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
        __Pyx_InterpreterIdAndModule* halfway = begin + (end - begin)/2;
        if (halfway->id == interpreterId) {
            return halfway;
        }
        if (halfway->id < interpreterId) {
            begin = halfway;
        } else {
            end = halfway;
        }
    }
    for (; begin < end; ++begin) {
        if (begin->id >= interpreterId) return begin;
    }
    return begin;
}
static PyObject *__Pyx_State_FindModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return NULL;
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData* data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
    {
        __pyx_atomic_incr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        if (likely(data)) {
            __Pyx_ModuleStateLookupData* new_data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_acquire(&__Pyx_ModuleStateLookup_data);
            if (likely(data == new_data)) {
                goto read_finished;
            }
        }
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        __Pyx_ModuleStateLookup_Lock();
        __pyx_atomic_incr_relaxed(&__Pyx_ModuleStateLookup_read_counter);
        data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
        __Pyx_ModuleStateLookup_Unlock();
    }
  read_finished:;
#else
    __Pyx_ModuleStateLookupData* data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_InterpreterIdAndModule* found = NULL;
    if (unlikely(!data)) goto end;
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            found = data->table+interpreter_id;
        }
    } else {
        found = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
    }
  end:
    {
        PyObject *result=NULL;
        if (found && found->id == interpreter_id) {
            result = found->module;
        }
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
#endif
        return result;
    }
}
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static void __Pyx_ModuleStateLookup_wait_until_no_readers(void) {
    while (__pyx_atomic_load(&__Pyx_ModuleStateLookup_read_counter) != 0);
}
#else
#define __Pyx_ModuleStateLookup_wait_until_no_readers()
#endif
static int __Pyx_State_AddModuleInterpIdAsIndex(__Pyx_ModuleStateLookupData **old_data, PyObject* module, int64_t interpreter_id) {
    Py_ssize_t to_allocate = (*old_data)->allocated;
    while (to_allocate <= interpreter_id) {
        if (to_allocate == 0) to_allocate = 1;
        else to_allocate *= 2;
    }
    __Pyx_ModuleStateLookupData *new_data = *old_data;
    if (to_allocate != (*old_data)->allocated) {
         new_data = (__Pyx_ModuleStateLookupData *)realloc(
            *old_data,
            sizeof(__Pyx_ModuleStateLookupData)+(to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
        if (!new_data) {
            PyErr_NoMemory();
            return -1;
        }
        for (Py_ssize_t i = new_data->allocated; i < to_allocate; ++i) {
            new_data->table[i].id = i;
            new_data->table[i].module = NULL;
        }
        new_data->allocated = to_allocate;
    }
    new_data->table[interpreter_id].module = module;
    if (new_data->count < interpreter_id+1) {
        new_data->count = interpreter_id+1;
    }
    *old_data = new_data;
    return 0;
}
static void __Pyx_State_ConvertFromInterpIdAsIndex(__Pyx_ModuleStateLookupData *data) {
    __Pyx_InterpreterIdAndModule *read = data->table;
    __Pyx_InterpreterIdAndModule *write = data->table;
    __Pyx_InterpreterIdAndModule *end = read + data->count;
    for (; read<end; ++read) {
        if (read->module) {
            write->id = read->id;
            write->module = read->module;
            ++write;
        }
    }
    data->count = write - data->table;
    for (; write<end; ++write) {
        write->id = 0;
        write->module = NULL;
    }
    data->interpreter_id_as_index = 0;
}
static int __Pyx_State_AddModule(PyObject* module, CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    int result = 0;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *old_data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *old_data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_ModuleStateLookupData *new_data = old_data;
    if (!new_data) {
        new_data = (__Pyx_ModuleStateLookupData *)calloc(1, sizeof(__Pyx_ModuleStateLookupData));
        if (!new_data) {
            result = -1;
            PyErr_NoMemory();
            goto end;
        }
        new_data->allocated = 1;
        new_data->interpreter_id_as_index = 1;
    }
    __Pyx_ModuleStateLookup_wait_until_no_readers();
    if (new_data->interpreter_id_as_index) {
        if (interpreter_id < __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
            result = __Pyx_State_AddModuleInterpIdAsIndex(&new_data, module, interpreter_id);
            goto end;
        }
        __Pyx_State_ConvertFromInterpIdAsIndex(new_data);
    }
    {
        Py_ssize_t insert_at = 0;
        {
            __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
                new_data->table, new_data->count, interpreter_id);
            assert(lower_bound);
            insert_at = lower_bound - new_data->table;
            if (unlikely(insert_at < new_data->count && lower_bound->id == interpreter_id)) {
                lower_bound->module = module;
                goto end;  // already in table, nothing more to do
            }
        }
        if (new_data->count+1 >= new_data->allocated) {
            Py_ssize_t to_allocate = (new_data->count+1)*2;
            new_data =
                (__Pyx_ModuleStateLookupData*)realloc(
                    new_data,
                    sizeof(__Pyx_ModuleStateLookupData) +
                    (to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
            if (!new_data) {
                result = -1;
                new_data = old_data;
                PyErr_NoMemory();
                goto end;
            }
            new_data->allocated = to_allocate;
        }
        ++new_data->count;
        int64_t last_id = interpreter_id;
        PyObject *last_module = module;
        for (Py_ssize_t i=insert_at; i<new_data->count; ++i) {
            int64_t current_id = new_data->table[i].id;
            new_data->table[i].id = last_id;
            last_id = current_id;
            PyObject *current_module = new_data->table[i].module;
            new_data->table[i].module = last_module;
            last_module = current_module;
        }
    }
  end:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, new_data);
#else
    __Pyx_ModuleStateLookup_data = new_data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return result;
}
static int __Pyx_State_RemoveModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *data = __Pyx_ModuleStateLookup_data;
#endif
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            data->table[interpreter_id].module = NULL;
        }
        goto done;
    }
    {
        __Pyx_ModuleStateLookup_wait_until_no_readers();
        __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
        if (!lower_bound) goto done;
        if (lower_bound->id != interpreter_id) goto done;
        __Pyx_InterpreterIdAndModule *end = data->table+data->count;
        for (;lower_bound<end-1; ++lower_bound) {
            lower_bound->id = (lower_bound+1)->id;
            lower_bound->module = (lower_bound+1)->module;
        }
    }
    --data->count;
    if (data->count == 0) {
        free(data);
        data = NULL;
    }
  done:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, data);
#else
    __Pyx_ModuleStateLookup_data = data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return 0;
}
#endif

/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
